@@ -25,7 +25,7 @@ Expected results for the top 5 most represented people in the dataset::
 
 
 """
-print __doc__
+from __future__ import print_function
 
 from time import time
 import logging
@@ -39,6 +39,9 @@ from sklearn.metrics import confusion_matrix
 from sklearn.decomposition import RandomizedPCA
 from sklearn.svm import SVC
 
+
+print(__doc__)
+
 # Display progress logs on stdout
 logging.basicConfig(level=logging.INFO, format='%(asctime)s %(message)s')
 
@@ -61,10 +64,10 @@ y = lfw_people.target
 target_names = lfw_people.target_names
 n_classes = target_names.shape[0]
 
-print "Total dataset size:"
-print "n_samples: %d" % n_samples
-print "n_features: %d" % n_features
-print "n_classes: %d" % n_classes
+print("Total dataset size:")
+print("n_samples: %d" % n_samples)
+print("n_features: %d" % n_features)
+print("n_classes: %d" % n_classes)
 
 
 ###############################################################################
@@ -80,45 +83,45 @@ X_train, X_test, y_train, y_test = train_test_split(
 # dataset): unsupervised feature extraction / dimensionality reduction
 n_components = 150
 
-print "Extracting the top %d eigenfaces from %d faces" % (
-    n_components, X_train.shape[0])
+print("Extracting the top %d eigenfaces from %d faces"
+      % (n_components, X_train.shape[0]))
 t0 = time()
 pca = RandomizedPCA(n_components=n_components, whiten=True).fit(X_train)
-print "done in %0.3fs" % (time() - t0)
+print("done in %0.3fs" % (time() - t0))
 
 eigenfaces = pca.components_.reshape((n_components, h, w))
 
-print "Projecting the input data on the eigenfaces orthonormal basis"
+print("Projecting the input data on the eigenfaces orthonormal basis")
 t0 = time()
 X_train_pca = pca.transform(X_train)
 X_test_pca = pca.transform(X_test)
-print "done in %0.3fs" % (time() - t0)
+print("done in %0.3fs" % (time() - t0))
 
 
 ###############################################################################
 # Train a SVM classification model
 
-print "Fitting the classifier to the training set"
+print("Fitting the classifier to the training set")
 t0 = time()
 param_grid = {'C': [1e3, 5e3, 1e4, 5e4, 1e5],
               'gamma': [0.0001, 0.0005, 0.001, 0.005, 0.01, 0.1], }
 clf = GridSearchCV(SVC(kernel='rbf', class_weight='auto'), param_grid)
 clf = clf.fit(X_train_pca, y_train)
-print "done in %0.3fs" % (time() - t0)
-print "Best estimator found by grid search:"
-print clf.best_estimator_
+print("done in %0.3fs" % (time() - t0))
+print("Best estimator found by grid search:")
+print(clf.best_estimator_)
 
 
 ###############################################################################
 # Quantitative evaluation of the model quality on the test set
 
-print "Predicting the people names on the testing set"
+print("Predicting people's names on the test set")
 t0 = time()
 y_pred = clf.predict(X_test_pca)
-print "done in %0.3fs" % (time() - t0)
+print("done in %0.3fs" % (time() - t0))
 
-print classification_report(y_test, y_pred, target_names=target_names)
-print confusion_matrix(y_test, y_pred, labels=range(n_classes))
+print(classification_report(y_test, y_pred, target_names=target_names))
+print(confusion_matrix(y_test, y_pred, labels=range(n_classes)))
 
 
 ###############################################################################
