@@ -8,7 +8,7 @@ number of samples on various clustering performance evaluation metrics.
 
 Non-adjusted measures such as the V-Measure show a dependency between
 the number of clusters and the number of samples: the mean V-Measure
-of random labeling increases signicantly as the number of clusters is
+of random labeling increases significantly as the number of clusters is
 closer to the total number of samples used to compute the measure.
 
 Adjusted for chance measure such as ARI display some random variations
@@ -20,10 +20,10 @@ to evaluate the average stability of clustering algorithms for a given
 value of k on various overlapping sub-samples of the dataset.
 
 """
-print __doc__
+print(__doc__)
 
 # Author: Olivier Grisel <olivier.grisel@ensta.org>
-# License: Simplified BSD
+# License: BSD 3 clause
 
 import numpy as np
 import pylab as pl
@@ -39,7 +39,7 @@ def uniform_labelings_scores(score_func, n_samples, n_clusters_range,
     possible value in ``n_clusters_range``.
 
     When fixed_n_classes is not None the first labeling is considered a ground
-    truth class assignement with fixed number of classes.
+    truth class assignment with fixed number of classes.
     """
     random_labels = np.random.RandomState(seed).random_integers
     scores = np.zeros((len(n_clusters_range), n_runs))
@@ -73,12 +73,12 @@ pl.figure(1)
 plots = []
 names = []
 for score_func in score_funcs:
-    print "Computing %s for %d values of n_clusters and n_samples=%d" % (
-        score_func.__name__, len(n_clusters_range), n_samples)
+    print("Computing %s for %d values of n_clusters and n_samples=%d"
+          % (score_func.__name__, len(n_clusters_range), n_samples))
 
     t0 = time()
     scores = uniform_labelings_scores(score_func, n_samples, n_clusters_range)
-    print "done in %0.3fs" % (time() - t0)
+    print("done in %0.3fs" % (time() - t0))
     plots.append(pl.errorbar(
         n_clusters_range, np.median(scores, axis=1), scores.std(axis=1))[0])
     names.append(score_func.__name__)
@@ -103,19 +103,19 @@ pl.figure(2)
 plots = []
 names = []
 for score_func in score_funcs:
-    print "Computing %s for %d values of n_clusters and n_samples=%d" % (
-        score_func.__name__, len(n_clusters_range), n_samples)
+    print("Computing %s for %d values of n_clusters and n_samples=%d"
+          % (score_func.__name__, len(n_clusters_range), n_samples))
 
     t0 = time()
     scores = uniform_labelings_scores(score_func, n_samples, n_clusters_range,
                                       fixed_n_classes=n_classes)
-    print "done in %0.3fs" % (time() - t0)
+    print("done in %0.3fs" % (time() - t0))
     plots.append(pl.errorbar(
         n_clusters_range, scores.mean(axis=1), scores.std(axis=1))[0])
     names.append(score_func.__name__)
 
 pl.title("Clustering measures for random uniform labeling\n"
-         "against reference assignement with %d classes" % n_classes)
+         "against reference assignment with %d classes" % n_classes)
 pl.xlabel('Number of clusters (Number of samples is fixed to %d)' % n_samples)
 pl.ylabel('Score value')
 pl.ylim(ymin=-0.05, ymax=1.05)
