@@ -16,12 +16,12 @@ The next plot displays what using eight clusters would deliver
 and finally the ground truth.
 
 """
-print __doc__
+print(__doc__)
 
 
 # Code source: Gael Varoqueux
 # Modified for Documentation merge by Jaques Grobler
-# License: BSD
+# License: BSD 3 clause
 
 import numpy as np
 import pylab as pl
