@@ -6,14 +6,14 @@
 Feature agglomeration
 =========================================================
 
-These images how similiar features are merged together using
+These images how similar features are merged together using
 feature agglomeration.
 """
-print __doc__
+print(__doc__)
 
 # Code source: Gael Varoqueux
 # Modified for Documentation merge by Jaques Grobler
-# License: BSD
+# License: BSD 3 clause
 
 import numpy as np
 import pylab as pl
