@@ -14,9 +14,9 @@ a BayesianRidge as supervised estimator.
 """
 
 # Author: Alexandre Gramfort <alexandre.gramfort@inria.fr>
-# License: BSD Style.
+# License: BSD 3 clause
 
-print __doc__
+print(__doc__)
 
 import shutil
 import tempfile
