@@ -5,17 +5,18 @@
 =========================================================
 Vector Quantization Example
 =========================================================
+
 The classic image processing example, Lena, an 8-bit grayscale
 bit-depth, 512 x 512 sized image, is used here to illustrate
 how `k`-means is used for vector quantization.
 
 """
-print __doc__
+print(__doc__)
 
 
 # Code source: Gael Varoqueux
 # Modified for Documentation merge by Jaques Grobler
-# License: BSD
+# License: BSD 3 clause
 
 import numpy as np
 import scipy as sp
