@@ -4,12 +4,14 @@ Hierarchical clustering: structured vs unstructured ward
 ===========================================================
 
 Example builds a swiss roll dataset and runs
-:ref:`hierarchical_clustering` on their position.
+hierarchical clustering on their position.
 
-In a first step, the hierarchical clustering without connectivity
-constraints on structure, solely based on distance, whereas in a second
-step clustering restricted to the k-Nearest Neighbors graph: it's a
-hierarchical clustering with structure prior.
+For more information, see :ref:`hierarchical_clustering`.
+
+In a first step, the hierarchical clustering is performed without connectivity
+constraints on the structure and is solely based on distance, whereas in
+a second step the clustering is restricted to the k-Nearest Neighbors
+graph: it's a hierarchical clustering with structure prior.
 
 Some of the clusters learned without connectivity constraints do not
 respect the structure of the swiss roll and extend across different folds of
@@ -20,9 +22,9 @@ the clusters form a nice parcellation of the swiss roll.
 # Authors : Vincent Michel, 2010
 #           Alexandre Gramfort, 2010
 #           Gael Varoquaux, 2010
-# License: BSD
+# License: BSD 3 clause
 
-print __doc__
+print(__doc__)
 
 import time as time
 import numpy as np
@@ -41,12 +43,12 @@ X[:, 1] *= .5
 
 ###############################################################################
 # Compute clustering
-print "Compute unstructured hierarchical clustering..."
+print("Compute unstructured hierarchical clustering...")
 st = time.time()
 ward = Ward(n_clusters=6).fit(X)
 label = ward.labels_
-print "Elapsed time: ", time.time() - st
-print "Number of points: ", label.size
+print("Elapsed time: ", time.time() - st)
+print("Number of points: ", label.size)
 
 ###############################################################################
 # Plot result
@@ -66,12 +68,12 @@ connectivity = kneighbors_graph(X, n_neighbors=10)
 
 ###############################################################################
 # Compute clustering
-print "Compute structured hierarchical clustering..."
+print("Compute structured hierarchical clustering...")
 st = time.time()
 ward = Ward(n_clusters=6, connectivity=connectivity).fit(X)
 label = ward.labels_
-print "Elapsed time: ", time.time() - st
-print "Number of points: ", label.size
+print("Elapsed time: ", time.time() - st)
+print("Number of points: ", label.size)
 
 ###############################################################################
 # Plot result
