@@ -5,7 +5,7 @@ Ledoit-Wolf vs OAS estimation
 
 The usual covariance maximum likelihood estimate can be regularized
 using shrinkage. Ledoit and Wolf proposed a close formula to compute
-the asymptotical optimal shrinkage parameter (minimizing a MSE
+the asymptotically optimal shrinkage parameter (minimizing a MSE
 criterion), yielding the Ledoit-Wolf covariance estimate.
 
 Chen et al. proposed an improvement of the Ledoit-Wolf shrinkage
@@ -20,7 +20,7 @@ distributed data.
 Chen et al., IEEE Trans. on Sign. Proc., Volume 58, Issue 10, October 2010.
 
 """
-print __doc__
+print(__doc__)
 
 import numpy as np
 import pylab as pl
