@@ -5,21 +5,22 @@
 =========================================================
 The Digit Dataset
 =========================================================
+
 This dataset is made up of 1797 8x8 images. Each image,
 like the one shown below, is of a hand-written digit.
-In order to ultilise an 8x8 figure like this, we'd have to
-first transform it into a feature vector with lengh 64.
+In order to utilize an 8x8 figure like this, we'd have to
+first transform it into a feature vector with length 64.
 
 See `here
 <http://archive.ics.uci.edu/ml/datasets/Pen-Based+Recognition+of+Handwritten+Digits>`_
 for more information about this dataset.
 """
-print __doc__
+print(__doc__)
 
 
 # Code source: Gael Varoqueux
 # Modified for Documentation merge by Jaques Grobler
-# License: BSD
+# License: BSD 3 clause
 
 from sklearn import datasets
 
