@@ -6,7 +6,7 @@ Sparse coding with a precomputed dictionary
 Transform a signal as a sparse combination of Ricker wavelets. This example
 visually compares different sparse coding methods using the
 :class:`sklearn.decomposition.SparseCoder` estimator. The Ricker (also known
-as mexican hat or the second derivative of a gaussian) is not a particularily
+as mexican hat or the second derivative of a gaussian) is not a particularly
 good kernel to represent piecewise constant signals like this one. It can
 therefore be seen how much adding different widths of atoms matters and it
 therefore motivates learning the dictionary to best fit your type of signals.
@@ -14,7 +14,7 @@ therefore motivates learning the dictionary to best fit your type of signals.
 The richer dictionary on the right is not larger in size, heavier subsampling
 is performed in order to stay on the same order of magnitude.
 """
-print __doc__
+print(__doc__)
 
 import numpy as np
 import matplotlib.pylab as pl
