@@ -10,7 +10,7 @@ the more important.
 The code below also illustrates how the construction and the computation
 of the predictions can be parallelized within multiple jobs.
 """
-print __doc__
+print(__doc__)
 
 from time import time
 import pylab as pl
@@ -31,16 +31,15 @@ X = X[mask]
 y = y[mask]
 
 # Build a forest and compute the pixel importances
-print "Fitting ExtraTreesClassifier on faces data with %d cores..." % n_jobs
+print("Fitting ExtraTreesClassifier on faces data with %d cores..." % n_jobs)
 t0 = time()
 forest = ExtraTreesClassifier(n_estimators=1000,
                               max_features=128,
-                              compute_importances=True,
                               n_jobs=n_jobs,
                               random_state=0)
 
 forest.fit(X, y)
-print "done in %0.3fs" % (time() - t0)
+print("done in %0.3fs" % (time() - t0))
 importances = forest.feature_importances_
 importances = importances.reshape(data.images[0].shape)
 
