@@ -8,11 +8,11 @@ Demonstrate Gradient Boosting on the boston housing dataset.
 This example fits a Gradient Boosting model with least squares loss and
 500 regression trees of depth 4.
 """
-print __doc__
+print(__doc__)
 
 # Author: Peter Prettenhofer <peter.prettenhofer@gmail.com>
 #
-# License: BSD
+# License: BSD 3 clause
 
 import numpy as np
 import pylab as pl
