@@ -40,12 +40,13 @@ Here is a sample output of a run on a quad-core machine::
       vect__max_features: 50000
 
 """
-print __doc__
 
 # Author: Olivier Grisel <olivier.grisel@ensta.org>
 #         Peter Prettenhofer <peter.prettenhofer@gmail.com>
 #         Mathieu Blondel <mathieu@mblondel.org>
-# License: Simplified BSD
+# License: BSD 3 clause
+
+from __future__ import print_function
 
 from pprint import pprint
 from time import time
@@ -58,6 +59,8 @@ from sklearn.linear_model import SGDClassifier
 from sklearn.grid_search import GridSearchCV
 from sklearn.pipeline import Pipeline
 
+print(__doc__)
+
 # Display progress logs on stdout
 logging.basicConfig(level=logging.INFO,
                     format='%(asctime)s %(levelname)s %(message)s')
@@ -72,13 +75,13 @@ categories = [
 # Uncomment the following to do the analysis on all the categories
 #categories = None
 
-print "Loading 20 newsgroups dataset for categories:"
-print categories
+print("Loading 20 newsgroups dataset for categories:")
+print(categories)
 
 data = fetch_20newsgroups(subset='train', categories=categories)
-print "%d documents" % len(data.filenames)
-print "%d categories" % len(data.target_names)
-print
+print("%d documents" % len(data.filenames))
+print("%d categories" % len(data.target_names))
+print()
 
 ###############################################################################
 # define a pipeline combining a text feature extractor with a simple
@@ -89,9 +92,9 @@ pipeline = Pipeline([
     ('clf', SGDClassifier()),
 ])
 
+# uncommenting more parameters will give better exploring power but will
+# increase processing time in a combinatorial way
 parameters = {
-    # uncommenting more parameters will give better exploring power but will
-    # increase processing time in a combinatorial way
     'vect__max_df': (0.5, 0.75, 1.0),
     #'vect__max_features': (None, 5000, 10000, 50000),
     'vect__ngram_range': ((1, 1), (1, 2)),  # unigrams or bigrams
@@ -110,17 +113,17 @@ if __name__ == "__main__":
     # classifier
     grid_search = GridSearchCV(pipeline, parameters, n_jobs=-1, verbose=1)
 
-    print "Performing grid search..."
-    print "pipeline:", [name for name, _ in pipeline.steps]
-    print "parameters:"
+    print("Performing grid search...")
+    print("pipeline:", [name for name, _ in pipeline.steps])
+    print("parameters:")
     pprint(parameters)
     t0 = time()
     grid_search.fit(data.data, data.target)
-    print "done in %0.3fs" % (time() - t0)
-    print
+    print("done in %0.3fs" % (time() - t0))
+    print()
 
-    print "Best score: %0.3f" % grid_search.best_score_
-    print "Best parameters set:"
+    print("Best score: %0.3f" % grid_search.best_score_)
+    print("Best parameters set:")
     best_parameters = grid_search.best_estimator_.get_params()
     for param_name in sorted(parameters.keys()):
-        print "\t%s: %r" % (param_name, best_parameters[param_name])
+        print("\t%s: %r" % (param_name, best_parameters[param_name]))
