@@ -3,10 +3,12 @@
 Automatic Relevance Determination Regression (ARD)
 ==================================================
 
-Fit regression model with :ref:`bayesian_ridge_regression`.
+Fit regression model with Bayesian Ridge Regression.
+
+See :ref:`bayesian_ridge_regression` for more information on the regressor.
 
 Compared to the OLS (ordinary least squares) estimator, the coefficient
-weights are slightly shifted toward zeros, wich stabilises them.
+weights are slightly shifted toward zeros, which stabilises them.
 
 The histogram of the estimated weights is very peaked, as a sparsity-inducing
 prior is implied on the weights.
@@ -14,7 +16,7 @@ prior is implied on the weights.
 The estimation of the model is done by iteratively maximizing the
 marginal log-likelihood of the observations.
 """
-print __doc__
+print(__doc__)
 
 import numpy as np
 import pylab as pl
