@@ -8,7 +8,7 @@ sparse signal corrupted with an additive noise. Estimated coefficients are
 compared with the ground-truth.
 
 """
-print __doc__
+print(__doc__)
 
 import numpy as np
 import pylab as pl
@@ -44,8 +44,8 @@ lasso = Lasso(alpha=alpha)
 
 y_pred_lasso = lasso.fit(X_train, y_train).predict(X_test)
 r2_score_lasso = r2_score(y_test, y_pred_lasso)
-print lasso
-print "r^2 on test data : %f" % r2_score_lasso
+print(lasso)
+print("r^2 on test data : %f" % r2_score_lasso)
 
 ###############################################################################
 # ElasticNet
@@ -55,8 +55,8 @@ enet = ElasticNet(alpha=alpha, l1_ratio=0.7)
 
 y_pred_enet = enet.fit(X_train, y_train).predict(X_test)
 r2_score_enet = r2_score(y_test, y_pred_enet)
-print enet
-print "r^2 on test data : %f" % r2_score_enet
+print(enet)
+print("r^2 on test data : %f" % r2_score_enet)
 
 pl.plot(enet.coef_, label='Elastic net coefficients')
 pl.plot(lasso.coef_, label='Lasso coefficients')
