@@ -5,16 +5,16 @@ Lasso path using LARS
 =====================
 
 Computes Lasso Path along the regularization parameter using the LARS
-algorithm on the diabetest dataset. Each color represents a different
+algorithm on the diabetes dataset. Each color represents a different
 feature of the coefficient vector, and this is displayed as a function
 of the regularization parameter.
 
 """
-print __doc__
+print(__doc__)
 
 # Author: Fabian Pedregosa <fabian.pedregosa@inria.fr>
 #         Alexandre Gramfort <alexandre.gramfort@inria.fr>
-# License: BSD Style.
+# License: BSD 3 clause
 
 import numpy as np
 import pylab as pl
@@ -26,7 +26,7 @@ diabetes = datasets.load_diabetes()
 X = diabetes.data
 y = diabetes.target
 
-print "Computing regularization path using the LARS ..."
+print("Computing regularization path using the LARS ...")
 alphas, _, coefs = linear_model.lars_path(X, y, method='lasso', verbose=True)
 
 xx = np.sum(np.abs(coefs.T), axis=1)
