@@ -6,16 +6,17 @@
 =========================================================
 Logit function
 =========================================================
+
 Show in the plot is how the logistic regression would, in this
 synthetic dataset, classify values as either 0 or 1,
 i.e. class one or two, using the logit-curve.
 
 """
-print __doc__
+print(__doc__)
 
 
-# Code source: Gael Varoqueux
-# License: BSD
+# Code source: Gael Varoquaux
+# License: BSD 3 clause
 
 import numpy as np
 import pylab as pl
