@@ -7,10 +7,10 @@ Path with L1- Logistic Regression
 Computes path on IRIS dataset.
 
 """
-print __doc__
+print(__doc__)
 
 # Author: Alexandre Gramfort <alexandre.gramfort@inria.fr>
-# License: BSD Style.
+# License: BSD 3 clause
 
 from datetime import datetime
 import numpy as np
@@ -35,7 +35,7 @@ X -= np.mean(X, 0)
 cs = l1_min_c(X, y, loss='log') * np.logspace(0, 3)
 
 
-print "Computing regularization path ..."
+print("Computing regularization path ...")
 start = datetime.now()
 clf = linear_model.LogisticRegression(C=1.0, penalty='l1', tol=1e-6)
 coefs_ = []
@@ -43,7 +43,7 @@ for c in cs:
     clf.set_params(C=c)
     clf.fit(X, y)
     coefs_.append(clf.coef_.ravel().copy())
-print "This took ", datetime.now() - start
+print("This took ", datetime.now() - start)
 
 coefs_ = np.array(coefs_)
 pl.plot(np.log10(cs), coefs_)
