@@ -16,11 +16,11 @@ The coefficients, the residual sum of squares and the variance score are also
 calculated.
 
 """
-print __doc__
+print(__doc__)
 
 
 # Code source: Jaques Grobler
-# License: BSD
+# License: BSD 3 clause
 
 
 import pylab as pl
@@ -50,12 +50,12 @@ regr = linear_model.LinearRegression()
 regr.fit(diabetes_X_train, diabetes_y_train)
 
 # The coefficients
-print 'Coefficients: \n', regr.coef_
+print('Coefficients: \n', regr.coef_)
 # The mean square error
-print ("Residual sum of squares: %.2f" %
-       np.mean((regr.predict(diabetes_X_test) - diabetes_y_test) ** 2))
+print("Residual sum of squares: %.2f"
+      % np.mean((regr.predict(diabetes_X_test) - diabetes_y_test) ** 2))
 # Explained variance score: 1 is perfect prediction
-print ('Variance score: %.2f' % regr.score(diabetes_X_test, diabetes_y_test))
+print('Variance score: %.2f' % regr.score(diabetes_X_test, diabetes_y_test))
 
 # Plot outputs
 pl.scatter(diabetes_X_test, diabetes_y_test,  color='black')
