@@ -7,7 +7,7 @@ Plot the maximum margin separating hyperplane within a two-class
 separable dataset using a linear Support Vector Machines classifier
 trained using SGD.
 """
-print __doc__
+print(__doc__)
 
 import numpy as np
 import pylab as pl
