@@ -8,9 +8,9 @@ with locally linear embedding
 """
 
 # Author: Fabian Pedregosa -- <fabian.pedregosa@inria.fr>
-# License: BSD, (C) INRIA 2011
+# License: BSD 3 clause (C) INRIA 2011
 
-print __doc__
+print(__doc__)
 
 import pylab as pl
 
@@ -24,10 +24,10 @@ Axes3D
 from sklearn import manifold, datasets
 X, color = datasets.samples_generator.make_swiss_roll(n_samples=1500)
 
-print "Computing LLE embedding"
+print("Computing LLE embedding")
 X_r, err = manifold.locally_linear_embedding(X, n_neighbors=12,
                                              n_components=2)
-print "Done. Reconstruction error: %g" % err
+print("Done. Reconstruction error: %g" % err)
 
 #----------------------------------------------------------------------
 # Plot result
