@@ -8,12 +8,12 @@ using a k-Nearest Neighbor and the interpolation of the
 target using both barycenter and constant weights.
 
 """
-print __doc__
+print(__doc__)
 
 # Author: Alexandre Gramfort <alexandre.gramfort@inria.fr>
 #         Fabian Pedregosa <fabian.pedregosa@inria.fr>
 #
-# License: BSD, (C) INRIA
+# License: BSD 3 clause (C) INRIA
 
 
 ###############################################################################
