@@ -12,9 +12,9 @@ obtained in the first place.
 """
 
 # Author:  Alexandre Gramfort <alexandre.gramfort@inria.fr>
-# License: BSD
+# License: BSD 3 clause
 
-print __doc__
+print(__doc__)
 
 import numpy as np
 import pylab as pl
@@ -22,7 +22,6 @@ import pylab as pl
 from sklearn.svm import SVC
 from sklearn.cross_validation import StratifiedKFold, permutation_test_score
 from sklearn import datasets
-from sklearn.metrics import accuracy_score
 
 
 ##############################################################################
@@ -43,9 +42,9 @@ svm = SVC(kernel='linear')
 cv = StratifiedKFold(y, 2)
 
 score, permutation_scores, pvalue = permutation_test_score(
-    svm, X, y, accuracy_score, cv=cv, n_permutations=100, n_jobs=1)
+    svm, X, y, scoring="accuracy", cv=cv, n_permutations=100, n_jobs=1)
 
-print "Classification score %s (pvalue : %s)" % (score, pvalue)
+print("Classification score %s (pvalue : %s)" % (score, pvalue))
 
 ###############################################################################
 # View histogram of permutation scores
