@@ -5,8 +5,13 @@ Recursive feature elimination
 
 A recursive feature elimination example showing the relevance of pixels in
 a digit classification task.
+
+.. note::
+
+    See also :ref:`example_plot_rfe_with_cross_validation.py`
+
 """
-print __doc__
+print(__doc__)
 
 from sklearn.svm import SVC
 from sklearn.datasets import load_digits
