@@ -6,7 +6,7 @@ Recursive feature elimination with cross-validation
 A recursive feature elimination example with automatic tuning of the
 number of features selected with cross-validation.
 """
-print __doc__
+print(__doc__)
 
 from sklearn.svm import SVC
 from sklearn.cross_validation import StratifiedKFold
@@ -22,15 +22,15 @@ X, y = make_classification(n_samples=1000, n_features=25, n_informative=3,
 # Create the RFE object and compute a cross-validated score.
 svc = SVC(kernel="linear")
 rfecv = RFECV(estimator=svc, step=1, cv=StratifiedKFold(y, 2),
-              loss_func=zero_one_loss)
+              scoring='accuracy')
 rfecv.fit(X, y)
 
-print "Optimal number of features : %d" % rfecv.n_features_
+print("Optimal number of features : %d" % rfecv.n_features_)
 
 # Plot number of features VS. cross-validation scores
 import pylab as pl
 pl.figure()
 pl.xlabel("Number of features selected")
 pl.ylabel("Cross validation score (nb of misclassifications)")
-pl.plot(xrange(1, len(rfecv.cv_scores_) + 1), rfecv.cv_scores_)
+pl.plot(range(1, len(rfecv.grid_scores_) + 1), rfecv.grid_scores_)
 pl.show()
