@@ -5,17 +5,18 @@
 =========================================================
 SVM-Kernels
 =========================================================
+
 Three different types of SVM-Kernels are displayed below.
 The polynomial and RBF are especially useful when the
-data-points are not linearly seperable.
+data-points are not linearly separable.
 
 
 """
-print __doc__
+print(__doc__)
 
 
 # Code source: Gael Varoqueux
-# License: BSD
+# License: BSD 3 clause
 
 import numpy as np
 import pylab as pl
