@@ -9,7 +9,7 @@ inputs.
 
 The color map illustrates the decision function learn by the SVC.
 """
-print __doc__
+print(__doc__)
 
 import numpy as np
 import pylab as pl
