@@ -3,15 +3,17 @@
 Decision Tree Regression
 ===================================================================
 
-1D regression with :ref:`decision trees <tree>`: the decision tree is
+A 1D regression with decision tree.
+
+The :ref:`decision trees <tree>` is
 used to fit a sine curve with addition noisy observation. As a result, it
 learns local linear regressions approximating the sine curve.
 
-We can see that if the maximum depth of the tree (controled by the
+We can see that if the maximum depth of the tree (controlled by the
 `max_depth` parameter) is set too high, the decision trees learn too fine
 details of the training data and learn from the noise, i.e. they overfit.
 """
-print __doc__
+print(__doc__)
 
 import numpy as np
 
