@@ -10,6 +10,7 @@ from .affinity_propagation_ import affinity_propagation, AffinityPropagation
 from .hierarchical import ward_tree, Ward, WardAgglomeration
 from .k_means_ import k_means, KMeans, MiniBatchKMeans
 from .dbscan_ import dbscan, DBSCAN
+from .bicluster import SpectralBiclustering, SpectralCoclustering
 from ..utils import deprecated
 
 
@@ -18,7 +19,7 @@ from ..utils import deprecated
             " use sklearn.manifold.spectral_embedding instead")
 def spectral_embedding(*args, **kwargs):
     """Deprecated, use ``sklearn.manifold.spectral_embedding`` instead"""
-    from ..manifold.spectral_embedding import spectral_embedding
+    from ..manifold.spectral_embedding_ import spectral_embedding
     return spectral_embedding(*args, **kwargs)
 
 
@@ -38,4 +39,6 @@ __all__ = ['AffinityPropagation',
            'mean_shift',
            'spectral_clustering',
            'spectral_embedding',
-           'ward_tree']
+           'ward_tree',
+           'SpectralBiclustering',
+           'SpectralCoclustering']
