@@ -1,6 +1,6 @@
 """Hierarchical Agglomerative Clustering
 
-These routines perform some hierachical agglomerative clustering of some
+These routines perform some hierarchical agglomerative clustering of some
 input data. Currently, only Ward's algorithm is implemented.
 
 Authors : Vincent Michel, Bertrand Thirion, Alexandre Gramfort,
@@ -15,10 +15,11 @@ from scipy import sparse
 from scipy.cluster import hierarchy
 
 from ..base import BaseEstimator, ClusterMixin
-from ..utils._csgraph import cs_graph_components
 from ..externals.joblib import Memory
+from ..externals import six
 from ..metrics import euclidean_distances
 from ..utils import array2d
+from ..utils.sparsetools import connected_components
 
 from . import _hierarchical
 from ._feature_agglomeration import AgglomerationTransform
@@ -31,9 +32,12 @@ def ward_tree(X, connectivity=None, n_components=None, copy=True,
               n_clusters=None):
     """Ward clustering based on a Feature matrix.
 
+    Recursively merges the pair of clusters that minimally increases
+    within-cluster variance.
+
     The inertia matrix uses a Heapq-based representation.
 
-    This is the structured version, that takes into account a some topological
+    This is the structured version, that takes into account some topological
     structure between samples.
 
     Parameters
@@ -42,7 +46,7 @@ def ward_tree(X, connectivity=None, n_components=None, copy=True,
         feature matrix  representing n_samples samples to be clustered
 
     connectivity : sparse matrix.
-        connectivity matrix. Defines for each sample the neigbhoring samples
+        connectivity matrix. Defines for each sample the neighboring samples
         following a given structure of the data. The matrix is assumed to
         be symmetric and only the upper triangular half is used.
         Default is None, i.e, the Ward algorithm is unstructured.
@@ -66,10 +70,11 @@ def ward_tree(X, connectivity=None, n_components=None, copy=True,
     Returns
     -------
     children : 2D array, shape (n_nodes, 2)
-        list of the children of each nodes.
-        Leaves of the tree have empty list of children.
+        The children of each non-leaf node. Values less than `n_samples` refer
+        to leaves of the tree. A greater value `i` indicates a node with
+        children `children[i - n_samples]`.
 
-    n_components : sparse matrix.
+    n_components : int
         The number of connected components in the graph.
 
     n_leaves : int
@@ -90,12 +95,12 @@ def ward_tree(X, connectivity=None, n_components=None, copy=True,
                           'structured Ward clustering (i.e. with '
                           'explicit connectivity.', stacklevel=2)
         out = hierarchy.ward(X)
-        children_ = out[:, :2].astype(np.int)
+        children_ = out[:, :2].astype(np.intp)
         return children_, 1, n_samples, None
 
     # Compute the number of nodes
     if n_components is None:
-        n_components, labels = cs_graph_components(connectivity)
+        n_components, labels = connected_components(connectivity)
 
     # Convert connectivity matrix to LIL with a copy if needed
     if sparse.isspmatrix_lil(connectivity) and copy:
@@ -135,30 +140,30 @@ def ward_tree(X, connectivity=None, n_components=None, copy=True,
         coord_row.extend(len(row) * [ind, ])
         coord_col.extend(row)
 
-    coord_row = np.array(coord_row, dtype=np.int)
-    coord_col = np.array(coord_col, dtype=np.int)
+    coord_row = np.array(coord_row, dtype=np.intp, order='C')
+    coord_col = np.array(coord_col, dtype=np.intp, order='C')
 
     # build moments as a list
-    moments_1 = np.zeros(n_nodes)
+    moments_1 = np.zeros(n_nodes, order='C')
     moments_1[:n_samples] = 1
-    moments_2 = np.zeros((n_nodes, n_features))
+    moments_2 = np.zeros((n_nodes, n_features), order='C')
     moments_2[:n_samples] = X
-    inertia = np.empty(len(coord_row), dtype=np.float)
+    inertia = np.empty(len(coord_row), dtype=np.float, order='C')
     _hierarchical.compute_ward_dist(moments_1, moments_2, coord_row, coord_col,
                                     inertia)
-    inertia = zip(inertia, coord_row, coord_col)
+    inertia = list(six.moves.zip(inertia, coord_row, coord_col))
     heapify(inertia)
 
     # prepare the main fields
-    parent = np.arange(n_nodes, dtype=np.int)
+    parent = np.arange(n_nodes, dtype=np.intp)
     heights = np.zeros(n_nodes)
     used_node = np.ones(n_nodes, dtype=bool)
     children = []
 
-    not_visited = np.empty(n_nodes, dtype=np.int8)
+    not_visited = np.empty(n_nodes, dtype=np.int8, order='C')
 
     # recursive merge loop
-    for k in xrange(n_samples, n_nodes):
+    for k in range(n_samples, n_nodes):
         # identify the merge
         while True:
             inert, i, j = heappop(inertia)
@@ -181,17 +186,17 @@ def ward_tree(X, connectivity=None, n_components=None, copy=True,
         # List comprehension is faster than a for loop
         [A[l].append(k) for l in coord_col]
         A.append(coord_col)
-        coord_col = np.array(coord_col, dtype=np.int)
-        coord_row = np.empty_like(coord_col)
+        coord_col = np.array(coord_col, dtype=np.intp, order='C')
+        coord_row = np.empty(coord_col.shape, dtype=np.intp, order='C')
         coord_row.fill(k)
         n_additions = len(coord_row)
-        ini = np.empty(n_additions, dtype=np.float)
+        ini = np.empty(n_additions, dtype=np.float, order='C')
 
         _hierarchical.compute_ward_dist(moments_1, moments_2,
                                         coord_row, coord_col, ini)
         # List comprehension is faster than a for loop
         [heappush(inertia, (ini[idx], k, coord_col[idx]))
-            for idx in xrange(n_additions)]
+            for idx in range(n_additions)]
 
     # Separate leaves in children (empty lists up to now)
     n_leaves = n_samples
@@ -234,8 +239,9 @@ def _hc_cut(n_clusters, children, n_leaves):
         The number of clusters to form.
 
     children : list of pairs. Length of n_nodes
-        List of the children of each nodes.
-        Leaves have empty list of children and are not stored.
+        The children of each non-leaf node. Values less than `n_samples` refer
+        to leaves of the tree. A greater value `i` indicates a node with
+        children `children[i - n_samples]`.
 
     n_leaves : int
         Number of leaves of the tree.
@@ -262,7 +268,7 @@ def _hc_cut(n_clusters, children, n_leaves):
         # Insert the 2 children and remove the largest node
         heappush(nodes, -these_children[0])
         heappushpop(nodes, -these_children[1])
-    label = np.zeros(n_leaves, dtype=np.int)
+    label = np.zeros(n_leaves, dtype=np.intp)
     for i, node in enumerate(nodes):
         label[_hierarchical._hc_get_descendent(-node, children, n_leaves)] = i
     return label
@@ -274,24 +280,27 @@ def _hc_cut(n_clusters, children, n_leaves):
 class Ward(BaseEstimator, ClusterMixin):
     """Ward hierarchical clustering: constructs a tree and cuts it.
 
+    Recursively merges the pair of clusters that minimally increases
+    within-cluster variance.
+
     Parameters
     ----------
-    n_clusters : int or ndarray
+    n_clusters : int, default=2
         The number of clusters to find.
 
-    connectivity : sparse matrix.
-        Connectivity matrix. Defines for each sample the neigbhoring
+    connectivity : sparse matrix (optional)
+        Connectivity matrix. Defines for each sample the neighboring
         samples following a given structure of the data.
-        Default is None, i.e, the hiearchical clustering algorithm is
+        Default is None, i.e, the hierarchical clustering algorithm is
         unstructured.
 
-    memory : Instance of joblib.Memory or string
+    memory : Instance of joblib.Memory or string (optional)
         Used to cache the output of the computation of the tree.
         By default, no caching is done. If a string is given, it is the
         path to the caching directory.
 
-    copy : bool
-        Copy the connectivity matrix or work inplace.
+    copy : bool, default=True
+        Copy the connectivity matrix or work in-place.
 
     n_components : int (optional)
         The number of connected components in the graph defined by the \
@@ -309,15 +318,17 @@ class Ward(BaseEstimator, ClusterMixin):
     Attributes
     ----------
     `children_` : array-like, shape = [n_nodes, 2]
-        List of the children of each nodes.  Leaves of the tree do not appear.
+        The children of each non-leaf node. Values less than `n_samples` refer
+        to leaves of the tree. A greater value `i` indicates a node with
+        children `children_[i - n_samples]`.
 
     `labels_` : array [n_samples]
         cluster labels for each point
 
     `n_leaves_` : int
-        Number of leaves in the hiearchical tree.
+        Number of leaves in the hierarchical tree.
 
-    `n_components_` : sparse matrix.
+    `n_components_` : int
         The estimated number of connected components in the graph.
 
     """
@@ -346,7 +357,7 @@ class Ward(BaseEstimator, ClusterMixin):
         """
         memory = self.memory
         X = array2d(X)
-        if isinstance(memory, basestring):
+        if isinstance(memory, six.string_types):
             memory = Memory(cachedir=memory, verbose=0)
 
         if not self.connectivity is None:
@@ -398,22 +409,22 @@ class WardAgglomeration(AgglomerationTransform, Ward):
 
     Parameters
     ----------
-    n_clusters : int or ndarray
+    n_clusters : int, default=2
         The number of clusters.
 
-    connectivity : sparse matrix
-        connectivity matrix. Defines for each feature the neigbhoring
+    connectivity : sparse matrix (optional)
+        connectivity matrix. Defines for each feature the neighboring
         features following a given structure of the data.
-        Default is None, i.e, the hiearchical agglomeration algorithm is
+        Default is None, i.e, the hierarchical agglomeration algorithm is
         unstructured.
 
-    memory : Instance of joblib.Memory or string
+    memory : Instance of joblib.Memory or string (optional)
         Used to cache the output of the computation of the tree.
         By default, no caching is done. If a string is given, it is the
         path to the caching directory.
 
-    copy : bool
-        Copy the connectivity matrix or work inplace.
+    copy : bool, default=True
+        Copy the connectivity matrix or work in-place.
 
     n_components : int (optional)
         The number of connected components in the graph defined by the
@@ -431,15 +442,18 @@ class WardAgglomeration(AgglomerationTransform, Ward):
     Attributes
     ----------
     `children_` : array-like, shape = [n_nodes, 2]
-        List of the children of each nodes.
-        Leaves of the tree do not appear.
+        The children of each non-leaf node. Values less than `n_samples` refer
+        to leaves of the tree. A greater value `i` indicates a node with
+        children `children_[i - n_samples]`.
 
-    `labels_` : array [n_samples]
-        cluster labels for each point
+    `labels_` : array [n_features]
+        cluster labels for each feature
 
     `n_leaves_` : int
-        Number of leaves in the hiearchical tree.
+        Number of leaves in the hierarchical tree.
 
+    `n_components_` : int
+        The estimated number of connected components in the graph.
     """
 
     def fit(self, X, y=None, **params):
