@@ -3,7 +3,7 @@ Several basic tests for hierarchical clustering procedures
 
 """
 # Authors: Vincent Michel, 2010, Gael Varoquaux 2012
-# License: BSD-like
+# License: BSD 3 clause
 import warnings
 from tempfile import mkdtemp
 
@@ -14,6 +14,7 @@ from scipy.cluster import hierarchy
 from sklearn.utils.testing import assert_true
 from sklearn.utils.testing import assert_raises
 from sklearn.utils.testing import assert_equal
+from sklearn.utils.testing import assert_array_almost_equal
 
 from sklearn.cluster import Ward, WardAgglomeration, ward_tree
 from sklearn.cluster.hierarchical import _hc_cut
@@ -47,6 +48,7 @@ def test_unstructured_ward_tree():
     for this_X in (X, X[0]):
         with warnings.catch_warnings(record=True) as warning_list:
             warnings.simplefilter("always", UserWarning)
+            warnings.simplefilter("ignore", DeprecationWarning)
             # With specified a number of clusters just for the sake of
             # raising a warning and testing the warning code
             children, n_nodes, n_leaves, parent = ward_tree(this_X.T,
@@ -85,6 +87,8 @@ def test_ward_clustering():
     clustering.fit(X)
     labels = clustering.labels_
     assert_true(np.size(np.unique(labels)) == 10)
+    # Turn caching off now
+    clustering = Ward(n_clusters=10, connectivity=connectivity)
     # Check that we obtain the same solution with early-stopping of the
     # tree building
     clustering.compute_full_tree = False
@@ -119,6 +123,7 @@ def test_ward_agglomeration():
     assert_true(Xred.shape[1] == 5)
     Xfull = ward.inverse_transform(Xred)
     assert_true(np.unique(Xfull[0]).size == 5)
+    assert_array_almost_equal(ward.transform(Xfull), Xred)
 
 
 def assess_same_labelling(cut1, cut2):
@@ -172,7 +177,7 @@ def test_connectivity_popagation():
                   (.018, .153), (.018, .153), (.018, .153),
                   (.018, .152), (.018, .149), (.018, .144),
                   ])
-    nn = NearestNeighbors(n_neighbors=10, warn_on_equidistant=False).fit(X)
+    nn = NearestNeighbors(n_neighbors=10).fit(X)
     connectivity = nn.kneighbors_graph(X)
     ward = Ward(n_clusters=4, connectivity=connectivity)
     # If changes are not propagated correctly, fit crashes with an
