@@ -9,11 +9,13 @@ Models.
 from .empirical_covariance_ import empirical_covariance, EmpiricalCovariance, \
     log_likelihood
 from .shrunk_covariance_ import shrunk_covariance, ShrunkCovariance, \
-    ledoit_wolf, ledoit_wolf_shrinkage, LedoitWolf, oas, OAS
+    ledoit_wolf, ledoit_wolf_shrinkage, \
+    LedoitWolf, oas, OAS
 from .robust_covariance import fast_mcd, MinCovDet
 from .graph_lasso_ import graph_lasso, GraphLasso, GraphLassoCV
 from .outlier_detection import EllipticEnvelope, EllipticEnvelop
 
+
 __all__ = ['EllipticEnvelop',
            'EllipticEnvelope',
            'EmpiricalCovariance',
