@@ -3,7 +3,7 @@ estimator.
 """
 
 # Author: Gael Varoquaux <gael.varoquaux@normalesup.org>
-# License: BSD Style
+# License: BSD 3 clause
 # Copyright: INRIA
 import warnings
 import operator
@@ -22,6 +22,7 @@ from ..linear_model import lars_path
 from ..linear_model import cd_fast
 from ..cross_validation import check_cv, cross_val_score
 from ..externals.joblib import Parallel, delayed
+import collections
 
 
 ###############################################################################
@@ -52,7 +53,7 @@ def alpha_max(emp_cov):
 
     Parameters
     ----------
-    emp_cov: 2D array, (n_features, n_features)
+    emp_cov : 2D array, (n_features, n_features)
         The sample covariance matrix
 
     Notes
@@ -60,7 +61,8 @@ def alpha_max(emp_cov):
 
     This results from the bound for the all the Lasso that are solved
     in GraphLasso: each time, the row of cov corresponds to Xy. As the
-    bound for alpha is given by max(abs(Xy)), the result follows.
+    bound for alpha is given by `max(abs(Xy))`, the result follows.
+
     """
     A = np.copy(emp_cov)
     A.flat[::A.shape[0] + 1] = 0
@@ -77,29 +79,37 @@ def graph_lasso(emp_cov, alpha, cov_init=None, mode='cd', tol=1e-4,
 
     Parameters
     ----------
-    emp_cov: 2D ndarray, shape (n_features, n_features)
-        Empirical covariance from which to compute the covariance estimate
-    alpha: positive float
+    emp_cov : 2D ndarray, shape (n_features, n_features)
+        Empirical covariance from which to compute the covariance estimate.
+
+    alpha : positive float
         The regularization parameter: the higher alpha, the more
-        regularization, the sparser the inverse covariance
-    cov_init: 2D array (n_features, n_features), optional
-        The initial guess for the covariance
-    mode: {'cd', 'lars'}
+        regularization, the sparser the inverse covariance.
+
+    cov_init : 2D array (n_features, n_features), optional
+        The initial guess for the covariance.
+
+    mode : {'cd', 'lars'}
         The Lasso solver to use: coordinate descent or LARS. Use LARS for
         very sparse underlying graphs, where p > n. Elsewhere prefer cd
         which is more numerically stable.
-    tol: positive float, optional
+
+    tol : positive float, optional
         The tolerance to declare convergence: if the dual gap goes below
-        this value, iterations are stopped
-    max_iter: integer, optional
-        The maximum number of iterations
-    verbose: boolean, optional
+        this value, iterations are stopped.
+
+    max_iter : integer, optional
+        The maximum number of iterations.
+
+    verbose : boolean, optional
         If verbose is True, the objective function and dual gap are
-        printed at each iteration
-    return_costs: boolean, optional
+        printed at each iteration.
+
+    return_costs : boolean, optional
         If return_costs is True, the objective function and dual gap
-        at each iteration are returned
-    eps: float, optional
+        at each iteration are returned.
+
+    eps : float, optional
         The machine-precision regularization in the computation of the
         Cholesky diagonal factors. Increase this for very ill-conditioned
         systems.
@@ -107,12 +117,14 @@ def graph_lasso(emp_cov, alpha, cov_init=None, mode='cd', tol=1e-4,
     Returns
     -------
     covariance : 2D ndarray, shape (n_features, n_features)
-        The estimated covariance matrix
+        The estimated covariance matrix.
+
     precision : 2D ndarray, shape (n_features, n_features)
-        The estimated (sparse) precision matrix
+        The estimated (sparse) precision matrix.
+
     costs : list of (objective, dual_gap) pairs
         The list of values of the objective function and the dual gap at
-        each iteration. Returned only if return_costs is True
+        each iteration. Returned only if return_costs is True.
 
     See Also
     --------
@@ -120,13 +132,13 @@ def graph_lasso(emp_cov, alpha, cov_init=None, mode='cd', tol=1e-4,
 
     Notes
     -----
-
     The algorithm employed to solve this problem is the GLasso algorithm,
     from the Friedman 2008 Biostatistics paper. It is the same algorithm
     as in the R `glasso` package.
 
     One possible difference with the `glasso` R package is that the
     diagonal coefficients are not penalized.
+
     """
     _, n_features = emp_cov.shape
     if alpha == 0:
@@ -154,8 +166,8 @@ def graph_lasso(emp_cov, alpha, cov_init=None, mode='cd', tol=1e-4,
     else:
         errors = dict(invalid='raise')
     try:
-        for i in xrange(max_iter):
-            for idx in xrange(n_features):
+        for i in range(max_iter):
+            for idx in range(n_features):
                 sub_covariance = covariance_[indices != idx].T[indices != idx]
                 row = emp_cov[idx, indices != idx]
                 with np.errstate(**errors):
@@ -187,7 +199,7 @@ def graph_lasso(emp_cov, alpha, cov_init=None, mode='cd', tol=1e-4,
             d_gap = _dual_gap(emp_cov, precision_, alpha)
             cost = _objective(emp_cov, precision_, alpha)
             if verbose:
-                print (
+                print(
                     '[graph_lasso] Iteration % 3i, cost % 3.2e, dual gap %.3e'
                     % (i, cost, d_gap))
             if return_costs:
@@ -215,23 +227,28 @@ class GraphLasso(EmpiricalCovariance):
 
     Parameters
     ----------
-    alpha: positive float, optional
+    alpha : positive float, optional
         The regularization parameter: the higher alpha, the more
-        regularization, the sparser the inverse covariance
-    cov_init: 2D array (n_features, n_features), optional
-        The initial guess for the covariance
-    mode: {'cd', 'lars'}
+        regularization, the sparser the inverse covariance.
+
+    cov_init : 2D array (n_features, n_features), optional
+        The initial guess for the covariance.
+
+    mode : {'cd', 'lars'}
         The Lasso solver to use: coordinate descent or LARS. Use LARS for
         very sparse underlying graphs, where p > n. Elsewhere prefer cd
         which is more numerically stable.
-    tol: positive float, optional
+
+    tol : positive float, optional
         The tolerance to declare convergence: if the dual gap goes below
-        this value, iterations are stopped
-    max_iter: integer, optional
-        The maximum number of iterations
-    verbose: boolean, optional
+        this value, iterations are stopped.
+
+    max_iter : integer, optional
+        The maximum number of iterations.
+
+    verbose : boolean, optional
         If verbose is True, the objective function and dual gap are
-        plotted at each iteration
+        plotted at each iteration.
 
     Attributes
     ----------
@@ -272,32 +289,40 @@ def graph_lasso_path(X, alphas, cov_init=None, X_test=None, mode='cd',
 
     Parameters
     ----------
-    X: 2D ndarray, shape (n_samples, n_features)
-        Data from which to compute the covariance estimate
-    alphas: list of positive floats
-        The list of regularization parameters, decreasing order
-    X_test: 2D array, shape (n_test_samples, n_features), optional
-        Optional test matrix to measure generalisation error
-    mode: {'cd', 'lars'}
+    X : 2D ndarray, shape (n_samples, n_features)
+        Data from which to compute the covariance estimate.
+
+    alphas : list of positive floats
+        The list of regularization parameters, decreasing order.
+
+    X_test : 2D array, shape (n_test_samples, n_features), optional
+        Optional test matrix to measure generalisation error.
+
+    mode : {'cd', 'lars'}
         The Lasso solver to use: coordinate descent or LARS. Use LARS for
         very sparse underlying graphs, where p > n. Elsewhere prefer cd
         which is more numerically stable.
-    tol: positive float, optional
+
+    tol : positive float, optional
         The tolerance to declare convergence: if the dual gap goes below
-        this value, iterations are stopped
-    max_iter: integer, optional
-        The maximum number of iterations
-    verbose: integer, optional
+        this value, iterations are stopped.
+
+    max_iter : integer, optional
+        The maximum number of iterations.
+
+    verbose : integer, optional
         The higher the verbosity flag, the more information is printed
         during the fitting.
 
     Returns
     -------
-    covariances_: List of 2D ndarray, shape (n_features, n_features)
-        The estimated covariance matrices
-    precisions_: List of 2D ndarray, shape (n_features, n_features)
-        The estimated (sparse) precision matrices
-    scores_: List of float
+    `covariances_` : List of 2D ndarray, shape (n_features, n_features)
+        The estimated covariance matrices.
+
+    `precisions_` : List of 2D ndarray, shape (n_features, n_features)
+        The estimated (sparse) precision matrices.
+
+    `scores_` : List of float
         The generalisation error (log-likelihood) on the test data.
         Returned only if test data is passed.
     """
@@ -312,6 +337,7 @@ def graph_lasso_path(X, alphas, cov_init=None, X_test=None, mode='cd',
     scores_ = list()
     if X_test is not None:
         test_emp_cov = empirical_covariance(X_test)
+
     for alpha in alphas:
         try:
             # Capture the errors, and move on
@@ -332,7 +358,7 @@ def graph_lasso_path(X, alphas, cov_init=None, X_test=None, mode='cd',
             scores_.append(this_score)
         if verbose == 1:
             sys.stderr.write('.')
-        elif verbose:
+        elif verbose > 1:
             if X_test is not None:
                 print('[graph_lasso_path] alpha: %.2e, score: %.2e'
                       % (alpha, this_score))
@@ -344,52 +370,60 @@ def graph_lasso_path(X, alphas, cov_init=None, X_test=None, mode='cd',
 
 
 class GraphLassoCV(GraphLasso):
-    """Sparse inverse covariance w/ cross-validated choice of the l1 penality
+    """Sparse inverse covariance w/ cross-validated choice of the l1 penalty
 
     Parameters
     ----------
-    alphas: integer, or list positive float, optional
+    alphas : integer, or list positive float, optional
         If an integer is given, it fixes the number of points on the
         grids of alpha to be used. If a list is given, it gives the
         grid to be used. See the notes in the class docstring for
         more details.
+
     n_refinements: strictly positive integer
-        The number of time the grid is refined. Not used if explicit
+        The number of times the grid is refined. Not used if explicit
         values of alphas are passed.
-    cv : crossvalidation generator, optional
-        see sklearn.cross_validation module. If None is passed, default to
+
+    cv : cross-validation generator, optional
+        see sklearn.cross_validation module. If None is passed, defaults to
         a 3-fold strategy
+
     tol: positive float, optional
         The tolerance to declare convergence: if the dual gap goes below
-        this value, iterations are stopped
+        this value, iterations are stopped.
+
     max_iter: integer, optional
-        The maximum number of iterations
+        Maximum number of iterations.
+
     mode: {'cd', 'lars'}
         The Lasso solver to use: coordinate descent or LARS. Use LARS for
-        very sparse underlying graphs, where p > n. Elsewhere prefer cd
-        which is more numerically stable.
+        very sparse underlying graphs, where number of features is greater
+        than number of samples. Elsewhere prefer cd which is more numerically
+        stable.
+
     n_jobs: int, optional
-        number of jobs to run in parallel (default 1)
+        number of jobs to run in parallel (default 1).
+
     verbose: boolean, optional
-        If verbose is True, the objective function and dual gap are
-        print at each iteration
+        If verbose is True, the objective function and duality gap are
+        printed at each iteration.
 
     Attributes
     ----------
-    `covariance_` : array-like, shape (n_features, n_features)
-        Estimated covariance matrix
+    `covariance_` : numpy.ndarray, shape (n_features, n_features)
+        Estimated covariance matrix.
 
-    `precision_` : array-like, shape (n_features, n_features)
+    `precision_` : numpy.ndarray, shape (n_features, n_features)
         Estimated precision matrix (inverse covariance).
 
     `alpha_`: float
-        Penalization parameter selected
+        Penalization parameter selected.
 
     `cv_alphas_`: list of float
-        All the penalization parameters explored
+        All penalization parameters explored.
 
-    `cv_scores`: 2D array (n_alphas, n_folds)
-        The log-likelihood score on left-out data across the folds.
+    `grid_scores`: 2D numpy.ndarray (n_alphas, n_folds)
+        Log-likelihood score on left-out data across folds.
 
     See Also
     --------
@@ -397,11 +431,12 @@ class GraphLassoCV(GraphLasso):
 
     Notes
     -----
-    The search for the optimal alpha is done on an iteratively refined
-    grid: first the cross-validated scores on a grid are computed, then
-    a new refined grid is center around the maximum...
+    The search for the optimal penalization parameter (alpha) is done on an
+    iteratively refined grid: first the cross-validated scores on a grid are
+    computed, then a new refined grid is centered around the maximum, and so
+    on.
 
-    One of the challenges that we have to face is that the solvers can
+    One of the challenges which is faced here is that the solvers can
     fail to converge to a well-conditioned estimate. The corresponding
     values of alpha then come out as missing values, but the optimum may
     be close to these missing values.
@@ -431,7 +466,7 @@ class GraphLassoCV(GraphLasso):
         n_alphas = self.alphas
         inner_verbose = max(0, self.verbose - 1)
 
-        if operator.isSequenceType(n_alphas):
+        if isinstance(n_alphas, collections.Sequence):
             alphas = self.alphas
             n_refinements = 1
         else:
@@ -440,7 +475,6 @@ class GraphLassoCV(GraphLasso):
             alpha_0 = 1e-2 * alpha_1
             alphas = np.logspace(np.log10(alpha_0), np.log10(alpha_1),
                                  n_alphas)[::-1]
-        covs_init = (None, None, None)
 
         t0 = time.time()
         for i in range(n_refinements):
@@ -448,8 +482,12 @@ class GraphLassoCV(GraphLasso):
                 # No need to see the convergence warnings on this grid:
                 # they will always be points that will not converge
                 # during the cross-validation
-                warnings.simplefilter('ignore',  ConvergenceWarning)
+                warnings.simplefilter('ignore', ConvergenceWarning)
                 # Compute the cross-validated loss on the current grid
+
+                # NOTE: Warm-restarting graph_lasso_path has been tried, and
+                # this did not allow to gain anything (same execution time with
+                # or without).
                 this_path = Parallel(
                     n_jobs=self.n_jobs,
                     verbose=self.verbose)(
@@ -459,7 +497,7 @@ class GraphLassoCV(GraphLasso):
                             tol=self.tol,
                             max_iter=int(.1 * self.max_iter),
                             verbose=inner_verbose)
-                        for (train, test), cov_init in zip(cv, covs_init))
+                        for train, test in cv)
 
             # Little danse to transform the list in what we need
             covs, _, scores = zip(*this_path)
@@ -468,9 +506,9 @@ class GraphLassoCV(GraphLasso):
             path.extend(zip(alphas, scores, covs))
             path = sorted(path, key=operator.itemgetter(0), reverse=True)
 
-            # Find the maximum (we avoid using built in 'max' function to
+            # Find the maximum (avoid using built in 'max' function to
             # have a fully-reproducible selection of the smallest alpha
-            # is case of equality)
+            # in case of equality)
             best_score = -np.inf
             last_finite_idx = 0
             for index, (alpha, scores, _) in enumerate(path):
@@ -483,45 +521,44 @@ class GraphLassoCV(GraphLasso):
                     best_score = this_score
                     best_index = index
 
-            # Refine our grid
+            # Refine the grid
             if best_index == 0:
-                # We do not need to go back: we have choosen
+                # We do not need to go back: we have chosen
                 # the highest value of alpha for which there are
                 # non-zero coefficients
                 alpha_1 = path[0][0]
                 alpha_0 = path[1][0]
-                covs_init = path[0][-1]
             elif (best_index == last_finite_idx
                     and not best_index == len(path) - 1):
                 # We have non-converged models on the upper bound of the
                 # grid, we need to refine the grid there
                 alpha_1 = path[best_index][0]
                 alpha_0 = path[best_index + 1][0]
-                covs_init = path[best_index][-1]
             elif best_index == len(path) - 1:
                 alpha_1 = path[best_index][0]
                 alpha_0 = 0.01 * path[best_index][0]
-                covs_init = path[best_index][-1]
             else:
                 alpha_1 = path[best_index - 1][0]
                 alpha_0 = path[best_index + 1][0]
-                covs_init = path[best_index - 1][-1]
-            alphas = np.logspace(np.log10(alpha_1), np.log10(alpha_0),
-                                 n_alphas + 2)
-            alphas = alphas[1:-1]
-            if self.verbose and n_refinements > 1:
-                print '[GraphLassoCV] Done refinement % 2i out of %i: % 3is'\
-                      % (i + 1, n_refinements, time.time() - t0)
 
-        path = zip(*path)
-        cv_scores = list(path[1])
+            if not isinstance(n_alphas, collections.Sequence):
+                alphas = np.logspace(np.log10(alpha_1), np.log10(alpha_0),
+                                     n_alphas + 2)
+                alphas = alphas[1:-1]
+
+            if self.verbose and n_refinements > 1:
+                print('[GraphLassoCV] Done refinement % 2i out of %i: % 3is'
+                      % (i + 1, n_refinements, time.time() - t0))
+
+        path = list(zip(*path))
+        grid_scores = list(path[1])
         alphas = list(path[0])
         # Finally, compute the score with alpha = 0
         alphas.append(0)
-        cv_scores.append(cross_val_score(EmpiricalCovariance(), X,
+        grid_scores.append(cross_val_score(EmpiricalCovariance(), X,
                                          cv=cv, n_jobs=self.n_jobs,
                                          verbose=inner_verbose))
-        self.cv_scores = np.array(cv_scores)
+        self.grid_scores = np.array(grid_scores)
         best_alpha = alphas[best_index]
         self.alpha_ = best_alpha
         self.cv_alphas_ = alphas
