@@ -6,7 +6,7 @@ Here are implemented estimators that are resistant to outliers.
 """
 # Author: Virgile Fritsch <virgile.fritsch@inria.fr>
 #
-# License: BSD Style.
+# License: BSD 3 clause
 import warnings
 import numbers
 import numpy as np
@@ -28,47 +28,53 @@ from ..utils import check_random_state
 def c_step(X, n_support, remaining_iterations=30, initial_estimates=None,
            verbose=False, cov_computation_method=empirical_covariance,
            random_state=None):
-    """C_step procedure described in [Rouseeuw1984] aiming at computing the MCD
+    """C_step procedure described in [Rouseeuw1984]_ aiming at computing MCD.
 
     Parameters
     ----------
-    X: array-like, shape (n_samples, n_features)
-      Data set in which we look for the n_support observations whose
-      scatter matrix has minimum determinant
-    n_support: int, > n_samples / 2
-      Number of observations to compute the robust estimates of location
-      and covariance from.
-    remaining_iterations: int
-      Number of iterations to perform.
-      According to [Rouseeuw1999], two iterations are sufficient to get close
-      to the minimum, and we never need more than 30 to reach convergence.
-    initial_estimates: 2-tuple
-      Initial estimates of location and shape from which to run the c_step
-      procedure:
-      - initial_estimates[0]: an initial location estimate
-      - initial_estimates[1]: an initial covariance estimate
-    verbose: boolean
-      Verbose mode
-    random_state: integer or numpy.RandomState, optional
+    X : array-like, shape (n_samples, n_features)
+        Data set in which we look for the n_support observations whose
+        scatter matrix has minimum determinant.
+
+    n_support : int, > n_samples / 2
+        Number of observations to compute the robust estimates of location
+        and covariance from.
+
+    remaining_iterations : int, optional
+        Number of iterations to perform.
+        According to [Rouseeuw1999]_, two iterations are sufficient to get close
+        to the minimum, and we never need more than 30 to reach convergence.
+
+    initial_estimates : 2-tuple, optional
+        Initial estimates of location and shape from which to run the c_step
+        procedure:
+        - initial_estimates[0]: an initial location estimate
+        - initial_estimates[1]: an initial covariance estimate
+
+    verbose : boolean, optional
+        Verbose mode.
+
+    random_state : integer or numpy.RandomState, optional
         The random generator used. If an integer is given, it fixes the
         seed. Defaults to the global numpy random number generator.
 
     Returns
     -------
-    location: array-like, shape (n_features,)
-      Robust location estimates
-    covariance: array-like, shape (n_features, n_features)
-      Robust covariance estimates
-    support: array-like, shape (n_samples,)
-      A mask for the `n_support` observations whose scatter matrix has
-      minimum determinant
+    location : array-like, shape (n_features,)
+        Robust location estimates.
+
+    covariance : array-like, shape (n_features, n_features)
+        Robust covariance estimates.
+
+    support : array-like, shape (n_samples,)
+        A mask for the `n_support` observations whose scatter matrix has
+        minimum determinant.
 
     References
     ----------
-
     .. [Rouseeuw1999] A Fast Algorithm for the Minimum Covariance Determinant
-       Estimator, 1999, American Statistical Association and the American
-       Society for Quality, TECHNOMETRICS
+        Estimator, 1999, American Statistical Association and the American
+        Society for Quality, TECHNOMETRICS
 
     """
     random_state = check_random_state(random_state)
@@ -126,7 +132,7 @@ def c_step(X, n_support, remaining_iterations=30, initial_estimates=None,
             "Please check that the covariance matrix corresponding "
             "to the dataset is full rank and that MinCovDet is used with "
             "Gaussian-distributed data (or at least data drawn from a "
-            "unimodal, symetric distribution.")
+            "unimodal, symmetric distribution.")
     # Check convergence
     if np.allclose(det, previous_det):
         # c_step procedure converged
@@ -144,7 +150,7 @@ def c_step(X, n_support, remaining_iterations=30, initial_estimates=None,
     # Check early stopping
     if remaining_iterations == 0:
         if verbose:
-            print 'Maximum number of iterations reached'
+            print('Maximum number of iterations reached')
         det = fast_logdet(covariance)
         results = location, covariance, det, support, dist
 
@@ -166,53 +172,61 @@ def select_candidates(X, n_support, n_trials, select=1, n_iter=30,
 
     Starting from a random support, the pure data set is found by the
     c_step procedure introduced by Rousseeuw and Van Driessen in
-    [Rouseeuw1999].
+    [Rouseeuw1999]_.
 
     Parameters
     ----------
-    X: array-like, shape (n_samples, n_features)
-      Data (sub)set in which we look for the n_support purest observations
-    n_support: int, [(n + p + 1)/2] < n_support < n
-      The number of samples the pure data set must contain.
-    select: int, int > 0
-      Number of best candidates results to return.
-    n_trials: int, nb_trials > 0 or 2-tuple
-      Number of different initial sets of observations from which to
-      run the algorithm.
-      Instead of giving a number of trials to perform, one can provide a
-      list of initial estimates that will be used to iteratively run
-      c_step procedures. In this case:
-      - n_trials[0]: array-like, shape (n_trials, n_features)
-        is the list of `n_trials` initial location estimates
-      - n_trials[1]: array-like, shape (n_trials, n_features, n_features)
-        is the list of `n_trials` initial covariances estimates
-    n_iter: int, nb_iter > 0
-      Maximum number of iterations for the c_step procedure.
-      (2 is enough to be close to the final solution. "Never" exceeds 20)
-    random_state: integer or numpy.RandomState, optional
+    X : array-like, shape (n_samples, n_features)
+        Data (sub)set in which we look for the n_support purest observations.
+
+    n_support : int, [(n + p + 1)/2] < n_support < n
+        The number of samples the pure data set must contain.
+
+    select : int, int > 0
+        Number of best candidates results to return.
+
+    n_trials : int, nb_trials > 0 or 2-tuple
+        Number of different initial sets of observations from which to
+        run the algorithm.
+        Instead of giving a number of trials to perform, one can provide a
+        list of initial estimates that will be used to iteratively run
+        c_step procedures. In this case:
+        - n_trials[0]: array-like, shape (n_trials, n_features)
+          is the list of `n_trials` initial location estimates
+        - n_trials[1]: array-like, shape (n_trials, n_features, n_features)
+          is the list of `n_trials` initial covariances estimates
+
+    n_iter : int, nb_iter > 0
+        Maximum number of iterations for the c_step procedure.
+        (2 is enough to be close to the final solution. "Never" exceeds 20).
+
+    random_state : integer or numpy.RandomState, optional
         The random generator used. If an integer is given, it fixes the
         seed. Defaults to the global numpy random number generator.
 
+
     See Also
     ---------
     `c_step` function
 
     Returns
     -------
-    best_locations: array-like, shape (select, n_features)
-      The `select` location estimates computed from the `select` best
-      supports found in the data set (`X`)
-    best_covariances: array-like, shape (select, n_features, n_features)
-      The `select` covariance estimates computed from the `select`
-      best supports found in the data set (`X`)
-    best_supports: array-like, shape (select, n_samples)
-      The `select` best supports found in the data set (`X`)
+    best_locations : array-like, shape (select, n_features)
+        The `select` location estimates computed from the `select` best
+        supports found in the data set (`X`).
+
+    best_covariances : array-like, shape (select, n_features, n_features)
+        The `select` covariance estimates computed from the `select`
+        best supports found in the data set (`X`).
+
+    best_supports : array-like, shape (select, n_samples)
+        The `select` best supports found in the data set (`X`).
 
     References
     ----------
     .. [Rouseeuw1999] A Fast Algorithm for the Minimum Covariance Determinant
-       Estimator, 1999, American Statistical Association and the American
-       Society for Quality, TECHNOMETRICS
+        Estimator, 1999, American Statistical Association and the American
+        Society for Quality, TECHNOMETRICS
 
     """
     random_state = check_random_state(random_state)
@@ -266,14 +280,16 @@ def fast_mcd(X, support_fraction=None,
 
     Parameters
     ----------
-    X: array-like, shape (n_samples, n_features)
+    X : array-like, shape (n_samples, n_features)
       The data matrix, with p features and n samples.
-    support_fraction: float, 0 < support_fraction < 1
+
+    support_fraction : float, 0 < support_fraction < 1
           The proportion of points to be included in the support of the raw
           MCD estimate. Default is None, which implies that the minimum
           value of support_fraction will be used within the algorithm:
-          [n_sample + n_features + 1] / 2
-    random_state: integer or numpy.RandomState, optional
+          `[n_sample + n_features + 1] / 2`.
+
+    random_state : integer or numpy.RandomState, optional
         The generator used to randomly subsample. If an integer is
         given, it fixes the seed. Defaults to the global numpy random
         number generator.
@@ -290,34 +306,36 @@ def fast_mcd(X, support_fraction=None,
     such computation levels.
 
     Note that only raw estimates are returned. If one is intersted in
-    the correction and reweighting steps described in [Rouseeuw1999],
+    the correction and reweighting steps described in [Rouseeuw1999]_,
     see the MinCovDet object.
 
     References
     ----------
 
     .. [Rouseeuw1999] A Fast Algorithm for the Minimum Covariance
-       Determinant Estimator, 1999, American Statistical Association
-       and the American Society for Quality, TECHNOMETRICS
+        Determinant Estimator, 1999, American Statistical Association
+        and the American Society for Quality, TECHNOMETRICS
 
     .. [Butler1993] R. W. Butler, P. L. Davies and M. Jhun,
-       Asymptotics For The Minimum Covariance Determinant Estimator,
-       The Annals of Statistics, 1993, Vol. 21, No. 3, 1385-1400
+        Asymptotics For The Minimum Covariance Determinant Estimator,
+        The Annals of Statistics, 1993, Vol. 21, No. 3, 1385-1400
 
     Returns
     -------
-    location: array-like, shape (n_features,)
-      Robust location of the data
-    covariance: array-like, shape (n_features, n_features)
-      Robust covariance of the features
-    support: array-like, type boolean, shape (n_samples,)
-      a mask of the observations that have been used to compute
-      the robust location and covariance estimates of the data set
+    location : array-like, shape (n_features,)
+        Robust location of the data.
+
+    covariance : array-like, shape (n_features, n_features)
+        Robust covariance of the features.
+
+    support : array-like, type boolean, shape (n_samples,)
+        A mask of the observations that have been used to compute
+        the robust location and covariance estimates of the data set.
 
     """
     random_state = check_random_state(random_state)
 
-    X = np.asanyarray(X)
+    X = np.asarray(X)
     if X.ndim == 1:
         X = np.reshape(X, (1, -1))
         warnings.warn("Only one sample available. "
@@ -365,7 +383,8 @@ def fast_mcd(X, support_fraction=None,
         n_subsets = n_samples // 300
         n_samples_subsets = n_samples // n_subsets
         samples_shuffle = random_state.permutation(n_samples)
-        h_subset = np.ceil(n_samples_subsets * (n_support / float(n_samples)))
+        h_subset = int(np.ceil(n_samples_subsets *
+                       (n_support / float(n_samples))))
         # b. perform a total of 500 trials
         n_trials_tot = 500
         # c. select 10 best (location, covariance) for each subset
@@ -398,7 +417,8 @@ def fast_mcd(X, support_fraction=None,
         ## 2. Pool the candidate supports into a merged set
         ##    (possibly the full dataset)
         n_samples_merged = min(1500, n_samples)
-        h_merged = np.ceil(n_samples_merged * (n_support / float(n_samples)))
+        h_merged = int(np.ceil(n_samples_merged *
+                       (n_support / float(n_samples))))
         if n_samples > 1500:
             n_best_merged = 10
         else:
@@ -461,61 +481,64 @@ class MinCovDet(EmpiricalCovariance):
 
     The Minimum Covariance Determinant covariance estimator is to be applied
     on Gaussian-distributed data, but could still be relevant on data
-    drawn from a unimodal, symetric distribution. It is not meant to be used
-    with multimodal data (the algorithm used to fit a MinCovDet object is
+    drawn from a unimodal, symmetric distribution. It is not meant to be used
+    with multi-modal data (the algorithm used to fit a MinCovDet object is
     likely to fail in such a case).
-    One should consider projection pursuit methods to deal with multimodal
+    One should consider projection pursuit methods to deal with multi-modal
     datasets.
 
     Parameters
     ----------
-    store_precision: bool
-      Specify if the estimated precision is stored
-    assume_centered: Boolean
-      If True, the support of robust location and covariance estimates
-      is computed, and a covariance estimate is recomputed from it,
-      without centering the data.
-      Useful to work with data whose mean is significantly equal to
-      zero but is not exactly zero.
-      If False, the robust location and covariance are directly computed
-      with the FastMCD algorithm without additional treatment.
-    support_fraction: float, 0 < support_fraction < 1
-      The proportion of points to be included in the support of the raw
-      MCD estimate. Default is None, which implies that the minimum
-      value of support_fraction will be used within the algorithm:
-      [n_sample + n_features + 1] / 2
-    random_state: integer or numpy.RandomState, optional
+    store_precision : bool
+        Specify if the estimated precision is stored.
+
+    assume_centered : Boolean
+        If True, the support of the robust location and the covariance
+        estimates is computed, and a covariance estimate is recomputed from
+        it, without centering the data.
+        Useful to work with data whose mean is significantly equal to
+        zero but is not exactly zero.
+        If False, the robust location and covariance are directly computed
+        with the FastMCD algorithm without additional treatment.
+
+    support_fraction : float, 0 < support_fraction < 1
+        The proportion of points to be included in the support of the raw
+        MCD estimate. Default is None, which implies that the minimum
+        value of support_fraction will be used within the algorithm:
+        [n_sample + n_features + 1] / 2
+
+    random_state : integer or numpy.RandomState, optional
         The random generator used. If an integer is given, it fixes the
         seed. Defaults to the global numpy random number generator.
 
     Attributes
     ----------
-    `raw_location_`: array-like, shape (n_features,)
-        The raw robust estimated location before correction and reweighting
+    `raw_location_` : array-like, shape (n_features,)
+        The raw robust estimated location before correction and re-weighting.
 
-    `raw_covariance_`: array-like, shape (n_features, n_features)
-        The raw robust estimated covariance before correction and reweighting
+    `raw_covariance_` : array-like, shape (n_features, n_features)
+        The raw robust estimated covariance before correction and re-weighting.
 
-    `raw_support_`: array-like, shape (n_samples,)
+    `raw_support_` : array-like, shape (n_samples,)
         A mask of the observations that have been used to compute
         the raw robust estimates of location and shape, before correction
-        and reweighting.
+        and re-weighting.
 
-    `location_`: array-like, shape (n_features,)
+    `location_` : array-like, shape (n_features,)
         Estimated robust location
 
-    `covariance_`: array-like, shape (n_features, n_features)
+    `covariance_` : array-like, shape (n_features, n_features)
         Estimated robust covariance matrix
 
-    `precision_`: array-like, shape (n_features, n_features)
+    `precision_` : array-like, shape (n_features, n_features)
         Estimated pseudo inverse matrix.
         (stored only if store_precision is True)
 
-    `support_`: array-like, shape (n_samples,)
+    `support_` : array-like, shape (n_samples,)
         A mask of the observations that have been used to compute
         the robust estimates of location and shape.
 
-    `dist_`: array-like, shape (n_samples,)
+    `dist_` : array-like, shape (n_samples,)
         Mahalanobis distances of the training set (on which `fit` is called)
         observations.
 
@@ -523,13 +546,13 @@ class MinCovDet(EmpiricalCovariance):
     ----------
 
     .. [Rouseeuw1984] `P. J. Rousseeuw. Least median of squares regression.
-       J. Am Stat Ass, 79:871, 1984.`
+        J. Am Stat Ass, 79:871, 1984.`
     .. [Rouseeuw1999] `A Fast Algorithm for the Minimum Covariance Determinant
-       Estimator, 1999, American Statistical Association and the American
-       Society for Quality, TECHNOMETRICS`
+        Estimator, 1999, American Statistical Association and the American
+        Society for Quality, TECHNOMETRICS`
     .. [Butler1993] `R. W. Butler, P. L. Davies and M. Jhun,
-       Asymptotics For The Minimum Covariance Determinant Estimator,
-       The Annals of Statistics, 1993, Vol. 21, No. 3, 1385-1400`
+        Asymptotics For The Minimum Covariance Determinant Estimator,
+        The Annals of Statistics, 1993, Vol. 21, No. 3, 1385-1400`
 
     """
     _nonrobust_covariance = staticmethod(empirical_covariance)
@@ -546,15 +569,16 @@ class MinCovDet(EmpiricalCovariance):
 
         Parameters
         ----------
-        X: array-like, shape = [n_samples, n_features]
-          Training data, where n_samples is the number of samples
-          and n_features is the number of features.
-        y: not used, present for API consistence purpose.
+        X : array-like, shape = [n_samples, n_features]
+            Training data, where n_samples is the number of samples
+            and n_features is the number of features.
+
+        y : not used, present for API consistence purpose.
 
         Returns
         -------
-        self: object
-          Returns self.
+        self : object
+            Returns self.
 
         """
         random_state = check_random_state(self.random_state)
@@ -583,7 +607,7 @@ class MinCovDet(EmpiricalCovariance):
         self.dist_ = raw_dist
         # obtain consistency at normal models
         self.correct_covariance(X)
-        # reweight estimator
+        # re-weight estimator
         self.reweight_covariance(X)
 
         return self
@@ -596,15 +620,15 @@ class MinCovDet(EmpiricalCovariance):
 
         Parameters
         ----------
-        data: array-like, shape (n_samples, n_features)
-          The data matrix, with p features and n samples.
-          The data set must be the one which was used to compute
-          the raw estimates.
+        data : array-like, shape (n_samples, n_features)
+            The data matrix, with p features and n samples.
+            The data set must be the one which was used to compute
+            the raw estimates.
 
         Returns
         -------
-        covariance_corrected: array-like, shape (n_features, n_features)
-          Corrected robust covariance estimate.
+        covariance_corrected : array-like, shape (n_features, n_features)
+            Corrected robust covariance estimate.
 
         """
         correction = np.median(self.dist_) / chi2(data.shape[1]).isf(0.5)
@@ -613,28 +637,30 @@ class MinCovDet(EmpiricalCovariance):
         return covariance_corrected
 
     def reweight_covariance(self, data):
-        """Reweight raw Minimum Covariance Determinant estimates.
+        """Re-weight raw Minimum Covariance Determinant estimates.
 
-        Reweight observations using Rousseeuw's method (equivalent to
+        Re-weight observations using Rousseeuw's method (equivalent to
         deleting outlying observations from the data set before
         computing location and covariance estimates). [Rouseeuw1984]_
 
         Parameters
         ----------
-        data: array-like, shape (n_samples, n_features)
-          The data matrix, with p features and n samples.
-          The data set must be the one which was used to compute
-          the raw estimates.
+        data : array-like, shape (n_samples, n_features)
+            The data matrix, with p features and n samples.
+            The data set must be the one which was used to compute
+            the raw estimates.
 
         Returns
         -------
-        location_reweighted: array-like, shape (n_features, )
-          Reweighted robust location estimate.
-        covariance_reweighted: array-like, shape (n_features, n_features)
-          Reweighted robust covariance estimate.
-        support_reweighted: array-like, type boolean, shape (n_samples,)
-          A mask of the observations that have been used to compute
-          the reweighted robust location and covariance estimates.
+        location_reweighted : array-like, shape (n_features, )
+            Re-weighted robust location estimate.
+
+        covariance_reweighted : array-like, shape (n_features, n_features)
+            Re-weighted robust covariance estimate.
+
+        support_reweighted : array-like, type boolean, shape (n_samples,)
+            A mask of the observations that have been used to compute
+            the re-weighted robust location and covariance estimates.
 
         """
         n_samples, n_features = data.shape
