@@ -1,7 +1,6 @@
 """ Test the graph_lasso module.
 """
 import sys
-from StringIO import StringIO
 
 import numpy as np
 from scipy import linalg
@@ -12,6 +11,7 @@ from sklearn.utils.testing import assert_array_less
 from sklearn.covariance import (graph_lasso, GraphLasso, GraphLassoCV,
                                 empirical_covariance)
 from sklearn.datasets.samples_generator import make_sparse_spd_matrix
+from sklearn.externals.six.moves import StringIO
 from sklearn.utils import check_random_state
 
 
@@ -56,6 +56,9 @@ def test_graph_lasso_cv(random_state=1):
     try:
         sys.stdout = StringIO()
         # We need verbose very high so that Parallel prints on stdout
-        GraphLassoCV(verbose=100, alphas=3).fit(X)
+        GraphLassoCV(verbose=100, alphas=3, tol=1e-1).fit(X)
     finally:
         sys.stdout = orig_stdout
+
+    # Smoke test with specified alphas
+    GraphLassoCV(alphas=[0.8, 0.5], tol=1e-1, n_jobs=1).fit(X)
