@@ -6,7 +6,7 @@ validation and performance evaluation.
 # Author: Alexandre Gramfort <alexandre.gramfort@inria.fr>,
 #         Gael Varoquaux <gael.varoquaux@normalesup.org>,
 #         Olivier Grisel <olivier.grisel@ensta.org>
-# License: BSD Style.
+# License: BSD 3 clause
 
 from __future__ import print_function
 
@@ -14,6 +14,7 @@ import warnings
 from itertools import combinations
 from math import ceil, floor, factorial
 import numbers
+from abc import ABCMeta, abstractmethod
 
 import numpy as np
 import scipy.sparse as sp
@@ -22,6 +23,8 @@ from .base import is_classifier, clone
 from .utils import check_arrays, check_random_state, safe_mask
 from .utils.fixes import unique
 from .externals.joblib import Parallel, delayed
+from .externals.six import string_types, with_metaclass
+from .metrics.scorer import _deprecate_loss_and_score_funcs
 
 __all__ = ['Bootstrap',
            'KFold',
@@ -38,13 +41,69 @@ __all__ = ['Bootstrap',
            'train_test_split']
 
 
-class LeaveOneOut(object):
+class _PartitionIterator(with_metaclass(ABCMeta)):
+    """Base class for CV iterators where train_mask = ~test_mask
+
+    Implementations must define `_iter_test_masks` or `_iter_test_indices`.
+
+    Parameters
+    ----------
+    n : int
+        Total number of elements in dataset.
+
+    indices : boolean, optional (default True)
+        Return train/test split as arrays of indices, rather than a boolean
+        mask array. Integer indices are required when dealing with sparse
+        matrices, since those cannot be indexed by boolean masks.
+    """
+
+    def __init__(self, n, indices=True):
+        if abs(n - int(n)) >= np.finfo('f').eps:
+            raise ValueError("n must be an integer")
+        self.n = int(n)
+        self.indices = indices
+
+    def __iter__(self):
+        indices = self.indices
+        if indices:
+            ind = np.arange(self.n)
+        for test_index in self._iter_test_masks():
+            train_index = np.logical_not(test_index)
+            if indices:
+                train_index = ind[train_index]
+                test_index = ind[test_index]
+            yield train_index, test_index
+
+    # Since subclasses must implement either _iter_test_masks or
+    # _iter_test_indices, neither can be abstract.
+    def _iter_test_masks(self):
+        """Generates boolean masks corresponding to test sets.
+
+        By default, delegates to _iter_test_indices()
+        """
+        for test_index in self._iter_test_indices():
+            test_mask = self._empty_mask()
+            test_mask[test_index] = True
+            yield test_mask
+
+    def _iter_test_indices(self):
+        """Generates integer indices corresponding to test sets."""
+        raise NotImplementedError
+
+    def _empty_mask(self):
+        return np.zeros(self.n, dtype=np.bool)
+
+
+class LeaveOneOut(_PartitionIterator):
     """Leave-One-Out cross validation iterator.
 
     Provides train/test indices to split data in train test sets. Each
     sample is used once as a test set (singleton) while the remaining
     samples form the training set.
 
+    Note: ``LeaveOneOut(n)`` is equivalent to ``KFold(n, n_folds=n)`` and
+    ``LeavePOut(n, p=1)``.
+
     Due to the high number of test sets (which is the same as the
     number of samples) this cross validation method can be very costly.
     For large datasets one should favor KFold, StratifiedKFold or
@@ -86,21 +145,8 @@ class LeaveOneOut(object):
     domain-specific stratification of the dataset.
     """
 
-    def __init__(self, n, indices=True):
-        self.n = n
-        self.indices = indices
-
-    def __iter__(self):
-        n = self.n
-        for i in xrange(n):
-            test_index = np.zeros(n, dtype=np.bool)
-            test_index[i] = True
-            train_index = np.logical_not(test_index)
-            if self.indices:
-                ind = np.arange(n)
-                train_index = ind[train_index]
-                test_index = ind[test_index]
-            yield train_index, test_index
+    def _iter_test_indices(self):
+        return range(self.n)
 
     def __repr__(self):
         return '%s.%s(n=%i)' % (
@@ -113,16 +159,19 @@ class LeaveOneOut(object):
         return self.n
 
 
-class LeavePOut(object):
+class LeavePOut(_PartitionIterator):
     """Leave-P-Out cross validation iterator
 
-    Provides train/test indices to split data in train test sets. The
-    test set is built using p samples while the remaining samples form
-    the training set.
+    Provides train/test indices to split data in train test sets. This results
+    in testing on all distinct samples of size p, while the remaining n - p
+    samples form the training set in each iteration.
 
-    Due to the high number of iterations which grows with the number of
-    samples this cross validation method can be very costly. For large
-    datasets one should favor KFold, StratifiedKFold or ShuffleSplit.
+    Note: ``LeavePOut(n, p)`` is NOT equivalent to ``KFold(n, n_folds=n // p)``
+    which creates non-overlapping test sets.
+
+    Due to the high number of iterations which grows combinatorically with the
+    number of samples this cross validation method can be very costly. For
+    large datasets one should favor KFold, StratifiedKFold or ShuffleSplit.
 
     Parameters
     ----------
@@ -160,23 +209,12 @@ class LeavePOut(object):
     """
 
     def __init__(self, n, p, indices=True):
-        self.n = n
+        super(LeavePOut, self).__init__(n, indices)
         self.p = p
-        self.indices = indices
 
-    def __iter__(self):
-        n = self.n
-        p = self.p
-        comb = combinations(range(n), p)
-        for idx in comb:
-            test_index = np.zeros(n, dtype=np.bool)
-            test_index[np.array(idx)] = True
-            train_index = np.logical_not(test_index)
-            if self.indices:
-                ind = np.arange(n)
-                train_index = ind[train_index]
-                test_index = ind[test_index]
-            yield train_index, test_index
+    def _iter_test_indices(self):
+        for comb in combinations(range(self.n), self.p):
+            yield np.array(comb)
 
     def __repr__(self):
         return '%s.%s(n=%i, p=%i)' % (
@@ -191,15 +229,33 @@ class LeavePOut(object):
                    / factorial(self.p))
 
 
-def _validate_kfold(k, n_samples):
-    if k <= 0:
-        raise ValueError("Cannot have number of folds k below 1.")
-    if k > n_samples:
-        raise ValueError("Cannot have number of folds k=%d greater than"
-                         " the number of samples: %d." % (k, n_samples))
+class _BaseKFold(with_metaclass(ABCMeta, _PartitionIterator)):
+    """Base class to validate KFold approaches"""
+
+    @abstractmethod
+    def __init__(self, n, n_folds, indices, k=None):
+        super(_BaseKFold, self).__init__(n, indices)
+        if k is not None:  # pragma: no cover
+            warnings.warn("The parameter k was renamed to n_folds and will be"
+                          " removed in 0.15.", DeprecationWarning)
+            n_folds = k
+
+        if abs(n_folds - int(n_folds)) >= np.finfo('f').eps:
+            raise ValueError("n_folds must be an integer")
+        self.n_folds = n_folds = int(n_folds)
+
+        if n_folds <= 1:
+            raise ValueError(
+                "k-fold cross validation requires at least one"
+                " train / test split by setting n_folds=2 or more,"
+                " got n_folds=%d.".format(n_folds))
+        if n_folds > self.n:
+            raise ValueError(
+                ("Cannot have number of folds n_folds={0} greater"
+                 "than the number of samples: {1}.").format(n_folds, n))
 
 
-class KFold(object):
+class KFold(_BaseKFold):
     """K-Folds cross validation iterator.
 
     Provides train/test indices to split data in train test sets. Split
@@ -214,7 +270,7 @@ class KFold(object):
         Total number of elements.
 
     n_folds : int, default=3
-        Number of folds.
+        Number of folds. Must be at least 2.
 
     indices : boolean, optional (default True)
         Return train/test split as arrays of indices, rather than a boolean
@@ -246,8 +302,8 @@ class KFold(object):
 
     Notes
     -----
-    All the folds have size trunc(n_samples / n_folds), the last one has the
-    complementary.
+    The first n % n_folds folds have size n // n_folds + 1, other folds have
+    size n // n_folds.
 
     See also
     --------
@@ -258,40 +314,22 @@ class KFold(object):
 
     def __init__(self, n, n_folds=3, indices=True, shuffle=False,
                  random_state=None, k=None):
-        if k is not None:  # pragma: no cover
-            warnings.warn("The parameter k was renamed to n_folds and will be"
-                          " removed in 0.15.", DeprecationWarning)
-            n_folds = k
-        _validate_kfold(n_folds, n)
+        super(KFold, self).__init__(n, n_folds, indices, k)
         random_state = check_random_state(random_state)
-
-        if abs(n - int(n)) >= np.finfo('f').eps:
-            raise ValueError("n must be an integer")
-        self.n = int(n)
-        if abs(n_folds - int(n_folds)) >= np.finfo('f').eps:
-            raise ValueError("n_folds must be an integer")
-        self.n_folds = int(n_folds)
-        self.indices = indices
         self.idxs = np.arange(n)
         if shuffle:
             random_state.shuffle(self.idxs)
 
-    def __iter__(self):
+    def _iter_test_indices(self):
         n = self.n
         n_folds = self.n_folds
-        fold_size = n // n_folds
-
-        for i in xrange(n_folds):
-            test_index = np.zeros(n, dtype=np.bool)
-            if i < n_folds - 1:
-                test_index[self.idxs[i * fold_size:(i + 1) * fold_size]] = True
-            else:
-                test_index[self.idxs[i * fold_size:]] = True
-            train_index = np.logical_not(test_index)
-            if self.indices:
-                train_index = self.idxs[train_index]
-                test_index = self.idxs[test_index]
-            yield train_index, test_index
+        fold_sizes = (n // n_folds) * np.ones(n_folds, dtype=np.int)
+        fold_sizes[:n % n_folds] += 1
+        current = 0
+        for fold_size in fold_sizes:
+            start, stop = current, current + fold_size
+            yield self.idxs[start:stop]
+            current = stop
 
     def __repr__(self):
         return '%s.%s(n=%i, n_folds=%i)' % (
@@ -305,7 +343,7 @@ class KFold(object):
         return self.n_folds
 
 
-class StratifiedKFold(object):
+class StratifiedKFold(_BaseKFold):
     """Stratified K-Folds cross validation iterator
 
     Provides train/test indices to split data in train test sets.
@@ -320,7 +358,7 @@ class StratifiedKFold(object):
         Samples to split in K folds.
 
     n_folds : int, default=3
-        Number of folds.
+        Number of folds. Must be at least 2.
 
     indices : boolean, optional (default True)
         Return train/test split as arrays of indices, rather than a boolean
@@ -351,40 +389,23 @@ class StratifiedKFold(object):
     """
 
     def __init__(self, y, n_folds=3, indices=True, k=None):
-        if k is not None:  # pragma: no cover
-            warnings.warn("The parameter k was renamed to n_folds and will be"
-                          " removed in 0.15.", DeprecationWarning)
-            n_folds = k
+        super(StratifiedKFold, self).__init__(len(y), n_folds, indices, k)
         y = np.asarray(y)
-        n = y.shape[0]
-        _validate_kfold(n_folds, n)
         _, y_sorted = unique(y, return_inverse=True)
         min_labels = np.min(np.bincount(y_sorted))
-        if n_folds > min_labels:
+        if self.n_folds > min_labels:
             warnings.warn(("The least populated class in y has only %d"
                           " members, which is too few. The minimum"
                           " number of labels for any class cannot"
                           " be less than n_folds=%d."
-                          % (min_labels, n_folds)), Warning)
+                          % (min_labels, self.n_folds)), Warning)
         self.y = y
-        self.n_folds = n_folds
-        self.indices = indices
 
-    def __iter__(self):
-        y = self.y.copy()
+    def _iter_test_indices(self):
         n_folds = self.n_folds
-        n = y.size
-        idx = np.argsort(y)
-
-        for i in xrange(n_folds):
-            test_index = np.zeros(n, dtype=np.bool)
-            test_index[idx[i::n_folds]] = True
-            train_index = np.logical_not(test_index)
-            if self.indices:
-                ind = np.arange(n)
-                train_index = ind[train_index]
-                test_index = ind[test_index]
-            yield train_index, test_index
+        idx = np.argsort(self.y)
+        for i in range(n_folds):
+            yield idx[i::n_folds]
 
     def __repr__(self):
         return '%s.%s(labels=%s, n_folds=%i)' % (
@@ -398,7 +419,7 @@ class StratifiedKFold(object):
         return self.n_folds
 
 
-class LeaveOneLabelOut(object):
+class LeaveOneLabelOut(_PartitionIterator):
     """Leave-One-Label_Out cross-validation iterator
 
     Provides train/test indices to split data according to a third-party
@@ -447,22 +468,15 @@ class LeaveOneLabelOut(object):
     """
 
     def __init__(self, labels, indices=True):
-        self.labels = labels
-        self.n_unique_labels = unique(labels).size
-        self.indices = indices
+        super(LeaveOneLabelOut, self).__init__(len(labels), indices)
+        # We make a copy of labels to avoid side-effects during iteration
+        self.labels = np.array(labels, copy=True)
+        self.unique_labels = unique(labels)
+        self.n_unique_labels = len(self.unique_labels)
 
-    def __iter__(self):
-        # We make a copy here to avoid side-effects during iteration
-        labels = np.array(self.labels, copy=True)
-        for i in unique(labels):
-            test_index = np.zeros(len(labels), dtype=np.bool)
-            test_index[labels == i] = True
-            train_index = np.logical_not(test_index)
-            if self.indices:
-                ind = np.arange(len(labels))
-                train_index = ind[train_index]
-                test_index = ind[test_index]
-            yield train_index, test_index
+    def _iter_test_masks(self):
+        for i in self.unique_labels:
+            yield self.labels == i
 
     def __repr__(self):
         return '%s.%s(labels=%s)' % (
@@ -475,7 +489,7 @@ class LeaveOneLabelOut(object):
         return self.n_unique_labels
 
 
-class LeavePLabelOut(object):
+class LeavePLabelOut(_PartitionIterator):
     """Leave-P-Label_Out cross-validation iterator
 
     Provides train/test indices to split data according to a third-party
@@ -532,29 +546,21 @@ class LeavePLabelOut(object):
     """
 
     def __init__(self, labels, p, indices=True):
-        self.labels = labels
-        self.unique_labels = unique(self.labels)
-        self.n_unique_labels = self.unique_labels.size
+        # We make a copy of labels to avoid side-effects during iteration
+        super(LeavePLabelOut, self).__init__(len(labels), indices)
+        self.labels = np.array(labels, copy=True)
+        self.unique_labels = unique(labels)
+        self.n_unique_labels = len(self.unique_labels)
         self.p = p
-        self.indices = indices
 
-    def __iter__(self):
-        # We make a copy here to avoid side-effects during iteration
-        labels = np.array(self.labels, copy=True)
-        unique_labels = unique(labels)
+    def _iter_test_masks(self):
         comb = combinations(range(self.n_unique_labels), self.p)
-
         for idx in comb:
-            test_index = np.zeros(labels.size, dtype=np.bool)
+            test_index = self._empty_mask()
             idx = np.array(idx)
-            for l in unique_labels[idx]:
-                test_index[labels == l] = True
-            train_index = np.logical_not(test_index)
-            if self.indices:
-                ind = np.arange(labels.size)
-                train_index = ind[train_index]
-                test_index = ind[test_index]
-            yield train_index, test_index
+            for l in self.unique_labels[idx]:
+                test_index[self.labels == l] = True
+            yield test_index
 
     def __repr__(self):
         return '%s.%s(labels=%s, p=%s)' % (
@@ -704,7 +710,43 @@ class Bootstrap(object):
         return self.n_iter
 
 
-class ShuffleSplit(object):
+class BaseShuffleSplit(with_metaclass(ABCMeta)):
+    """Base class for ShuffleSplit and StratifiedShuffleSplit"""
+
+    def __init__(self, n, n_iter=10, test_size=0.1, train_size=None,
+                 indices=True, random_state=None, n_iterations=None):
+        self.n = n
+        self.n_iter = n_iter
+        if n_iterations is not None:  # pragma: no cover
+            warnings.warn("n_iterations was renamed to n_iter for consistency "
+                          " and will be removed in 0.16.")
+            self.n_iter = n_iterations
+        self.test_size = test_size
+        self.train_size = train_size
+        self.random_state = random_state
+        self.indices = indices
+        self.n_train, self.n_test = _validate_shuffle_split(n,
+                                                            test_size,
+                                                            train_size)
+
+    def __iter__(self):
+        if self.indices:
+            for train, test in self._iter_indices():
+                yield train, test
+            return
+        for train, test in self._iter_indices():
+            train_m = np.zeros(self.n, dtype=bool)
+            test_m = np.zeros(self.n, dtype=bool)
+            train_m[train] = True
+            test_m[test] = True
+            yield train_m, test_m
+
+    @abstractmethod
+    def _iter_indices(self):
+        """Generate (train, test) indices"""
+
+
+class ShuffleSplit(BaseShuffleSplit):
     """Random permutation cross-validation iterator.
 
     Yields indices to split data into training and test sets.
@@ -772,39 +814,14 @@ class ShuffleSplit(object):
     Bootstrap: cross-validation using re-sampling with replacement.
     """
 
-    def __init__(self, n, n_iter=10, test_size=0.1, train_size=None,
-                 indices=True, random_state=None, n_iterations=None):
-        self.n = n
-        self.n_iter = n_iter
-        if n_iterations is not None:  # pragma: no cover
-            warnings.warn("n_iterations was renamed to n_iter for consistency "
-                          " and will be removed in 0.16.")
-            self.n_iter = n_iterations
-        self.test_size = test_size
-        self.train_size = train_size
-        self.random_state = random_state
-        self.indices = indices
-
-        self.n_train, self.n_test = _validate_shuffle_split(n,
-                                                            test_size,
-                                                            train_size)
-
-    def __iter__(self):
+    def _iter_indices(self):
         rng = check_random_state(self.random_state)
         for i in range(self.n_iter):
             # random partition
             permutation = rng.permutation(self.n)
             ind_test = permutation[:self.n_test]
             ind_train = permutation[self.n_test:self.n_test + self.n_train]
-
-            if self.indices:
-                yield ind_train, ind_test
-            else:
-                train_mask = np.zeros(self.n, dtype=np.bool)
-                train_mask[ind_train] = True
-                test_mask = np.zeros(self.n, dtype=np.bool)
-                test_mask[ind_test] = True
-                yield train_mask, test_mask
+            yield ind_train, ind_test
 
     def __repr__(self):
         return ('%s(%d, n_iter=%d, test_size=%s, indices=%s, '
@@ -884,31 +901,7 @@ def _validate_shuffle_split(n, test_size, train_size):
     return int(n_train), int(n_test)
 
 
-def _validate_stratified_shuffle_split(y, test_size, train_size):
-    classes, y = unique(y, return_inverse=True)
-    n_cls = classes.shape[0]
-
-    if np.min(np.bincount(y)) < 2:
-        raise ValueError("The least populated class in y has only 1"
-                         " member, which is too few. The minimum"
-                         " number of labels for any class cannot"
-                         " be less than 2.")
-
-    n_train, n_test = _validate_shuffle_split(y.size, test_size, train_size)
-
-    if n_train < n_cls:
-        raise ValueError('The train_size = %d should be greater or '
-                         'equal to the number of classes = %d' %
-                         (n_train, n_cls))
-    if n_test < n_cls:
-        raise ValueError('The test_size = %d should be greater or '
-                         'equal to the number of classes = %d' %
-                         (n_test, n_cls))
-
-    return n_train, n_test, classes, y
-
-
-class StratifiedShuffleSplit(object):
+class StratifiedShuffleSplit(BaseShuffleSplit):
     """Stratified ShuffleSplit cross validation iterator
 
     Provides train/test indices to split data in train test sets.
@@ -946,6 +939,9 @@ class StratifiedShuffleSplit(object):
         mask array. Integer indices are required when dealing with sparse
         matrices, since those cannot be indexed by boolean masks.
 
+    random_state : int or RandomState
+        Pseudo-random number generator state used for random sampling.
+
     Examples
     --------
     >>> from sklearn.cross_validation import StratifiedShuffleSplit
@@ -968,21 +964,29 @@ class StratifiedShuffleSplit(object):
     def __init__(self, y, n_iter=10, test_size=0.1, train_size=None,
                  indices=True, random_state=None, n_iterations=None):
 
+        super(StratifiedShuffleSplit, self).__init__(
+            len(y), n_iter, test_size, train_size, indices, random_state,
+            n_iterations)
         self.y = np.array(y)
-        self.n = self.y.size
-        self.n_iter = n_iter
-        if n_iterations is not None:  # pragma: no cover
-            warnings.warn("n_iterations was renamed to n_iter for consistency"
-                          " and will be removed in 0.16.")
-            self.n_iter = n_iterations
-        self.test_size = test_size
-        self.train_size = train_size
-        self.random_state = random_state
-        self.indices = indices
-        self.n_train, self.n_test, self.classes, self.y_indices = \
-            _validate_stratified_shuffle_split(y, test_size, train_size)
+        self.classes, self.y_indices = unique(y, return_inverse=True)
+        n_cls = self.classes.shape[0]
 
-    def __iter__(self):
+        if np.min(np.bincount(self.y_indices)) < 2:
+            raise ValueError("The least populated class in y has only 1"
+                             " member, which is too few. The minimum"
+                             " number of labels for any class cannot"
+                             " be less than 2.")
+
+        if self.n_train < n_cls:
+            raise ValueError('The train_size = %d should be greater or '
+                             'equal to the number of classes = %d' %
+                             (self.n_train, n_cls))
+        if self.n_test < n_cls:
+            raise ValueError('The test_size = %d should be greater or '
+                             'equal to the number of classes = %d' %
+                             (self.n_test, n_cls))
+
+    def _iter_indices(self):
         rng = check_random_state(self.random_state)
         cls_count = np.bincount(self.y_indices)
         p_i = cls_count / float(self.n)
@@ -1004,15 +1008,7 @@ class StratifiedShuffleSplit(object):
             train = rng.permutation(train)
             test = rng.permutation(test)
 
-            if self.indices:
-                yield train, test
-            else:
-                train_m = np.zeros(self.n, dtype=bool)
-                test_m = np.zeros(self.n, dtype=bool)
-                train_m[train] = True
-                test_m[test] = True
-
-                yield train_m, test_m
+            yield train, test
 
     def __repr__(self):
         return ('%s(labels=%s, n_iter=%d, test_size=%s, indices=%s, '
@@ -1031,13 +1027,12 @@ class StratifiedShuffleSplit(object):
 
 ##############################################################################
 
-def _cross_val_score(estimator, X, y, score_func, train, test, verbose,
+def _cross_val_score(estimator, X, y, scorer, train, test, verbose,
                      fit_params):
     """Inner loop for cross validation"""
     n_samples = X.shape[0] if sp.issparse(X) else len(X)
     fit_params = dict([(k, np.asarray(v)[train]
-                        if hasattr(v, '__len__')
-                        and len(v) == n_samples else v)
+                       if hasattr(v, '__len__') and len(v) == n_samples else v)
                        for k, v in fit_params.items()])
     if not hasattr(X, "shape"):
         if getattr(estimator, "_pairwise", False):
@@ -1057,24 +1052,27 @@ def _cross_val_score(estimator, X, y, score_func, train, test, verbose,
             X_test = X[safe_mask(X, test)]
 
     if y is None:
-        estimator.fit(X_train, **fit_params)
-        if score_func is None:
-            score = estimator.score(X_test)
-        else:
-            score = score_func(X_test)
+        y_train = None
+        y_test = None
     else:
-        estimator.fit(X_train, y[train], **fit_params)
-        if score_func is None:
-            score = estimator.score(X_test, y[test])
-        else:
-            score = score_func(y[test], estimator.predict(X_test))
+        y_train = y[train]
+        y_test = y[test]
+    estimator.fit(X_train, y_train, **fit_params)
+    if scorer is None:
+        score = estimator.score(X_test, y_test)
+    else:
+        score = scorer(estimator, X_test, y_test)
+        if not isinstance(score, numbers.Number):
+            raise ValueError("scoring must return a number, got %s (%s)"
+                             " instead." % (str(score), type(score)))
     if verbose > 1:
         print("score: %f" % score)
     return score
 
 
-def cross_val_score(estimator, X, y=None, score_func=None, cv=None, n_jobs=1,
-                    verbose=0, fit_params=None):
+def cross_val_score(estimator, X, y=None, scoring=None, cv=None, n_jobs=1,
+                    verbose=0, fit_params=None, score_func=None,
+                    pre_dispatch='2*n_jobs'):
     """Evaluate a score by cross-validation
 
     Parameters
@@ -1085,18 +1083,16 @@ def cross_val_score(estimator, X, y=None, score_func=None, cv=None, n_jobs=1,
     X : array-like of shape at least 2D
         The data to fit.
 
-    y : array-like, optional
+    y : array-like, optional, default: None
         The target variable to try to predict in the case of
         supervised learning.
 
-    score_func : callable, optional
-        Score function to use for evaluation.
-        Has priority over the score function in the estimator.
-        In a non-supervised setting, where y is None, it takes the test
-        data (X_test) as its only argument. In a supervised setting it takes
-        the test target (y_true) and the test prediction (y_pred) as arguments.
+    scoring : string, callable or None, optional, default: None
+        A string (see model evaluation documentation) or
+        a scorer callable object / function with signature
+        ``scorer(estimator, X, y)``.
 
-    cv : cross-validation generator, optional
+    cv : cross-validation generator, optional, default: None
         A cross-validation generator. If None, a 3-fold cross
         validation is used or 3-fold stratified cross-validation
         when y is supplied and estimator is a classifier.
@@ -1111,6 +1107,23 @@ def cross_val_score(estimator, X, y=None, score_func=None, cv=None, n_jobs=1,
     fit_params : dict, optional
         Parameters to pass to the fit method of the estimator.
 
+    pre_dispatch : int, or string, optional
+        Controls the number of jobs that get dispatched during parallel
+        execution. Reducing this number can be useful to avoid an
+        explosion of memory consumption when more jobs get dispatched
+        than CPUs can process. This parameter can be:
+
+            - None, in which case all the jobs are immediately
+              created and spawned. Use this for lightweight and
+              fast-running jobs, to avoid delays due to on-demand
+              spawning of the jobs
+
+            - An int, giving the exact number of total jobs that are
+              spawned
+
+            - A string, giving an expression as a function of n_jobs,
+              as in '2*n_jobs'
+
     Returns
     -------
     scores : array of float, shape=(len(list(cv)),)
@@ -1118,39 +1131,43 @@ def cross_val_score(estimator, X, y=None, score_func=None, cv=None, n_jobs=1,
     """
     X, y = check_arrays(X, y, sparse_format='csr', allow_lists=True)
     cv = check_cv(cv, X, y, classifier=is_classifier(estimator))
-    if score_func is None:
-        if not hasattr(estimator, 'score'):
-            raise TypeError(
-                "If no score_func is specified, the estimator passed "
-                "should have a 'score' method. The estimator %s "
-                "does not." % estimator)
+    scorer = _deprecate_loss_and_score_funcs(
+        loss_func=None,
+        score_func=score_func,
+        scoring=scoring
+    )
+    if scorer is None and not hasattr(estimator, 'score'):
+        raise TypeError(
+            "If no scoring is specified, the estimator passed "
+            "should have a 'score' method. The estimator %s "
+            "does not." % estimator)
     # We clone the estimator to make sure that all the folds are
     # independent, and that it is pickle-able.
     fit_params = fit_params if fit_params is not None else {}
-    scores = Parallel(n_jobs=n_jobs, verbose=verbose)(
-        delayed(_cross_val_score)(
-            clone(estimator), X, y, score_func,
-            train, test, verbose, fit_params)
+    parallel = Parallel(n_jobs=n_jobs, verbose=verbose,
+                        pre_dispatch=pre_dispatch)
+    scores = parallel(
+        delayed(_cross_val_score)(clone(estimator), X, y, scorer, train, test,
+                                  verbose, fit_params)
         for train, test in cv)
     return np.array(scores)
 
 
-def _permutation_test_score(estimator, X, y, cv, score_func):
-    """Auxilary function for permutation_test_score"""
+def _permutation_test_score(estimator, X, y, cv, scorer):
+    """Auxiliary function for permutation_test_score"""
     avg_score = []
     for train, test in cv:
-        avg_score.append(score_func(y[test],
-                                    estimator.fit(X[train],
-                                                  y[train]).predict(X[test])))
+        estimator.fit(X[train], y[train])
+        avg_score.append(scorer(estimator, X[test], y[test]))
     return np.mean(avg_score)
 
 
 def _shuffle(y, labels, random_state):
     """Return a shuffled copy of y eventually shuffle among same labels."""
     if labels is None:
-        ind = random_state.permutation(y.size)
+        ind = random_state.permutation(len(y))
     else:
-        ind = np.arange(labels.size)
+        ind = np.arange(len(labels))
         for label in unique(labels):
             this_mask = (labels == label)
             ind[this_mask] = random_state.permutation(ind[this_mask])
@@ -1177,6 +1194,12 @@ def check_cv(cv, X=None, y=None, classifier=False):
     classifier : boolean optional
         Whether the task is a classification task, in which case
         stratified KFold will be used.
+
+    Returns
+    -------
+    checked_cv: a cross-validation generator instance.
+        The return value is guaranteed to be a cv generator instance, whatever
+        the input type.
     """
     is_sparse = sp.issparse(X)
     needs_indices = is_sparse or not hasattr(X, "shape")
@@ -1197,9 +1220,9 @@ def check_cv(cv, X=None, y=None, classifier=False):
     return cv
 
 
-def permutation_test_score(estimator, X, y, score_func, cv=None,
+def permutation_test_score(estimator, X, y, score_func=None, cv=None,
                            n_permutations=100, n_jobs=1, labels=None,
-                           random_state=0, verbose=0):
+                           random_state=0, verbose=0, scoring=None):
     """Evaluate the significance of a cross-validated score with permutations
 
     Parameters
@@ -1214,16 +1237,14 @@ def permutation_test_score(estimator, X, y, score_func, cv=None,
         The target variable to try to predict in the case of
         supervised learning.
 
-    score_func : callable
-        Callable taking as arguments the test targets (y_test) and
-        the predicted targets (y_pred) and returns a float. The score
-        functions are expected to return a bigger value for a better result
-        otherwise the returned value does not correspond to a p-value (see
-        Returns below for further details).
+    scoring : string, callable or None, optional, default: None
+        A string (see model evaluation documentation) or
+        a scorer callable object / function with signature
+        ``scorer(estimator, X, y)``.
 
-    cv : integer or crossvalidation generator, optional
+    cv : integer or cross-validation generator, optional
         If an integer is passed, it is the number of fold (default 3).
-        Specific crossvalidation objects can be passed, see
+        Specific cross-validation objects can be passed, see
         sklearn.cross_validation module for the list of possible objects.
 
     n_jobs : integer, optional
@@ -1267,16 +1288,20 @@ def permutation_test_score(estimator, X, y, score_func, cv=None,
     """
     X, y = check_arrays(X, y, sparse_format='csr')
     cv = check_cv(cv, X, y, classifier=is_classifier(estimator))
-
+    scorer = _deprecate_loss_and_score_funcs(
+        loss_func=None,
+        score_func=score_func,
+        scoring=scoring
+    )
     random_state = check_random_state(random_state)
 
     # We clone the estimator to make sure that all the folds are
     # independent, and that it is pickle-able.
-    score = _permutation_test_score(clone(estimator), X, y, cv, score_func)
+    score = _permutation_test_score(clone(estimator), X, y, cv, scorer)
     permutation_scores = Parallel(n_jobs=n_jobs, verbose=verbose)(
-        delayed(_permutation_test_score)(clone(estimator), X,
-                                         _shuffle(y, labels, random_state),
-                                         cv, score_func)
+        delayed(_permutation_test_score)(
+            clone(estimator), X, _shuffle(y, labels, random_state), cv,
+            scorer)
         for _ in range(n_permutations))
     permutation_scores = np.array(permutation_scores)
     pvalue = (np.sum(permutation_scores >= score) + 1.0) / (n_permutations + 1)
