@@ -40,13 +40,15 @@ from .samples_generator import make_spd_matrix
 from .samples_generator import make_swiss_roll
 from .samples_generator import make_s_curve
 from .samples_generator import make_sparse_spd_matrix
+from .samples_generator import make_gaussian_quantiles
+from .samples_generator import make_biclusters
+from .samples_generator import make_checkerboard
 from .svmlight_format import load_svmlight_file
 from .svmlight_format import load_svmlight_files
 from .svmlight_format import dump_svmlight_file
 from .olivetti_faces import fetch_olivetti_faces
 from .species_distributions import fetch_species_distributions
 from .california_housing import fetch_california_housing
-from ..utils import deprecated
 
 __all__ = ['clear_data_home',
            'dump_svmlight_file',
@@ -60,11 +62,9 @@ __all__ = ['clear_data_home',
            'fetch_california_housing',
            'fetch_covtype',
            'get_data_home',
-           'load_20newsgroups',
            'load_boston',
            'load_diabetes',
            'load_digits',
-           'load_filenames',
            'load_files',
            'load_iris',
            'load_lfw_pairs',
@@ -75,12 +75,15 @@ __all__ = ['clear_data_home',
            'load_sample_images',
            'load_svmlight_file',
            'load_svmlight_files',
+           'make_biclusters',
            'make_blobs',
            'make_circles',
            'make_classification',
+           'make_checkerboard',
            'make_friedman1',
            'make_friedman2',
            'make_friedman3',
+           'make_gaussian_quantiles',
            'make_hastie_10_2',
            'make_low_rank_matrix',
            'make_moons',
@@ -92,13 +95,4 @@ __all__ = ['clear_data_home',
            'make_sparse_uncorrelated',
            'make_spd_matrix',
            'make_swiss_roll',
-           'mldata_filename',
-           'samples_generator']
-
-
-# backward compatibility
-@deprecated("to be removed in 0.9;"
-            " use sklearn.datasets.load_files instead")
-def load_filenames(*args, **kwargs):
-    """Deprecated, use ``sklearn.datasets.load_files`` instead"""
-    return load_files(*args, **kwargs)
+           'mldata_filename']
