@@ -5,11 +5,12 @@ Base IO code for all datasets
 # Copyright (c) 2007 David Cournapeau <cournape@gmail.com>
 #               2010 Fabian Pedregosa <fabian.pedregosa@inria.fr>
 #               2010 Olivier Grisel <olivier.grisel@ensta.org>
-# License: Simplified BSD
+# License: BSD 3 clause
 
 import os
 import csv
 import shutil
+import warnings
 from os import environ
 from os.path import dirname
 from os.path import join
@@ -64,8 +65,9 @@ def clear_data_home(data_home=None):
 
 
 def load_files(container_path, description=None, categories=None,
-               load_content=True, shuffle=True, charset=None,
-               charse_error='strict', random_state=0):
+               load_content=True, shuffle=True, encoding=None,
+               charset=None, charset_error=None,
+               decode_error='strict', random_state=0):
     """Load text files with categories as subfolder names.
 
     Individual samples are assumed to be files stored a two levels folder
@@ -82,19 +84,25 @@ def load_files(container_path, description=None, categories=None,
                 file_44.txt
                 ...
 
-    The folder names are used has supervised signal label names. The indivial
-    file names are not important.
+    The folder names are used has supervised signal label names. The
+    individual file names are not important.
 
     This function does not try to extract features into a numpy array or
     scipy sparse matrix. In addition, if load_content is false it
     does not try to load the files in memory.
 
-    To use utf-8 text files in a scikit-learn classification or clustering
-    algorithm you will first need to use the `sklearn.features.text`
+    To use text files in a scikit-learn classification or clustering
+    algorithm, you will need to use the `sklearn.feature_extraction.text`
     module to build a feature extraction transformer that suits your
     problem.
 
-    Similar feature extractors should be build for other kind of unstructured
+    If you set load_content=True, you should also specify the encoding of
+    the text using the 'encoding' parameter. For many modern text files,
+    'utf-8' will be the correct encoding. If you leave encoding equal to None,
+    then the content will be made of bytes instead of Unicode, and you will
+    not be able to use most functions in `sklearn.feature_extraction.text`.
+
+    Similar feature extractors should be built for other kind of unstructured
     data input such as images, audio, video, ...
 
     Parameters
@@ -116,17 +124,16 @@ def load_files(container_path, description=None, categories=None,
         in the data structure returned. If not, a filenames attribute
         gives the path to the files.
 
-    charset : string or None (default is None)
+    encoding : string or None (default is None)
         If None, do not try to decode the content of the files (e.g. for
         images or other non-text content).
-        If not None, charset to use to decode text files if load_content is
-        True.
+        If not None, encoding to use to decode text files to Unicode if
+        load_content is True.
 
-    charset_error: {'strict', 'ignore', 'replace'}
+    decode_error: {'strict', 'ignore', 'replace'}, optional
         Instruction on what to do if a byte sequence is given to analyze that
-        contains characters not of the given `charset`. By default, it is
-        'strict', meaning that a UnicodeDecodeError will be raised. Other
-        values are 'ignore' and 'replace'.
+        contains characters not of the given `encoding`. Passed as keyword
+        argument 'errors' to bytes.decode.
 
     shuffle : bool, optional (default=True)
         Whether or not to shuffle the data: might be important for models that
@@ -148,6 +155,19 @@ def load_files(container_path, description=None, categories=None,
         'target_names', the meaning of the labels, and 'DESCR', the full
         description of the dataset.
     """
+    if charset is not None:
+        warnings.warn("The charset parameter is deprecated as of version "
+                      "0.14 and will be removed in 0.16. Use encode instead.",
+                      DeprecationWarning)
+        encoding = charset
+
+    if charset_error is not None:
+        warnings.warn("The charset_error parameter is deprecated as of "
+                      "version 0.14 and will be removed in 0.16. Use "
+                      "decode_error instead.",
+                      DeprecationWarning)
+        decode_error = charset_error
+
     target = []
     target_names = []
     filenames = []
@@ -178,9 +198,9 @@ def load_files(container_path, description=None, categories=None,
         target = target[indices]
 
     if load_content:
-        data = [open(filename).read() for filename in filenames]
-        if charset is not None:
-            data = [d.decode(charset, charse_error) for d in data]
+        data = [open(filename, 'rb').read() for filename in filenames]
+        if encoding is not None:
+            data = [d.decode(encoding, decode_error) for d in data]
         return Bunch(data=data,
                      filenames=filenames,
                      target_names=target_names,
@@ -283,7 +303,7 @@ def load_digits(n_class=10):
 
         >>> from sklearn.datasets import load_digits
         >>> digits = load_digits()
-        >>> print digits.data.shape
+        >>> print(digits.data.shape)
         (1797, 64)
         >>> import pylab as pl #doctest: +SKIP
         >>> pl.gray() #doctest: +SKIP
@@ -391,19 +411,19 @@ def load_boston():
     --------
     >>> from sklearn.datasets import load_boston
     >>> boston = load_boston()
-    >>> print boston.data.shape
+    >>> print(boston.data.shape)
     (506, 13)
     """
     module_path = dirname(__file__)
     data_file = csv.reader(open(join(module_path, 'data',
                                      'boston_house_prices.csv')))
     fdescr = open(join(module_path, 'descr', 'boston_house_prices.rst'))
-    temp = data_file.next()
+    temp = next(data_file)
     n_samples = int(temp[0])
     n_features = int(temp[1])
     data = np.empty((n_samples, n_features))
     target = np.empty((n_samples,))
-    temp = data_file.next()  # names of features
+    temp = next(data_file)  # names of features
     feature_names = np.array(temp)
 
     for i, d in enumerate(data_file):
