@@ -1,14 +1,24 @@
 """Automatically download MLdata datasets."""
 
 # Copyright (c) 2011 Pietro Berkes
-# License: Simplified BSD
+# License: BSD 3 clause
 
 import os
 from os.path import join, exists
 import re
 import numbers
-import urllib2
+try:
+    # Python 2
+    from urllib2 import HTTPError
+    from urllib2 import quote
+    from urllib2 import urlopen
+except ImportError:
+    # Python 3+
+    from urllib.error import HTTPError
+    from urllib.parse import quote
+    from urllib.request import urlopen
 
+import numpy as np
 import scipy as sp
 from scipy import io
 from shutil import copyfileobj
@@ -81,25 +91,35 @@ def fetch_mldata(dataname, target_name='label', data_name='data',
     Examples
     --------
     Load the 'iris' dataset from mldata.org:
+
     >>> from sklearn.datasets.mldata import fetch_mldata
-    >>> iris = fetch_mldata('iris')
-    >>> iris.target[0]
-    1
-    >>> print(iris.data[0])
-    [-0.555556  0.25     -0.864407 -0.916667]
+    >>> import tempfile
+    >>> test_data_home = tempfile.mkdtemp()
+
+    >>> iris = fetch_mldata('iris', data_home=test_data_home)
+    >>> iris.target.shape
+    (150,)
+    >>> iris.data.shape
+    (150, 4)
 
     Load the 'leukemia' dataset from mldata.org, which needs to be transposed
     to respects the sklearn axes convention:
-    >>> leuk = fetch_mldata('leukemia', transpose_data=True)
-    >>> print(leuk.data.shape[0])
-    72
+    >>> leuk = fetch_mldata('leukemia', transpose_data=True,
+    ...                     data_home=test_data_home)
+    >>> leuk.data.shape
+    (72, 7129)
 
     Load an alternative 'iris' dataset, which has different names for the
     columns:
+
     >>> iris2 = fetch_mldata('datasets-UCI iris', target_name=1,
-    ...                      data_name=0)
+    ...                      data_name=0, data_home=test_data_home)
     >>> iris3 = fetch_mldata('datasets-UCI iris',
-    ...                      target_name='class', data_name='double0')
+    ...                      target_name='class', data_name='double0',
+    ...                      data_home=test_data_home)
+
+    >>> import shutil
+    >>> shutil.rmtree(test_data_home)
     """
 
     # normalize dataset name
@@ -116,10 +136,10 @@ def fetch_mldata(dataname, target_name='label', data_name='data',
 
     # if the file does not exist, download it
     if not exists(filename):
-        urlname = MLDATA_BASE_URL % urllib2.quote(dataname)
+        urlname = MLDATA_BASE_URL % quote(dataname)
         try:
-            mldata_url = urllib2.urlopen(urlname)
-        except urllib2.HTTPError as e:
+            mldata_url = urlopen(urlname)
+        except HTTPError as e:
             if e.code == 404:
                 e.msg = "Dataset '%s' not found on mldata.org." % dataname
             raise
@@ -192,3 +212,28 @@ def fetch_mldata(dataname, target_name='label', data_name='data',
             dataset['target'] = dataset['target'].squeeze()
 
     return Bunch(**dataset)
+
+
+# The following is used by nosetests to setup the docstring tests fixture
+
+def setup_module(module):
+    # setup mock urllib2 module to avoid downloading from mldata.org
+    from sklearn.utils.testing import install_mldata_mock
+    install_mldata_mock({
+        'iris': {
+            'data': np.empty((150, 4)),
+            'label': np.empty(150),
+        },
+        'datasets-uci-iris': {
+            'double0': np.empty((150, 4)),
+            'class': np.empty((150,)),
+        },
+        'leukemia': {
+            'data': np.empty((72, 7129)),
+        },
+    })
+
+
+def teardown_module(module):
+    from sklearn.utils.testing import uninstall_mldata_mock
+    uninstall_mldata_mock()
