@@ -3,6 +3,7 @@
 import numpy
 import os
 
+
 def configuration(parent_package='', top_path=None):
     from numpy.distutils.misc_util import Configuration
     config = Configuration('datasets', parent_package, top_path)
@@ -10,6 +11,9 @@ def configuration(parent_package='', top_path=None):
     config.add_data_dir('descr')
     config.add_data_dir('images')
     config.add_data_dir(os.path.join('tests', 'data'))
+    config.add_extension('_svmlight_format',
+                         sources=['_svmlight_format.c'],
+                         include_dirs=[numpy.get_include()])
 
     return config
 
