@@ -13,11 +13,9 @@ libsvm command line programs.
 # Authors: Mathieu Blondel <mathieu@mblondel.org>
 #          Lars Buitinck <L.J.Buitinck@uva.nl>
 #          Olivier Grisel <olivier.grisel@ensta.org>
-# License: Simple BSD.
+# License: BSD 3 clause
 
-from bz2 import BZ2File
 from contextlib import closing
-import gzip
 import io
 import os.path
 
@@ -26,7 +24,9 @@ import scipy.sparse as sp
 
 from ._svmlight_format import _load_svmlight_file
 from .. import __version__
+from ..externals import six
 from ..utils import atleast2d_or_csr
+from ..externals.six import u, b
 
 
 def load_svmlight_file(f, n_features=None, dtype=np.float64,
@@ -48,20 +48,19 @@ def load_svmlight_file(f, n_features=None, dtype=np.float64,
     CSR results of the first call and benefit from the near instantaneous
     loading of memmapped structures for the subsequent calls.
 
-    This implementation is naive: it does allocate too much memory and
-    is slow since written in python. On large datasets it is recommended
-    to use an optimized loader such as:
-
-      https://github.com/mblondel/svmlight-loader
-
     In case the file contains a pairwise preference constraint (known
     as "qid" in the svmlight format) these are ignored unless the
     query_id parameter is set to True. These pairwise preference
-    constraints can be used to contraint the combination of samples
+    constraints can be used to constraint the combination of samples
     when using pairwise loss functions (as is the case in some
     learning to rank problems) so that only pairs with the same
     query_id value are considered.
 
+    This implementation is written in Cython and is reasonably fast.
+    However, a faster API-compatible loader is also available at:
+
+      https://github.com/mblondel/svmlight-loader
+
     Parameters
     ----------
     f: {str, file-like, int}
@@ -116,13 +115,15 @@ def load_svmlight_file(f, n_features=None, dtype=np.float64,
 def _gen_open(f):
     if isinstance(f, int):  # file descriptor
         return io.open(f, "rb", closefd=False)
-    elif not isinstance(f, basestring):
+    elif not isinstance(f, six.string_types):
         raise TypeError("expected {str, int, file-like}, got %s" % type(f))
 
     _, ext = os.path.splitext(f)
     if ext == ".gz":
+        import gzip
         return gzip.open(f, "rb")
     elif ext == ".bz2":
+        from bz2 import BZ2File
         return BZ2File(f, "rb")
     else:
         return open(f, "rb")
@@ -228,31 +229,32 @@ def load_svmlight_files(files, n_features=None, dtype=np.float64,
 
 def _dump_svmlight(X, y, f, one_based, comment, query_id):
     is_sp = int(hasattr(X, "tocsr"))
-    if X.dtype == np.float64:
-        value_pattern = u"%d:%0.16e"
+    if X.dtype.kind == 'i':
+        value_pattern = u("%d:%d")
     else:
-        value_pattern = u"%d:%f"
+        value_pattern = u("%d:%.16g")
 
     if y.dtype.kind == 'i':
-        line_pattern = u"%d"
+        line_pattern = u("%d")
     else:
-        line_pattern = u"%f"
+        line_pattern = u("%.16g")
 
     if query_id is not None:
-        line_pattern += u" qid:%d"
-    line_pattern += u" %s\n"
+        line_pattern += u(" qid:%d")
+    line_pattern += u(" %s\n")
 
     if comment:
-        f.write("# Generated by dump_svmlight_file from scikit-learn %s\n"
-                % __version__)
-        f.write("# Column indices are %s-based\n" % ["zero", "one"][one_based])
+        f.write(b("# Generated by dump_svmlight_file from scikit-learn %s\n"
+                % __version__))
+        f.write(b("# Column indices are %s-based\n"
+                  % ["zero", "one"][one_based]))
 
-        f.write("#\n")
-        f.writelines("# %s\n" % line for line in comment.splitlines())
+        f.write(b("#\n"))
+        f.writelines(b("# %s\n" % line) for line in comment.splitlines())
 
-    for i in xrange(X.shape[0]):
-        s = u" ".join([value_pattern % (j + one_based, X[i, j])
-                       for j in X[i].nonzero()[is_sp]])
+    for i in range(X.shape[0]):
+        s = " ".join([value_pattern % (j + one_based, X[i, j])
+                      for j in X[i].nonzero()[is_sp]])
         if query_id is not None:
             feat = (y[i], query_id[i], s)
         else:
@@ -308,7 +310,7 @@ def dump_svmlight_file(X, y, f, zero_based=True, comment=None, query_id=None):
             comment.decode("ascii")     # just for the exception
         else:
             comment = comment.encode("utf-8")
-        if "\0" in comment:
+        if six.b("\0") in comment:
             raise ValueError("comment string contains NUL byte")
 
     y = np.asarray(y)
