@@ -21,6 +21,10 @@ from sklearn.datasets import make_sparse_uncorrelated
 from sklearn.datasets import make_spd_matrix
 from sklearn.datasets import make_swiss_roll
 from sklearn.datasets import make_s_curve
+from sklearn.datasets import make_biclusters
+from sklearn.datasets import make_checkerboard
+
+from sklearn.utils.validation import assert_all_finite
 
 
 def test_make_classification():
@@ -50,6 +54,17 @@ def test_make_multilabel_classification():
         assert_true(max([len(y) for y in Y]) <= 3)
 
 
+def test_make_multilabel_classification_return_indicator():
+    for allow_unlabeled, min_length in zip((True, False), (0, 1)):
+        X, Y = make_multilabel_classification(n_samples=25, n_features=20,
+                                              n_classes=3, random_state=0,
+                                              return_indicator=True,
+                                              allow_unlabeled=allow_unlabeled)
+        assert_equal(X.shape, (25, 20), "X shape mismatch")
+        assert_equal(Y.shape, (25, 3), "Y shape mismatch")
+        assert_true(np.all(np.sum(Y, axis=0) > min_length))
+
+
 def test_make_hastie_10_2():
     X, y = make_hastie_10_2(n_samples=100, random_state=0)
     assert_equal(X.shape, (100, 10), "X shape mismatch")
@@ -191,3 +206,39 @@ def test_make_s_curve():
     assert_equal(t.shape, (5,), "t shape mismatch")
     assert_array_equal(X[:, 0], np.sin(t))
     assert_array_equal(X[:, 2], np.sign(t) * (np.cos(t) - 1))
+
+
+def test_make_biclusters():
+    X, rows, cols = make_biclusters(
+        shape=(100, 100), n_clusters=4, shuffle=True, random_state=0)
+    assert_equal(X.shape, (100, 100), "X shape mismatch")
+    assert_equal(rows.shape, (4, 100), "rows shape mismatch")
+    assert_equal(cols.shape, (4, 100,), "columns shape mismatch")
+    assert_all_finite(X)
+    assert_all_finite(rows)
+    assert_all_finite(cols)
+
+    X2, _, _ = make_biclusters(shape=(100, 100), n_clusters=4,
+                               shuffle=True, random_state=0)
+    assert_array_equal(X, X2)
+
+
+def test_make_checkerboard():
+    X, rows, cols = make_checkerboard(
+        shape=(100, 100), n_clusters=(20, 5),
+        shuffle=True, random_state=0)
+    assert_equal(X.shape, (100, 100), "X shape mismatch")
+    assert_equal(rows.shape, (100, 100), "rows shape mismatch")
+    assert_equal(cols.shape, (100, 100,), "columns shape mismatch")
+
+    X, rows, cols = make_checkerboard(
+        shape=(100, 100), n_clusters=2, shuffle=True, random_state=0)
+    assert_all_finite(X)
+    assert_all_finite(rows)
+    assert_all_finite(cols)
+
+    X1, _, _ = make_checkerboard(shape=(100, 100), n_clusters=2,
+                                 shuffle=True, random_state=0)
+    X2, _, _ = make_checkerboard(shape=(100, 100), n_clusters=2,
+                                 shuffle=True, random_state=0)
+    assert_array_equal(X1, X2)
