@@ -1,7 +1,7 @@
 """Kernel Principal Components Analysis"""
 
 # Author: Mathieu Blondel <mathieu@mblondel.org>
-# License: BSD Style.
+# License: BSD 3 clause
 
 import numpy as np
 from scipy import linalg
@@ -26,16 +26,20 @@ class KernelPCA(BaseEstimator, TransformerMixin):
         Kernel.
         Default: "linear"
 
-    degree : int, optional
-        Degree for poly, rbf and sigmoid kernels.
-        Default: 3.
+    degree : int, default=3
+        Degree for poly, rbf and sigmoid kernels. Ignored by other kernels.
 
     gamma : float, optional
-        Kernel coefficient for rbf and poly kernels.
-        Default: 1/n_features.
+        Kernel coefficient for rbf and poly kernels. Default: 1/n_features.
+        Ignored by other kernels.
 
     coef0 : float, optional
         Independent term in poly and sigmoid kernels.
+        Ignored by other kernels.
+
+    kernel_params : mapping of string to any, optional
+        Parameters (keyword arguments) and values for kernel passed as
+        callable object. Ignored by other kernels.
 
     alpha: int
         Hyperparameter of the ridge regression that learns the
@@ -60,6 +64,13 @@ class KernelPCA(BaseEstimator, TransformerMixin):
         maximum number of iterations for arpack
         Default: None (optimal value will be chosen by arpack)
 
+    remove_zero_eig : boolean, default=True
+        If True, then all components with zero eigenvalues are removed, so
+        that the number of components in the output may be < n_components
+        (and sometimes even zero due to numerical instability).
+        When n_components is None, this parameter is ignored and components
+        with zero eigenvalues are removed regardless.
+
     Attributes
     ----------
 
@@ -74,27 +85,30 @@ class KernelPCA(BaseEstimator, TransformerMixin):
 
     References
     ----------
-    Kernel PCA was intoduced in:
+    Kernel PCA was introduced in:
         Bernhard Schoelkopf, Alexander J. Smola,
         and Klaus-Robert Mueller. 1999. Kernel principal
         component analysis. In Advances in kernel methods,
         MIT Press, Cambridge, MA, USA 327-352.
     """
 
-    def __init__(self, n_components=None, kernel="linear", gamma=None, degree=3,
-                 coef0=1, alpha=1.0, fit_inverse_transform=False,
-                 eigen_solver='auto', tol=0, max_iter=None):
+    def __init__(self, n_components=None, kernel="linear",
+                 gamma=None, degree=3, coef0=1, kernel_params=None,
+                 alpha=1.0, fit_inverse_transform=False, eigen_solver='auto',
+                 tol=0, max_iter=None, remove_zero_eig=False):
         if fit_inverse_transform and kernel == 'precomputed':
             raise ValueError(
                 "Cannot fit_inverse_transform with a precomputed kernel.")
         self.n_components = n_components
-        self.kernel = kernel.lower()
+        self.kernel = kernel
+        self.kernel_params = kernel_params
         self.gamma = gamma
         self.degree = degree
         self.coef0 = coef0
         self.alpha = alpha
         self.fit_inverse_transform = fit_inverse_transform
         self.eigen_solver = eigen_solver
+        self.remove_zero_eig = remove_zero_eig
         self.tol = tol
         self.max_iter = max_iter
         self._centerer = KernelCenterer()
@@ -104,16 +118,14 @@ class KernelPCA(BaseEstimator, TransformerMixin):
         return self.kernel == "precomputed"
 
     def _get_kernel(self, X, Y=None):
-        params = {"gamma": self.gamma,
-                  "degree": self.degree,
-                  "coef0": self.coef0}
-        try:
-            return pairwise_kernels(X, Y, metric=self.kernel,
-                                    filter_params=True, **params)
-        except AttributeError:
-            raise ValueError("%s is not a valid kernel. Valid kernels are: "
-                             "rbf, poly, sigmoid, linear and precomputed."
-                             % self.kernel)
+        if callable(self.kernel):
+            params = self.kernel_params or {}
+        else:
+            params = {"gamma": self.gamma,
+                      "degree": self.degree,
+                      "coef0": self.coef0}
+        return pairwise_kernels(X, Y, metric=self.kernel,
+                                filter_params=True, **params)
 
     def _fit_transform(self, K):
         """ Fit's using kernel K"""
@@ -143,14 +155,15 @@ class KernelPCA(BaseEstimator, TransformerMixin):
                                                 tol=self.tol,
                                                 maxiter=self.max_iter)
 
-        # sort eignenvectors in descending order
+        # sort eigenvectors in descending order
         indices = self.lambdas_.argsort()[::-1]
         self.lambdas_ = self.lambdas_[indices]
         self.alphas_ = self.alphas_[:, indices]
 
         # remove eigenvectors with a zero eigenvalue
-        self.alphas_ = self.alphas_[:, self.lambdas_ > 0]
-        self.lambdas_ = self.lambdas_[self.lambdas_ > 0]
+        if self.remove_zero_eig or self.n_components is None:
+            self.alphas_ = self.alphas_[:, self.lambdas_ > 0]
+            self.lambdas_ = self.lambdas_[self.lambdas_ > 0]
 
         return K
 
