@@ -1,4 +1,5 @@
 import numpy as np
+from scipy import linalg
 from sklearn.decomposition import nmf
 
 from sklearn.utils.testing import assert_true
@@ -6,6 +7,7 @@ from sklearn.utils.testing import assert_false
 from sklearn.utils.testing import raises
 from sklearn.utils.testing import assert_array_almost_equal
 from sklearn.utils.testing import assert_greater
+from sklearn.utils.testing import assert_less
 
 
 random_state = np.random.mtrand.RandomState(0)
@@ -21,7 +23,7 @@ def test_initialize_nn_output():
     """Test that NNDSVD does not return negative values"""
     data = np.abs(random_state.randn(10, 10))
     for var in (None, 'a', 'ar'):
-        W, H = nmf._initialize_nmf(data, 10)
+        W, H = nmf._initialize_nmf(data, 10, random_state=0)
         assert_false((W < 0).any() or (H < 0).any())
 
 
@@ -33,8 +35,8 @@ def test_initialize_close():
     """
     A = np.abs(random_state.randn(10, 10))
     W, H = nmf._initialize_nmf(A, 10)
-    error = np.linalg.norm(np.dot(W, H) - A)
-    sdev = np.linalg.norm(A - A.mean())
+    error = linalg.norm(np.dot(W, H) - A)
+    sdev = linalg.norm(A - A.mean())
     assert_true(error <= sdev)
 
 
@@ -47,7 +49,7 @@ def test_initialize_variants():
     data = np.abs(random_state.randn(10, 10))
     W0, H0 = nmf._initialize_nmf(data, 10, variant=None)
     Wa, Ha = nmf._initialize_nmf(data, 10, variant='a')
-    War, Har = nmf._initialize_nmf(data, 10, variant='ar')
+    War, Har = nmf._initialize_nmf(data, 10, variant='ar', random_state=0)
 
     for ref, evl in ((W0, Wa), (W0, War), (H0, Ha), (H0, Har)):
         assert_true(np.allclose(evl[ref != 0], ref[ref != 0]))
@@ -57,16 +59,17 @@ def test_initialize_variants():
 def test_projgrad_nmf_fit_nn_input():
     """Test model fit behaviour on negative input"""
     A = -np.ones((2, 2))
-    m = nmf.ProjectedGradientNMF(n_components=2, init=None)
+    m = nmf.ProjectedGradientNMF(n_components=2, init=None, random_state=0)
     m.fit(A)
 
 
 def test_projgrad_nmf_fit_nn_output():
     """Test that the decomposition does not contain negative values"""
-    A = np.c_[5 * np.ones(5) - xrange(1, 6),
-              5 * np.ones(5) + xrange(1, 6)]
+    A = np.c_[5 * np.ones(5) - np.arange(1, 6),
+              5 * np.ones(5) + np.arange(1, 6)]
     for init in (None, 'nndsvd', 'nndsvda', 'nndsvdar'):
-        model = nmf.ProjectedGradientNMF(n_components=2, init=init)
+        model = nmf.ProjectedGradientNMF(n_components=2, init=init,
+                                         random_state=0)
         transf = model.fit_transform(A)
         assert_false((model.components_ < 0).any() or
                      (transf < 0).any())
@@ -74,8 +77,9 @@ def test_projgrad_nmf_fit_nn_output():
 
 def test_projgrad_nmf_fit_close():
     """Test that the fit is not too far away"""
-    assert_true(nmf.ProjectedGradientNMF(5, init='nndsvda').fit(np.abs(
-        random_state.randn(6, 5))).reconstruction_err_ < 0.05)
+    pnmf = nmf.ProjectedGradientNMF(5, init='nndsvda', random_state=0)
+    X = np.abs(random_state.randn(6, 5))
+    assert_less(pnmf.fit(X).reconstruction_err_, 0.05)
 
 
 @raises(ValueError)
@@ -87,14 +91,14 @@ def test_nls_nn_input():
 
 def test_nls_nn_output():
     """Test that NLS solver doesn't return negative values"""
-    A = np.atleast_2d(range(1, 5))
+    A = np.arange(1, 5).reshape(1, -1)
     Ap, _, _ = nmf._nls_subproblem(np.dot(A.T, -A), A.T, A, 0.001, 100)
     assert_false((Ap < 0).any())
 
 
 def test_nls_close():
     """Test that the NLS results should be close"""
-    A = np.atleast_2d(range(1, 5))
+    A = np.arange(1, 5).reshape(1, -1)
     Ap, _, _ = nmf._nls_subproblem(np.dot(A.T, A), A.T, np.zeros_like(A),
                                    0.001, 100)
     assert_true((np.abs(Ap - A) < 0.01).all())
@@ -106,7 +110,7 @@ def test_projgrad_nmf_transform():
     (transform uses scipy.optimize.nnls for now)
     """
     A = np.abs(random_state.randn(6, 5))
-    m = nmf.ProjectedGradientNMF(n_components=5, init='nndsvd')
+    m = nmf.ProjectedGradientNMF(n_components=5, init='nndsvd', random_state=0)
     transf = m.fit_transform(A)
     assert_true(np.allclose(transf, m.transform(A), atol=1e-2, rtol=0))
 
@@ -114,38 +118,42 @@ def test_projgrad_nmf_transform():
 def test_n_components_greater_n_features():
     """Smoke test for the case of more components than features."""
     A = np.abs(random_state.randn(30, 10))
-    nmf.ProjectedGradientNMF(n_components=15, sparseness='data').fit(A)
+    nmf.ProjectedGradientNMF(n_components=15, sparseness='data',
+                             random_state=0).fit(A)
 
 
 def test_projgrad_nmf_sparseness():
     """Test sparseness
 
-    Test that sparsity contraints actually increase sparseness in the
+    Test that sparsity constraints actually increase sparseness in the
     part where they are applied.
     """
-
     A = np.abs(random_state.randn(10, 10))
-    m = nmf.ProjectedGradientNMF(n_components=5).fit(A)
-    data_sp = nmf.ProjectedGradientNMF(
-        n_components=5, sparseness='data').fit(A).data_sparseness_
-    comp_sp = nmf.ProjectedGradientNMF(
-        n_components=5, sparseness='components').fit(A).comp_sparseness_
+    m = nmf.ProjectedGradientNMF(n_components=5, random_state=0).fit(A)
+    data_sp = nmf.ProjectedGradientNMF(n_components=5, sparseness='data',
+                                       random_state=0).fit(A).data_sparseness_
+    comp_sp = nmf.ProjectedGradientNMF(n_components=5, sparseness='components',
+                                       random_state=0).fit(A).comp_sparseness_
     assert_greater(data_sp, m.data_sparseness_)
     assert_greater(comp_sp, m.comp_sparseness_)
 
 
 def test_sparse_input():
     """Test that sparse matrices are accepted as input"""
-    from scipy.sparse import csr_matrix
+    from scipy.sparse import csc_matrix
 
     A = np.abs(random_state.randn(10, 10))
     A[:, 2 * np.arange(5)] = 0
     T1 = nmf.ProjectedGradientNMF(n_components=5, init='random',
                                   random_state=999).fit_transform(A)
 
-    A_sparse = csr_matrix(A)
-    T2 = nmf.ProjectedGradientNMF(n_components=5, init='random',
-                                  random_state=999).fit_transform(A_sparse)
+    A_sparse = csc_matrix(A)
+    pg_nmf = nmf.ProjectedGradientNMF(n_components=5, init='random',
+                                      random_state=999)
+    T2 = pg_nmf.fit_transform(A_sparse)
+    assert_array_almost_equal(pg_nmf.reconstruction_err_,
+                              linalg.norm(A - np.dot(T2, pg_nmf.components_),
+                                          'fro'))
     assert_array_almost_equal(T1, T2)
 
     # same with sparseness
@@ -158,6 +166,21 @@ def test_sparse_input():
         random_state=999).fit_transform(A)
 
 
+def test_sparse_transform():
+    """Test that transform works on sparse data.  Issue #2124"""
+    from scipy.sparse import csc_matrix
+
+    A = np.abs(random_state.randn(5, 4))
+    A[A > 1.0] = 0
+    A = csc_matrix(A)
+
+    model = nmf.NMF()
+    A_fit_tr = model.fit_transform(A)
+    A_tr = model.transform(A)
+    # This solver seems pretty inconsistent
+    assert_array_almost_equal(A_fit_tr, A_tr, decimal=2)
+
+
 if __name__ == '__main__':
     import nose
     nose.run(argv=['', __file__])
