@@ -9,15 +9,19 @@ from .forest import RandomForestRegressor
 from .forest import RandomTreesEmbedding
 from .forest import ExtraTreesClassifier
 from .forest import ExtraTreesRegressor
+from .weight_boosting import AdaBoostClassifier
+from .weight_boosting import AdaBoostRegressor
 from .gradient_boosting import GradientBoostingClassifier
 from .gradient_boosting import GradientBoostingRegressor
 
 from . import forest
+from . import weight_boosting
 from . import gradient_boosting
 from . import partial_dependence
 
 __all__ = ["BaseEnsemble", "RandomForestClassifier", "RandomForestRegressor",
            "RandomTreesEmbedding", "ExtraTreesClassifier",
            "ExtraTreesRegressor", "GradientBoostingClassifier",
-           "GradientBoostingRegressor", "forest", "gradient_boosting",
-           "partial_dependence"]
+           "GradientBoostingRegressor", "AdaBoostClassifier",
+           "AdaBoostRegressor", "forest", "gradient_boosting",
+           "partial_dependence", "weight_boosting"]
