@@ -2,10 +2,9 @@
 # Script to do a local install of joblib
 rm -rf tmp joblib
 mkdir -p tmp/lib/python2.7/site-packages
-ln -s tmp/lib/python2.7 tmp/lib/python2.5
 ln -s tmp/lib/python2.7 tmp/lib/python2.6
 mkdir -p tmp/bin
-export PYTHONPATH=$(pwd)/tmp/lib/python2.7/site-packages:$(pwd)/tmp/lib/python2.6/site-packages:$(pwd)/tmp/lib/python2.5/site-packages
+export PYTHONPATH=$(pwd)/tmp/lib/python2.7/site-packages:$(pwd)/tmp/lib/python2.6/site-packages
 easy_install -Zeab tmp joblib
 old_pwd=$(pwd)
 #cd /home/varoquau/dev/joblib/ 
@@ -16,3 +15,4 @@ cp -r tmp/lib/python2.7/site-packages/joblib-*.egg/joblib .
 rm -rf tmp
 # Needed to rewrite the doctests
 find joblib -name "*.py" | xargs sed -i "s/from joblib/from sklearn.externals.joblib/"
+chmod -x joblib/*.py joblib/test/*.py
