@@ -1,5 +1,5 @@
 # Author: Lars Buitinck <L.J.Buitinck@uva.nl>
-# License: BSD-style.
+# License: BSD 3 clause
 
 from random import Random
 import numpy as np
@@ -39,9 +39,9 @@ def test_dictvectorizer():
 def test_feature_selection():
     # make two feature dicts with two useful features and a bunch of useless
     # ones, in terms of chi2
-    d1 = dict([("useless%d" % i, 10) for i in xrange(20)],
+    d1 = dict([("useless%d" % i, 10) for i in range(20)],
               useful1=1, useful2=20)
-    d2 = dict([("useless%d" % i, 10) for i in xrange(20)],
+    d2 = dict([("useless%d" % i, 10) for i in range(20)],
               useful1=20, useful2=1)
 
     for indices in (True, False):
@@ -69,12 +69,20 @@ def test_one_of_k():
     assert_false("version" in names)
 
 
-def test_unseen_features():
+def test_unseen_or_no_features():
     D = [{"camelot": 0, "spamalot": 1}]
-    v = DictVectorizer(sparse=False).fit(D)
-    X = v.transform({"push the pram a lot": 2})
+    for sparse in [True, False]:
+        v = DictVectorizer(sparse=sparse).fit(D)
 
-    assert_array_equal(X, np.zeros((1, 2)))
+        X = v.transform({"push the pram a lot": 2})
+        if sparse:
+            X = X.toarray()
+        assert_array_equal(X, np.zeros((1, 2)))
+
+        X = v.transform({})
+        if sparse:
+            X = X.toarray()
+        assert_array_equal(X, np.zeros((1, 2)))
 
 
 def test_deterministic_vocabulary():
