@@ -3,28 +3,33 @@
 #          Mathieu Blondel <mathieu@mblondel.org>
 #          Lars Buitinck <L.J.Buitinck@uva.nl>
 #          Robert Layton <robertlayton@gmail.com>
+#          Jochen Wersdörfer <jochen@wersdoerfer.de>
+#          Roman Sinayev <roman.sinayev@gmail.com>
 #
-# License: BSD Style.
+# License: BSD 3 clause
 """
 The :mod:`sklearn.feature_extraction.text` submodule gathers utilities to
 build feature vectors from text documents.
 """
+from __future__ import unicode_literals
 
-from collections import Mapping
+import array
+from collections import Mapping, defaultdict
+import numbers
 from operator import itemgetter
 import re
 import unicodedata
 import warnings
-import numbers
 
 import numpy as np
 import scipy.sparse as sp
 
 from ..base import BaseEstimator, TransformerMixin
+from ..externals.six.moves import xrange
 from ..preprocessing import normalize
-from ..utils.fixes import Counter
 from .hashing import FeatureHasher
 from .stop_words import ENGLISH_STOP_WORDS
+from sklearn.externals import six
 
 __all__ = ['CountVectorizer',
            'ENGLISH_STOP_WORDS',
@@ -48,8 +53,8 @@ def strip_accents_unicode(s):
         Remove accentuated char for any unicode symbol that has a direct
         ASCII equivalent.
     """
-    return u''.join([c for c in unicodedata.normalize('NFKD', s)
-                     if not unicodedata.combining(c)])
+    return ''.join([c for c in unicodedata.normalize('NFKD', s)
+                    if not unicodedata.combining(c)])
 
 
 def strip_accents_ascii(s):
@@ -73,13 +78,13 @@ def strip_tags(s):
     For serious HTML/XML preprocessing you should rather use an external
     library such as lxml or BeautifulSoup.
     """
-    return re.compile(ur"<([^>]+)>", flags=re.UNICODE).sub(u" ", s)
+    return re.compile(r"<([^>]+)>", flags=re.UNICODE).sub(" ", s)
 
 
 def _check_stop_list(stop):
     if stop == "english":
         return ENGLISH_STOP_WORDS
-    elif isinstance(stop, str) or isinstance(stop, unicode):
+    elif isinstance(stop, six.string_types):
         raise ValueError("not a built-in stop list: %s" % stop)
     else:               # assume it's a collection
         return stop
@@ -88,7 +93,7 @@ def _check_stop_list(stop):
 class VectorizerMixin(object):
     """Provides common code for text vectorizers (tokenization logic)."""
 
-    _white_spaces = re.compile(ur"\s\s+")
+    _white_spaces = re.compile(r"\s\s+")
 
     def decode(self, doc):
         """Decode the input into a string of unicode symbols
@@ -103,7 +108,7 @@ class VectorizerMixin(object):
             doc = doc.read()
 
         if isinstance(doc, bytes):
-            doc = doc.decode(self.charset, self.charset_error)
+            doc = doc.decode(self.encoding, self.decode_error)
         return doc
 
     def _word_ngrams(self, tokens, stop_words=None):
@@ -121,14 +126,14 @@ class VectorizerMixin(object):
             for n in xrange(min_n,
                             min(max_n + 1, n_original_tokens + 1)):
                 for i in xrange(n_original_tokens - n + 1):
-                    tokens.append(u" ".join(original_tokens[i: i + n]))
+                    tokens.append(" ".join(original_tokens[i: i + n]))
 
         return tokens
 
     def _char_ngrams(self, text_document):
         """Tokenize text_document into a sequence of character n-grams"""
         # normalize white spaces
-        text_document = self._white_spaces.sub(u" ", text_document)
+        text_document = self._white_spaces.sub(" ", text_document)
 
         text_len = len(text_document)
         ngrams = []
@@ -144,12 +149,12 @@ class VectorizerMixin(object):
         Tokenize text_document into a sequence of character n-grams
         excluding any whitespace (operating only inside word boundaries)"""
         # normalize white spaces
-        text_document = self._white_spaces.sub(u" ", text_document)
+        text_document = self._white_spaces.sub(" ", text_document)
 
         min_n, max_n = self.ngram_range
         ngrams = []
         for w in text_document.split():
-            w = u' ' + w + u' '
+            w = ' ' + w + ' '
             w_len = len(w)
             for n in xrange(min_n, max_n + 1):
                 offset = 0
@@ -176,7 +181,7 @@ class VectorizerMixin(object):
         # accent stripping
         if not self.strip_accents:
             strip_accents = noop
-        elif hasattr(self.strip_accents, '__call__'):
+        elif callable(self.strip_accents):
             strip_accents = self.strip_accents
         elif self.strip_accents == 'ascii':
             strip_accents = strip_accents_ascii
@@ -204,7 +209,7 @@ class VectorizerMixin(object):
 
     def build_analyzer(self):
         """Return a callable that handles preprocessing and tokenization"""
-        if hasattr(self.analyzer, '__call__'):
+        if callable(self.analyzer):
             return self.analyzer
 
         preprocess = self.build_preprocessor()
@@ -279,13 +284,13 @@ class HashingVectorizer(BaseEstimator, VectorizerMixin):
         Otherwise the input is expected to be the sequence strings or
         bytes items are expected to be analyzed directly.
 
-    charset: string, 'utf-8' by default.
-        If bytes or files are given to analyze, this charset is used to
+    encoding : string, 'utf-8' by default.
+        If bytes or files are given to analyze, this encoding is used to
         decode.
 
-    charset_error: {'strict', 'ignore', 'replace'}
+    decode_error : {'strict', 'ignore', 'replace'}
         Instruction on what to do if a byte sequence is given to analyze that
-        contains characters not of the given `charset`. By default, it is
+        contains characters not of the given `encoding`. By default, it is
         'strict', meaning that a UnicodeDecodeError will be raised. Other
         values are 'ignore' and 'replace'.
 
@@ -334,7 +339,7 @@ class HashingVectorizer(BaseEstimator, VectorizerMixin):
         or more letters characters (punctuation is completely ignored
         and always treated as a token separator).
 
-    n_features : interger, optional, (2 ** 20) by default
+    n_features : integer, optional, (2 ** 20) by default
         The number of features (columns) in the output matrices. Small numbers
         of features are likely to cause hash collisions, but large numbers
         will cause larger coefficient dimensions in linear learners.
@@ -353,25 +358,38 @@ class HashingVectorizer(BaseEstimator, VectorizerMixin):
     non_negative : boolean, optional
         Whether output matrices should contain non-negative values only;
         effectively calls abs on the matrix prior to returning it.
-        When True, output values will be multinomially distributed.
-        When False, output values will be normally distributed (Gaussian) with
-        mean 0, assuming a good hash function.
+        When True, output values can be interpreted as frequencies.
+        When False, output values will have expected value zero.
 
     See also
     --------
     CountVectorizer, TfidfVectorizer
 
     """
-    def __init__(self, input='content', charset='utf-8',
-                 charset_error='strict', strip_accents=None,
+    def __init__(self, input='content', charset=None, encoding='utf-8',
+                 decode_error='strict', charset_error=None,
+                 strip_accents=None,
                  lowercase=True, preprocessor=None, tokenizer=None,
-                 stop_words=None, token_pattern=ur"(?u)\b\w\w+\b",
+                 stop_words=None, token_pattern=r"(?u)\b\w\w+\b",
                  ngram_range=(1, 1), analyzer='word', n_features=(2 ** 20),
                  binary=False, norm='l2', non_negative=False,
                  dtype=np.float64):
         self.input = input
-        self.charset = charset
-        self.charset_error = charset_error
+        self.encoding = encoding
+        self.decode_error = decode_error
+        if charset is not None:
+            warnings.warn("The charset parameter is deprecated as of version "
+                          "0.14 and will be removed in 0.16. Use encoding "
+                          "instead.",
+                          DeprecationWarning)
+            self.encoding = charset
+        if charset_error is not None:
+            warnings.warn("The charset_error parameter is deprecated as of "
+                          "version 0.14 and will be removed in 0.16. Use "
+                          "decode_error instead.",
+                          DeprecationWarning)
+            self.decode_error = charset_error
+
         self.strip_accents = strip_accents
         self.preprocessor = preprocessor
         self.tokenizer = tokenizer
@@ -436,6 +454,11 @@ class HashingVectorizer(BaseEstimator, VectorizerMixin):
                              non_negative=self.non_negative)
 
 
+def _document_frequency(X):
+    """Count the number of non-zero values for each feature in csc_matrix X."""
+    return np.diff(X.indptr)
+
+
 class CountVectorizer(BaseEstimator, VectorizerMixin):
     """Convert a collection of text documents to a matrix of token counts
 
@@ -444,8 +467,7 @@ class CountVectorizer(BaseEstimator, VectorizerMixin):
 
     If you do not provide an a-priori dictionary and you do not use an analyzer
     that does some kind of feature selection then the number of features will
-    be equal to the vocabulary size found by analysing the data. The default
-    analyzer does simple stop word filtering for English.
+    be equal to the vocabulary size found by analyzing the data.
 
     Parameters
     ----------
@@ -460,13 +482,13 @@ class CountVectorizer(BaseEstimator, VectorizerMixin):
         Otherwise the input is expected to be the sequence strings or
         bytes items are expected to be analyzed directly.
 
-    charset : string, 'utf-8' by default.
-        If bytes or files are given to analyze, this charset is used to
+    encoding : string, 'utf-8' by default.
+        If bytes or files are given to analyze, this encoding is used to
         decode.
 
-    charset_error : {'strict', 'ignore', 'replace'}
+    decode_error : {'strict', 'ignore', 'replace'}
         Instruction on what to do if a byte sequence is given to analyze that
-        contains characters not of the given `charset`. By default, it is
+        contains characters not of the given `encoding`. By default, it is
         'strict', meaning that a UnicodeDecodeError will be raised. Other
         values are 'ignore' and 'replace'.
 
@@ -526,7 +548,7 @@ class CountVectorizer(BaseEstimator, VectorizerMixin):
         absolute counts.
         This parameter is ignored if vocabulary is not None.
 
-    min_df : float in range [0.0, 1.0] or int, optional, 2 by default
+    min_df : float in range [0.0, 1.0] or int, optional, 1 by default
         When building the vocabulary ignore terms that have a term frequency
         strictly lower than the given threshold. This value is also called
         cut-off in the literature.
@@ -569,17 +591,30 @@ class CountVectorizer(BaseEstimator, VectorizerMixin):
     HashingVectorizer, TfidfVectorizer
     """
 
-    def __init__(self, input='content', charset='utf-8',
-                 charset_error='strict', strip_accents=None,
+    def __init__(self, input='content', encoding='utf-8', charset=None,
+                 decode_error='strict', charset_error=None,
+                 strip_accents=None,
                  lowercase=True, preprocessor=None, tokenizer=None,
-                 stop_words=None, token_pattern=ur"(?u)\b\w\w+\b",
-                 ngram_range=(1, 1),
-                 min_n=None, max_n=None, analyzer='word',
-                 max_df=1.0, min_df=2, max_features=None,
-                 vocabulary=None, binary=False, dtype=long):
+                 stop_words=None, token_pattern=r"(?u)\b\w\w+\b",
+                 ngram_range=(1, 1), analyzer='word',
+                 max_df=1.0, min_df=1, max_features=None,
+                 vocabulary=None, binary=False, dtype=np.int64):
         self.input = input
-        self.charset = charset
-        self.charset_error = charset_error
+        self.encoding = encoding
+        self.decode_error = decode_error
+        if charset is not None:
+            warnings.warn("The charset parameter is deprecated as of version "
+                          "0.14 and will be removed in 0.16. Use encoding "
+                          "instead.",
+                          DeprecationWarning)
+            self.encoding = charset
+        if charset_error is not None:
+            warnings.warn("The charset_error parameter is deprecated as of "
+                          "version 0.14 and will be removed in 0.16. Use "
+                          "decode_error instead.",
+                          DeprecationWarning)
+            self.decode_error = charset_error
+
         self.strip_accents = strip_accents
         self.preprocessor = preprocessor
         self.tokenizer = tokenizer
@@ -589,16 +624,15 @@ class CountVectorizer(BaseEstimator, VectorizerMixin):
         self.stop_words = stop_words
         self.max_df = max_df
         self.min_df = min_df
+        if max_df < 0 or min_df < 0:
+            raise ValueError("negative value for max_df of min_df")
         self.max_features = max_features
-        if not (max_n is None) or not (min_n is None):
-            warnings.warn('Parameters max_n and min_n are deprecated. Use '
-                          'ngram_range instead. This will be removed in 0.14.',
-                          DeprecationWarning, stacklevel=2)
-            if min_n is None:
-                min_n = 1
-            if max_n is None:
-                max_n = min_n
-            ngram_range = (min_n, max_n)
+        if max_features is not None:
+            if (not isinstance(max_features, numbers.Integral) or
+                    max_features <= 0):
+                raise ValueError(
+                    "max_features=%r, neither a positive integer nor None"
+                    % max_features)
         self.ngram_range = ngram_range
         if vocabulary is not None:
             if not isinstance(vocabulary, Mapping):
@@ -606,34 +640,106 @@ class CountVectorizer(BaseEstimator, VectorizerMixin):
             if not vocabulary:
                 raise ValueError("empty vocabulary passed to fit")
             self.fixed_vocabulary = True
-            self.vocabulary_ = vocabulary
+            self.vocabulary_ = dict(vocabulary)
         else:
             self.fixed_vocabulary = False
         self.binary = binary
         self.dtype = dtype
 
-    def _term_count_dicts_to_matrix(self, term_count_dicts):
-        i_indices = []
-        j_indices = []
-        values = []
-        vocabulary = self.vocabulary_
+    def _sort_features(self, cscmatrix, vocabulary):
+        """Sort features by name
 
-        for i, term_count_dict in enumerate(term_count_dicts):
-            for term, count in term_count_dict.iteritems():
-                j = vocabulary.get(term)
-                if j is not None:
-                    i_indices.append(i)
-                    j_indices.append(j)
-                    values.append(count)
-            # free memory as we go
-            term_count_dict.clear()
+        Returns a reordered matrix and modifies the vocabulary in place
+        """
+        sorted_features = sorted(six.iteritems(vocabulary))
+        map_index = np.empty(len(sorted_features), dtype=np.int32)
+        for new_val, (term, old_val) in enumerate(sorted_features):
+            map_index[new_val] = old_val
+            vocabulary[term] = new_val
+        return cscmatrix[:, map_index]
 
-        shape = (i + 1, max(vocabulary.itervalues()) + 1)
-        spmatrix = sp.coo_matrix((values, (i_indices, j_indices)),
-                                 shape=shape, dtype=self.dtype)
-        if self.binary:
-            spmatrix.data.fill(1)
-        return spmatrix
+    def _limit_features(self, cscmatrix, vocabulary, high=None, low=None,
+                        limit=None):
+        """Remove too rare or too common features.
+
+        Prune features that are non zero in more samples than high or less
+        documents than low, modifying the vocabulary, and restricting it to
+        at most the limit most frequent.
+
+        This does not prune samples with zero features.
+        """
+        if high is None and low is None and limit is None:
+            return cscmatrix, set()
+
+        # Calculate a mask based on document frequencies
+        dfs = _document_frequency(cscmatrix)
+        mask = np.ones(len(dfs), dtype=bool)
+        if high is not None:
+            mask &= dfs <= high
+        if low is not None:
+            mask &= dfs >= low
+        if limit is not None and mask.sum() > limit:
+            # backward compatibility requires us to keep lower indices in ties!
+            # (and hence to reverse the sort by negating dfs)
+            mask_inds = (-dfs[mask]).argsort()[:limit]
+            new_mask = np.zeros(len(dfs), dtype=bool)
+            new_mask[np.where(mask)[0][mask_inds]] = True
+            mask = new_mask
+
+        new_indices = np.cumsum(mask) - 1  # maps old indices to new
+        removed_terms = set()
+        for term, old_index in list(six.iteritems(vocabulary)):
+            if mask[old_index]:
+                vocabulary[term] = new_indices[old_index]
+            else:
+                del vocabulary[term]
+                removed_terms.add(term)
+        kept_indices = np.where(mask)[0]
+        return cscmatrix[:, kept_indices], removed_terms
+
+    def _count_vocab(self, raw_documents, fixed_vocab):
+        """Create sparse feature matrix, and vocabulary where fixed_vocab=False
+        """
+        if fixed_vocab:
+            vocabulary = self.vocabulary_
+        else:
+            # Add a new value when a new vocabulary item is seen
+            vocabulary = defaultdict(None)
+            vocabulary.default_factory = vocabulary.__len__
+
+        analyze = self.build_analyzer()
+        j_indices = _make_int_array()
+        indptr = _make_int_array()
+        indptr.append(0)
+        for doc in raw_documents:
+            for feature in analyze(doc):
+                try:
+                    j_indices.append(vocabulary[feature])
+                except KeyError:
+                    # Ignore out-of-vocabulary items for fixed_vocab=True
+                    continue
+            indptr.append(len(j_indices))
+
+        if not fixed_vocab:
+            # disable defaultdict behaviour
+            vocabulary = dict(vocabulary)
+            if not vocabulary:
+                raise ValueError("empty vocabulary; perhaps the documents only"
+                                 " contain stop words")
+
+        # some Python/Scipy versions won't accept an array.array:
+        if j_indices:
+            j_indices = np.frombuffer(j_indices, dtype=np.intc)
+        else:
+            j_indices = np.array([], dtype=np.int32)
+        indptr = np.frombuffer(indptr, dtype=np.intc)
+        values = np.ones(len(j_indices))
+
+        X = sp.csr_matrix((values, j_indices, indptr),
+                          shape=(len(indptr) - 1, len(vocabulary)),
+                          dtype=self.dtype)
+        X.sum_duplicates()
+        return vocabulary, X
 
     def fit(self, raw_documents, y=None):
         """Learn a vocabulary dictionary of all tokens in the raw documents.
@@ -664,88 +770,40 @@ class CountVectorizer(BaseEstimator, VectorizerMixin):
         -------
         vectors : array, [n_samples, n_features]
         """
-        if self.fixed_vocabulary:
-            # No need to fit anything, directly perform the transformation.
-            # We intentionally don't call the transform method to make it
-            # fit_transform overridable without unwanted side effects in
-            # TfidfVectorizer
-            analyze = self.build_analyzer()
-            term_counts_per_doc = (Counter(analyze(doc))
-                                   for doc in raw_documents)
-            return self._term_count_dicts_to_matrix(term_counts_per_doc)
-
-        self.vocabulary_ = {}
-        # result of document conversion to term count dicts
-        term_counts_per_doc = []
-        term_counts = Counter()
-
-        # term counts across entire corpus (count each term maximum once per
-        # document)
-        document_counts = Counter()
-
-        analyze = self.build_analyzer()
-
-        # TODO: parallelize the following loop with joblib?
-        # (see XXX up ahead)
-        for doc in raw_documents:
-            term_count_current = Counter(analyze(doc))
-            term_counts.update(term_count_current)
-
-            document_counts.update(term_count_current.iterkeys())
-
-            term_counts_per_doc.append(term_count_current)
-
-        n_doc = len(term_counts_per_doc)
-        max_features = self.max_features
+        # We intentionally don't call the transform method to make
+        # fit_transform overridable without unwanted side effects in
+        # TfidfVectorizer.
         max_df = self.max_df
         min_df = self.min_df
+        max_features = self.max_features
 
-        max_doc_count = (max_df
-                         if isinstance(max_df, numbers.Integral)
-                         else max_df * n_doc)
-        min_doc_count = (min_df
-                         if isinstance(min_df, numbers.Integral)
-                         else min_df * n_doc)
+        vocabulary, X = self._count_vocab(raw_documents, self.fixed_vocabulary)
+        X = X.tocsc()
 
-        # filter out stop words: terms that occur in almost all documents
-        if max_doc_count < n_doc or min_doc_count > 1:
-            stop_words = set(t for t, dc in document_counts.iteritems()
-                             if dc > max_doc_count or dc < min_doc_count)
-        else:
-            stop_words = set()
+        if self.binary:
+            X.data.fill(1)
 
-        # list the terms that should be part of the vocabulary
-        if max_features is None:
-            terms = set(term_counts) - stop_words
-        else:
-            # extract the most frequent terms for the vocabulary
-            terms = set()
-            for t, tc in term_counts.most_common():
-                if t not in stop_words:
-                    terms.add(t)
-                if len(terms) >= max_features:
-                    break
+        if not self.fixed_vocabulary:
+            X = self._sort_features(X, vocabulary)
 
-        # store the learned stop words to make it easier to debug the value of
-        # max_df
-        self.stop_words_ = stop_words
+            n_doc = X.shape[0]
+            max_doc_count = (max_df
+                             if isinstance(max_df, numbers.Integral)
+                             else int(round(max_df * n_doc)))
+            min_doc_count = (min_df
+                             if isinstance(min_df, numbers.Integral)
+                             else int(round(min_df * n_doc)))
+            if max_doc_count < min_doc_count:
+                raise ValueError(
+                    "max_df corresponds to < documents than min_df")
+            X, self.stop_words_ = self._limit_features(X, vocabulary,
+                                                       max_doc_count,
+                                                       min_doc_count,
+                                                       max_features)
 
-        # store map from term name to feature integer index: we sort the term
-        # to have reproducible outcome for the vocabulary structure: otherwise
-        # the mapping from feature name to indices might depend on the memory
-        # layout of the machine. Furthermore sorted terms might make it
-        # possible to perform binary search in the feature names array.
-        vocab = dict(((t, i) for i, t in enumerate(sorted(terms))))
-        if not vocab:
-            raise ValueError("empty vocabulary; training set may have"
-                             " contained only stop words or min_df (resp. "
-                             "max_df) may be too high (resp. too low).")
-        self.vocabulary_ = vocab
+            self.vocabulary_ = vocabulary
 
-        # the term_counts and document_counts might be useful statistics, are
-        # we really sure want we want to drop them? They take some memory but
-        # can be useful for corpus introspection
-        return self._term_count_dicts_to_matrix(term_counts_per_doc)
+        return X
 
     def transform(self, raw_documents):
         """Extract token counts out of raw text documents using the vocabulary
@@ -763,14 +821,11 @@ class CountVectorizer(BaseEstimator, VectorizerMixin):
         if not hasattr(self, 'vocabulary_') or len(self.vocabulary_) == 0:
             raise ValueError("Vocabulary wasn't fitted or is empty!")
 
-        # raw_documents can be an iterable so we don't know its size in
-        # advance
-
-        # XXX @larsmans tried to parallelize the following loop with joblib.
-        # The result was some 20% slower than the serial version.
-        analyze = self.build_analyzer()
-        term_counts_per_doc = (Counter(analyze(doc)) for doc in raw_documents)
-        return self._term_count_dicts_to_matrix(term_counts_per_doc)
+        # use the same matrix-building strategy as fit_transform
+        _, X = self._count_vocab(raw_documents, fixed_vocab=True)
+        if self.binary:
+            X.data.fill(1)
+        return X
 
     def inverse_transform(self, X):
         """Return terms per document with nonzero entries in X.
@@ -784,27 +839,28 @@ class CountVectorizer(BaseEstimator, VectorizerMixin):
         X_inv : list of arrays, len = n_samples
             List of arrays of terms.
         """
-        if sp.isspmatrix_coo(X):  # COO matrix is not indexable
+        if sp.issparse(X):
+            # We need CSR format for fast row manipulations.
             X = X.tocsr()
-        elif not sp.issparse(X):
+        else:
             # We need to convert X to a matrix, so that the indexing
             # returns 2D objects
             X = np.asmatrix(X)
         n_samples = X.shape[0]
 
-        terms = np.array(self.vocabulary_.keys())
-        indices = np.array(self.vocabulary_.values())
+        terms = np.array(list(self.vocabulary_.keys()))
+        indices = np.array(list(self.vocabulary_.values()))
         inverse_vocabulary = terms[np.argsort(indices)]
 
         return [inverse_vocabulary[X[i, :].nonzero()[1]].ravel()
-                for i in xrange(n_samples)]
+                for i in range(n_samples)]
 
     def get_feature_names(self):
         """Array mapping from feature integer indices to feature name"""
         if not hasattr(self, 'vocabulary_') or len(self.vocabulary_) == 0:
             raise ValueError("Vocabulary wasn't fitted or is empty!")
 
-        return [t for t, i in sorted(self.vocabulary_.iteritems(),
+        return [t for t, i in sorted(six.iteritems(self.vocabulary_),
                                      key=itemgetter(1))]
 
     @property
@@ -815,6 +871,11 @@ class CountVectorizer(BaseEstimator, VectorizerMixin):
         return self.stop_words_
 
 
+def _make_int_array():
+    """Construct an array.array of a type suitable for scipy.sparse indices."""
+    return array.array(str("i"))
+
+
 class TfidfTransformer(BaseEstimator, TransformerMixin):
     """Transform a count matrix to a normalized tf or tf–idf representation
 
@@ -877,15 +938,11 @@ class TfidfTransformer(BaseEstimator, TransformerMixin):
         X : sparse matrix, [n_samples, n_features]
             a matrix of term/token counts
         """
+        if not sp.isspmatrix_csc(X):
+            X = sp.csc_matrix(X)
         if self.use_idf:
-            if not hasattr(X, 'nonzero'):
-                X = sp.csr_matrix(X)
-
             n_samples, n_features = X.shape
-            df = np.bincount(X.nonzero()[1])
-            if df.shape[0] < n_features:
-                # bincount might return fewer bins than there are features
-                df = np.concatenate([df, np.zeros(n_features - df.shape[0])])
+            df = _document_frequency(X)
 
             # perform idf smoothing if required
             df += int(self.smooth_idf)
@@ -893,9 +950,8 @@ class TfidfTransformer(BaseEstimator, TransformerMixin):
 
             # avoid division by zeros for features that occur in all documents
             idf = np.log(float(n_samples) / df) + 1.0
-            idf_diag = sp.lil_matrix((n_features, n_features))
-            idf_diag.setdiag(idf)
-            self._idf_diag = sp.csc_matrix(idf_diag)
+            self._idf_diag = sp.spdiags(idf,
+                                        diags=0, m=n_features, n=n_features)
 
         return self
 
@@ -966,13 +1022,13 @@ class TfidfVectorizer(CountVectorizer):
         Otherwise the input is expected to be the sequence strings or
         bytes items are expected to be analyzed directly.
 
-    charset : string, 'utf-8' by default.
-        If bytes or files are given to analyze, this charset is used to
+    encoding : string, 'utf-8' by default.
+        If bytes or files are given to analyze, this encoding is used to
         decode.
 
-    charset_error : {'strict', 'ignore', 'replace'}
+    decode_error : {'strict', 'ignore', 'replace'}
         Instruction on what to do if a byte sequence is given to analyze that
-        contains characters not of the given `charset`. By default, it is
+        contains characters not of the given `encoding`. By default, it is
         'strict', meaning that a UnicodeDecodeError will be raised. Other
         values are 'ignore' and 'replace'.
 
@@ -997,7 +1053,6 @@ class TfidfVectorizer(CountVectorizer):
         Override the string tokenization step while preserving the
         preprocessing and n-grams generation steps.
 
-
     ngram_range : tuple (min_n, max_n)
         The lower and upper boundary of the range of n-values for different
         n-grams to be extracted. All values of n such that min_n <= n <= max_n
@@ -1031,7 +1086,7 @@ class TfidfVectorizer(CountVectorizer):
         absolute counts.
         This parameter is ignored if vocabulary is not None.
 
-    min_df : float in range [0.0, 1.0] or int, optional, 2 by default
+    min_df : float in range [0.0, 1.0] or int, optional, 1 by default
         When building the vocabulary ignore terms that have a term frequency
         strictly lower than the given threshold.
         This value is also called cut-off in the literature.
@@ -1084,20 +1139,23 @@ class TfidfVectorizer(CountVectorizer):
 
     """
 
-    def __init__(self, input='content', charset='utf-8',
-                 charset_error='strict', strip_accents=None, lowercase=True,
+    def __init__(self, input='content', encoding='utf-8', charset=None,
+                 decode_error='strict', charset_error=None,
+                 strip_accents=None, lowercase=True,
                  preprocessor=None, tokenizer=None, analyzer='word',
-                 stop_words=None, token_pattern=ur"(?u)\b\w\w+\b", min_n=None,
-                 max_n=None, ngram_range=(1, 1), max_df=1.0, min_df=2,
-                 max_features=None, vocabulary=None, binary=False, dtype=long,
-                 norm='l2', use_idf=True, smooth_idf=True, sublinear_tf=False):
+                 stop_words=None, token_pattern=r"(?u)\b\w\w+\b",
+                 ngram_range=(1, 1), max_df=1.0, min_df=1,
+                 max_features=None, vocabulary=None, binary=False,
+                 dtype=np.int64, norm='l2', use_idf=True, smooth_idf=True,
+                 sublinear_tf=False):
 
         super(TfidfVectorizer, self).__init__(
             input=input, charset=charset, charset_error=charset_error,
+            encoding=encoding, decode_error=decode_error,
             strip_accents=strip_accents, lowercase=lowercase,
             preprocessor=preprocessor, tokenizer=tokenizer, analyzer=analyzer,
-            stop_words=stop_words, token_pattern=token_pattern, min_n=min_n,
-            max_n=max_n, ngram_range=ngram_range, max_df=max_df, min_df=min_df,
+            stop_words=stop_words, token_pattern=token_pattern,
+            ngram_range=ngram_range, max_df=max_df, min_df=min_df,
             max_features=max_features, vocabulary=vocabulary, binary=False,
             dtype=dtype)
 
