@@ -2,6 +2,8 @@
 Testing Recursive feature elimination
 """
 
+import warnings
+
 import numpy as np
 from numpy.testing import assert_array_almost_equal, assert_array_equal
 from nose.tools import assert_equal
@@ -12,7 +14,7 @@ from sklearn.datasets import load_iris
 from sklearn.metrics import zero_one_loss
 from sklearn.svm import SVC
 from sklearn.utils import check_random_state
-
+from sklearn.metrics.scorer import SCORERS
 
 def test_rfe_set_params():
     generator = check_random_state(0)
@@ -70,7 +72,7 @@ def test_rfecv():
     rfecv = RFECV(estimator=SVC(kernel="linear"), step=1, cv=3)
     rfecv.fit(X, y)
     # non-regression test for missing worst feature:
-    assert_equal(len(rfecv.cv_scores_), X.shape[1])
+    assert_equal(len(rfecv.grid_scores_), X.shape[1])
     assert_equal(len(rfecv.ranking_), X.shape[1])
     X_r = rfecv.transform(X)
 
@@ -87,6 +89,17 @@ def test_rfecv():
     # Test using a customized loss function
     rfecv = RFECV(estimator=SVC(kernel="linear"), step=1, cv=3,
                   loss_func=zero_one_loss)
+    with warnings.catch_warnings(record=True):
+        rfecv.fit(X, y)
+    X_r = rfecv.transform(X)
+
+    assert_equal(X_r.shape, iris.data.shape)
+    assert_array_almost_equal(X_r[:10], iris.data[:10])
+
+    # Test using a scorer
+    scorer = SCORERS['accuracy']
+    rfecv = RFECV(estimator=SVC(kernel="linear"), step=1, cv=3,
+                  scoring=scorer)
     rfecv.fit(X, y)
     X_r = rfecv.transform(X)
 
