@@ -1,15 +1,18 @@
 # Authors: Fabian Pedregosa <fabian@fseoane.net>
 #          Alexandre Gramfort <alexandre.gramfort@inria.fr>
 #          Nelle Varoquaux <nelle.varoquaux@gmail.com>
-# License: BSD Style.
+# License: BSD 3 clause
 
 import numpy as np
 from scipy import interpolate
 from .base import BaseEstimator, TransformerMixin, RegressorMixin
 from .utils import as_float_array, check_arrays
+from ._isotonic import _isotonic_regression
+import warnings
 
 
-def isotonic_regression(y, weight=None, y_min=None, y_max=None):
+def isotonic_regression(y, sample_weight=None, y_min=None, y_max=None,
+                        weight=None, increasing=True):
     """Solve the isotonic regression model::
 
         min sum w[i] (y[i] - y_[i]) ** 2
@@ -26,7 +29,7 @@ def isotonic_regression(y, weight=None, y_min=None, y_max=None):
     y : iterable of floating-point values
         The data.
 
-    weight : iterable of floating-point values, optional, default: None
+    sample_weight : iterable of floating-point values, optional, default: None
         Weights on each point of the regression.
         If None, weight is set to 1 (equal weights).
 
@@ -36,6 +39,10 @@ def isotonic_regression(y, weight=None, y_min=None, y_max=None):
     y_max : optional, default: None
         If not None, set the highest value of the fit to y_max.
 
+    increasing : boolean, optional, default: True
+        Whether to compute ``y_`` is increasing (if set to True) or decreasing
+        (if set to False)
+
     Returns
     -------
     `y_` : list of floating-point values
@@ -46,55 +53,39 @@ def isotonic_regression(y, weight=None, y_min=None, y_max=None):
     "Active set algorithms for isotonic regression; A unifying framework"
     by Michael J. Best and Nilotpal Chakravarti, section 3.
     """
-    if weight is None:
-        weight = np.ones(len(y), dtype=y.dtype)
+    if weight is not None:
+        warnings.warn("'weight' was renamed to 'sample_weight' and will "
+                      "be removed in 0.16.",
+                      DeprecationWarning)
+        sample_weight = weight
+
+    y = np.asarray(y, dtype=np.float)
+    if sample_weight is None:
+        sample_weight = np.ones(len(y), dtype=y.dtype)
+    else:
+        sample_weight = np.asarray(sample_weight, dtype=np.float)
+    if not increasing:
+        y = y[::-1]
+        sample_weight = sample_weight[::-1]
+
     if y_min is not None or y_max is not None:
         y = np.copy(y)
-        weight = np.copy(weight)
-        C = np.dot(weight, y * y) * 10  # upper bound on the cost function
+        sample_weight = np.copy(sample_weight)
+        # upper bound on the cost function
+        C = np.dot(sample_weight, y * y) * 10
         if y_min is not None:
             y[0] = y_min
-            weight[0] = C
+            sample_weight[0] = C
         if y_max is not None:
             y[-1] = y_max
-            weight[-1] = C
-
-    active_set = [(weight[i] * y[i], weight[i], [i, ])
-                  for i in range(len(y))]
-    current = 0
-
-    while current < len(active_set) - 1:
-        value0, value1, value2 = 0, 0, np.inf
-        weight0, weight1, weight2 = 1, 1, 1
-        while value0 * weight1 <= value1 * weight0 and \
-                current < len(active_set) - 1:
-            value0, weight0, idx0 = active_set[current]
-            value1, weight1, idx1 = active_set[current + 1]
-            if value0 * weight1 <= value1 * weight0:
-                current += 1
-
-        if current == len(active_set) - 1:
-            break
-
-        # merge two groups
-        value0, weight0, idx0 = active_set.pop(current)
-        value1, weight1, idx1 = active_set.pop(current)
-        active_set.insert(current,
-                          (value0 + value1,
-                           weight0 + weight1, idx0 + idx1))
-        while value2 * weight0 > value0 * weight2 and current > 0:
-            value0, weight0, idx0 = active_set[current]
-            value2, weight2, idx2 = active_set[current - 1]
-            if weight0 * value2 >= weight2 * value0:
-                active_set.pop(current)
-                active_set[current - 1] = (value0 + value2, weight0 + weight2,
-                                           idx0 + idx2)
-                current -= 1
+            sample_weight[-1] = C
 
     solution = np.empty(len(y))
-    for value, weight, idx in active_set:
-        solution[idx] = value / weight
-    return solution
+    y_ = _isotonic_regression(y, sample_weight, solution)
+    if increasing:
+        return y_
+    else:
+        return y_[::-1]
 
 
 class IsotonicRegression(BaseEstimator, TransformerMixin, RegressorMixin):
@@ -137,15 +128,16 @@ class IsotonicRegression(BaseEstimator, TransformerMixin, RegressorMixin):
     Mathematics of Operations Research
     Vol. 14, No. 2 (May, 1989), pp. 303-308
     """
-    def __init__(self, y_min=None, y_max=None):
+    def __init__(self, y_min=None, y_max=None, increasing=True):
         self.y_min = y_min
         self.y_max = y_max
+        self.increasing = increasing
 
-    def _check_fit_data(self, X, y, weight=None):
+    def _check_fit_data(self, X, y, sample_weight=None):
         if len(X.shape) != 1:
             raise ValueError("X should be a vector")
 
-    def fit(self, X, y, weight=None):
+    def fit(self, X, y, sample_weight=None, weight=None):
         """Fit the model using X, y as training data.
 
         Parameters
@@ -156,7 +148,7 @@ class IsotonicRegression(BaseEstimator, TransformerMixin, RegressorMixin):
         y : array-like, shape=(n_samples,)
             Training target.
 
-        weight : array-like, shape=(n_samples,), optional, default: None
+        sample_weight : array-like, shape=(n_samples,), optional, default: None
             Weights. If set to None, all weights will be set to 1 (equal
             weights).
 
@@ -170,12 +162,20 @@ class IsotonicRegression(BaseEstimator, TransformerMixin, RegressorMixin):
         X is stored for future use, as `transform` needs X to interpolate
         new input data.
         """
-        X, y, weight = check_arrays(X, y, weight, sparse_format='dense')
+        if weight is not None:
+            warnings.warn("'weight' was renamed to 'sample_weight' and will "
+                          "be removed in 0.16.",
+                          DeprecationWarning)
+            sample_weight = weight
+
+        X, y, sample_weight = check_arrays(X, y, sample_weight,
+                                           sparse_format='dense')
         y = as_float_array(y)
-        self._check_fit_data(X, y, weight)
+        self._check_fit_data(X, y, sample_weight)
         order = np.argsort(X)
         self.X_ = as_float_array(X[order], copy=False)
-        self.y_ = isotonic_regression(y[order], weight, self.y_min, self.y_max)
+        self.y_ = isotonic_regression(y[order], sample_weight, self.y_min,
+                                      self.y_max, increasing=self.increasing)
         return self
 
     def transform(self, T):
@@ -199,7 +199,7 @@ class IsotonicRegression(BaseEstimator, TransformerMixin, RegressorMixin):
                                  bounds_error=True)
         return f(T)
 
-    def fit_transform(self, X, y, weight=None):
+    def fit_transform(self, X, y, sample_weight=None, weight=None):
         """Fit model and transform y by linear interpolation.
 
         Parameters
@@ -210,7 +210,7 @@ class IsotonicRegression(BaseEstimator, TransformerMixin, RegressorMixin):
         y : array-like, shape=(n_samples,)
             Training target.
 
-        weight : array-like, shape=(n_samples,), optional, default: None
+        sample_weight : array-like, shape=(n_samples,), optional, default: None
             Weights. If set to None, all weights will be equal to 1 (equal
             weights).
 
@@ -225,13 +225,21 @@ class IsotonicRegression(BaseEstimator, TransformerMixin, RegressorMixin):
         for future use, as `transform` needs X to interpolate new input
         data.
         """
-        X, y, weight = check_arrays(X, y, weight, sparse_format='dense')
+        if weight is not None:
+            warnings.warn("'weight' was renamed to 'sample_weight' and will "
+                          "be removed in 0.16.",
+                          DeprecationWarning)
+            sample_weight = weight
+
+        X, y, sample_weight = check_arrays(X, y, sample_weight,
+                                           sparse_format='dense')
         y = as_float_array(y)
-        self._check_fit_data(X, y, weight)
+        self._check_fit_data(X, y, sample_weight)
         order = np.lexsort((y, X))
         order_inv = np.argsort(order)
         self.X_ = as_float_array(X[order], copy=False)
-        self.y_ = isotonic_regression(y[order], weight, self.y_min, self.y_max)
+        self.y_ = isotonic_regression(y[order], sample_weight, self.y_min,
+                                      self.y_max, increasing=self.increasing)
         return self.y_[order_inv]
 
     def predict(self, T):
