@@ -10,7 +10,7 @@ Generalized Linear models.
 #         Mathieu Blondel <mathieu@mblondel.org>
 #         Lars Buitinck <L.J.Buitinck@uva.nl>
 #
-# License: BSD Style.
+# License: BSD 3 clause
 
 from abc import ABCMeta, abstractmethod
 import numbers
@@ -18,7 +18,9 @@ import numbers
 import numpy as np
 import scipy.sparse as sp
 from scipy import linalg
+from scipy import sparse
 
+from ..externals import six
 from ..externals.joblib import Parallel, delayed
 from ..base import BaseEstimator, ClassifierMixin, RegressorMixin
 from ..utils import as_float_array, atleast2d_or_csr, safe_asarray
@@ -44,8 +46,10 @@ def sparse_center_data(X, y, fit_intercept, normalize=False):
     axis 0. Be aware that X will not be centered since it would break
     the sparsity, but will be normalized if asked so.
     """
-    X_data = np.array(X.data, np.float64)
+    X = X.astype(np.float64)
+
     if fit_intercept:
+        X_data = X.data
         # copy if 'normalize' is True or X is not a csc matrix
         X = sp.csc_matrix(X, copy=normalize)
         X_mean, X_std = csc_mean_variance_axis0(X)
@@ -64,8 +68,7 @@ def sparse_center_data(X, y, fit_intercept, normalize=False):
         X_std = np.ones(X.shape[1])
         y_mean = 0. if y.ndim == 1 else np.zeros(y.shape[1], dtype=X.dtype)
 
-    X_data = np.array(X.data, np.float64)
-    return X_data, y, X_mean, y_mean, X_std
+    return X, y, X_mean, y_mean, X_std
 
 
 def center_data(X, y, fit_intercept, normalize=False, copy=True,
@@ -116,39 +119,41 @@ def center_data(X, y, fit_intercept, normalize=False, copy=True,
     return X, y, X_mean, y_mean, X_std
 
 
-class LinearModel(BaseEstimator):
+class LinearModel(six.with_metaclass(ABCMeta, BaseEstimator)):
     """Base class for Linear Models"""
-    __metaclass__ = ABCMeta
 
     @abstractmethod
     def fit(self, X, y):
         """Fit model."""
 
     def decision_function(self, X):
-        """Decision function of the linear model
+        """Decision function of the linear model.
 
         Parameters
         ----------
-        X : numpy array of shape [n_samples, n_features]
+        X : {array-like, sparse matrix}, shape = (n_samples, n_features)
+            Samples.
 
         Returns
         -------
-        C : array, shape = [n_samples]
+        C : array, shape = (n_samples,)
             Returns predicted values.
         """
         X = safe_asarray(X)
-        return safe_sparse_dot(X, self.coef_.T) + self.intercept_
+        return safe_sparse_dot(X, self.coef_.T,
+                               dense_output=True) + self.intercept_
 
     def predict(self, X):
         """Predict using the linear model
 
         Parameters
         ----------
-        X : numpy array of shape [n_samples, n_features]
+        X : {array-like, sparse matrix}, shape = (n_samples, n_features)
+            Samples.
 
         Returns
         -------
-        C : array, shape = [n_samples]
+        C : array, shape = (n_samples,)
             Returns predicted values.
         """
         return self.decision_function(X)
@@ -181,14 +186,15 @@ class LinearClassifierMixin(ClassifierMixin):
 
         Parameters
         ----------
-        X : {array-like, sparse matrix}, shape = [n_samples, n_features]
+        X : {array-like, sparse matrix}, shape = (n_samples, n_features)
             Samples.
 
         Returns
         -------
-        array, shape = [n_samples] if n_classes == 2 else [n_samples,n_classes]
+        array, shape=(n_samples,) if n_classes == 2 else (n_samples, n_classes)
             Confidence scores per (sample, class) combination. In the binary
-            case, confidence score for the "positive" class.
+            case, confidence score for self.classes_[1] where >0 means this
+            class would be predicted.
         """
         X = atleast2d_or_csr(X)
 
@@ -197,7 +203,8 @@ class LinearClassifierMixin(ClassifierMixin):
             raise ValueError("X has %d features per sample; expecting %d"
                              % (X.shape[1], n_features))
 
-        scores = safe_sparse_dot(X, self.coef_.T) + self.intercept_
+        scores = safe_sparse_dot(X, self.coef_.T,
+                                 dense_output=True) + self.intercept_
         return scores.ravel() if scores.shape[1] == 1 else scores
 
     def predict(self, X):
@@ -220,6 +227,79 @@ class LinearClassifierMixin(ClassifierMixin):
             indices = scores.argmax(axis=1)
         return self.classes_[indices]
 
+    def _predict_proba_lr(self, X):
+        """Probability estimation for OvR logistic regression.
+
+        Positive class probabilities are computed as
+        1. / (1. + np.exp(-self.decision_function(X)));
+        multiclass is handled by normalizing that over all classes.
+        """
+        prob = self.decision_function(X)
+        prob *= -1
+        np.exp(prob, prob)
+        prob += 1
+        np.reciprocal(prob, prob)
+        if len(prob.shape) == 1:
+            return np.vstack([1 - prob, prob]).T
+        else:
+            # OvR normalization, like LibLinear's predict_probability
+            prob /= prob.sum(axis=1).reshape((prob.shape[0], -1))
+            return prob
+
+
+class SparseCoefMixin(object):
+    """Mixin for converting coef_ to and from CSR format.
+
+    L1-regularizing estimators should inherit this.
+    """
+
+    def densify(self):
+        """Convert coefficient matrix to dense array format.
+
+        Converts the ``coef_`` member (back) to a numpy.ndarray. This is the
+        default format of ``coef_`` and is required for fitting, so calling
+        this method is only required on models that have previously been
+        sparsified; otherwise, it is a no-op.
+
+        Returns
+        -------
+        self: estimator
+        """
+        if not hasattr(self, "coef_"):
+            raise ValueError("Estimator must be fitted before densifying.")
+        if sp.issparse(self.coef_):
+            self.coef_ = self.coef_.toarray()
+        return self
+
+    def sparsify(self):
+        """Convert coefficient matrix to sparse format.
+
+        Converts the ``coef_`` member to a scipy.sparse matrix, which for
+        L1-regularized models can be much more memory- and storage-efficient
+        than the usual numpy.ndarray representation.
+
+        The ``intercept_`` member is not converted.
+
+        Notes
+        -----
+        For non-sparse models, i.e. when there are not many zeros in ``coef_``,
+        this may actually *increase* memory usage, so use this method with
+        care. A rule of thumb is that the number of zero elements, which can
+        be computed with ``(coef_ == 0).sum()``, must be more than 50% for this
+        to provide significant benefits.
+
+        After calling this method, further fitting with the partial_fit
+        method (if any) will not work until you call densify.
+
+        Returns
+        -------
+        self: estimator
+        """
+        if not hasattr(self, "coef_"):
+            raise ValueError("Estimator must be fitted before sparsifying.")
+        self.coef_ = sp.csr_matrix(self.coef_)
+        return self
+
 
 class LinearRegression(LinearModel, RegressorMixin):
     """
@@ -228,7 +308,7 @@ class LinearRegression(LinearModel, RegressorMixin):
     Parameters
     ----------
     fit_intercept : boolean, optional
-        wether to calculate the intercept for this model. If set
+        whether to calculate the intercept for this model. If set
         to false, no intercept will be used in calculations
         (e.g. data is expected to be already centered).
 
@@ -241,7 +321,7 @@ class LinearRegression(LinearModel, RegressorMixin):
         Estimated coefficients for the linear regression problem.
         If multiple targets are passed during the fit (y 2D), this
         is a 2D array of shape (n_targets, n_features), while if only
-        one target is passed, this is a 1D array of lenght n_features.
+        one target is passed, this is a 1D array of length n_features.
 
     `intercept_` : array
         Independent term in the linear model.
@@ -249,7 +329,7 @@ class LinearRegression(LinearModel, RegressorMixin):
     Notes
     -----
     From the implementation point of view, this is just plain Ordinary
-    Least Squares (numpy.linalg.lstsq) wrapped as a predictor object.
+    Least Squares (scipy.linalg.lstsq) wrapped as a predictor object.
 
     """
 
@@ -303,3 +383,38 @@ class LinearRegression(LinearModel, RegressorMixin):
             self.coef_ = np.ravel(self.coef_)
         self._set_intercept(X_mean, y_mean, X_std)
         return self
+
+
+def _pre_fit(X, y, Xy, precompute, normalize, fit_intercept, copy):
+    """Aux function used at beginning of fit in linear models"""
+    n_samples, n_features = X.shape
+    if sparse.isspmatrix(X):
+        precompute = False
+        X, y, X_mean, y_mean, X_std = sparse_center_data(
+            X, y, fit_intercept, normalize)
+    else:
+        # copy was done in fit if necessary
+        X, y, X_mean, y_mean, X_std = center_data(
+            X, y, fit_intercept, normalize, copy=copy)
+
+    if hasattr(precompute, '__array__') \
+            and not np.allclose(X_mean, np.zeros(n_features)) \
+            and not np.allclose(X_std, np.ones(n_features)):
+        # recompute Gram
+        precompute = 'auto'
+        Xy = None
+
+    # precompute if n_samples > n_features
+    if precompute == 'auto':
+        precompute = (n_samples > n_features)
+
+    if precompute is True:
+        precompute = np.dot(X.T, X)
+
+    if not hasattr(precompute, '__array__'):
+        Xy = None  # cannot use Xy if precompute is not Gram
+
+    if hasattr(precompute, '__array__') and Xy is None:
+        Xy = np.dot(X.T, y)
+
+    return X, y, X_mean, y_mean, X_std, precompute, Xy
