@@ -2,12 +2,13 @@
 Least Angle Regression algorithm. See the documentation on the
 Generalized Linear Model for a complete discussion.
 """
+from __future__ import print_function
 
 # Author: Fabian Pedregosa <fabian.pedregosa@inria.fr>
 #         Alexandre Gramfort <alexandre.gramfort@inria.fr>
 #         Gael Varoquaux
 #
-# License: BSD Style.
+# License: BSD 3 clause
 
 from math import log
 import sys
@@ -22,18 +23,22 @@ from ..base import RegressorMixin
 from ..utils import array2d, arrayfuncs, as_float_array
 from ..cross_validation import check_cv
 from ..externals.joblib import Parallel, delayed
+from ..externals.six.moves import xrange
 
 
 def lars_path(X, y, Xy=None, Gram=None, max_iter=500,
               alpha_min=0, method='lar', copy_X=True,
               eps=np.finfo(np.float).eps,
               copy_Gram=True, verbose=0, return_path=True):
-    """Compute Least Angle Regression and Lasso path
+    """Compute Least Angle Regression or Lasso path using LARS algorithm [1]
 
-    The optimization objective for Lasso is::
+    The optimization objective for the case method='lasso' is::
 
     (1 / (2 * n_samples)) * ||y - Xw||^2_2 + alpha * ||w||_1
 
+    in the case of method='lars', the objective function is only known in
+    the form of an implicit equation (see discussion in [1])
+
     Parameters
     -----------
     X : array, shape: (n_samples, n_features)
@@ -42,45 +47,52 @@ def lars_path(X, y, Xy=None, Gram=None, max_iter=500,
     y : array, shape: (n_samples)
         Input targets.
 
-    max_iter : integer, optional
+    max_iter : integer, optional (default=500)
         Maximum number of iterations to perform, set to infinity for no limit.
 
     Gram : None, 'auto', array, shape: (n_features, n_features), optional
-        Precomputed Gram matrix (X' * X), if 'auto', the Gram
+        Precomputed Gram matrix (X' * X), if ``'auto'``, the Gram
         matrix is precomputed from the given X, if there are more samples
         than features.
 
-    alpha_min : float, optional
+    alpha_min : float, optional (default=0)
         Minimum correlation along the path. It corresponds to the
         regularization parameter alpha parameter in the Lasso.
 
-    method : {'lar', 'lasso'}
-        Specifies the returned model. Select 'lar' for Least Angle
-        Regression, 'lasso' for the Lasso.
+    method : {'lar', 'lasso'}, optional (default='lar')
+        Specifies the returned model. Select ``'lar'`` for Least Angle
+        Regression, ``'lasso'`` for the Lasso.
 
-    eps : float, optional
+    eps : float, optional (default=``np.finfo(np.float).eps``)
         The machine-precision regularization in the computation of the
         Cholesky diagonal factors. Increase this for very ill-conditioned
         systems.
 
-    copy_X : bool
-        If False, X is overwritten.
+    copy_X : bool, optional (default=True)
+        If ``False``, ``X`` is overwritten.
 
-    copy_Gram : bool
-        If False, Gram is overwritten.
+    copy_Gram : bool, optional (default=True)
+        If ``False``, ``Gram`` is overwritten.
 
     verbose : int (default=0)
         Controls output verbosity.
 
+    return_path: bool, (optional=True)
+        If ``return_path==True`` returns the entire path, else returns only the
+        last point of the path.
+
     Returns
     --------
-    alphas: array, shape: (max_features + 1,)
+    alphas: array, shape: [n_alphas + 1]
         Maximum of covariances (in absolute value) at each iteration.
+        ``n_alphas`` is either ``max_iter``, ``n_features`` or the
+        number of nodes in the path with ``alpha >= alpha_min``, whichever
+        is smaller.
 
-    active: array, shape (max_features,)
+    active: array, shape [n_alphas]
         Indices of active variables at the end of the path.
 
-    coefs: array, shape (n_features, max_features + 1)
+    coefs: array, shape (n_features, n_alphas + 1)
         Coefficients along the path
 
     See also
@@ -92,11 +104,17 @@ def lars_path(X, y, Xy=None, Gram=None, max_iter=500,
     LarsCV
     sklearn.decomposition.sparse_encode
 
-    Notes
-    ------
-    * http://en.wikipedia.org/wiki/Least-angle_regression
+    References
+    ----------
+    .. [1] "Least Angle Regression", Effron et al.
+           http://www-stat.stanford.edu/~tibs/ftp/lars.pdf
+
+    .. [2] `Wikipedia entry on the Least-angle regression
+           <http://en.wikipedia.org/wiki/Least-angle_regression>`_
+
+    .. [3] `Wikipedia entry on the Lasso
+           <http://en.wikipedia.org/wiki/Lasso_(statistics)#Lasso_method>`_
 
-    * http://en.wikipedia.org/wiki/Lasso_(statistics)#LASSO_method
     """
 
     n_features = X.shape[1]
@@ -142,7 +160,7 @@ def lars_path(X, y, Xy=None, Gram=None, max_iter=500,
 
     if verbose:
         if verbose > 1:
-            print "Step\t\tAdded\t\tDropped\t\tActive set size\t\tC"
+            print("Step\t\tAdded\t\tDropped\t\tActive set size\t\tC")
         else:
             sys.stdout.write('.')
             sys.stdout.flush()
@@ -241,8 +259,8 @@ def lars_path(X, y, Xy=None, Gram=None, max_iter=500,
             n_active += 1
 
             if verbose > 1:
-                print "%s\t\t%s\t\t%s\t\t%s\t\t%s" % (n_iter, active[-1], '',
-                                                      n_active, C)
+                print("%s\t\t%s\t\t%s\t\t%s\t\t%s" % (n_iter, active[-1], '',
+                                                      n_active, C))
 
         if method == 'lasso' and n_iter > 0 and prev_alpha[0] < alpha[0]:
             # alpha is increasing. This is because the updates of Cov are
@@ -251,7 +269,7 @@ def lars_path(X, y, Xy=None, Gram=None, max_iter=500,
             # regressors. Time to bail out
             warnings.warn('Early stopping the lars path, as the residues '
                           'are small and the current value of alpha is no '
-                          'longer well controled. %i iterations, alpha=%.3e, '
+                          'longer well controlled. %i iterations, alpha=%.3e, '
                           'previous alpha=%.3e, with an active set of %i '
                           'regressors.'
                           % (n_iter, alpha, prev_alpha, n_active))
@@ -323,8 +341,8 @@ def lars_path(X, y, Xy=None, Gram=None, max_iter=500,
                 del coef, alpha, prev_alpha, prev_coef
                 # resize the coefs and alphas array
                 add_features = 2 * max(1, (max_features - n_active))
-                coefs.resize((n_iter + add_features, n_features))
-                alphas.resize(n_iter + add_features)
+                coefs = np.resize(coefs, (n_iter + add_features, n_features))
+                alphas = np.resize(alphas, n_iter + add_features)
             coef = coefs[n_iter]
             prev_coef = coefs[n_iter - 1]
             alpha = alphas[n_iter, np.newaxis]
@@ -382,8 +400,8 @@ def lars_path(X, y, Xy=None, Gram=None, max_iter=500,
             sign_active = np.delete(sign_active, idx)
             sign_active = np.append(sign_active, 0.)  # just to maintain size
             if verbose > 1:
-                print "%s\t\t%s\t\t%s\t\t%s\t\t%s" % (n_iter, '', drop_idx,
-                                                      n_active, abs(temp))
+                print("%s\t\t%s\t\t%s\t\t%s\t\t%s" % (n_iter, '', drop_idx,
+                                                      n_active, abs(temp)))
 
     if return_path:
         # resize coefs in case of early stop
@@ -404,7 +422,7 @@ class Lars(LinearModel, RegressorMixin):
     Parameters
     ----------
     n_nonzero_coefs : int, optional
-        Target number of non-zero coefficients. Use np.inf for no limit.
+        Target number of non-zero coefficients. Use ``np.inf`` for no limit.
 
     fit_intercept : boolean
         Whether to calculate the intercept for this model. If set
@@ -415,40 +433,48 @@ class Lars(LinearModel, RegressorMixin):
         Sets the verbosity amount
 
     normalize : boolean, optional, default False
-        If True, the regressors X will be normalized before regression.
+        If ``True``, the regressors X will be normalized before regression.
 
     precompute : True | False | 'auto' | array-like
         Whether to use a precomputed Gram matrix to speed up
-        calculations. If set to 'auto' let us decide. The Gram
+        calculations. If set to ``'auto'`` let us decide. The Gram
         matrix can also be passed as argument.
 
     copy_X : boolean, optional, default True
-        If True, X will be copied; else, it may be overwritten.
+        If ``True``, X will be copied; else, it may be overwritten.
 
     eps: float, optional
         The machine-precision regularization in the computation of the
         Cholesky diagonal factors. Increase this for very ill-conditioned
-        systems. Unlike the 'tol' parameter in some iterative
+        systems. Unlike the ``tol`` parameter in some iterative
         optimization-based algorithms, this parameter does not control
         the tolerance of the optimization.
 
     fit_path : boolean
-        If True the full path is stored in the `coef_path_` attribute.
+        If True the full path is stored in the ``coef_path_`` attribute.
         If you compute the solution for a large problem or many targets,
-        setting fit_path to False will lead to a speedup, especially
+        setting ``fit_path`` to ``False`` will lead to a speedup, especially
         with a small alpha.
 
     Attributes
     ----------
-    `coef_path_` : array, shape = [n_features, n_alpha]
-        The varying values of the coefficients along the path. It is not \
-    present if the fit_path parameter is False.
+    ``alphas_`` : array, shape (n_alphas + 1,) | list of n_targets such arrays
+        Maximum of covariances (in absolute value) at each iteration. \
+        ``n_alphas`` is either ``n_nonzero_coefs`` or ``n_features``, \
+        whichever is smaller.
 
+    ``active_`` : list, length = n_alphas | list of n_targets such lists
+        Indices of active variables at the end of the path.
 
-    `coef_` : array, shape = [n_features]
-        Parameter vector (w in the fomulation formula).
+    ``coef_path_`` : array, shape (n_features, n_alphas + 1) \
+        | list of n_targets such arrays
+        The varying values of the coefficients along the path. It is not
+        present if the ``fit_path`` parameter is ``False``.
 
-    `intercept_` : float
+    ``coef_`` : array, shape (n_features,) or (n_targets, n_features)
+        Parameter vector (w in the formulation formula).
+
+    ``intercept_`` : float | array, shape (n_targets,)
         Independent term in decision function.
 
     Examples
@@ -467,7 +493,6 @@ class Lars(LinearModel, RegressorMixin):
     lars_path, LarsCV
     sklearn.decomposition.sparse_encode
 
-    http://en.wikipedia.org/wiki/Least_angle_regression
     """
     def __init__(self, fit_intercept=True, verbose=False, normalize=True,
                  precompute='auto', n_nonzero_coefs=500,
@@ -498,13 +523,14 @@ class Lars(LinearModel, RegressorMixin):
 
         parameters
         ----------
-        X : array-like, shape = [n_samples, n_features]
+        X : array-like, shape (n_samples, n_features)
             Training data.
 
-        y : array-like, shape = [n_samples] or [n_samples, n_targets]
+        y : array-like, shape (n_samples,) or (n_samples, n_targets)
             Target values.
 
-        Xy : array-like, shape = [n_samples] or [n_samples, n_targets], optional
+        Xy : array-like, shape (n_samples,) or (n_samples, n_targets), \
+                optional
             Xy = np.dot(X.T, y) that can be precomputed. It is useful
             only when the Gram matrix is precomputed.
 
@@ -594,10 +620,10 @@ class LassoLars(Lars):
     ----------
     alpha : float
         Constant that multiplies the penalty term. Defaults to 1.0.
-        alpha = 0 is equivalent to an ordinary least square, solved
-        by the LinearRegression object in the scikit. For numerical
-        reasons, using alpha = 0 with the LassoLars object is not advised
-        and you should prefer the LinearRegression object.
+        ``alpha = 0`` is equivalent to an ordinary least square, solved
+        by :class:`LinearRegression`. For numerical reasons, using
+        ``alpha = 0`` with the LassoLars object is not advised and you
+        should prefer the LinearRegression object.
 
     fit_intercept : boolean
         whether to calculate the intercept for this model. If set
@@ -615,35 +641,45 @@ class LassoLars(Lars):
 
     precompute : True | False | 'auto' | array-like
         Whether to use a precomputed Gram matrix to speed up
-        calculations. If set to 'auto' let us decide. The Gram
+        calculations. If set to ``'auto'`` let us decide. The Gram
         matrix can also be passed as argument.
 
-    max_iter: integer, optional
+    max_iter : integer, optional
         Maximum number of iterations to perform.
 
-    eps: float, optional
+    eps : float, optional
         The machine-precision regularization in the computation of the
         Cholesky diagonal factors. Increase this for very ill-conditioned
-        systems. Unlike the 'tol' parameter in some iterative
+        systems. Unlike the ``tol`` parameter in some iterative
         optimization-based algorithms, this parameter does not control
         the tolerance of the optimization.
 
     fit_path : boolean
-        If True the full path is stored in the `coef_path_` attribute.
+        If ``True`` the full path is stored in the ``coef_path_`` attribute.
         If you compute the solution for a large problem or many targets,
-        setting fit_path to False will lead to a speedup, especially
+        setting ``fit_path`` to ``False`` will lead to a speedup, especially
         with a small alpha.
 
     Attributes
     ----------
-    `coef_path_` : array, shape = [n_features, n_alpha]
-        The varying values of the coefficients along the path. It is not \
-    present if fit_path parameter is False.
+    ``alphas_`` : array, shape (n_alphas + 1,) | list of n_targets such arrays
+        Maximum of covariances (in absolute value) at each iteration. \
+        ``n_alphas`` is either ``max_iter``, ``n_features``, or the number of \
+        nodes in the path with correlation greater than ``alpha``, whichever \
+        is smaller.
 
-    `coef_` : array, shape = [n_features]
-        Parameter vector (w in the fomulation formula).
+    ``active_`` : list, length = n_alphas | list of n_targets such lists
+        Indices of active variables at the end of the path.
 
-    `intercept_` : float
+    ``coef_path_`` : array, shape (n_features, n_alphas + 1) or list
+        If a list is passed it's expected to be one of n_targets such arrays.
+        The varying values of the coefficients along the path. It is not
+        present if the ``fit_path`` parameter is ``False``.
+
+    ``coef_`` : array, shape (n_features,) or (n_targets, n_features)
+        Parameter vector (w in the formulation formula).
+
+    ``intercept_`` : float | array, shape (n_targets,)
         Independent term in decision function.
 
     Examples
@@ -667,7 +703,6 @@ class LassoLars(Lars):
     LassoLarsCV
     sklearn.decomposition.sparse_encode
 
-    http://en.wikipedia.org/wiki/Least_angle_regression
     """
 
     def __init__(self, alpha=1.0, fit_intercept=True, verbose=False,
@@ -696,25 +731,25 @@ def _lars_path_residues(X_train, y_train, X_test, y_test, Gram=None,
 
     Parameters
     -----------
-    X_train: array, shape (n_samples, n_features)
+    X_train : array, shape (n_samples, n_features)
         The data to fit the LARS on
-    y_train: array, shape (n_samples)
+    y_train : array, shape (n_samples)
         The target variable to fit LARS on
-    X_test: array, shape (n_samples, n_features)
+    X_test : array, shape (n_samples, n_features)
         The data to compute the residues on
-    y_test: array, shape (n_samples)
+    y_test : array, shape (n_samples)
         The target variable to compute the residues on
-    Gram: None, 'auto', array, shape: (n_features, n_features), optional
-        Precomputed Gram matrix (X' * X), if 'auto', the Gram
+    Gram : None, 'auto', array, shape: (n_features, n_features), optional
+        Precomputed Gram matrix (X' * X), if ``'auto'``, the Gram
         matrix is precomputed from the given X, if there are more samples
         than features
-    copy: boolean, optional
+    copy : boolean, optional
         Whether X_train, X_test, y_train and y_test should be copied;
         if False, they may be overwritten.
-    method: 'lar' | 'lasso'
-        Specifies the returned model. Select 'lar' for Least Angle
-        Regression, 'lasso' for the Lasso.
-    verbose: integer, optional
+    method : 'lar' | 'lasso'
+        Specifies the returned model. Select ``'lar'`` for Least Angle
+        Regression, ``'lasso'`` for the Lasso.
+    verbose : integer, optional
         Sets the amount of verbosity
     fit_intercept : boolean
         whether to calculate the intercept for this model. If set
@@ -722,29 +757,30 @@ def _lars_path_residues(X_train, y_train, X_test, y_test, Gram=None,
         (e.g. data is expected to be already centered).
     normalize : boolean, optional, default False
         If True, the regressors X will be normalized before regression.
-    max_iter: integer, optional
+    max_iter : integer, optional
         Maximum number of iterations to perform.
-    eps: float, optional
-            The machine-precision regularization in the computation of the
+    eps : float, optional
+        The machine-precision regularization in the computation of the
         Cholesky diagonal factors. Increase this for very ill-conditioned
-        systems. Unlike the 'tol' parameter in some iterative
+        systems. Unlike the ``tol`` parameter in some iterative
         optimization-based algorithms, this parameter does not control
         the tolerance of the optimization.
 
 
     Returns
     --------
-    alphas: array, shape: (max_features + 1,)
-        Maximum of covariances (in absolute value) at each
-        iteration.
+    alphas : array, shape (n_alphas,)
+        Maximum of covariances (in absolute value) at each iteration.
+        ``n_alphas`` is either ``max_iter`` or ``n_features``, whichever
+        is smaller.
 
-    active: array, shape (max_features,)
+    active : list
         Indices of active variables at the end of the path.
 
-    coefs: array, shape (n_features, max_features + 1)
+    coefs : array, shape (n_features, n_alphas)
         Coefficients along the path
 
-    residues: array, shape (n_features, max_features + 1)
+    residues : array, shape (n_alphas, n_samples)
         Residues of the prediction on the test data
     """
     if copy:
@@ -773,9 +809,8 @@ def _lars_path_residues(X_train, y_train, X_test, y_test, Gram=None,
         method=method, verbose=max(0, verbose - 1), max_iter=max_iter, eps=eps)
     if normalize:
         coefs[nonzeros] /= norms[nonzeros][:, np.newaxis]
-    residues = np.array([(np.dot(X_test, coef) - y_test)
-                         for coef in coefs.T])
-    return alphas, active, coefs, residues
+    residues = np.dot(X_test, coefs) - y_test[:, np.newaxis]
+    return alphas, active, coefs, residues.T
 
 
 class LarsCV(Lars):
@@ -795,18 +830,18 @@ class LarsCV(Lars):
         If True, the regressors X will be normalized before regression.
 
     copy_X : boolean, optional, default True
-        If True, X will be copied; else, it may be overwritten.
+        If ``True``, X will be copied; else, it may be overwritten.
 
     precompute : True | False | 'auto' | array-like
         Whether to use a precomputed Gram matrix to speed up
-        calculations. If set to 'auto' let us decide. The Gram
+        calculations. If set to ``'auto'`` let us decide. The Gram
         matrix can also be passed as argument.
 
     max_iter: integer, optional
         Maximum number of iterations to perform.
 
-    cv : crossvalidation generator, optional
-        see sklearn.cross_validation module. If None is passed, default to
+    cv : cross-validation generator, optional
+        see :mod:`sklearn.cross_validation`. If ``None`` is passed, default to
         a 5-fold strategy
 
     max_n_alphas : integer, optional
@@ -814,7 +849,7 @@ class LarsCV(Lars):
         residuals in the cross-validation
 
     n_jobs : integer, optional
-        Number of CPUs to use during the cross validation. If '-1', use
+        Number of CPUs to use during the cross validation. If ``-1``, use
         all the CPUs
 
     eps: float, optional
@@ -825,27 +860,27 @@ class LarsCV(Lars):
 
     Attributes
     ----------
-    `coef_` : array, shape = [n_features]
-        parameter vector (w in the fomulation formula)
+    ``coef_`` : array, shape (n_features,)
+        parameter vector (w in the formulation formula)
 
-    `intercept_` : float
+    ``intercept_`` : float
         independent term in decision function
 
-    `coef_path_`: array, shape = [n_features, n_alpha]
+    ``coef_path_`` : array, shape (n_features, n_alphas)
         the varying values of the coefficients along the path
 
-    `alpha_`: float
+    ``alpha_`` : float
         the estimated regularization parameter alpha
 
-    `alphas_`: array, shape = [n_alpha]
+    ``alphas_`` : array, shape (n_alphas,)
         the different values of alpha along the path
 
-    `cv_alphas_`: array, shape = [n_cv_alphas]
+    ``cv_alphas_`` : array, shape (n_cv_alphas,)
         all the values of alpha along the path for the different folds
 
-    `cv_mse_path_`: array, shape = [n_folds, n_cv_alphas]
+    ``cv_mse_path_`` : array, shape (n_folds, n_cv_alphas)
         the mean square error on left-out for each fold along the path
-        (alpha values given by cv_alphas)
+        (alpha values given by ``cv_alphas``)
 
     See also
     --------
@@ -874,10 +909,10 @@ class LarsCV(Lars):
 
         Parameters
         ----------
-        X : array-like, shape = [n_samples, n_features]
+        X : array-like, shape (n_samples, n_features)
             Training data.
 
-        y : array-like, shape = [n_samples]
+        y : array-like, shape (n_samples,)
             Target values.
 
         Returns
@@ -946,14 +981,6 @@ class LarsCV(Lars):
         # impedance matching for the above Lars.fit (should not be documented)
         return self.alpha_
 
-    @property
-    def cv_alphas(self):
-        warnings.warn("Use cv_alphas_. Using cv_alphas is deprecated"
-                      "since version 0.12, and backward compatibility "
-                      "won't be maintained from version 0.14 onward. ",
-                      DeprecationWarning, stacklevel=2)
-        return self.cv_alphas_
-
 
 class LassoLarsCV(LarsCV):
     """Cross-validated Lasso, using the LARS algorithm
@@ -977,13 +1004,13 @@ class LassoLarsCV(LarsCV):
 
     precompute : True | False | 'auto' | array-like
         Whether to use a precomputed Gram matrix to speed up
-        calculations. If set to 'auto' let us decide. The Gram
+        calculations. If set to ``'auto'`` let us decide. The Gram
         matrix can also be passed as argument.
 
     max_iter: integer, optional
         Maximum number of iterations to perform.
 
-    cv : crossvalidation generator, optional
+    cv : cross-validation generator, optional
         see sklearn.cross_validation module. If None is passed, default to
         a 5-fold strategy
 
@@ -992,7 +1019,7 @@ class LassoLarsCV(LarsCV):
         residuals in the cross-validation
 
     n_jobs : integer, optional
-        Number of CPUs to use during the cross validation. If '-1', use
+        Number of CPUs to use during the cross validation. If ``-1``, use
         all the CPUs
 
     eps: float, optional
@@ -1005,33 +1032,33 @@ class LassoLarsCV(LarsCV):
 
     Attributes
     ----------
-    `coef_` : array, shape = [n_features]
-        parameter vector (w in the fomulation formula)
+    ``coef_`` : array, shape (n_features,)
+        parameter vector (w in the formulation formula)
 
-    `intercept_` : float
+    ``intercept_`` : float
         independent term in decision function.
 
-    `coef_path_`: array, shape = [n_features, n_alpha]
+    ``coef_path_`` : array, shape (n_features, n_alphas)
         the varying values of the coefficients along the path
 
-    `alpha_`: float
+    ``alpha_`` : float
         the estimated regularization parameter alpha
 
-    `alphas_`: array, shape = [n_alpha]
+    ``alphas_`` : array, shape (n_alphas,)
         the different values of alpha along the path
 
-    `cv_alphas_`: array, shape = [n_cv_alphas]
+    ``cv_alphas_`` : array, shape (n_cv_alphas,)
         all the values of alpha along the path for the different folds
 
-    `cv_mse_path_`: array, shape = [n_folds, n_cv_alphas]
+    ``cv_mse_path_`` : array, shape (n_folds, n_cv_alphas)
         the mean square error on left-out for each fold along the path
-        (alpha values given by cv_alphas)
+        (alpha values given by ``cv_alphas``)
 
     Notes
     -----
 
     The object solves the same problem as the LassoCV object. However,
-    unlike the LassoCV, it find the relevent alphas values by itself.
+    unlike the LassoCV, it find the relevant alphas values by itself.
     In general, because of this property, it will be more stable.
     However, it is more fragile to heavily multicollinear datasets.
 
@@ -1081,7 +1108,7 @@ class LassoLarsIC(LassoLars):
 
     precompute : True | False | 'auto' | array-like
         Whether to use a precomputed Gram matrix to speed up
-        calculations. If set to 'auto' let us decide. The Gram
+        calculations. If set to ``'auto'`` let us decide. The Gram
         matrix can also be passed as argument.
 
     max_iter: integer, optional
@@ -1091,20 +1118,20 @@ class LassoLarsIC(LassoLars):
     eps: float, optional
         The machine-precision regularization in the computation of the
         Cholesky diagonal factors. Increase this for very ill-conditioned
-        systems. Unlike the 'tol' parameter in some iterative
+        systems. Unlike the ``tol`` parameter in some iterative
         optimization-based algorithms, this parameter does not control
         the tolerance of the optimization.
 
 
     Attributes
     ----------
-    `coef_` : array, shape = [n_features]
-        parameter vector (w in the fomulation formula)
+    ``coef_`` : array, shape (n_features,)
+        parameter vector (w in the formulation formula)
 
-    `intercept_` : float
+    ``intercept_`` : float
         independent term in decision function.
 
-    `alpha_` : float
+    ``alpha_`` : float
         the alpha parameter chosen by the information criterion
 
     Examples
@@ -1151,10 +1178,10 @@ class LassoLarsIC(LassoLars):
 
         parameters
         ----------
-        x : array-like, shape = [n_samples, n_features]
+        x : array-like, shape (n_samples, n_features)
             training data.
 
-        y : array-like, shape = [n_samples]
+        y : array-like, shape (n_samples,)
             target values.
 
         returns
