@@ -3,7 +3,7 @@
 
 # Author: Vlad Niculae
 #
-# License: BSD Style.
+# License: BSD 3 clause
 
 import warnings
 
@@ -11,9 +11,11 @@ import numpy as np
 from scipy import linalg
 from scipy.linalg.lapack import get_lapack_funcs
 
-from .base import LinearModel
+from .base import LinearModel, _pre_fit
 from ..base import RegressorMixin
-from ..utils import array2d
+from ..utils import array2d, as_float_array
+from ..cross_validation import check_cv
+from ..externals.joblib import Parallel, delayed
 from ..utils.arrayfuncs import solve_triangular
 
 premature = """ Orthogonal matching pursuit ended prematurely due to linear
@@ -21,37 +23,47 @@ dependence in the dictionary. The requested precision might not have been met.
 """
 
 
-def _cholesky_omp(X, y, n_nonzero_coefs, tol=None, copy_X=True):
+def _cholesky_omp(X, y, n_nonzero_coefs, tol=None, copy_X=True,
+                  return_path=False):
     """Orthogonal Matching Pursuit step using the Cholesky decomposition.
 
-    Parameters:
-    -----------
-    X: array, shape = (n_samples, n_features)
+    Parameters
+    ----------
+    X : array, shape (n_samples, n_features)
         Input dictionary. Columns are assumed to have unit norm.
 
-    y: array, shape = (n_samples,)
+    y : array, shape (n_samples,)
         Input targets
 
-    n_nonzero_coefs: int
+    n_nonzero_coefs : int
         Targeted number of non-zero elements
 
-    tol: float
+    tol : float
         Targeted squared error, if not None overrides n_nonzero_coefs.
 
-    copy_X: bool, optional
+    copy_X : bool, optional
         Whether the design matrix X must be copied by the algorithm. A false
         value is only helpful if X is already Fortran-ordered, otherwise a
         copy is made anyway.
 
-    Returns:
-    --------
-    gamma: array, shape = (n_nonzero_coefs,)
+    return_path : bool, optional. Default: False
+        Whether to return every value of the nonzero coefficients along the
+        forward path. Useful for cross-validation.
+
+    Returns
+    -------
+    gamma : array, shape (n_nonzero_coefs,)
         Non-zero elements of the solution
 
-    idx: array, shape = (n_nonzero_coefs,)
+    idx : array, shape (n_nonzero_coefs,)
         Indices of the positions of the elements in gamma within the solution
         vector
 
+    coef : array, shape (n_features, n_nonzero_coefs)
+        The first k values of column k correspond to the coefficient value
+        for the active features at that step. The lower left triangle contains
+        garbage. Only returned if ``return_path=True``.
+
     """
     if copy_X:
         X = X.copy('F')
@@ -66,11 +78,13 @@ def _cholesky_omp(X, y, n_nonzero_coefs, tol=None, copy_X=True):
     residual = y
     gamma = np.empty(0)
     n_active = 0
-    indices = range(X.shape[1])  # keeping track of swapping
+    indices = np.arange(X.shape[1])  # keeping track of swapping
 
     max_features = X.shape[1] if tol is not None else n_nonzero_coefs
     L = np.empty((max_features, max_features), dtype=X.dtype)
     L[0, 0] = 1.
+    if return_path:
+        coefs = np.empty_like(L)
 
     while True:
         lam = np.argmax(np.abs(np.dot(X.T, residual)))
@@ -94,57 +108,70 @@ def _cholesky_omp(X, y, n_nonzero_coefs, tol=None, copy_X=True):
         # solves LL'x = y as a composition of two triangular systems
         gamma, _ = potrs(L[:n_active, :n_active], alpha[:n_active], lower=True,
                          overwrite_b=False)
-
+        if return_path:
+            coefs[:n_active, n_active - 1] = gamma
         residual = y - np.dot(X[:, :n_active], gamma)
         if tol is not None and nrm2(residual) ** 2 <= tol:
             break
         elif n_active == max_features:
             break
 
-    return gamma, indices[:n_active]
+    if return_path:
+        return gamma, indices[:n_active], coefs[:, :n_active]
+    else:
+        return gamma, indices[:n_active]
 
 
 def _gram_omp(Gram, Xy, n_nonzero_coefs, tol_0=None, tol=None,
-              copy_Gram=True, copy_Xy=True):
+              copy_Gram=True, copy_Xy=True, return_path=False):
     """Orthogonal Matching Pursuit step on a precomputed Gram matrix.
 
     This function uses the the Cholesky decomposition method.
 
-    Parameters:
-    -----------
-    Gram: array, shape = (n_features, n_features)
+    Parameters
+    ----------
+    Gram : array, shape (n_features, n_features)
         Gram matrix of the input data matrix
 
-    Xy: array, shape = (n_features,)
+    Xy : array, shape (n_features,)
         Input targets
 
-    n_nonzero_coefs: int
+    n_nonzero_coefs : int
         Targeted number of non-zero elements
 
-    tol_0: float
+    tol_0 : float
         Squared norm of y, required if tol is not None.
 
-    tol: float
+    tol : float
         Targeted squared error, if not None overrides n_nonzero_coefs.
 
-    copy_Gram: bool, optional
+    copy_Gram : bool, optional
         Whether the gram matrix must be copied by the algorithm. A false
         value is only helpful if it is already Fortran-ordered, otherwise a
         copy is made anyway.
 
-    copy_Xy: bool, optional
+    copy_Xy : bool, optional
         Whether the covariance vector Xy must be copied by the algorithm.
         If False, it may be overwritten.
 
-    Returns:
-    --------
-    gamma: array, shape = (n_nonzero_coefs,)
+    return_path : bool, optional. Default: False
+        Whether to return every value of the nonzero coefficients along the
+        forward path. Useful for cross-validation.
+
+    Returns
+    -------
+    gamma : array, shape (n_nonzero_coefs,)
         Non-zero elements of the solution
 
-    idx: array, shape = (n_nonzero_coefs,)
+    idx : array, shape (n_nonzero_coefs,)
         Indices of the positions of the elements in gamma within the solution
         vector
 
+    coefs : array, shape (n_features, n_nonzero_coefs)
+        The first k values of column k correspond to the coefficient value
+        for the active features at that step. The lower left triangle contains
+        garbage. Only returned if ``return_path=True``.
+
     """
     Gram = Gram.copy('F') if copy_Gram else np.asfortranarray(Gram)
 
@@ -155,7 +182,7 @@ def _gram_omp(Gram, Xy, n_nonzero_coefs, tol_0=None, tol=None,
     nrm2, swap = linalg.get_blas_funcs(('nrm2', 'swap'), (Gram,))
     potrs, = get_lapack_funcs(('potrs',), (Gram,))
 
-    indices = range(len(Gram))  # keeping track of swapping
+    indices = np.arange(len(Gram))  # keeping track of swapping
     alpha = Xy
     tol_curr = tol_0
     delta = 0
@@ -165,6 +192,8 @@ def _gram_omp(Gram, Xy, n_nonzero_coefs, tol_0=None, tol=None,
     max_features = len(Gram) if tol is not None else n_nonzero_coefs
     L = np.empty((max_features, max_features), dtype=Gram.dtype)
     L[0, 0] = 1.
+    if return_path:
+        coefs = np.empty_like(L)
 
     while True:
         lam = np.argmax(np.abs(alpha))
@@ -188,7 +217,8 @@ def _gram_omp(Gram, Xy, n_nonzero_coefs, tol_0=None, tol=None,
         # solves LL'x = y as a composition of two triangular systems
         gamma, _ = potrs(L[:n_active, :n_active], Xy[:n_active], lower=True,
                          overwrite_b=False)
-
+        if return_path:
+            coefs[:n_active, n_active - 1] = gamma
         beta = np.dot(Gram[:, :n_active], gamma)
         alpha = Xy - beta
         if tol is not None:
@@ -200,11 +230,14 @@ def _gram_omp(Gram, Xy, n_nonzero_coefs, tol_0=None, tol=None,
         elif n_active == max_features:
             break
 
-    return gamma, indices[:n_active]
+    if return_path:
+        return gamma, indices[:n_active], coefs[:, :n_active]
+    else:
+        return gamma, indices[:n_active]
 
 
-def orthogonal_mp(X, y, n_nonzero_coefs=None, tol=None, precompute_gram=False,
-                  copy_X=True):
+def orthogonal_mp(X, y, n_nonzero_coefs=None, tol=None, precompute=False,
+                  copy_X=True, return_path=False, precompute_gram=None):
     """Orthogonal Matching Pursuit (OMP)
 
     Solves n_targets Orthogonal Matching Pursuit problems.
@@ -219,10 +252,10 @@ def orthogonal_mp(X, y, n_nonzero_coefs=None, tol=None, precompute_gram=False,
 
     Parameters
     ----------
-    X: array, shape = (n_samples, n_features)
+    X: array, shape (n_samples, n_features)
         Input data. Columns are assumed to have unit norm.
 
-    y: array, shape = (n_samples,) or (n_samples, n_targets)
+    y: array, shape (n_samples,) or (n_samples, n_targets)
         Input targets
 
     n_nonzero_coefs: int
@@ -232,7 +265,7 @@ def orthogonal_mp(X, y, n_nonzero_coefs=None, tol=None, precompute_gram=False,
     tol: float
         Maximum norm of the residual. If not None, overrides n_nonzero_coefs.
 
-    precompute_gram: {True, False, 'auto'},
+    precompute: {True, False, 'auto'},
         Whether to perform precomputations. Improves performance when n_targets
         or n_samples is very large.
 
@@ -241,10 +274,18 @@ def orthogonal_mp(X, y, n_nonzero_coefs=None, tol=None, precompute_gram=False,
         value is only helpful if X is already Fortran-ordered, otherwise a
         copy is made anyway.
 
+    return_path: bool, optional. Default: False
+        Whether to return every value of the nonzero coefficients along the
+        forward path. Useful for cross-validation.
+
     Returns
     -------
-    coef: array, shape = (n_features,) or (n_features, n_targets)
-        Coefficients of the OMP solution
+    coef: array, shape (n_features,) or (n_features, n_targets)
+        Coefficients of the OMP solution. If `return_path=True`, this contains
+        the whole coefficient path. In this case its shape is
+        (n_features, n_features) or (n_features, n_targets, n_features) and
+        iterating over the last axis yields coefficients in increasing order
+        of active features.
 
     See also
     --------
@@ -266,6 +307,14 @@ def orthogonal_mp(X, y, n_nonzero_coefs=None, tol=None, precompute_gram=False,
     http://www.cs.technion.ac.il/~ronrubin/Publications/KSVD-OMP-v2.pdf
 
     """
+    if precompute_gram is not None:
+        warnings.warn("precompute_gram will be removed in 0.15."
+                      " Use the precompute parameter.",
+                      DeprecationWarning, stacklevel=2)
+        precompute = precompute_gram
+
+    del precompute_gram
+
     X = array2d(X, order='F', copy=copy_X)
     copy_X = False
     y = np.asarray(y)
@@ -284,9 +333,9 @@ def orthogonal_mp(X, y, n_nonzero_coefs=None, tol=None, precompute_gram=False,
     if tol is None and n_nonzero_coefs > X.shape[1]:
         raise ValueError("The number of atoms cannot be more than the number "
                          "of features")
-    if precompute_gram == 'auto':
-        precompute_gram = X.shape[0] > X.shape[1]
-    if precompute_gram:
+    if precompute == 'auto':
+        precompute = X.shape[0] > X.shape[1]
+    if precompute:
         G = np.dot(X.T, X)
         G = np.asfortranarray(G)
         Xy = np.dot(X.T, y)
@@ -297,17 +346,28 @@ def orthogonal_mp(X, y, n_nonzero_coefs=None, tol=None, precompute_gram=False,
         return orthogonal_mp_gram(G, Xy, n_nonzero_coefs, tol, norms_squared,
                                   copy_Gram=copy_X, copy_Xy=False)
 
-    coef = np.zeros((X.shape[1], y.shape[1]))
-    for k in xrange(y.shape[1]):
-        x, idx = _cholesky_omp(X, y[:, k], n_nonzero_coefs, tol,
-                               copy_X=copy_X)
-        coef[idx, k] = x
+    if return_path:
+        coef = np.zeros((X.shape[1], y.shape[1], X.shape[1]))
+    else:
+        coef = np.zeros((X.shape[1], y.shape[1]))
+
+    for k in range(y.shape[1]):
+        out = _cholesky_omp(X, y[:, k], n_nonzero_coefs, tol,
+                            copy_X=copy_X, return_path=return_path)
+        if return_path:
+            _, idx, coefs = out
+            coef = coef[:, :, :len(idx)]
+            for n_active, x in enumerate(coefs.T):
+                coef[idx[:n_active + 1], k, n_active] = x[:n_active + 1]
+        else:
+            x, idx = out
+            coef[idx, k] = x
     return np.squeeze(coef)
 
 
 def orthogonal_mp_gram(Gram, Xy, n_nonzero_coefs=None, tol=None,
                        norms_squared=None, copy_Gram=True,
-                       copy_Xy=True):
+                       copy_Xy=True, return_path=False):
     """Gram Orthogonal Matching Pursuit (OMP)
 
     Solves n_targets Orthogonal Matching Pursuit problems using only
@@ -315,10 +375,10 @@ def orthogonal_mp_gram(Gram, Xy, n_nonzero_coefs=None, tol=None,
 
     Parameters
     ----------
-    Gram: array, shape = (n_features, n_features)
+    Gram: array, shape (n_features, n_features)
         Gram matrix of the input data: X.T * X
 
-    Xy: array, shape = (n_features,) or (n_features, n_targets)
+    Xy: array, shape (n_features,) or (n_features, n_targets)
         Input targets multiplied by X: X.T * y
 
     n_nonzero_coefs: int
@@ -328,7 +388,7 @@ def orthogonal_mp_gram(Gram, Xy, n_nonzero_coefs=None, tol=None,
     tol: float
         Maximum norm of the residual. If not None, overrides n_nonzero_coefs.
 
-    norms_squared: array-like, shape = (n_targets,)
+    norms_squared: array-like, shape (n_targets,)
         Squared L2 norms of the lines of y. Required if tol is not None.
 
     copy_Gram: bool, optional
@@ -340,10 +400,18 @@ def orthogonal_mp_gram(Gram, Xy, n_nonzero_coefs=None, tol=None,
         Whether the covariance vector Xy must be copied by the algorithm.
         If False, it may be overwritten.
 
+    return_path: bool, optional. Default: False
+        Whether to return every value of the nonzero coefficients along the
+        forward path. Useful for cross-validation.
+
     Returns
     -------
-    coef: array, shape = (n_features,) or (n_features, n_targets)
-        Coefficients of the OMP solution
+    coef: array, shape (n_features,) or (n_features, n_targets)
+        Coefficients of the OMP solution. If `return_path=True`, this contains
+        the whole coefficient path. In this case its shape is
+        (n_features, n_features) or (n_features, n_targets, n_features) and
+        iterating over the last axis yields coefficients in increasing order
+        of active features.
 
     See also
     --------
@@ -387,12 +455,26 @@ def orthogonal_mp_gram(Gram, Xy, n_nonzero_coefs=None, tol=None,
     if tol is None and n_nonzero_coefs > len(Gram):
         raise ValueError("The number of atoms cannot be more than the number "
                          "of features")
-    coef = np.zeros((len(Gram), Xy.shape[1]))
+
+    if return_path:
+        coef = np.zeros((len(Gram), Xy.shape[1], len(Gram)))
+    else:
+        coef = np.zeros((len(Gram), Xy.shape[1]))
+
     for k in range(Xy.shape[1]):
-        x, idx = _gram_omp(Gram, Xy[:, k], n_nonzero_coefs,
-                           norms_squared[k] if tol is not None else None, tol,
-                           copy_Gram=copy_Gram, copy_Xy=copy_Xy)
-        coef[idx, k] = x
+        out = _gram_omp(Gram, Xy[:, k], n_nonzero_coefs,
+                        norms_squared[k] if tol is not None else None, tol,
+                        copy_Gram=copy_Gram, copy_Xy=copy_Xy,
+                        return_path=return_path)
+        if return_path:
+            _, idx, coefs = out
+            coef = coef[:, :, :len(idx)]
+            for n_active, x in enumerate(coefs.T):
+                coef[idx[:n_active + 1], k, n_active] = x[:n_active + 1]
+        else:
+            x, idx = out
+            coef[idx, k] = x
+
     return np.squeeze(coef)
 
 
@@ -416,7 +498,7 @@ class OrthogonalMatchingPursuit(LinearModel, RegressorMixin):
     normalize : boolean, optional
         If False, the regressors X are assumed to be already normalized.
 
-    precompute_gram : {True, False, 'auto'},
+    precompute : {True, False, 'auto'}, default 'auto'
         Whether to use a precomputed Gram and Xy matrix to speed up
         calculations. Improves performance when `n_targets` or `n_samples` is
         very large. Note that if you already have such matrices, you can pass
@@ -426,23 +508,25 @@ class OrthogonalMatchingPursuit(LinearModel, RegressorMixin):
         Whether the design matrix X must be copied by the algorithm. A false
         value is only helpful if X is already Fortran-ordered, otherwise a
         copy is made anyway.
+        WARNING : will be deprecated in 0.15
 
     copy_Gram : bool, optional
         Whether the gram matrix must be copied by the algorithm. A false
         value is only helpful if X is already Fortran-ordered, otherwise a
         copy is made anyway.
+        WARNING : will be deprecated in 0.15
 
     copy_Xy : bool, optional
         Whether the covariance vector Xy must be copied by the algorithm.
         If False, it may be overwritten.
-
+        WARNING : will be deprecated in 0.15
 
     Attributes
     ----------
-    `coef_` : array, shape = (n_features,) or (n_features, n_targets)
+    `coef_` : array, shape (n_features,) or (n_features, n_targets)
         parameter vector (w in the fomulation formula)
 
-    `intercept_` : float or array, shape =(n_targets,)
+    `intercept_` : float or array, shape (n_targets,)
         independent term in decision function.
 
     Notes
@@ -467,13 +551,14 @@ class OrthogonalMatchingPursuit(LinearModel, RegressorMixin):
     decomposition.sparse_encode
 
     """
-    def __init__(self, copy_X=True, copy_Gram=True, copy_Xy=True,
+    def __init__(self, copy_X=None, copy_Gram=None, copy_Xy=None,
                  n_nonzero_coefs=None, tol=None, fit_intercept=True,
-                 normalize=True, precompute_gram=False):
+                 normalize=True, precompute='auto', precompute_gram=None):
         self.n_nonzero_coefs = n_nonzero_coefs
         self.tol = tol
         self.fit_intercept = fit_intercept
         self.normalize = normalize
+        self.precompute = precompute
         self.precompute_gram = precompute_gram
         self.copy_Gram = copy_Gram
         self.copy_Xy = copy_Xy
@@ -484,18 +569,20 @@ class OrthogonalMatchingPursuit(LinearModel, RegressorMixin):
 
         Parameters
         ----------
-        X: array-like, shape = (n_samples, n_features)
+        X : array-like, shape (n_samples, n_features)
             Training data.
 
-        y: array-like, shape = (n_samples,) or (n_samples, n_targets)
+        y : array-like, shape (n_samples,) or (n_samples, n_targets)
             Target values.
 
-        Gram: array-like, shape = (n_features, n_features) (optional)
+        Gram : array-like, shape (n_features, n_features) (optional)
             Gram matrix of the input data: X.T * X
+            WARNING : will be deprecated in 0.15
 
-        Xy: array-like, shape = (n_features,) or (n_features, n_targets)
+        Xy : array-like, shape (n_features,) or (n_features, n_targets)
             (optional)
             Input targets multiplied by X: X.T * y
+            WARNING : will be deprecated in 0.15
 
 
         Returns
@@ -507,20 +594,53 @@ class OrthogonalMatchingPursuit(LinearModel, RegressorMixin):
         y = np.asarray(y)
         n_features = X.shape[1]
 
-        X, y, X_mean, y_mean, X_std = self._center_data(X, y,
-                                                        self.fit_intercept,
-                                                        self.normalize,
-                                                        self.copy_X)
-
-        if y.ndim == 1:
-            y = y[:, np.newaxis]
-
-        if self.n_nonzero_coefs is None and self.tol is None:
-            # default for n_nonzero_coefs is 0.1 * n_features
-            # but at least one.
-            self.n_nonzero_coefs_ = max(int(0.1 * n_features), 1)
+        if self.precompute_gram is not None:
+            warnings.warn("precompute_gram will be removed in 0.15."
+                          " Use the precompute parameter.",
+                          DeprecationWarning, stacklevel=2)
+            precompute = self.precompute_gram
         else:
-            self.n_nonzero_coefs_ = self.n_nonzero_coefs
+            precompute = self.precompute
+
+        if self.copy_Gram is not None:
+            warnings.warn("copy_Gram will be removed in 0.15."
+                          " Use the orthogonal_mp function for"
+                          " low level memory control.",
+                          DeprecationWarning, stacklevel=2)
+            copy_Gram = self.copy_Gram
+        else:
+            copy_Gram = True
+
+        if self.copy_Xy is not None:
+            warnings.warn("copy_Xy will be removed in 0.15."
+                          " Use the orthogonal_mp function for"
+                          " low level memory control.",
+                          DeprecationWarning, stacklevel=2)
+            copy_Xy = self.copy_Xy
+        else:
+            copy_Xy = True
+
+        if self.copy_X is not None:
+            warnings.warn("copy_X will be removed in 0.15."
+                          " Use the orthogonal_mp function for"
+                          " low level memory control.",
+                          DeprecationWarning, stacklevel=2)
+            copy_X = self.copy_X
+        else:
+            copy_X = True
+
+        if Gram is not None:
+            warnings.warn("Gram will be removed in 0.15."
+                          " Use the orthogonal_mp function for"
+                          " low level memory control.",
+                          DeprecationWarning, stacklevel=2)
+
+        if Xy is not None:
+            warnings.warn("Xy will be removed in 0.15."
+                          " Use the orthogonal_mp function for"
+                          " low level memory control.",
+                          DeprecationWarning, stacklevel=2)
+
         if (Gram is not None or Xy is not None) and (self.fit_intercept
                                                      or self.normalize):
             warnings.warn('Mean subtraction (fit_intercept) and normalization '
@@ -532,32 +652,214 @@ class OrthogonalMatchingPursuit(LinearModel, RegressorMixin):
             Gram, Xy = None, None
 
         if Gram is not None:
-            if Xy is None:
-                Xy = np.dot(X.T, y)
-            else:
-                if self.copy_Xy:
-                    Xy = Xy.copy()
-                if self.normalize:
-                    if len(Xy.shape) == 1:
-                        Xy /= X_std
-                    else:
-                        Xy /= X_std[:, np.newaxis]
+            precompute = Gram
+            if Xy is not None and copy_Xy:
+                Xy = Xy.copy()
 
-            if self.normalize:
-                Gram /= X_std
-                Gram /= X_std[:, np.newaxis]
+        X, y, X_mean, y_mean, X_std, Gram, Xy = \
+            _pre_fit(X, y, Xy, precompute, self.normalize, self.fit_intercept,
+                     copy=copy_X)
 
+        if y.ndim == 1:
+            y = y[:, np.newaxis]
+
+        if self.n_nonzero_coefs is None and self.tol is None:
+            # default for n_nonzero_coefs is 0.1 * n_features
+            # but at least one.
+            self.n_nonzero_coefs_ = max(int(0.1 * n_features), 1)
+        else:
+            self.n_nonzero_coefs_ = self.n_nonzero_coefs
+
+        if Gram is False:
+            self.coef_ = orthogonal_mp(X, y, self.n_nonzero_coefs_, self.tol,
+                                       precompute=False, copy_X=copy_X).T
+        else:
             norms_sq = np.sum(y ** 2, axis=0) if self.tol is not None else None
             self.coef_ = orthogonal_mp_gram(Gram, Xy, self.n_nonzero_coefs_,
                                             self.tol, norms_sq,
-                                            self.copy_Gram, True).T
-        else:
-            precompute_gram = self.precompute_gram
-            if precompute_gram == 'auto':
-                precompute_gram = X.shape[0] > X.shape[1]
-            self.coef_ = orthogonal_mp(X, y, self.n_nonzero_coefs_, self.tol,
-                                       precompute_gram=self.precompute_gram,
-                                       copy_X=self.copy_X).T
+                                            copy_Gram, True).T
 
         self._set_intercept(X_mean, y_mean, X_std)
         return self
+
+
+def _omp_path_residues(X_train, y_train, X_test, y_test, copy=True,
+                       fit_intercept=True, normalize=True, max_iter=100):
+    """Compute the residues on left-out data for a full LARS path
+
+    Parameters
+    -----------
+    X_train : array, shape (n_samples, n_features)
+        The data to fit the LARS on
+
+    y_train : array, shape (n_samples)
+        The target variable to fit LARS on
+
+    X_test : array, shape (n_samples, n_features)
+        The data to compute the residues on
+
+    y_test : array, shape (n_samples)
+        The target variable to compute the residues on
+
+    copy : boolean, optional
+        Whether X_train, X_test, y_train and y_test should be copied.  If
+        False, they may be overwritten.
+
+    fit_intercept : boolean
+        whether to calculate the intercept for this model. If set
+        to false, no intercept will be used in calculations
+        (e.g. data is expected to be already centered).
+
+    normalize : boolean, optional, default False
+        If True, the regressors X will be normalized before regression.
+
+    max_iter : integer, optional
+        Maximum numbers of iterations to perform, therefore maximum features
+        to include. 100 by default.
+
+    Returns
+    -------
+    residues: array, shape (n_samples, max_features)
+        Residues of the prediction on the test data
+    """
+
+    if copy:
+        X_train = X_train.copy()
+        y_train = y_train.copy()
+        X_test = X_test.copy()
+        y_test = y_test.copy()
+
+    if fit_intercept:
+        X_mean = X_train.mean(axis=0)
+        X_train -= X_mean
+        X_test -= X_mean
+        y_mean = y_train.mean(axis=0)
+        y_train = as_float_array(y_train, copy=False)
+        y_train -= y_mean
+        y_test = as_float_array(y_test, copy=False)
+        y_test -= y_mean
+
+    if normalize:
+        norms = np.sqrt(np.sum(X_train ** 2, axis=0))
+        nonzeros = np.flatnonzero(norms)
+        X_train[:, nonzeros] /= norms[nonzeros]
+
+    coefs = orthogonal_mp(X_train, y_train, n_nonzero_coefs=max_iter, tol=None,
+                          precompute=False, copy_X=False,
+                          return_path=True)
+    if coefs.ndim == 1:
+        coefs = coefs[:, np.newaxis]
+    if normalize:
+        coefs[nonzeros] /= norms[nonzeros][:, np.newaxis]
+
+    return np.dot(coefs.T, X_test.T) - y_test
+
+
+class OrthogonalMatchingPursuitCV(LinearModel, RegressorMixin):
+    """Cross-validated Orthogonal Mathching Pursuit model (OMP)
+
+    Parameters
+    ----------
+    copy : bool, optional
+        Whether the design matrix X must be copied by the algorithm. A false
+        value is only helpful if X is already Fortran-ordered, otherwise a
+        copy is made anyway.
+
+    fit_intercept : boolean, optional
+        whether to calculate the intercept for this model. If set
+        to false, no intercept will be used in calculations
+        (e.g. data is expected to be already centered).
+
+    normalize : boolean, optional
+        If False, the regressors X are assumed to be already normalized.
+
+    max_iter : integer, optional
+        Maximum numbers of iterations to perform, therefore maximum features
+        to include. 10% of ``n_features`` but at least 5 if available.
+
+    cv : cross-validation generator, optional
+        see :mod:`sklearn.cross_validation`. If ``None`` is passed, default to
+        a 5-fold strategy
+
+    n_jobs : integer, optional
+        Number of CPUs to use during the cross validation. If ``-1``, use
+        all the CPUs
+
+    verbose : boolean or integer, optional
+        Sets the verbosity amount
+
+    Attributes
+    ----------
+    `n_nonzero_coefs_` : int
+        Estimated number of non-zero coefficients giving the best mean
+        squared error over the cross-validation folds.
+
+    `coef_` : array, shape (n_features,) or (n_features, n_targets)
+        parameter vector (w in the problem formulation).
+
+    `intercept_` : float or array, shape (n_targets,)
+        independent term in decision function.
+
+    See also
+    --------
+    orthogonal_mp
+    orthogonal_mp_gram
+    lars_path
+    Lars
+    LassoLars
+    OrthogonalMatchingPursuit
+    LarsCV
+    LassoLarsCV
+    decomposition.sparse_encode
+
+    """
+    def __init__(self, copy=True, fit_intercept=True, normalize=True,
+                 max_iter=None, cv=None, n_jobs=1, verbose=False):
+        self.copy = copy
+        self.fit_intercept = fit_intercept
+        self.normalize = normalize
+        self.max_iter = max_iter
+        self.cv = cv
+        self.n_jobs = n_jobs
+        self.verbose = verbose
+
+    def fit(self, X, y):
+        """Fit the model using X, y as training data.
+
+        Parameters
+        ----------
+        X : array-like, shape [n_samples, n_features]
+            Training data.
+
+        y : array-like, shape [n_samples]
+            Target values.
+
+        Returns
+        -------
+        self : object
+            returns an instance of self.
+        """
+        X = array2d(X)
+        cv = check_cv(self.cv, X, y, classifier=False)
+        max_iter = (min(max(int(0.1 * X.shape[1]), 5), X.shape[1])
+                    if not self.max_iter
+                    else self.max_iter)
+        cv_paths = Parallel(n_jobs=self.n_jobs, verbose=self.verbose)(
+            delayed(_omp_path_residues)(
+                X[train], y[train], X[test], y[test], self.copy,
+                self.fit_intercept, self.normalize, max_iter)
+            for train, test in cv)
+
+        min_early_stop = min(fold.shape[0] for fold in cv_paths)
+        mse_folds = np.array([(fold[:min_early_stop] ** 2).mean(axis=1)
+                              for fold in cv_paths])
+        best_n_nonzero_coefs = np.argmin(mse_folds.mean(axis=0)) + 1
+        self.n_nonzero_coefs_ = best_n_nonzero_coefs
+        omp = OrthogonalMatchingPursuit(n_nonzero_coefs=best_n_nonzero_coefs,
+                                        copy_X=None,
+                                        fit_intercept=self.fit_intercept,
+                                        normalize=self.normalize)
+        omp.fit(X, y)
+        self.coef_ = omp.coef_
+        self.intercept_ = omp.intercept_
+        return self
