@@ -1,7 +1,7 @@
 # Authors: Peter Prettenhofer <peter.prettenhofer@gmail.com> (main author)
 #          Mathieu Blondel (partial_fit support)
 #
-# License: BSD Style.
+# License: BSD 3 clause
 """Classification and regression using Stochastic Gradient Descent (SGD)."""
 
 import numpy as np
@@ -12,11 +12,14 @@ import warnings
 
 from ..externals.joblib import Parallel, delayed
 
-from .base import LinearClassifierMixin
+from .base import LinearClassifierMixin, SparseCoefMixin
 from ..base import BaseEstimator, RegressorMixin
-from ..feature_selection.selector_mixin import SelectorMixin
-from ..utils import array2d, atleast2d_or_csr, check_arrays, deprecated
+from ..feature_selection.from_model import _LearntSelectorMixin
+from ..utils import (array2d, atleast2d_or_csr, check_arrays, deprecated,
+                     column_or_1d)
 from ..utils.extmath import safe_sparse_dot
+from ..utils.multiclass import _check_partial_fit_first_call
+from ..externals import six
 
 from .sgd_fast import plain_sgd as plain_sgd
 from ..utils.seq_dataset import ArrayDataset, CSRDataset
@@ -44,11 +47,9 @@ DEFAULT_EPSILON = 0.1
 """Default value of ``epsilon`` parameter. """
 
 
-class BaseSGD(BaseEstimator):
+class BaseSGD(six.with_metaclass(ABCMeta, BaseEstimator, SparseCoefMixin)):
     """Base class for SGD classification and regression."""
 
-    __metaclass__ = ABCMeta
-
     def __init__(self, loss, penalty='l2', alpha=0.0001, C=1.0,
                  l1_ratio=0.15, fit_intercept=True, n_iter=5, shuffle=False,
                  verbose=0, epsilon=0.1, random_state=None,
@@ -114,8 +115,8 @@ class BaseSGD(BaseEstimator):
     def _init_t(self, loss_function):
         """Initialize iteration counter attr ``t_``.
 
-        If ``self.loss=='optimal'`` initialize ``t_`` such that ``eta`` at
-        first sample equals ``self.eta0``.
+        If ``self.learning_rate=='optimal'`` initialize ``t_`` such that
+        ``eta`` at first sample equals ``self.eta0``.
         """
         self.t_ = 1.0
         if self.learning_rate == "optimal":
@@ -283,7 +284,8 @@ def fit_binary(est, i, X, y, alpha, C, learning_rate, n_iter,
                      est.power_t, est.t_, intercept_decay)
 
 
-class BaseSGDClassifier(BaseSGD, LinearClassifierMixin):
+class BaseSGDClassifier(six.with_metaclass(ABCMeta, BaseSGD,
+                                           LinearClassifierMixin)):
 
     loss_functions = {
         "hinge": (Hinge, 1.0),
@@ -298,6 +300,7 @@ class BaseSGDClassifier(BaseSGD, LinearClassifierMixin):
                                         DEFAULT_EPSILON),
     }
 
+    @abstractmethod
     def __init__(self, loss="hinge", penalty='l2', alpha=0.0001, l1_ratio=0.15,
                  fit_intercept=True, n_iter=5, shuffle=False, verbose=0,
                  epsilon=DEFAULT_EPSILON, n_jobs=1, random_state=None,
@@ -326,7 +329,7 @@ class BaseSGDClassifier(BaseSGD, LinearClassifierMixin):
         self.n_jobs = int(n_jobs)
 
     @property
-    @deprecated("Parameter 'seed' war renamed to 'random_state' for"
+    @deprecated("Parameter 'seed' was renamed to 'random_state' for"
                 " consistency and will be removed in 0.15")
     def seed(self):
         return self.random_state
@@ -336,31 +339,24 @@ class BaseSGDClassifier(BaseSGD, LinearClassifierMixin):
                      classes, sample_weight,
                      coef_init, intercept_init):
         X = atleast2d_or_csr(X, dtype=np.float64, order="C")
-        y = np.asarray(y).ravel()
+        y = column_or_1d(y, warn=True)
 
         n_samples, n_features = X.shape
         _check_fit_data(X, y)
 
         self._validate_params()
-
-        if self.classes_ is None and classes is None:
-            raise ValueError("classes must be passed on the first call "
-                             "to partial_fit.")
-        elif classes is not None and self.classes_ is not None:
-            if not np.all(self.classes_ == np.unique(classes)):
-                raise ValueError("`classes` is not the same as on last call "
-                                 "to partial_fit.")
-        elif classes is not None:
-            self.classes_ = classes
+        _check_partial_fit_first_call(self, classes)
 
         n_classes = self.classes_.shape[0]
 
         # Allocate datastructures from input arguments
+        y_ind = np.searchsorted(self.classes_, y)   # XXX use a LabelBinarizer?
         self._expanded_class_weight = compute_class_weight(self.class_weight,
-                                                           self.classes_, y)
+                                                           self.classes_,
+                                                           y_ind)
         sample_weight = self._validate_sample_weight(sample_weight, n_samples)
 
-        if self.coef_ is None:
+        if self.coef_ is None or coef_init is not None:
             self._allocate_parameter_mem(n_classes, n_features,
                                          coef_init, intercept_init)
 
@@ -388,6 +384,9 @@ class BaseSGDClassifier(BaseSGD, LinearClassifierMixin):
     def _fit(self, X, y, alpha, C, loss, learning_rate,
              coef_init=None, intercept_init=None, class_weight=None,
              sample_weight=None):
+        if hasattr(self, "classes_"):
+            self.classes_ = None
+
         if class_weight is not None:
             warnings.warn("Using 'class_weight' as a parameter to the 'fit'"
                           "method is deprecated and will be removed in 0.13. "
@@ -449,7 +448,7 @@ class BaseSGDClassifier(BaseSGD, LinearClassifierMixin):
             delayed(fit_binary)(self, i, X, y, alpha, C, learning_rate,
                                 n_iter, self._expanded_class_weight[i], 1.,
                                 sample_weight)
-            for i in xrange(len(self.classes_)))
+            for i in range(len(self.classes_)))
 
         for i, (coef, intercept) in enumerate(result):
             self.coef_[i] = coef
@@ -500,7 +499,7 @@ class BaseSGDClassifier(BaseSGD, LinearClassifierMixin):
             Target values
 
         coef_init : array, shape = [n_classes,n_features]
-            The initial coeffients to warm-start the optimization.
+            The initial coefficients to warm-start the optimization.
 
         intercept_init : array, shape = [n_classes]
             The initial intercept to warm-start the optimization.
@@ -520,12 +519,19 @@ class BaseSGDClassifier(BaseSGD, LinearClassifierMixin):
                          sample_weight=sample_weight)
 
 
-class SGDClassifier(BaseSGDClassifier, SelectorMixin):
-    """Linear model fitted by minimizing a regularized empirical loss with SGD.
+class SGDClassifier(BaseSGDClassifier, _LearntSelectorMixin):
+    """Linear classifiers (SVM, logistic regression, a.o.) with SGD training.
 
-    SGD stands for Stochastic Gradient Descent: the gradient of the loss is
-    estimated each sample at a time and the model is updated along the way with
-    a decreasing strength schedule (aka learning rate).
+    This estimator implements regularized linear models with stochastic
+    gradient descent (SGD) learning: the gradient of the loss is estimated
+    each sample at a time and the model is updated along the way with a
+    decreasing strength schedule (aka learning rate). SGD allows minibatch
+    (online/out-of-core) learning, see the partial_fit method.
+
+    This implementation works with data represented as dense or sparse arrays
+    of floating point values for the features. The model it fits can be
+    controlled with the loss parameter; by default, it fits a linear support
+    vector machine (SVM).
 
     The regularizer is a penalty added to the loss function that shrinks model
     parameters towards the zero vector using either the squared euclidean norm
@@ -534,17 +540,20 @@ class SGDClassifier(BaseSGDClassifier, SelectorMixin):
     update is truncated to 0.0 to allow for learning sparse models and achieve
     online feature selection.
 
-    This implementation works with data represented as dense or sparse arrays
-    of floating point values for the features.
-
     Parameters
     ----------
-    loss : str, 'hinge' or 'log' or 'modified_huber'
-        The loss function to be used. Defaults to 'hinge'. The hinge loss is
-        a margin loss used by standard linear SVM models. The 'log' loss is
-        the loss of logistic regression models and can be used for
-        probability estimation in binary classifiers. 'modified_huber'
-        is another smooth loss that brings tolerance to outliers.
+    loss : str, 'hinge', 'log', 'modified_huber', 'squared_hinge',\
+                'perceptron', or a regression loss: 'squared_loss', 'huber',\
+                'epsilon_insensitive', or 'squared_epsilon_insensitive'
+        The loss function to be used. Defaults to 'hinge', which gives a
+        linear SVM.
+        The 'log' loss gives logistic regression, a probabilistic classifier.
+        'modified_huber' is another smooth loss that brings tolerance to
+        outliers as well as probability estimates.
+        'squared_hinge' is like hinge but is quadratically penalized.
+        'perceptron' is the linear loss used by the perceptron algorithm.
+        The other losses are designed for regression but can be useful in
+        classification as well; see SGDRegressor for a description.
 
     penalty : str, 'l2' or 'l1' or 'elasticnet'
         The penalty (aka regularization term) to be used. Defaults to 'l2'
@@ -580,10 +589,12 @@ class SGDClassifier(BaseSGDClassifier, SelectorMixin):
         The verbosity level
 
     epsilon: float
-        Epsilon in the epsilon-insensitive loss functions;
-        only if `loss=='huber'` or `loss='epsilon_insensitive'`.
-        If the difference between the current prediction and the correct label
-        is below this threshold, the model is not updated.
+        Epsilon in the epsilon-insensitive loss functions; only if `loss` is
+        'huber', 'epsilon_insensitive', or 'squared_epsilon_insensitive'.
+        For 'huber', determines the threshold at which it becomes less
+        important to get the prediction exactly right.
+        For epsilon-insensitive, any differences between the current prediction
+        and the correct label are ignored if they are less than this threshold.
 
     n_jobs: integer, optional
         The number of CPUs to use to do the OVA (One Versus All, for
@@ -647,10 +658,28 @@ class SGDClassifier(BaseSGDClassifier, SelectorMixin):
 
     """
 
+    def __init__(self, loss="hinge", penalty='l2', alpha=0.0001, l1_ratio=0.15,
+                 fit_intercept=True, n_iter=5, shuffle=False, verbose=0,
+                 epsilon=DEFAULT_EPSILON, n_jobs=1, random_state=None,
+                 learning_rate="optimal", eta0=0.0, power_t=0.5,
+                 class_weight=None, warm_start=False, rho=None, seed=None):
+        super(SGDClassifier, self).__init__(
+            loss=loss, penalty=penalty, alpha=alpha, l1_ratio=l1_ratio,
+            fit_intercept=fit_intercept, n_iter=n_iter, shuffle=shuffle,
+            verbose=verbose, epsilon=epsilon, n_jobs=n_jobs,
+            random_state=random_state, learning_rate=learning_rate, eta0=eta0,
+            power_t=power_t, class_weight=class_weight, warm_start=warm_start,
+            rho=rho, seed=seed)
+
     def predict_proba(self, X):
         """Probability estimates.
 
-        Probability estimates are only supported for binary classification.
+        Multiclass probability estimates are derived from binary (one-vs.-rest)
+        estimates by simple normalization, as recommended by Zadrozny and
+        Elkan.
+
+        Binary probability estimates for loss="modified_huber" are given by
+        (clip(decision_function(X), -1, 1) + 1) / 2.
 
         Parameters
         ----------
@@ -664,34 +693,59 @@ class SGDClassifier(BaseSGDClassifier, SelectorMixin):
 
         References
         ----------
+        Zadrozny and Elkan, "Transforming classifier scores into multiclass
+        probability estimates", SIGKDD'02,
+        http://www.research.ibm.com/people/z/zadrozny/kdd2002-Transf.pdf
 
         The justification for the formula in the loss="modified_huber"
         case is in the appendix B in:
         http://jmlr.csail.mit.edu/papers/volume2/zhang02c/zhang02c.pdf
         """
-        if len(self.classes_) != 2:
-            raise NotImplementedError("predict_(log_)proba only supported"
-                                      " for binary classification")
-
-        scores = self.decision_function(X)
-        proba = np.ones((scores.shape[0], 2), dtype=np.float64)
         if self.loss == "log":
-            proba[:, 1] = 1. / (1. + np.exp(-scores))
+            return self._predict_proba_lr(X)
 
         elif self.loss == "modified_huber":
-            proba[:, 1] = (np.clip(scores, -1, 1) + 1) / 2.
+            binary = (len(self.classes_) == 2)
+            scores = self.decision_function(X)
+
+            if binary:
+                prob2 = np.ones((scores.shape[0], 2))
+                prob = prob2[:, 1]
+            else:
+                prob = scores
+
+            np.clip(scores, -1, 1, prob)
+            prob += 1.
+            prob /= 2.
+
+            if binary:
+                prob2[:, 0] -= prob
+                prob = prob2
+            else:
+                # the above might assign zero to all classes, which doesn't
+                # normalize neatly; work around this to produce uniform
+                # probabilities
+                prob_sum = prob.sum(axis=1)
+                all_zero = (prob_sum == 0)
+                if np.any(all_zero):
+                    prob[all_zero, :] = 1
+                    prob_sum[all_zero] = len(self.classes_)
+
+                # normalize
+                prob /= prob_sum.reshape((prob.shape[0], -1))
+
+            return prob
 
         else:
             raise NotImplementedError("predict_(log_)proba only supported when"
                                       " loss='log' or loss='modified_huber' "
-                                      "(%s given)" % self.loss)
-        proba[:, 0] -= proba[:, 1]
-        return proba
+                                      "(%r given)" % self.loss)
 
     def predict_log_proba(self, X):
         """Log of probability estimates.
 
-        Log probability estimates are only supported for binary classification.
+        When loss="modified_huber", probability estimates may be hard zeros
+        and ones, so taking the logarithm is not possible.
 
         Parameters
         ----------
@@ -717,18 +771,12 @@ class BaseSGDRegressor(BaseSGD, RegressorMixin):
                                         DEFAULT_EPSILON),
     }
 
+    @abstractmethod
     def __init__(self, loss="squared_loss", penalty="l2", alpha=0.0001,
                  l1_ratio=0.15, fit_intercept=True, n_iter=5, shuffle=False,
-                 verbose=0, epsilon=DEFAULT_EPSILON, p=None, random_state=None,
+                 verbose=0, epsilon=DEFAULT_EPSILON, random_state=None,
                  learning_rate="invscaling", eta0=0.01, power_t=0.25,
                  warm_start=False, rho=None):
-        if p is not None:
-            warnings.warn("Using 'p' is deprecated and will be removed in "
-                          "scikit-learn 0.14, use epsilon instead.",
-                          DeprecationWarning, stacklevel=2)
-            self.p = float(p)
-            epsilon = p
-
         super(BaseSGDRegressor, self).__init__(loss=loss, penalty=penalty,
                                                alpha=alpha, l1_ratio=l1_ratio,
                                                fit_intercept=fit_intercept,
@@ -746,7 +794,7 @@ class BaseSGDRegressor(BaseSGD, RegressorMixin):
                      coef_init, intercept_init):
         X, y = check_arrays(X, y, sparse_format="csr", copy=False,
                             check_ccontiguous=True, dtype=np.float64)
-        y = y.ravel()
+        y = column_or_1d(y, warn=True)
 
         n_samples, n_features = X.shape
         _check_fit_data(X, y)
@@ -823,7 +871,7 @@ class BaseSGDRegressor(BaseSGD, RegressorMixin):
             Target values
 
         coef_init : array, shape = [n_features]
-            The initial coeffients to warm-start the optimization.
+            The initial coefficients to warm-start the optimization.
 
         intercept_init : array, shape = [1]
             The initial intercept to warm-start the optimization.
@@ -902,7 +950,7 @@ class BaseSGDRegressor(BaseSGD, RegressorMixin):
         self.intercept_ = np.atleast_1d(intercept)
 
 
-class SGDRegressor(BaseSGDRegressor, SelectorMixin):
+class SGDRegressor(BaseSGDRegressor, _LearntSelectorMixin):
     """Linear model fitted by minimizing a regularized empirical loss with SGD
 
     SGD stands for Stochastic Gradient Descent: the gradient of the loss is
@@ -921,10 +969,15 @@ class SGDRegressor(BaseSGDRegressor, SelectorMixin):
 
     Parameters
     ----------
-    loss : str, 'squared_loss' or 'huber'
+    loss : str, 'squared_loss', 'huber', 'epsilon_insensitive', \
+                or 'squared_epsilon_insensitive'
         The loss function to be used. Defaults to 'squared_loss' which refers
-        to the ordinary least squares fit. 'huber' is an epsilon insensitive
-        loss function for robust regression.
+        to the ordinary least squares fit. 'huber' modifies 'squared_loss' to
+        focus less on getting outliers correct by switching from squared to
+        linear loss past a distance of epsilon. 'epsilon_insensitive' ignores
+        errors less than epsilon and is linear past that; this is the loss
+        function used in SVR. 'squared_epsilon_insensitive' is the same but
+        becomes squared loss past a tolerance of epsilon.
 
     penalty : str, 'l2' or 'l1' or 'elasticnet'
         The penalty (aka regularization term) to be used. Defaults to 'l2'
@@ -960,10 +1013,12 @@ class SGDRegressor(BaseSGDRegressor, SelectorMixin):
         The verbosity level.
 
     epsilon: float
-        Epsilon in the epsilon-insensitive loss functions;
-        only if `loss=='huber'` or `loss='epsilon_insensitive'`.
-        If the difference between the current prediction and the correct label
-        is below this threshold, the model is not updated.
+        Epsilon in the epsilon-insensitive loss functions; only if `loss` is
+        'huber', 'epsilon_insensitive', or 'squared_epsilon_insensitive'.
+        For 'huber', determines the threshold at which it becomes less
+        important to get the prediction exactly right.
+        For epsilon-insensitive, any differences between the current prediction
+        and the correct label are ignored if they are less than this threshold.
 
     learning_rate : string, optional
         The learning rate:
@@ -1001,12 +1056,28 @@ class SGDRegressor(BaseSGDRegressor, SelectorMixin):
     >>> clf.fit(X, y)
     SGDRegressor(alpha=0.0001, epsilon=0.1, eta0=0.01, fit_intercept=True,
            l1_ratio=0.15, learning_rate='invscaling', loss='squared_loss',
-           n_iter=5, p=None, penalty='l2', power_t=0.25, random_state=None,
-           rho=None, shuffle=False, verbose=0, warm_start=False)
+           n_iter=5, penalty='l2', power_t=0.25, random_state=None, rho=None,
+           shuffle=False, verbose=0, warm_start=False)
 
     See also
     --------
     Ridge, ElasticNet, Lasso, SVR
 
     """
-    pass
+    def __init__(self, loss="squared_loss", penalty="l2", alpha=0.0001,
+                 l1_ratio=0.15, fit_intercept=True, n_iter=5, shuffle=False,
+                 verbose=0, epsilon=DEFAULT_EPSILON, random_state=None,
+                 learning_rate="invscaling", eta0=0.01, power_t=0.25,
+                 warm_start=False, rho=None):
+        super(SGDRegressor, self).__init__(loss=loss, penalty=penalty,
+                                               alpha=alpha, l1_ratio=l1_ratio,
+                                               fit_intercept=fit_intercept,
+                                               n_iter=n_iter, shuffle=shuffle,
+                                               verbose=verbose,
+                                               epsilon=epsilon,
+                                               random_state=random_state,
+                                               rho=rho,
+                                               learning_rate=learning_rate,
+                                               eta0=eta0, power_t=power_t,
+                                               warm_start=False)
+
