@@ -4,9 +4,10 @@ import scipy.sparse as sp
 from sklearn.utils.testing import assert_array_equal
 from sklearn.utils.testing import assert_array_almost_equal
 from sklearn.utils.testing import assert_equal
-from sklearn.utils.testing import assert_raises
-from sklearn.utils.testing import raises
 from sklearn.utils.testing import assert_greater
+from sklearn.utils.testing import assert_raises
+from sklearn.utils.testing import assert_true
+from sklearn.utils.testing import raises
 
 from sklearn.linear_model import logistic
 from sklearn import datasets
@@ -41,17 +42,19 @@ def test_predict_2_classes():
 
     Make sure it predicts the correct result on simple datasets.
     """
-    check_predictions(logistic.LogisticRegression(), X, Y1)
-    check_predictions(logistic.LogisticRegression(), X_sp, Y1)
+    check_predictions(logistic.LogisticRegression(random_state=0), X, Y1)
+    check_predictions(logistic.LogisticRegression(random_state=0), X_sp, Y1)
 
-    check_predictions(logistic.LogisticRegression(C=100), X, Y1)
-    check_predictions(logistic.LogisticRegression(C=100), X_sp, Y1)
-
-    check_predictions(logistic.LogisticRegression(fit_intercept=False),
+    check_predictions(logistic.LogisticRegression(C=100, random_state=0),
                       X, Y1)
-    check_predictions(logistic.LogisticRegression(fit_intercept=False),
+    check_predictions(logistic.LogisticRegression(C=100, random_state=0),
                       X_sp, Y1)
 
+    check_predictions(logistic.LogisticRegression(fit_intercept=False,
+                                                  random_state=0), X, Y1)
+    check_predictions(logistic.LogisticRegression(fit_intercept=False,
+                                                  random_state=0), X_sp, Y1)
+
 
 def test_error():
     """Test for appropriate exception on errors"""
@@ -64,7 +67,7 @@ def test_predict_3_classes():
 
 
 def test_predict_iris():
-    """Test logisic regression with the iris dataset"""
+    """Test logistic regression with the iris dataset"""
     n_samples, n_features = iris.data.shape
 
     target = iris.target_names[iris.target]
@@ -81,6 +84,29 @@ def test_predict_iris():
     assert_greater(np.mean(pred == target), .95)
 
 
+def test_sparsify():
+    """Test sparsify and densify members."""
+    n_samples, n_features = iris.data.shape
+    target = iris.target_names[iris.target]
+    clf = logistic.LogisticRegression(random_state=0).fit(iris.data, target)
+
+    pred_d_d = clf.decision_function(iris.data)
+
+    clf.sparsify()
+    assert_true(sp.issparse(clf.coef_))
+    pred_s_d = clf.decision_function(iris.data)
+
+    sp_data = sp.coo_matrix(iris.data)
+    pred_s_s = clf.decision_function(sp_data)
+
+    clf.densify()
+    pred_d_s = clf.decision_function(sp_data)
+
+    assert_array_almost_equal(pred_d_d, pred_s_d)
+    assert_array_almost_equal(pred_d_d, pred_s_s)
+    assert_array_almost_equal(pred_d_d, pred_d_s)
+
+
 def test_inconsistent_input():
     """Test that an exception is raised on inconsistent input"""
     rng = np.random.RandomState(0)
@@ -88,7 +114,7 @@ def test_inconsistent_input():
     y_ = np.ones(X_.shape[0])
     y_[0] = 0
 
-    clf = logistic.LogisticRegression()
+    clf = logistic.LogisticRegression(random_state=0)
 
     # Wrong dimensions for training data
     y_wrong = y_[:-1]
@@ -104,7 +130,7 @@ def test_write_parameters():
     #rng = np.random.RandomState(0)
     #X = rng.random_sample((5, 10))
     #y = np.ones(X.shape[0])
-    clf = logistic.LogisticRegression()
+    clf = logistic.LogisticRegression(random_state=0)
     clf.fit(X, Y1)
     clf.coef_[:] = 0
     clf.intercept_[:] = 0
@@ -119,7 +145,7 @@ def test_nan():
     """
     Xnan = np.array(X, dtype=np.float64)
     Xnan[0, 1] = np.nan
-    logistic.LogisticRegression().fit(Xnan, Y1)
+    logistic.LogisticRegression(random_state=0).fit(Xnan, Y1)
 
 
 def test_liblinear_random_state():
