@@ -1,5 +1,5 @@
 # Author: Vlad Niculae
-# License: BSD style
+# Licence: BSD 3 clause
 
 import warnings
 
@@ -13,8 +13,11 @@ from sklearn.utils.testing import assert_array_almost_equal
 from sklearn.utils.testing import assert_greater
 
 from sklearn.linear_model import (orthogonal_mp, orthogonal_mp_gram,
-                                  OrthogonalMatchingPursuit)
+                                  OrthogonalMatchingPursuit,
+                                  OrthogonalMatchingPursuitCV,
+                                  LinearRegression)
 from sklearn.utils.fixes import count_nonzero
+from sklearn.utils import check_random_state
 from sklearn.datasets import make_sparse_coded_signal
 
 n_samples, n_features, n_nonzero_coefs, n_targets = 20, 30, 5, 3
@@ -43,13 +46,13 @@ def test_n_nonzero_coefs():
     assert_true(count_nonzero(orthogonal_mp(X, y[:, 0],
                               n_nonzero_coefs=5)) <= 5)
     assert_true(count_nonzero(orthogonal_mp(X, y[:, 0], n_nonzero_coefs=5,
-                                            precompute_gram=True)) <= 5)
+                                            precompute=True)) <= 5)
 
 
 def test_tol():
     tol = 0.5
     gamma = orthogonal_mp(X, y[:, 0], tol=tol)
-    gamma_gram = orthogonal_mp(X, y[:, 0], tol=tol, precompute_gram=True)
+    gamma_gram = orthogonal_mp(X, y[:, 0], tol=tol, precompute=True)
     assert_true(np.sum((y[:, 0] - np.dot(X, gamma)) ** 2) <= tol)
     assert_true(np.sum((y[:, 0] - np.dot(X, gamma_gram)) ** 2) <= tol)
 
@@ -57,13 +60,13 @@ def test_tol():
 def test_with_without_gram():
     assert_array_almost_equal(
         orthogonal_mp(X, y, n_nonzero_coefs=5),
-        orthogonal_mp(X, y, n_nonzero_coefs=5, precompute_gram=True))
+        orthogonal_mp(X, y, n_nonzero_coefs=5, precompute=True))
 
 
 def test_with_without_gram_tol():
     assert_array_almost_equal(
         orthogonal_mp(X, y, tol=1.),
-        orthogonal_mp(X, y, tol=1., precompute_gram=True))
+        orthogonal_mp(X, y, tol=1., precompute=True))
 
 
 def test_unreachable_accuracy():
@@ -74,8 +77,8 @@ def test_unreachable_accuracy():
             orthogonal_mp(X, y, n_nonzero_coefs=n_features))
 
         assert_array_almost_equal(
-            orthogonal_mp(X, y, tol=0, precompute_gram=True),
-            orthogonal_mp(X, y, precompute_gram=True,
+            orthogonal_mp(X, y, tol=0, precompute=True),
+            orthogonal_mp(X, y, precompute=True,
                           n_nonzero_coefs=n_features))
         assert_greater(len(w), 0)  # warnings should be raised
 
@@ -92,7 +95,6 @@ def test_bad_input():
 
 
 def test_perfect_signal_recovery():
-    # XXX: use signal generator
     idx, = gamma[:, 0].nonzero()
     gamma_rec = orthogonal_mp(X, y[:, 0], 5)
     gamma_gram = orthogonal_mp_gram(G, Xy[:, 0], 5)
@@ -116,15 +118,21 @@ def test_estimator():
 
     omp.set_params(fit_intercept=False, normalize=False)
 
-    omp.fit(X, y[:, 0], Gram=G, Xy=Xy[:, 0])
-    assert_equal(omp.coef_.shape, (n_features,))
-    assert_equal(omp.intercept_, 0)
-    assert_true(count_nonzero(omp.coef_) <= n_nonzero_coefs)
+    with warnings.catch_warnings(record=True) as w:
+        warnings.simplefilter('always')
+        omp.fit(X, y[:, 0], Gram=G, Xy=Xy[:, 0])
+        assert_equal(omp.coef_.shape, (n_features,))
+        assert_equal(omp.intercept_, 0)
+        assert_true(count_nonzero(omp.coef_) <= n_nonzero_coefs)
+        assert_true(len(w) == 2)
 
-    omp.fit(X, y, Gram=G, Xy=Xy)
-    assert_equal(omp.coef_.shape, (n_targets, n_features))
-    assert_equal(omp.intercept_, 0)
-    assert_true(count_nonzero(omp.coef_) <= n_targets * n_nonzero_coefs)
+    with warnings.catch_warnings(record=True) as w:
+        warnings.simplefilter('always')
+        omp.fit(X, y, Gram=G, Xy=Xy)
+        assert_equal(omp.coef_.shape, (n_targets, n_features))
+        assert_equal(omp.intercept_, 0)
+        assert_true(count_nonzero(omp.coef_) <= n_targets * n_nonzero_coefs)
+        assert_true(len(w) == 2)
 
 
 def test_scaling_with_gram():
@@ -139,15 +147,15 @@ def test_scaling_with_gram():
                                          fit_intercept=False, normalize=True)
         omp1.fit(X, y, Gram=G)
         omp1.fit(X, y, Gram=G, Xy=Xy)
-        assert_true(len(w) == 0)
-        omp2.fit(X, y, Gram=G)
-        assert_true(len(w) == 1)
-        omp2.fit(X, y, Gram=G, Xy=Xy)
-        assert_true(len(w) == 2)
-        omp3.fit(X, y, Gram=G)
         assert_true(len(w) == 3)
+        omp2.fit(X, y, Gram=G)
+        assert_true(len(w) == 5)
+        omp2.fit(X, y, Gram=G, Xy=Xy)
+        assert_true(len(w) == 8)
+        omp3.fit(X, y, Gram=G)
+        assert_true(len(w) == 10)
         omp3.fit(X, y, Gram=G, Xy=Xy)
-        assert_true(len(w) == 4)
+        assert_true(len(w) == 13)
 
 
 def test_identical_regressors():
@@ -186,3 +194,42 @@ def test_no_atoms():
         gamma_empty_gram = orthogonal_mp_gram(G, Xy_empty, 1)
     assert_equal(np.all(gamma_empty == 0), True)
     assert_equal(np.all(gamma_empty_gram == 0), True)
+
+
+def test_omp_path():
+    path = orthogonal_mp(X, y, n_nonzero_coefs=5, return_path=True)
+    last = orthogonal_mp(X, y, n_nonzero_coefs=5, return_path=False)
+    assert_equal(path.shape, (n_features, n_targets, 5))
+    assert_array_almost_equal(path[:, :, -1], last)
+    path = orthogonal_mp_gram(G, Xy, n_nonzero_coefs=5, return_path=True)
+    last = orthogonal_mp_gram(G, Xy, n_nonzero_coefs=5, return_path=False)
+    assert_equal(path.shape, (n_features, n_targets, 5))
+    assert_array_almost_equal(path[:, :, -1], last)
+
+
+def test_omp_cv():
+    y_ = y[:, 0]
+    gamma_ = gamma[:, 0]
+    ompcv = OrthogonalMatchingPursuitCV(normalize=True, fit_intercept=False,
+                                        max_iter=10, cv=5)
+    ompcv.fit(X, y_)
+    assert_equal(ompcv.n_nonzero_coefs_, n_nonzero_coefs)
+    assert_array_almost_equal(ompcv.coef_, gamma_)
+    omp = OrthogonalMatchingPursuit(normalize=True, fit_intercept=False,
+                                    n_nonzero_coefs=ompcv.n_nonzero_coefs_)
+    omp.fit(X, y_)
+    assert_array_almost_equal(ompcv.coef_, omp.coef_)
+
+
+def test_omp_reaches_least_squares():
+    # Use small simple data; it's a sanity check but OMP can stop early
+    rng = check_random_state(0)
+    n_samples, n_features = (10, 8)
+    n_targets = 3
+    X = rng.randn(n_samples, n_features)
+    Y = rng.randn(n_samples, n_targets)
+    omp = OrthogonalMatchingPursuit(n_nonzero_coefs=n_features)
+    lstsq = LinearRegression()
+    omp.fit(X, Y)
+    lstsq.fit(X, Y)
+    assert_array_almost_equal(omp.coef_, lstsq.coef_)
