@@ -45,7 +45,7 @@ class DPGMMTester(GMMTester):
     do_test_eval = False
 
     def score(self, g, train_obs):
-        _, z = g.eval(train_obs)
+        _, z = g.score_samples(train_obs)
         return g.lower_bound(train_obs, z)
 
 
@@ -74,7 +74,7 @@ class VBGMMTester(GMMTester):
     do_test_eval = False
 
     def score(self, g, train_obs):
-        _, z = g.eval(train_obs)
+        _, z = g.score_samples(train_obs)
         return g.lower_bound(train_obs, z)
 
 
