@@ -1,4 +1,3 @@
-import itertools
 import unittest
 
 from nose.tools import assert_true
@@ -51,7 +50,7 @@ def _naive_lmvnpdf_diag(X, mu, cv):
     # slow and naive implementation of lmvnpdf
     ref = np.empty((len(X), len(mu)))
     stds = np.sqrt(cv)
-    for i, (m, std) in enumerate(itertools.izip(mu, stds)):
+    for i, (m, std) in enumerate(zip(mu, stds)):
         ref[:, i] = np.log(stats.norm.pdf(X, m, std)).sum(axis=1)
     return ref
 
@@ -162,11 +161,11 @@ class GMMTester():
         g.covars_ = self.covars[self.covariance_type]
         g.weights_ = self.weights
 
-        gaussidx = np.repeat(range(self.n_components), 5)
+        gaussidx = np.repeat(np.arange(self.n_components), 5)
         n_samples = len(gaussidx)
         X = rng.randn(n_samples, self.n_features) + g.means_[gaussidx]
 
-        ll, responsibilities = g.eval(X)
+        ll, responsibilities = g.score_samples(X)
 
         self.assertEqual(len(ll), n_samples)
         self.assertEqual(responsibilities.shape,
@@ -206,7 +205,7 @@ class GMMTester():
         # the log likelihood to make sure that it increases after each
         # iteration.
         trainll = []
-        for iter in xrange(5):
+        for _ in range(5):
             g.params = params
             g.init_params = ''
             g.fit(X)
