@@ -14,18 +14,23 @@ multiclass classifier. It is also possible to use these estimators with
 multiclass estimators in the hope that their accuracy or runtime performance
 improves.
 
-The one-vs-the-rest meta-classifier also implements a `predic_proba` method, so
-long as such a method is implemented by the base classifier. This method
+All classifiers in scikit-learn implement multiclass classification; you
+only need to use this module if you want to experiment with custom multiclass
+strategies.
+
+The one-vs-the-rest meta-classifier also implements a `predict_proba` method,
+so long as such a method is implemented by the base classifier. This method
 returns probabilities of class membership in both the single label and
 multilabel case.  Note that in the multilabel case, probabilities are the
 marginal probability that a given sample falls in the given class. As such, in
 the multilabel case the sum of these probabilities over all possible labels
 for a given sample *will not* sum to unity, as they do in the single label
-case.  """
+case.
+"""
 
 # Author: Mathieu Blondel <mathieu@mblondel.org>
 #
-# License: BSD Style.
+# License: BSD 3 clause
 
 import numpy as np
 import warnings
@@ -152,7 +157,6 @@ class OneVsRestClassifier(BaseEstimator, ClassifierMixin, MetaEstimatorMixin):
         or `predict_proba`.
 
     n_jobs : int, optional, default: 1
-
         The number of jobs to use for the computation. If -1 all CPUs are used.
         If 1 is given, no parallel computing code is used at all, which is
         useful for debugging. For n_jobs below -1, (n_cpus + 1 + n_jobs) are
@@ -206,7 +210,7 @@ class OneVsRestClassifier(BaseEstimator, ClassifierMixin, MetaEstimatorMixin):
 
         Parameters
         ----------
-        X: {array-like, sparse matrix}, shape = [n_samples, n_features]
+        X : {array-like, sparse matrix}, shape = [n_samples, n_features]
             Data.
 
         Returns
@@ -244,10 +248,29 @@ class OneVsRestClassifier(BaseEstimator, ClassifierMixin, MetaEstimatorMixin):
         return predict_proba_ovr(self.estimators_, X,
                                  is_multilabel=self.multilabel_)
 
+    def decision_function(self, X):
+        """Returns the distance of each sample from the decision boundary for
+        each class. This can only be used with estimators which implement the
+        decision_function method.
+
+        Parameters
+        ----------
+        X : array-like, shape = [n_samples, n_features]
+
+        Returns
+        -------
+        T : array-like, shape = [n_samples, n_classes]
+        """
+        if not hasattr(self.estimators_[0], "decision_function"):
+            raise AttributeError(
+                "Base estimator doesn't have a decision_function attribute.")
+        return np.array([est.decision_function(X).ravel()
+                         for est in self.estimators_]).T
+
     @property
     def multilabel_(self):
         """Whether this is a multilabel classifier"""
-        return self.label_binarizer_.multilabel
+        return self.label_binarizer_.multilabel_
 
     def score(self, X, y):
         if self.multilabel_:
@@ -311,11 +334,12 @@ def predict_ovo(estimators, classes, X):
         for j in range(i + 1, n_classes):
             pred = estimators[k].predict(X)
             score = _predict_binary(estimators[k], X)
-            scores[:, 0] += score
-            scores[:, 1] -= score
+            scores[:, i] += score
+            scores[:, j] -= score
             votes[pred == 0, i] += 1
             votes[pred == 1, j] += 1
             k += 1
+
     # find all places with maximum votes per sample
     maxima = votes == np.max(votes, axis=1)[:, np.newaxis]
 
@@ -347,7 +371,6 @@ class OneVsOneClassifier(BaseEstimator, ClassifierMixin, MetaEstimatorMixin):
         An estimator object implementing `fit` and `predict`.
 
     n_jobs : int, optional, default: 1
-
         The number of jobs to use for the computation. If -1 all CPUs are used.
         If 1 is given, no parallel computing code is used at all, which is
         useful for debugging. For n_jobs below -1, (n_cpus + 1 + n_jobs) are
@@ -371,7 +394,7 @@ class OneVsOneClassifier(BaseEstimator, ClassifierMixin, MetaEstimatorMixin):
 
         Parameters
         ----------
-        X: {array-like, sparse matrix}, shape = [n_samples, n_features]
+        X : {array-like, sparse matrix}, shape = [n_samples, n_features]
             Data.
 
         y : numpy array of shape [n_samples]
@@ -414,10 +437,10 @@ def fit_ecoc(estimator, X, y, code_size=1.5, random_state=None, n_jobs=1):
         An estimator object implementing `fit` and one of `decision_function`
         or `predict_proba`.
 
-    code_size: float, optional
+    code_size : float, optional
         Percentage of the number of classes to be used to create the code book.
 
-    random_state: numpy.RandomState, optional
+    random_state : numpy.RandomState, optional
         The generator used to initialize the codebook. Defaults to
         numpy.random.
 
@@ -452,7 +475,7 @@ def fit_ecoc(estimator, X, y, code_size=1.5, random_state=None, n_jobs=1):
 
     cls_idx = dict((c, i) for i, c in enumerate(classes))
 
-    Y = np.array([code_book[cls_idx[y[i]]] for i in xrange(X.shape[0])],
+    Y = np.array([code_book[cls_idx[y[i]]] for i in range(X.shape[0])],
                  dtype=np.int)
 
     estimators = Parallel(n_jobs=n_jobs)(
@@ -498,7 +521,6 @@ class OutputCodeClassifier(BaseEstimator, ClassifierMixin, MetaEstimatorMixin):
         numpy.random.
 
     n_jobs : int, optional, default: 1
-
         The number of jobs to use for the computation. If -1 all CPUs are used.
         If 1 is given, no parallel computing code is used at all, which is
         useful for debugging. For n_jobs below -1, (n_cpus + 1 + n_jobs) are
@@ -548,7 +570,7 @@ class OutputCodeClassifier(BaseEstimator, ClassifierMixin, MetaEstimatorMixin):
 
         Parameters
         ----------
-        X: {array-like, sparse matrix}, shape = [n_samples, n_features]
+        X : {array-like, sparse matrix}, shape = [n_samples, n_features]
             Data.
 
         y : numpy array of shape [n_samples]
@@ -568,7 +590,7 @@ class OutputCodeClassifier(BaseEstimator, ClassifierMixin, MetaEstimatorMixin):
 
         Parameters
         ----------
-        X: {array-like, sparse matrix}, shape = [n_samples, n_features]
+        X : {array-like, sparse matrix}, shape = [n_samples, n_features]
             Data.
 
         Returns
