@@ -4,13 +4,18 @@ algorithm.
 """
 
 from .ball_tree import BallTree
+from .kd_tree import KDTree
+from .dist_metrics import DistanceMetric
 from .graph import kneighbors_graph, radius_neighbors_graph
 from .unsupervised import NearestNeighbors
 from .classification import KNeighborsClassifier, RadiusNeighborsClassifier
 from .regression import KNeighborsRegressor, RadiusNeighborsRegressor
 from .nearest_centroid import NearestCentroid
+from .kde import KernelDensity
 
 __all__ = ['BallTree',
+           'DistanceMetric',
+           'KDTree',
            'KNeighborsClassifier',
            'KNeighborsRegressor',
            'NearestCentroid',
@@ -18,4 +23,5 @@ __all__ = ['BallTree',
            'RadiusNeighborsClassifier',
            'RadiusNeighborsRegressor',
            'kneighbors_graph',
-           'radius_neighbors_graph']
+           'radius_neighbors_graph',
+           'KernelDensity']
