@@ -3,35 +3,53 @@
 #          Fabian Pedregosa <fabian.pedregosa@inria.fr>
 #          Alexandre Gramfort <alexandre.gramfort@inria.fr>
 #          Sparseness support by Lars Buitinck <L.J.Buitinck@uva.nl>
+#          Multi-output support by Arnaud Joly <a.joly@ulg.ac.be>
 #
-# License: BSD, (C) INRIA, University of Amsterdam
+# License: BSD 3 clause (C) INRIA, University of Amsterdam
 import warnings
+from abc import ABCMeta, abstractmethod
 
 import numpy as np
-from abc import ABCMeta, abstractmethod
 from scipy.sparse import csr_matrix, issparse
-from scipy.spatial.ckdtree import cKDTree
 
 from .ball_tree import BallTree
+from .kd_tree import KDTree
 from ..base import BaseEstimator
 from ..metrics import pairwise_distances
+from ..metrics.pairwise import PAIRWISE_DISTANCE_FUNCTIONS
 from ..utils import safe_asarray, atleast2d_or_csr, check_arrays
+from ..utils.validation import DataConversionWarning
 from ..utils.fixes import unique
+from ..externals import six
+
+
+VALID_METRICS = dict(ball_tree=BallTree.valid_metrics,
+                     kd_tree=KDTree.valid_metrics,
+                     # The following list comes from the
+                     # sklearn.metrics.pairwise doc string
+                     brute=(list(PAIRWISE_DISTANCE_FUNCTIONS.keys()) +
+                            ['braycurtis', 'canberra', 'chebyshev',
+                             'correlation', 'cosine', 'dice', 'hamming',
+                             'jaccard', 'kulsinski', 'mahalanobis',
+                             'matching', 'minkowski', 'rogerstanimoto',
+                             'russellrao', 'seuclidean', 'sokalmichener',
+                             'sokalsneath', 'sqeuclidean',
+                             'yule', 'wminkowski']))
+
+
+VALID_METRICS_SPARSE = dict(ball_tree=[],
+                            kd_tree=[],
+                            brute=PAIRWISE_DISTANCE_FUNCTIONS.keys())
 
 
 class NeighborsWarning(UserWarning):
     pass
 
+
 # Make sure that NeighborsWarning are displayed more than once
 warnings.simplefilter("always", NeighborsWarning)
 
 
-def warn_equidistant():
-    msg = ("kneighbors: neighbor k+1 and neighbor k have the same "
-           "distance: results will be dependent on data order.")
-    warnings.warn(msg, NeighborsWarning, stacklevel=3)
-
-
 def _check_weights(weights):
     """Check to make sure weights are valid"""
     if weights in (None, 'uniform', 'distance'):
@@ -71,37 +89,73 @@ def _get_weights(dist, weights):
                          "'distance', or a callable function")
 
 
-class NeighborsBase(BaseEstimator):
+class NeighborsBase(six.with_metaclass(ABCMeta, BaseEstimator)):
     """Base class for nearest neighbors estimators."""
-    __metaclass__ = ABCMeta
 
     @abstractmethod
     def __init__(self):
         pass
 
-    #FIXME: include float parameter p for using different distance metrics.
-    # this can be passed directly to BallTree and cKDTree.  Brute-force will
-    # rely on soon-to-be-updated functionality in the pairwise module.
     def _init_params(self, n_neighbors=None, radius=None,
-                     algorithm='auto', leaf_size=30,
-                     warn_on_equidistant=True, p=2):
+                     algorithm='auto', leaf_size=30, metric='minkowski',
+                     p=2, **kwargs):
         self.n_neighbors = n_neighbors
         self.radius = radius
         self.algorithm = algorithm
         self.leaf_size = leaf_size
-        self.warn_on_equidistant = warn_on_equidistant
+        self.metric = metric
+        self.metric_kwds = kwargs
         self.p = p
 
-        if algorithm not in ['auto', 'brute', 'kd_tree', 'ball_tree']:
+        if algorithm not in ['auto', 'brute',
+                             'kd_tree', 'ball_tree']:
             raise ValueError("unrecognized algorithm: '%s'" % algorithm)
-        if p < 1:
-            raise ValueError("p must be greater than or equal to 1")
+
+        if algorithm == 'auto':
+            alg_check = 'ball_tree'
+        else:
+            alg_check = algorithm
+
+        if callable(metric):
+            if algorithm == 'kd_tree':
+                # callable metric is only valid for brute force and ball_tree
+                raise ValueError(
+                    "kd_tree algorithm does not support callable metric '%s'"
+                    % metric)
+        elif metric not in VALID_METRICS[alg_check]:
+            raise ValueError("Metric '%s' not valid for algorithm '%s'"
+                             % (metric, algorithm))
+
+        if self.metric in ['wminkowski', 'minkowski']:
+            self.metric_kwds['p'] = p
+            if p < 1:
+                raise ValueError("p must be greater than one "
+                                 "for minkowski metric")
 
         self._fit_X = None
         self._tree = None
         self._fit_method = None
 
     def _fit(self, X):
+        self.effective_metric_ = self.metric
+        self.effective_metric_kwds_ = self.metric_kwds
+
+        # For minkowski distance, use more efficient methods where available
+        if self.metric == 'minkowski':
+            self.effective_metric_kwds_ = self.metric_kwds.copy()
+            p = self.effective_metric_kwds_.pop('p', 2)
+            if p < 1:
+                raise ValueError("p must be greater than one "
+                                 "for minkowski metric")
+            elif p == 1:
+                self.effective_metric_ = 'manhattan'
+            elif p == 2:
+                self.effective_metric_ = 'euclidean'
+            elif p == np.inf:
+                self.effective_metric_ = 'chebyshev'
+            else:
+                self.effective_metric_kwds_['p'] = p
+
         if isinstance(X, NeighborsBase):
             self._fit_X = X._fit_X
             self._tree = X._tree
@@ -114,7 +168,7 @@ class NeighborsBase(BaseEstimator):
             self._fit_method = 'ball_tree'
             return self
 
-        elif isinstance(X, cKDTree):
+        elif isinstance(X, KDTree):
             self._fit_X = X.data
             self._tree = X
             self._fit_method = 'kd_tree'
@@ -125,10 +179,17 @@ class NeighborsBase(BaseEstimator):
         if X.ndim != 2:
             raise ValueError("data type not understood")
 
+        n_samples = X.shape[0]
+        if n_samples == 0:
+            raise ValueError("n_samples must be greater than 0")
+
         if issparse(X):
             if self.algorithm not in ('auto', 'brute'):
                 warnings.warn("cannot use tree with sparse input: "
                               "using brute force")
+            if self.effective_metric_ not in VALID_METRICS_SPARSE['brute']:
+                raise ValueError("metric '%s' not valid for sparse input"
+                                 % self.effective_metric_)
             self._fit_X = X.tocsr()
             self._tree = None
             self._fit_method = 'brute'
@@ -138,18 +199,25 @@ class NeighborsBase(BaseEstimator):
         self._fit_X = X
 
         if self._fit_method == 'auto':
-            # BallTree outperforms the others in nearly any circumstance.
-            if self.n_neighbors is None:
-                self._fit_method = 'ball_tree'
-            elif self.n_neighbors < self._fit_X.shape[0] // 2:
-                self._fit_method = 'ball_tree'
+            # A tree approach is better for small number of neighbors,
+            # and KDTree is generally faster when available
+            if (self.n_neighbors is None
+                    or self.n_neighbors < self._fit_X.shape[0] // 2):
+                if self.effective_metric_ in VALID_METRICS['kd_tree']:
+                    self._fit_method = 'kd_tree'
+                else:
+                    self._fit_method = 'ball_tree'
             else:
                 self._fit_method = 'brute'
 
-        if self._fit_method == 'kd_tree':
-            self._tree = cKDTree(X, self.leaf_size)
-        elif self._fit_method == 'ball_tree':
-            self._tree = BallTree(X, self.leaf_size, p=self.p)
+        if self._fit_method == 'ball_tree':
+            self._tree = BallTree(X, self.leaf_size,
+                                  metric=self.effective_metric_,
+                                  **self.effective_metric_kwds_)
+        elif self._fit_method == 'kd_tree':
+            self._tree = KDTree(X, self.leaf_size,
+                                metric=self.effective_metric_,
+                                **self.effective_metric_kwds_)
         elif self._fit_method == 'brute':
             self._tree = None
         else:
@@ -220,49 +288,30 @@ class KNeighborsMixin(object):
             n_neighbors = self.n_neighbors
 
         if self._fit_method == 'brute':
-            if self.p == 1:
-                dist = pairwise_distances(X, self._fit_X, 'manhattan')
-            elif self.p == 2:
+            # for efficiency, use squared euclidean distances
+            if self.effective_metric_ == 'euclidean':
                 dist = pairwise_distances(X, self._fit_X, 'euclidean',
                                           squared=True)
-            elif self.p == np.inf:
-                dist = pairwise_distances(X, self._fit_X, 'chebyshev')
             else:
-                dist = pairwise_distances(X, self._fit_X, 'minkowski',
-                                          p=self.p)
+                dist = pairwise_distances(X, self._fit_X,
+                                          self.effective_metric_,
+                                          **self.effective_metric_kwds_)
+
             # XXX: should be implemented with a partial sort
             neigh_ind = dist.argsort(axis=1)
-            if self.warn_on_equidistant and n_neighbors < self._fit_X.shape[0]:
-                ii = np.arange(dist.shape[0])
-                ind_k = neigh_ind[:, n_neighbors - 1]
-                ind_k1 = neigh_ind[:, n_neighbors]
-                if np.any(dist[ii, ind_k] == dist[ii, ind_k1]):
-                    warn_equidistant()
             neigh_ind = neigh_ind[:, :n_neighbors]
             if return_distance:
                 j = np.arange(neigh_ind.shape[0])[:, None]
-                if self.p == 2:
+                if self.effective_metric_ == 'euclidean':
                     return np.sqrt(dist[j, neigh_ind]), neigh_ind
                 else:
                     return dist[j, neigh_ind], neigh_ind
             else:
                 return neigh_ind
-        elif self._fit_method == 'ball_tree':
+        elif self._fit_method in ['ball_tree', 'kd_tree']:
             result = self._tree.query(X, n_neighbors,
                                       return_distance=return_distance)
-            if self.warn_on_equidistant and self._tree.warning_flag:
-                warn_equidistant()
             return result
-        elif self._fit_method == 'kd_tree':
-            dist, ind = self._tree.query(X, n_neighbors, p=self.p)
-            # kd_tree returns a 1D array for n_neighbors = 1
-            if n_neighbors == 1:
-                dist = dist[:, None]
-                ind = ind[:, None]
-            if return_distance:
-                return dist, ind
-            else:
-                return ind
         else:
             raise ValueError("internal: _fit_method not recognized")
 
@@ -367,7 +416,7 @@ class RadiusNeighborsMixin(object):
 
         Examples
         --------
-        In the following example, we construnct a NeighborsClassifier
+        In the following example, we construct a NeighborsClassifier
         class from an array representing our data set and ask who's
         the closest point to [1,1,1]
 
@@ -401,18 +450,15 @@ class RadiusNeighborsMixin(object):
             radius = self.radius
 
         if self._fit_method == 'brute':
-            if self.p == 1:
-                dist = pairwise_distances(X, self._fit_X, 'manhattan')
-            elif self.p == 2:
+            # for efficiency, use squared euclidean distances
+            if self.effective_metric_ == 'euclidean':
                 dist = pairwise_distances(X, self._fit_X, 'euclidean',
                                           squared=True)
                 radius *= radius
-            elif self.p == np.inf:
-                dist = pairwise_distances(X, self._fit_X, 'chebyshev')
             else:
-                dist = pairwise_distances(X, self._fit_X, 'minkowski',
-                                          p=self.p)
-
+                dist = pairwise_distances(X, self._fit_X,
+                                          self.effective_metric_,
+                                          **self.effective_metric_kwds_)
             neigh_ind = [np.where(d < radius)[0] for d in dist]
 
             # if there are the same number of neighbors for each point,
@@ -426,7 +472,7 @@ class RadiusNeighborsMixin(object):
                 dtype_F = object
 
             if return_distance:
-                if self.p == 2:
+                if self.effective_metric_ == 'euclidean':
                     dist = np.array([np.sqrt(d[neigh_ind[i]])
                                      for i, d in enumerate(dist)],
                                     dtype=dtype_F)
@@ -437,40 +483,14 @@ class RadiusNeighborsMixin(object):
                 return dist, neigh_ind
             else:
                 return neigh_ind
-        elif self._fit_method == 'ball_tree':
+        elif self._fit_method in ['ball_tree', 'kd_tree']:
+            results = self._tree.query_radius(X, radius,
+                                              return_distance=return_distance)
             if return_distance:
-                ind, dist = self._tree.query_radius(X, radius,
-                                                    return_distance=True)
+                ind, dist = results
                 return dist, ind
             else:
-                ind = self._tree.query_radius(X, radius,
-                                              return_distance=False)
-                return ind
-        elif self._fit_method == 'kd_tree':
-            Npts = self._fit_X.shape[0]
-            dist, ind = self._tree.query(X, Npts,
-                                         distance_upper_bound=radius,
-                                         p=self.p)
-
-            ind = [ind_i[:ind_i.searchsorted(Npts)] for ind_i in ind]
-
-            # if there are the same number of neighbors for each point,
-            # we can do a normal array.  Otherwise, we return an object
-            # array with elements that are numpy arrays
-            try:
-                ind = np.asarray(ind, dtype=int)
-                dtype_F = float
-            except ValueError:
-                ind = np.asarray(ind, dtype='object')
-                dtype_F = object
-
-            if return_distance:
-                dist = np.array([dist_i[:len(ind[i])]
-                                 for i, dist_i in enumerate(dist)],
-                                dtype=dtype_F)
-                return dist, ind
-            else:
-                return ind
+                return results
         else:
             raise ValueError("internal: _fit_method not recognized")
 
@@ -556,14 +576,15 @@ class SupervisedFloatMixin(object):
 
         Parameters
         ----------
-        X : {array-like, sparse matrix, BallTree, cKDTree}
-            Training data. If array or matrix, then the shape
-            is [n_samples, n_features]
+        X : {array-like, sparse matrix, BallTree, KDTree}
+            Training data. If array or matrix, shape = [n_samples, n_features]
 
-        y : {array-like, sparse matrix}, shape = [n_samples]
-            Target values, array of float values.
+        y : {array-like, sparse matrix}
+            Target values, array of float values, shape = [n_samples]
+             or [n_samples, n_outputs]
         """
-        X, y = check_arrays(X, y, sparse_format="csr")
+        if not isinstance(X, (KDTree, BallTree)):
+            X, y = check_arrays(X, y, sparse_format="csr")
         self._y = y
         return self._fit(X)
 
@@ -574,15 +595,38 @@ class SupervisedIntegerMixin(object):
 
         Parameters
         ----------
-        X : {array-like, sparse matrix, BallTree, cKDTree}
-            Training data. If array or matrix, then the shape
-            is [n_samples, n_features]
+        X : {array-like, sparse matrix, BallTree, KDTree}
+            Training data. If array or matrix, shape = [n_samples, n_features]
+
+        y : {array-like, sparse matrix}
+            Target values of shape = [n_samples] or [n_samples, n_outputs]
 
-        y : {array-like, sparse matrix}, shape = [n_samples]
-            Target values, array of integer values.
         """
-        X, y = check_arrays(X, y, sparse_format="csr")
-        self.classes_, self._y = unique(y, return_inverse=True)
+        if not isinstance(X, (KDTree, BallTree)):
+            X, y = check_arrays(X, y, sparse_format="csr")
+
+        if y.ndim == 1 or y.ndim == 2 and y.shape[1] == 1:
+            if y.ndim != 1:
+                warnings.warn("A column-vector y was passed when a 1d array"
+                              "was expected. Please change the shape of y to"
+                              "(n_samples, ), for example using ravel().",
+                              DataConversionWarning, stacklevel=2)
+
+            self.outputs_2d_ = False
+            y = y.reshape((-1, 1))
+        else:
+            self.outputs_2d_ = True
+
+        self.classes_ = []
+        self._y = np.empty(y.shape, dtype=np.int)
+        for k in range(self._y.shape[1]):
+            classes, self._y[:, k] = unique(y[:, k], return_inverse=True)
+            self.classes_.append(classes)
+
+        if not self.outputs_2d_:
+            self.classes_ = self.classes_[0]
+            self._y = self._y.ravel()
+
         return self._fit(X)
 
 
@@ -592,7 +636,7 @@ class UnsupervisedMixin(object):
 
         Parameters
         ----------
-        X : {array-like, sparse matrix, BallTree, cKDTree}
+        X : {array-like, sparse matrix, BallTree, KDTree}
             Training data. If array or matrix, shape = [n_samples, n_features]
         """
         return self._fit(X)
