@@ -4,8 +4,11 @@
 #          Fabian Pedregosa <fabian.pedregosa@inria.fr>
 #          Alexandre Gramfort <alexandre.gramfort@inria.fr>
 #          Sparseness support by Lars Buitinck <L.J.Buitinck@uva.nl>
+#          Multi-output support by Arnaud Joly <a.joly@ulg.ac.be>
 #
-# License: BSD, (C) INRIA, University of Amsterdam
+# License: BSD 3 clause (C) INRIA, University of Amsterdam
+
+import warnings
 
 import numpy as np
 from scipy import stats
@@ -46,7 +49,7 @@ class KNeighborsClassifier(NeighborsBase, KNeighborsMixin,
         Algorithm used to compute the nearest neighbors:
 
         - 'ball_tree' will use :class:`BallTree`
-        - 'kd_tree' will use :class:`scipy.spatial.cKDtree`
+        - 'kd_tree' will use :class:`KDTree`
         - 'brute' will use a brute-force search.
         - 'auto' will attempt to decide the most appropriate algorithm
           based on the values passed to :meth:`fit` method.
@@ -55,25 +58,26 @@ class KNeighborsClassifier(NeighborsBase, KNeighborsMixin,
         this parameter, using brute force.
 
     leaf_size : int, optional (default = 30)
-        Leaf size passed to BallTree or cKDTree.  This can affect the
+        Leaf size passed to BallTree or KDTree.  This can affect the
         speed of the construction and query, as well as the memory
         required to store the tree.  The optimal value depends on the
         nature of the problem.
 
-    warn_on_equidistant : boolean, optional.  Defaults to True.
-        Generate a warning if equidistant neighbors are discarded.
-        For classification or regression based on k-neighbors, if
-        neighbor k and neighbor k+1 have identical distances but
-        different labels, then the result will be dependent on the
-        ordering of the training data.
-        If the fit method is ``'kd_tree'``, no warnings will be generated.
+    metric : string or DistanceMetric object (default='minkowski')
+        the distance metric to use for the tree.  The default metric is
+        minkowski, and with p=2 is equivalent to the standard Euclidean
+        metric. See the documentation of the DistanceMetric class for a
+        list of available metrics.
 
-    p: integer, optional (default = 2)
-        Parameter for the Minkowski metric from
-        sklearn.metrics.pairwise.pairwise_distances. When p = 1, this is
+    p : integer, optional (default = 2)
+        Power parameter for the Minkowski metric. When p = 1, this is
         equivalent to using manhattan_distance (l1), and euclidean_distance
         (l2) for p = 2. For arbitrary p, minkowski_distance (l_p) is used.
 
+    **kwargs :
+        additional keyword arguments are passed to the distance function as
+        additional arguments.
+
     Examples
     --------
     >>> X = [[0], [1], [2], [3]]
@@ -99,18 +103,29 @@ class KNeighborsClassifier(NeighborsBase, KNeighborsMixin,
     See :ref:`Nearest Neighbors <neighbors>` in the online documentation
     for a discussion of the choice of ``algorithm`` and ``leaf_size``.
 
+    .. warning::
+
+       Regarding the Nearest Neighbors algorithms, if it is found that two
+       neighbors, neighbor `k+1` and `k`, have identical distances but
+       but different labels, the results will depend on the ordering of the
+       training data.
+
     http://en.wikipedia.org/wiki/K-nearest_neighbor_algorithm
     """
 
     def __init__(self, n_neighbors=5,
-                 weights='uniform',
-                 algorithm='auto', leaf_size=30,
-                 warn_on_equidistant=True, p=2):
+                 weights='uniform', algorithm='auto', leaf_size=30,
+                 p=2, metric='minkowski', **kwargs):
+        if kwargs:
+            if 'warn_on_equidistant' in kwargs:
+                kwargs.pop('warn_on_equidistant')
+                warnings.warn("The warn_on_equidistant parameter is "
+                              "deprecated and will be removed in 0.16.",
+                              DeprecationWarning,
+                              stacklevel=2)
         self._init_params(n_neighbors=n_neighbors,
                           algorithm=algorithm,
-                          leaf_size=leaf_size,
-                          warn_on_equidistant=warn_on_equidistant,
-                          p=p)
+                          leaf_size=leaf_size, metric=metric, p=p, **kwargs)
         self.weights = _check_weights(weights)
 
     def predict(self, X):
@@ -118,62 +133,92 @@ class KNeighborsClassifier(NeighborsBase, KNeighborsMixin,
 
         Parameters
         ----------
-        X: array
+        X : array of shape [n_samples, n_features]
             A 2-D array representing the test points.
 
         Returns
         -------
-        labels: array
-            List of class labels (one for each data sample).
+        y : array of shape [n_samples] or [n_samples, n_outputs]
+            Class labels for each data sample.
         """
         X = atleast2d_or_csr(X)
 
         neigh_dist, neigh_ind = self.kneighbors(X)
-        pred_labels = self._y[neigh_ind]
 
+        classes_ = self.classes_
+        _y = self._y
+        if not self.outputs_2d_:
+            _y = self._y.reshape((-1, 1))
+            classes_ = [self.classes_]
+
+        n_outputs = len(classes_)
+        n_samples = X.shape[0]
         weights = _get_weights(neigh_dist, self.weights)
 
-        if weights is None:
-            mode, _ = stats.mode(pred_labels, axis=1)
-        else:
-            mode, _ = weighted_mode(pred_labels, weights, axis=1)
+        y_pred = np.empty((n_samples, n_outputs), dtype=classes_[0].dtype)
+        for k, classes_k in enumerate(classes_):
+            if weights is None:
+                mode, _ = stats.mode(_y[neigh_ind, k], axis=1)
+            else:
+                mode, _ = weighted_mode(_y[neigh_ind, k], weights, axis=1)
 
-        return self.classes_.take(mode.flatten().astype(np.int))
+            y_pred[:, k] = classes_k.take(mode.flatten().astype(np.int))
+
+        if not self.outputs_2d_:
+            y_pred = y_pred.ravel()
+
+        return y_pred
 
     def predict_proba(self, X):
         """Return probability estimates for the test data X.
 
         Parameters
         ----------
-        X: array, shape = (n_samples, n_features)
+        X : array, shape = (n_samples, n_features)
             A 2-D array representing the test points.
 
         Returns
         -------
-        probabilities : array, shape = [n_samples, n_classes]
-            Probabilities of the samples for each class in the model,
-            where classes are ordered arithmetically.
+        p : array of shape = [n_samples, n_classes], or a list of n_outputs
+            of such arrays if n_outputs > 1.
+            The class probabilities of the input samples. Classes are ordered
+            by lexicographic order.
         """
         X = atleast2d_or_csr(X)
 
         neigh_dist, neigh_ind = self.kneighbors(X)
-        pred_labels = self._y[neigh_ind]
+
+        classes_ = self.classes_
+        _y = self._y
+        if not self.outputs_2d_:
+            _y = self._y.reshape((-1, 1))
+            classes_ = [self.classes_]
+
+        n_samples = X.shape[0]
 
         weights = _get_weights(neigh_dist, self.weights)
-
         if weights is None:
-            weights = np.ones_like(pred_labels)
+            weights = np.ones_like(neigh_ind)
 
-        probabilities = np.zeros((X.shape[0], self.classes_.size))
-
-        # a simple ':' index doesn't work right
         all_rows = np.arange(X.shape[0])
+        probabilities = []
+        for k, classes_k in enumerate(classes_):
+            pred_labels = _y[:, k][neigh_ind]
+            proba_k = np.zeros((n_samples, classes_k.size))
 
-        for i, idx in enumerate(pred_labels.T):  # loop is O(n_neighbors)
-            probabilities[all_rows, idx] += weights[:, i]
+            # a simple ':' index doesn't work right
+            for i, idx in enumerate(pred_labels.T):  # loop is O(n_neighbors)
+                proba_k[all_rows, idx] += weights[:, i]
 
-        # normalize 'votes' into real [0,1] probabilities
-        probabilities = (probabilities.T / probabilities.sum(axis=1)).T
+            # normalize 'votes' into real [0,1] probabilities
+            normalizer = proba_k.sum(axis=1)[:, np.newaxis]
+            normalizer[normalizer == 0.0] = 1.0
+            proba_k /= normalizer
+
+            probabilities.append(proba_k)
+
+        if not self.outputs_2d_:
+            probabilities = probabilities[0]
 
         return probabilities
 
@@ -206,7 +251,7 @@ class RadiusNeighborsClassifier(NeighborsBase, RadiusNeighborsMixin,
         Algorithm used to compute the nearest neighbors:
 
         - 'ball_tree' will use :class:`BallTree`
-        - 'kd_tree' will use :class:`scipy.spatial.cKDtree`
+        - 'kd_tree' will use :class:`KDtree`
         - 'brute' will use a brute-force search.
         - 'auto' will attempt to decide the most appropriate algorithm
           based on the values passed to :meth:`fit` method.
@@ -215,22 +260,31 @@ class RadiusNeighborsClassifier(NeighborsBase, RadiusNeighborsMixin,
         this parameter, using brute force.
 
     leaf_size : int, optional (default = 30)
-        Leaf size passed to BallTree or cKDTree.  This can affect the
+        Leaf size passed to BallTree or KDTree.  This can affect the
         speed of the construction and query, as well as the memory
         required to store the tree.  The optimal value depends on the
         nature of the problem.
 
-    p: integer, optional (default = 2)
-        Parameter for the Minkowski metric from
-        sklearn.metrics.pairwise.pairwise_distances. When p = 1, this is
+    metric : string or DistanceMetric object (default='minkowski')
+        the distance metric to use for the tree.  The default metric is
+        minkowski, and with p=2 is equivalent to the standard Euclidean
+        metric. See the documentation of the DistanceMetric class for a
+        list of available metrics.
+
+    p : integer, optional (default = 2)
+        Power parameter for the Minkowski metric. When p = 1, this is
         equivalent to using manhattan_distance (l1), and euclidean_distance
         (l2) for p = 2. For arbitrary p, minkowski_distance (l_p) is used.
 
-    outlier_label: int, optional (default = None)
+    outlier_label : int, optional (default = None)
         Label, which is given for outlier samples (samples with no
         neighbors on given radius).
         If set to None, ValueError is raised, when outlier is detected.
 
+    **kwargs :
+        additional keyword arguments are passed to the distance function as
+        additional arguments.
+
     Examples
     --------
     >>> X = [[0], [1], [2], [3]]
@@ -258,11 +312,12 @@ class RadiusNeighborsClassifier(NeighborsBase, RadiusNeighborsMixin,
     """
 
     def __init__(self, radius=1.0, weights='uniform',
-                 algorithm='auto', leaf_size=30, p=2, outlier_label=None):
+                 algorithm='auto', leaf_size=30, p=2, metric='minkowski',
+                 outlier_label=None, **kwargs):
         self._init_params(radius=radius,
                           algorithm=algorithm,
                           leaf_size=leaf_size,
-                          p=p)
+                          metric=metric, p=p, **kwargs)
         self.weights = _check_weights(weights)
         self.outlier_label = outlier_label
 
@@ -271,13 +326,14 @@ class RadiusNeighborsClassifier(NeighborsBase, RadiusNeighborsMixin,
 
         Parameters
         ----------
-        X: array
+        X : array of shape [n_samples, n_features]
             A 2-D array representing the test points.
 
         Returns
         -------
-        labels: array
-            List of class labels (one for each data sample).
+        y : array of shape [n_samples] or [n_samples, n_outputs]
+            Class labels for each data sample.
+
         """
         X = atleast2d_or_csr(X)
         n_samples = X.shape[0]
@@ -286,6 +342,13 @@ class RadiusNeighborsClassifier(NeighborsBase, RadiusNeighborsMixin,
         inliers = [i for i, nind in enumerate(neigh_ind) if len(nind) != 0]
         outliers = [i for i, nind in enumerate(neigh_ind) if len(nind) == 0]
 
+        classes_ = self.classes_
+        _y = self._y
+        if not self.outputs_2d_:
+            _y = self._y.reshape((-1, 1))
+            classes_ = [self.classes_]
+        n_outputs = len(classes_)
+
         if self.outlier_label is not None:
             neigh_dist[outliers] = 1e-6
         elif outliers:
@@ -297,20 +360,27 @@ class RadiusNeighborsClassifier(NeighborsBase, RadiusNeighborsMixin,
 
         weights = _get_weights(neigh_dist, self.weights)
 
-        pred_labels = np.array([self._y[ind] for ind in neigh_ind],
-                               dtype=object)
-        if weights is None:
-            mode = np.array([stats.mode(pl)[0] for pl in pred_labels[inliers]],
-                            dtype=np.int)
-        else:
-            mode = np.array([weighted_mode(pl, w)[0]
-                             for (pl, w) in zip(pred_labels[inliers], weights)],
-                            dtype=np.int)
+        y_pred = np.empty((n_samples, n_outputs), dtype=classes_[0].dtype)
+        for k, classes_k in enumerate(classes_):
+            pred_labels = np.array([_y[ind, k] for ind in neigh_ind],
+                                   dtype=object)
+            if weights is None:
+                mode = np.array([stats.mode(pl)[0]
+                                 for pl in pred_labels[inliers]], dtype=np.int)
+            else:
+                mode = np.array([weighted_mode(pl, w)[0]
+                                 for (pl, w)
+                                 in zip(pred_labels[inliers], weights)],
+                                dtype=np.int)
+
+            mode = mode.ravel().astype(np.int)
+
+            y_pred[inliers, k] = classes_k.take(mode)
 
-        mode = mode.ravel().astype(np.int)
-        prediction = np.empty(n_samples, dtype=self.classes_.dtype)
-        prediction[inliers] = self.classes_.take(mode)
         if outliers:
-            prediction[outliers] = self.outlier_label
+            y_pred[outliers, :] = self.outlier_label
 
-        return prediction
+        if not self.outputs_2d_:
+            y_pred = y_pred.ravel()
+
+        return y_pred
