@@ -4,15 +4,16 @@
 #          Fabian Pedregosa <fabian.pedregosa@inria.fr>
 #          Alexandre Gramfort <alexandre.gramfort@inria.fr>
 #          Sparseness support by Lars Buitinck <L.J.Buitinck@uva.nl>
+#          Multi-output support by Arnaud Joly <a.joly@ulg.ac.be>
 #
-# License: BSD, (C) INRIA, University of Amsterdam
+# License: BSD 3 clause (C) INRIA, University of Amsterdam
+
+import warnings
 
 import numpy as np
 
-from .base import \
-    _get_weights, _check_weights, \
-    NeighborsBase, KNeighborsMixin, \
-    RadiusNeighborsMixin, SupervisedFloatMixin
+from .base import _get_weights, _check_weights, NeighborsBase, KNeighborsMixin
+from .base import RadiusNeighborsMixin, SupervisedFloatMixin
 from ..base import RegressorMixin
 from ..utils import atleast2d_or_csr
 
@@ -48,7 +49,7 @@ class KNeighborsRegressor(NeighborsBase, KNeighborsMixin,
         Algorithm used to compute the nearest neighbors:
 
         - 'ball_tree' will use :class:`BallTree`
-        - 'kd_tree' will use :class:`scipy.spatial.cKDtree`
+        - 'kd_tree' will use :class:`KDtree`
         - 'brute' will use a brute-force search.
         - 'auto' will attempt to decide the most appropriate algorithm
           based on the values passed to :meth:`fit` method.
@@ -57,25 +58,26 @@ class KNeighborsRegressor(NeighborsBase, KNeighborsMixin,
         this parameter, using brute force.
 
     leaf_size : int, optional (default = 30)
-        Leaf size passed to BallTree or cKDTree.  This can affect the
+        Leaf size passed to BallTree or KDTree.  This can affect the
         speed of the construction and query, as well as the memory
         required to store the tree.  The optimal value depends on the
         nature of the problem.
 
-    warn_on_equidistant : boolean, optional.  Defaults to True.
-        Generate a warning if equidistant neighbors are discarded.
-        For classification or regression based on k-neighbors, if
-        neighbor k and neighbor k+1 have identical distances but
-        different labels, then the result will be dependent on the
-        ordering of the training data.
-        If the fit method is ``'kd_tree'``, no warnings will be generated.
+    metric : string or DistanceMetric object (default='minkowski')
+        the distance metric to use for the tree.  The default metric is
+        minkowski, and with p=2 is equivalent to the standard Euclidean
+        metric. See the documentation of the DistanceMetric class for a
+        list of available metrics.
 
-    p: integer, optional (default = 2)
-        Parameter for the Minkowski metric from
-        sklearn.metrics.pairwise.pairwise_distances. When p = 1, this is
+    p : integer, optional (default = 2)
+        Power parameter for the Minkowski metric. When p = 1, this is
         equivalent to using manhattan_distance (l1), and euclidean_distance
         (l2) for p = 2. For arbitrary p, minkowski_distance (l_p) is used.
 
+    **kwargs :
+        additional keyword arguments are passed to the distance function as
+        additional arguments.
+
     Examples
     --------
     >>> X = [[0], [1], [2], [3]]
@@ -99,17 +101,29 @@ class KNeighborsRegressor(NeighborsBase, KNeighborsMixin,
     See :ref:`Nearest Neighbors <neighbors>` in the online documentation
     for a discussion of the choice of ``algorithm`` and ``leaf_size``.
 
+    .. warning::
+
+       Regarding the Nearest Neighbors algorithms, if it is found that two
+       neighbors, neighbor `k+1` and `k`, have identical distances but
+       but different labels, the results will depend on the ordering of the
+       training data.
+
     http://en.wikipedia.org/wiki/K-nearest_neighbor_algorithm
     """
 
     def __init__(self, n_neighbors=5, weights='uniform',
-                 algorithm='auto', leaf_size=30, warn_on_equidistant=True,
-                 p=2):
+                 algorithm='auto', leaf_size=30,
+                 p=2, metric='minkowski', **kwargs):
+        if kwargs:
+            if 'warn_on_equidistant' in kwargs:
+                kwargs.pop('warn_on_equidistant')
+                warnings.warn("The warn_on_equidistant parameter is "
+                              "deprecated and will be removed in the future",
+                              DeprecationWarning,
+                              stacklevel=2)
         self._init_params(n_neighbors=n_neighbors,
                           algorithm=algorithm,
-                          leaf_size=leaf_size,
-                          warn_on_equidistant=warn_on_equidistant,
-                          p=p)
+                          leaf_size=leaf_size, metric=metric, p=p, **kwargs)
         self.weights = _check_weights(weights)
 
     def predict(self, X):
@@ -117,13 +131,13 @@ class KNeighborsRegressor(NeighborsBase, KNeighborsMixin,
 
         Parameters
         ----------
-        X : array
-            A 2-D array representing the test data.
+        X : array or matrix, shape = [n_samples, n_features]
+
 
         Returns
         -------
-        y: array
-            List of target values (one for each data sample).
+        y : array of int, shape = [n_samples] or [n_samples, n_outputs]
+            Target values
         """
         X = atleast2d_or_csr(X)
 
@@ -131,12 +145,24 @@ class KNeighborsRegressor(NeighborsBase, KNeighborsMixin,
 
         weights = _get_weights(neigh_dist, self.weights)
 
+        _y = self._y
+        if _y.ndim == 1:
+            _y = _y.reshape((-1, 1))
+
         if weights is None:
-            return np.mean(self._y[neigh_ind], axis=1)
+            y_pred = np.mean(_y[neigh_ind], axis=1)
         else:
-            num = np.sum(self._y[neigh_ind] * weights, axis=1)
+            y_pred = np.empty((X.shape[0], _y.shape[1]), dtype=np.float)
             denom = np.sum(weights, axis=1)
-            return num / denom
+
+            for j in range(_y.shape[1]):
+                num = np.sum(_y[neigh_ind, j] * weights, axis=1)
+                y_pred[:, j] = num / denom
+
+        if self._y.ndim == 1:
+            y_pred = y_pred.ravel()
+
+        return y_pred
 
 
 class RadiusNeighborsRegressor(NeighborsBase, RadiusNeighborsMixin,
@@ -171,7 +197,7 @@ class RadiusNeighborsRegressor(NeighborsBase, RadiusNeighborsMixin,
         Algorithm used to compute the nearest neighbors:
 
         - 'ball_tree' will use :class:`BallTree`
-        - 'kd_tree' will use :class:`scipy.spatial.cKDtree`
+        - 'kd_tree' will use :class:`KDtree`
         - 'brute' will use a brute-force search.
         - 'auto' will attempt to decide the most appropriate algorithm
           based on the values passed to :meth:`fit` method.
@@ -180,17 +206,25 @@ class RadiusNeighborsRegressor(NeighborsBase, RadiusNeighborsMixin,
         this parameter, using brute force.
 
     leaf_size : int, optional (default = 30)
-        Leaf size passed to BallTree or cKDTree.  This can affect the
+        Leaf size passed to BallTree or KDTree.  This can affect the
         speed of the construction and query, as well as the memory
         required to store the tree.  The optimal value depends on the
         nature of the problem.
 
-    p: integer, optional (default = 2)
-        Parameter for the Minkowski metric from
-        sklearn.metrics.pairwise.pairwise_distances. When p = 1, this is
+    metric : string or DistanceMetric object (default='minkowski')
+        the distance metric to use for the tree.  The default metric is
+        minkowski, and with p=2 is equivalent to the standard Euclidean
+        metric. See the documentation of the DistanceMetric class for a
+        list of available metrics.
+
+    p : integer, optional (default = 2)
+        Power parameter for the Minkowski metric. When p = 1, this is
         equivalent to using manhattan_distance (l1), and euclidean_distance
         (l2) for p = 2. For arbitrary p, minkowski_distance (l_p) is used.
 
+    **kwargs :
+        additional keyword arguments are passed to the distance function as
+        additional arguments.
 
     Examples
     --------
@@ -219,11 +253,12 @@ class RadiusNeighborsRegressor(NeighborsBase, RadiusNeighborsMixin,
     """
 
     def __init__(self, radius=1.0, weights='uniform',
-                 algorithm='auto', leaf_size=30, p=2):
+                 algorithm='auto', leaf_size=30,
+                 p=2, metric='minkowski', **kwargs):
         self._init_params(radius=radius,
                           algorithm=algorithm,
                           leaf_size=leaf_size,
-                          p=p)
+                          p=p, metric=metric, **kwargs)
         self.weights = _check_weights(weights)
 
     def predict(self, X):
@@ -231,13 +266,12 @@ class RadiusNeighborsRegressor(NeighborsBase, RadiusNeighborsMixin,
 
         Parameters
         ----------
-        X : array
-            A 2-D array representing the test data.
+        X : array or matrix, shape = [n_samples, n_features]
 
         Returns
         -------
-        y: array
-            List of target values (one for each data sample).
+        y : array of int, shape = [n_samples] or [n_samples, n_outputs]
+            Target values
         """
         X = atleast2d_or_csr(X)
 
@@ -245,10 +279,19 @@ class RadiusNeighborsRegressor(NeighborsBase, RadiusNeighborsMixin,
 
         weights = _get_weights(neigh_dist, self.weights)
 
+        _y = self._y
+        if _y.ndim == 1:
+            _y = _y.reshape((-1, 1))
+
         if weights is None:
-            return np.array([np.mean(self._y[ind])
-                             for ind in neigh_ind])
+            y_pred = np.array([np.mean(_y[ind, :], axis=0)
+                               for ind in neigh_ind])
         else:
-            return np.array([(np.sum(self._y[ind] * weights[i])
-                              / np.sum(weights[i]))
-                             for (i, ind) in enumerate(neigh_ind)])
+            y_pred = np.array([(np.average(_y[ind, :], axis=0,
+                                           weights=weights[i]))
+                               for (i, ind) in enumerate(neigh_ind)])
+
+        if self._y.ndim == 1:
+            y_pred = y_pred.ravel()
+
+        return y_pred
