@@ -4,15 +4,16 @@ Quadratic Discriminant Analysis
 
 # Author: Matthieu Perrot <matthieu.perrot@gmail.com>
 #
-# License: BSD Style.
+# License: BSD 3 clause
 
 import warnings
 
 import numpy as np
 
 from .base import BaseEstimator, ClassifierMixin
+from .externals.six.moves import xrange
 from .utils.fixes import unique
-from .utils import check_arrays, array2d
+from .utils import check_arrays, array2d, column_or_1d
 
 __all__ = ['QDA']
 
@@ -32,6 +33,10 @@ class QDA(BaseEstimator, ClassifierMixin):
     priors : array, optional, shape = [n_classes]
         Priors on classes
 
+    reg_param : float, optional
+        Regularizes the covariance estimate as
+        ``(1-reg_param)*Sigma + reg_param*np.eye(n_features)``
+
     Attributes
     ----------
     `covariances_` : list of array-like, shape = [n_features, n_features]
@@ -60,7 +65,7 @@ class QDA(BaseEstimator, ClassifierMixin):
     >>> y = np.array([1, 1, 1, 2, 2, 2])
     >>> clf = QDA()
     >>> clf.fit(X, y)
-    QDA(priors=None)
+    QDA(priors=None, reg_param=0.0)
     >>> print(clf.predict([[-0.8, -1]]))
     [1]
 
@@ -69,8 +74,9 @@ class QDA(BaseEstimator, ClassifierMixin):
     sklearn.lda.LDA: Linear discriminant analysis
     """
 
-    def __init__(self, priors=None):
+    def __init__(self, priors=None, reg_param=0.):
         self.priors = np.asarray(priors) if priors is not None else None
+        self.reg_param = reg_param
 
     def fit(self, X, y, store_covariances=False, tol=1.0e-4):
         """
@@ -90,6 +96,7 @@ class QDA(BaseEstimator, ClassifierMixin):
             `self.covariances_` attribute.
         """
         X, y = check_arrays(X, y)
+        y = column_or_1d(y, warn=True)
         self.classes_, y = unique(y, return_inverse=True)
         n_samples, n_features = X.shape
         n_classes = len(self.classes_)
@@ -117,6 +124,7 @@ class QDA(BaseEstimator, ClassifierMixin):
             if rank < n_features:
                 warnings.warn("Variables are collinear")
             S2 = (S ** 2) / (len(Xg) - 1)
+            S2 = ((1 - self.reg_param) * S2) + self.reg_param
             if store_covariances:
                 # cov = V * (S^2 / (n-1)) * V.T
                 cov.append(np.dot(S2 * Vt.T, Vt))
@@ -129,13 +137,6 @@ class QDA(BaseEstimator, ClassifierMixin):
         self.rotations_ = rotations
         return self
 
-    @property
-    def classes(self):  # pragma: no cover
-        warnings.warn("QDA.classes is deprecated and will be removed in 0.14. "
-                      "Use QDA.classes_ instead.", DeprecationWarning,
-                      stacklevel=2)
-        return self.classes_
-
     @property
     def scalings(self):  # pragma: no cover
         warnings.warn("QDA.scalings is deprecated and will be removed in 0.15."
@@ -217,7 +218,7 @@ class QDA(BaseEstimator, ClassifierMixin):
         values = self._decision_function(X)
         # compute the likelihood of the underlying gaussian models
         # up to a multiplicative constant.
-        likelihood = np.exp(values - values.min(axis=1)[:, np.newaxis])
+        likelihood = np.exp(values - values.max(axis=1)[:, np.newaxis])
         # compute posterior probabilities
         return likelihood / likelihood.sum(axis=1)[:, np.newaxis]
 
