@@ -22,8 +22,11 @@ def configuration(parent_package='', top_path=None):
     config.add_subpackage('feature_extraction/tests')
     config.add_subpackage('cluster')
     config.add_subpackage('cluster/tests')
+    config.add_subpackage('cluster/bicluster')
+    config.add_subpackage('cluster/bicluster/tests')
     config.add_subpackage('covariance')
     config.add_subpackage('covariance/tests')
+    config.add_subpackage('cross_decomposition')
     config.add_subpackage('decomposition')
     config.add_subpackage('decomposition/tests')
     config.add_subpackage("ensemble")
@@ -38,6 +41,8 @@ def configuration(parent_package='', top_path=None):
     config.add_subpackage('gaussian_process')
     config.add_subpackage('gaussian_process/tests')
     config.add_subpackage('neighbors')
+    config.add_subpackage('neural_network')
+    config.add_subpackage('preprocessing')
     config.add_subpackage('manifold')
     config.add_subpackage('metrics')
     config.add_subpackage('semi_supervised')
@@ -46,6 +51,8 @@ def configuration(parent_package='', top_path=None):
     config.add_subpackage('metrics/tests')
     config.add_subpackage('metrics/cluster')
     config.add_subpackage('metrics/cluster/tests')
+    config.add_subpackage('metrics/cluster/bicluster')
+    config.add_subpackage('metrics/cluster/bicluster/tests')
 
     # add cython extension module for hmm
     config.add_extension(
@@ -54,6 +61,12 @@ def configuration(parent_package='', top_path=None):
         include_dirs=[numpy.get_include()],
         libraries=libraries,
     )
+    config.add_extension(
+        '_isotonic',
+        sources=['_isotonic.c'],
+        include_dirs=[numpy.get_include()],
+        libraries=libraries,
+    )
 
     # some libs needs cblas, fortran-compiled BLAS will not be sufficient
     blas_info = get_info('blas_opt', 0)
