@@ -1,3 +1,5 @@
+from __future__ import print_function
+
 import numpy as np
 import scipy.sparse as sp
 import warnings
@@ -7,10 +9,11 @@ from . import libsvm, liblinear
 from . import libsvm_sparse
 from ..base import BaseEstimator, ClassifierMixin
 from ..preprocessing import LabelEncoder
-from ..utils import atleast2d_or_csr, array2d, check_random_state
+from ..utils import atleast2d_or_csr, array2d, check_random_state, column_or_1d
 from ..utils import ConvergenceWarning, compute_class_weight, deprecated
 from ..utils.fixes import unique
 from ..utils.extmath import safe_sparse_dot
+from ..externals import six
 
 
 LIBSVM_IMPL = ['c_svc', 'nu_svc', 'one_class', 'epsilon_svr', 'nu_svr']
@@ -31,10 +34,10 @@ def _one_vs_one_coef(dual_coef, n_support, support_vectors):
     # would have to take care in the sparse case
     coef = []
     sv_locs = np.cumsum(np.hstack([[0], n_support]))
-    for class1 in xrange(n_class):
+    for class1 in range(n_class):
         # SVs for class1:
         sv1 = support_vectors[sv_locs[class1]:sv_locs[class1 + 1], :]
-        for class2 in xrange(class1 + 1, n_class):
+        for class2 in range(class1 + 1, n_class):
             # SVs for class1:
             sv2 = support_vectors[sv_locs[class2]:sv_locs[class2 + 1], :]
 
@@ -49,35 +52,29 @@ def _one_vs_one_coef(dual_coef, n_support, support_vectors):
     return coef
 
 
-class BaseLibSVM(BaseEstimator):
+class BaseLibSVM(six.with_metaclass(ABCMeta, BaseEstimator)):
     """Base class for estimators that use libsvm as backing library
 
     This implements support vector machine classification and regression.
 
     Parameter documentation is in the derived `SVC` class.
     """
-    # see ./classes.py for SVC class.
 
-    __metaclass__ = ABCMeta
+    # The order of these must match the integer values in LibSVM.
+    # XXX These are actually the same in the dense case. Need to factor
+    # this out.
     _sparse_kernels = ["linear", "poly", "rbf", "sigmoid", "precomputed"]
 
     @abstractmethod
     def __init__(self, impl, kernel, degree, gamma, coef0,
                  tol, C, nu, epsilon, shrinking, probability, cache_size,
-                 sparse, class_weight, verbose, max_iter):
+                 class_weight, verbose, max_iter, random_state):
 
         if not impl in LIBSVM_IMPL:  # pragma: no cover
             raise ValueError("impl should be one of %s, %s was given" % (
                 LIBSVM_IMPL, impl))
 
-        if C is None:  # pragma: no cover
-            warnings.warn("Using 'None' for C of BaseLibSVM is deprecated "
-                          "since version 0.12, and backward compatibility "
-                          "won't be maintained from version 0.14 onward. "
-                          "Setting C=1.0.", DeprecationWarning, stacklevel=2)
-            C = 1.0
-
-        self.impl = impl
+        self._impl = impl
         self.kernel = kernel
         self.degree = degree
         self.gamma = gamma
@@ -89,31 +86,32 @@ class BaseLibSVM(BaseEstimator):
         self.shrinking = shrinking
         self.probability = probability
         self.cache_size = cache_size
-        self.sparse = sparse
         self.class_weight = class_weight
         self.verbose = verbose
         self.max_iter = max_iter
+        self.random_state = random_state
 
     @property
     def _pairwise(self):
         kernel = self.kernel
-        return kernel == "precomputed" or hasattr(kernel, "__call__")
+        return kernel == "precomputed" or callable(kernel)
 
     def fit(self, X, y, sample_weight=None):
         """Fit the SVM model according to the given training data.
 
         Parameters
         ----------
-        X : {array-like, sparse matrix}, shape = [n_samples, n_features]
+        X : {array-like, sparse matrix}, shape (n_samples, n_features)
             Training vectors, where n_samples is the number of samples
             and n_features is the number of features.
 
-        y : array-like, shape = [n_samples]
+        y : array-like, shape (n_samples,)
             Target values (class labels in classification, real numbers in
             regression)
 
-        sample_weight : array-like, shape = [n_samples], optional
-            Weights applied to individual samples (1. for unweighted).
+        sample_weight : array-like, shape (n_samples,)
+            Per-sample weights. Rescale C per sample. Higher weights
+            force the classifier to put more emphasis on these points.
 
         Returns
         -------
@@ -129,10 +127,9 @@ class BaseLibSVM(BaseEstimator):
         matrices as input.
         """
 
-        if self.sparse == "auto":
-            self._sparse = sp.isspmatrix(X) and not self._pairwise
-        else:
-            self._sparse = self.sparse
+        rnd = check_random_state(self.random_state)
+
+        self._sparse = sp.isspmatrix(X) and not self._pairwise
 
         if self._sparse and self._pairwise:
             raise ValueError("Sparse precomputed kernels are not supported. "
@@ -140,24 +137,12 @@ class BaseLibSVM(BaseEstimator):
                              "by not using the ``sparse`` parameter")
 
         X = atleast2d_or_csr(X, dtype=np.float64, order='C')
-
-        if self.impl in ['c_svc', 'nu_svc']:
-            # classification
-            self.classes_, y = unique(y, return_inverse=True)
-            self.class_weight_ = compute_class_weight(self.class_weight,
-                                                      self.classes_, y)
-        else:
-            self.class_weight_ = np.empty(0)
-        if self.impl != "one_class" and len(np.unique(y)) < 2:
-            raise ValueError("The number of classes has to be greater than"
-                             " one.")
-
-        y = np.asarray(y, dtype=np.float64, order='C')
+        y = self._validate_targets(y)
 
         sample_weight = np.asarray([]
                                    if sample_weight is None
                                    else sample_weight, dtype=np.float64)
-        solver_type = LIBSVM_IMPL.index(self.impl)
+        solver_type = LIBSVM_IMPL.index(self._impl)
 
         # input validation
         if solver_type != 2 and X.shape[0] != y.shape[0]:
@@ -182,23 +167,36 @@ class BaseLibSVM(BaseEstimator):
             self._gamma = self.gamma
 
         kernel = self.kernel
-        if hasattr(kernel, '__call__'):
+        if callable(kernel):
             kernel = 'precomputed'
 
         fit = self._sparse_fit if self._sparse else self._dense_fit
         if self.verbose:  # pragma: no cover
-            print '[LibSVM]',
-        fit(X, y, sample_weight, solver_type, kernel)
+            print('[LibSVM]', end='')
+
+        seed = rnd.randint(np.iinfo('i').max)
+        fit(X, y, sample_weight, solver_type, kernel, random_seed=seed)
+        # see comment on the other call to np.iinfo in this file
 
         self.shape_fit_ = X.shape
 
         # In binary case, we need to flip the sign of coef, intercept and
         # decision function. Use self._intercept_ internally.
         self._intercept_ = self.intercept_.copy()
-        if self.impl in ['c_svc', 'nu_svc'] and len(self.classes_) == 2:
+        if self._impl in ['c_svc', 'nu_svc'] and len(self.classes_) == 2:
             self.intercept_ *= -1
         return self
 
+    def _validate_targets(self, y):
+        """Validation of y and class_weight.
+
+        Default implementation for SVR and one-class; overridden in BaseSVC.
+        """
+        # XXX this is ugly.
+        # Regression models should not have a class_weight_ attribute.
+        self.class_weight_ = np.empty(0)
+        return np.asarray(y, dtype=np.float64, order='C')
+
     def _warn_from_fit_status(self):
         assert self.fit_status_ in (0, 1)
         if self.fit_status_ == 1:
@@ -207,16 +205,16 @@ class BaseLibSVM(BaseEstimator):
                           ' StandardScaler or MinMaxScaler.'
                           % self.max_iter, ConvergenceWarning)
 
-    def _dense_fit(self, X, y, sample_weight, solver_type, kernel):
-
-        if hasattr(self.kernel, '__call__'):
+    def _dense_fit(self, X, y, sample_weight, solver_type, kernel,
+                   random_seed):
+        if callable(self.kernel):
             # you must store a reference to X to compute the kernel in predict
             # TODO: add keyword copy to copy on demand
             self.__Xfit = X
             X = self._compute_kernel(X)
 
-        if hasattr(self.kernel, '__call__') and X.shape[0] != X.shape[1]:
-            raise ValueError("X.shape[0] should be equal to X.shape[1]")
+            if X.shape[0] != X.shape[1]:
+                raise ValueError("X.shape[0] should be equal to X.shape[1]")
 
         libsvm.set_verbosity_wrap(self.verbose)
 
@@ -232,11 +230,12 @@ class BaseLibSVM(BaseEstimator):
                 shrinking=self.shrinking, tol=self.tol,
                 cache_size=self.cache_size, coef0=self.coef0,
                 gamma=self._gamma, epsilon=self.epsilon,
-                max_iter=self.max_iter)
+                max_iter=self.max_iter, random_seed=random_seed)
 
         self._warn_from_fit_status()
 
-    def _sparse_fit(self, X, y, sample_weight, solver_type, kernel):
+    def _sparse_fit(self, X, y, sample_weight, solver_type, kernel,
+                    random_seed):
         X.data = np.asarray(X.data, dtype=np.float64, order='C')
         X.sort_indices()
 
@@ -244,14 +243,16 @@ class BaseLibSVM(BaseEstimator):
 
         libsvm_sparse.set_verbosity_wrap(self.verbose)
 
-        self.support_vectors_, dual_coef_data, self.intercept_, self._label, \
-            self.n_support_, self.probA_, self.probB_, self.fit_status_ = \
+        self.support_, self.support_vectors_, dual_coef_data, \
+            self.intercept_, self._label, self.n_support_, \
+            self.probA_, self.probB_, self.fit_status_ = \
             libsvm_sparse.libsvm_sparse_train(
                 X.shape[1], X.data, X.indices, X.indptr, y, solver_type,
                 kernel_type, self.degree, self._gamma, self.coef0, self.tol,
                 self.C, self.class_weight_,
                 sample_weight, self.nu, self.cache_size, self.epsilon,
-                int(self.shrinking), int(self.probability), self.max_iter)
+                int(self.shrinking), int(self.probability), self.max_iter,
+                random_seed)
 
         self._warn_from_fit_status()
 
@@ -272,11 +273,11 @@ class BaseLibSVM(BaseEstimator):
 
         Parameters
         ----------
-        X : {array-like, sparse matrix}, shape = [n_samples, n_features]
+        X : {array-like, sparse matrix}, shape (n_samples, n_features)
 
         Returns
         -------
-        y_pred : array, shape = [n_samples]
+        y_pred : array, shape (n_samples,)
         """
         X = self._validate_for_predict(X)
         predict = self._sparse_predict if self._sparse else self._dense_predict
@@ -289,32 +290,27 @@ class BaseLibSVM(BaseEstimator):
             X = array2d(X, order='C')
 
         kernel = self.kernel
-        if hasattr(self.kernel, "__call__"):
+        if callable(self.kernel):
             kernel = 'precomputed'
             if X.shape[1] != self.shape_fit_[0]:
                 raise ValueError("X.shape[1] = %d should be equal to %d, "
                                  "the number of samples at training time" %
                                  (X.shape[1], self.shape_fit_[0]))
 
-        C = 0.0  # C is not useful here
-
-        svm_type = LIBSVM_IMPL.index(self.impl)
+        svm_type = LIBSVM_IMPL.index(self._impl)
 
         return libsvm.predict(
             X, self.support_, self.support_vectors_, self.n_support_,
-            self.dual_coef_, self._intercept_,
-            self._label, self.probA_, self.probB_,
-            svm_type=svm_type,
-            kernel=kernel, C=C, nu=self.nu,
-            probability=self.probability, degree=self.degree,
-            shrinking=self.shrinking, tol=self.tol, cache_size=self.cache_size,
-            coef0=self.coef0, gamma=self._gamma, epsilon=self.epsilon)
+            self.dual_coef_, self._intercept_, self._label,
+            self.probA_, self.probB_, svm_type=svm_type, kernel=kernel,
+            degree=self.degree, coef0=self.coef0, gamma=self._gamma,
+            cache_size=self.cache_size)
 
     def _sparse_predict(self, X):
         X = sp.csr_matrix(X, dtype=np.float64)
 
         kernel = self.kernel
-        if hasattr(kernel, '__call__'):
+        if callable(kernel):
             kernel = 'precomputed'
 
         kernel_type = self._sparse_kernels.index(kernel)
@@ -327,7 +323,7 @@ class BaseLibSVM(BaseEstimator):
             self.support_vectors_.indices,
             self.support_vectors_.indptr,
             self.dual_coef_.data, self._intercept_,
-            LIBSVM_IMPL.index(self.impl), kernel_type,
+            LIBSVM_IMPL.index(self._impl), kernel_type,
             self.degree, self._gamma, self.coef0, self.tol,
             C, self.class_weight_,
             self.nu, self.epsilon, self.shrinking,
@@ -336,7 +332,7 @@ class BaseLibSVM(BaseEstimator):
 
     def _compute_kernel(self, X):
         """Return the data transformed by a callable kernel"""
-        if hasattr(self.kernel, '__call__'):
+        if callable(self.kernel):
             # in the case of precomputed kernel given as a function, we
             # have to compute explicitly the kernel matrix
             kernel = self.kernel(X, self.__Xfit)
@@ -363,26 +359,23 @@ class BaseLibSVM(BaseEstimator):
                                       " sparse SVM.")
 
         X = self._validate_for_predict(X)
-
-        C = 0.0  # C is not useful here
+        X = self._compute_kernel(X)
 
         kernel = self.kernel
-        if hasattr(kernel, '__call__'):
+        if callable(kernel):
             kernel = 'precomputed'
 
         dec_func = libsvm.decision_function(
             X, self.support_, self.support_vectors_, self.n_support_,
             self.dual_coef_, self._intercept_, self._label,
             self.probA_, self.probB_,
-            svm_type=LIBSVM_IMPL.index(self.impl),
-            kernel=kernel, C=C, nu=self.nu,
-            probability=self.probability, degree=self.degree,
-            shrinking=self.shrinking, tol=self.tol, cache_size=self.cache_size,
-            coef0=self.coef0, gamma=self._gamma, epsilon=self.epsilon)
+            svm_type=LIBSVM_IMPL.index(self._impl),
+            kernel=kernel, degree=self.degree, cache_size=self.cache_size,
+            coef0=self.coef0, gamma=self._gamma)
 
         # In binary case, we need to flip the sign of coef, intercept and
         # decision function.
-        if self.impl in ['c_svc', 'nu_svc'] and len(self.classes_) == 2:
+        if self._impl in ['c_svc', 'nu_svc'] and len(self.classes_) == 2:
             return -dec_func
 
         return dec_func
@@ -394,8 +387,7 @@ class BaseLibSVM(BaseEstimator):
         if self._sparse:
             X.sort_indices()
 
-        if (sp.issparse(X) and not self._sparse and
-                not hasattr(self.kernel, '__call__')):
+        if sp.issparse(X) and not self._sparse and not callable(self.kernel):
             raise ValueError(
                 "cannot use sparse input in %r trained on dense data"
                 % type(self).__name__)
@@ -444,6 +436,19 @@ class BaseLibSVM(BaseEstimator):
 class BaseSVC(BaseLibSVM, ClassifierMixin):
     """ABC for LibSVM-based classifiers."""
 
+    def _validate_targets(self, y):
+        y = column_or_1d(y, warn=True)
+        cls, y = unique(y, return_inverse=True)
+        self.class_weight_ = compute_class_weight(self.class_weight, cls, y)
+        if len(cls) < 2:
+            raise ValueError(
+                "The number of classes has to be greater than one; got %d"
+                % len(cls))
+
+        self.classes_ = cls
+
+        return np.asarray(y, dtype=np.float64, order='C')
+
     def predict(self, X):
         """Perform classification on samples in X.
 
@@ -475,8 +480,8 @@ class BaseSVC(BaseLibSVM, ClassifierMixin):
         -------
         X : array-like, shape = [n_samples, n_classes]
             Returns the probability of the sample for each class in
-            the model, where classes are ordered by arithmetical
-            order.
+            the model. The columns correspond to the classes in sorted
+            order, as they appear in the attribute `classes_`.
 
         Notes
         -----
@@ -489,7 +494,7 @@ class BaseSVC(BaseLibSVM, ClassifierMixin):
             raise NotImplementedError(
                 "probability estimates must be enabled to use this method")
 
-        if self.impl not in ('c_svc', 'nu_svc'):
+        if self._impl not in ('c_svc', 'nu_svc'):
             raise NotImplementedError("predict_proba only implemented for SVC "
                                       "and NuSVC")
 
@@ -512,8 +517,8 @@ class BaseSVC(BaseLibSVM, ClassifierMixin):
         -------
         X : array-like, shape = [n_samples, n_classes]
             Returns the log-probabilities of the sample for each class in
-            the model, where classes are ordered by arithmetical
-            order.
+            the model. The columns correspond to the classes in sorted
+            order, as they appear in the attribute `classes_`.
 
         Notes
         -----
@@ -527,21 +532,17 @@ class BaseSVC(BaseLibSVM, ClassifierMixin):
     def _dense_predict_proba(self, X):
         X = self._compute_kernel(X)
 
-        C = 0.0  # C is not useful here
-
         kernel = self.kernel
-        if hasattr(kernel, '__call__'):
+        if callable(kernel):
             kernel = 'precomputed'
 
-        svm_type = LIBSVM_IMPL.index(self.impl)
+        svm_type = LIBSVM_IMPL.index(self._impl)
         pprob = libsvm.predict_proba(
             X, self.support_, self.support_vectors_, self.n_support_,
             self.dual_coef_, self._intercept_, self._label,
             self.probA_, self.probB_,
-            svm_type=svm_type, kernel=kernel, C=C, nu=self.nu,
-            probability=self.probability, degree=self.degree,
-            shrinking=self.shrinking, tol=self.tol, cache_size=self.cache_size,
-            coef0=self.coef0, gamma=self._gamma, epsilon=self.epsilon)
+            svm_type=svm_type, kernel=kernel, degree=self.degree,
+            cache_size=self.cache_size, coef0=self.coef0, gamma=self._gamma)
 
         return pprob
 
@@ -549,7 +550,7 @@ class BaseSVC(BaseLibSVM, ClassifierMixin):
         X.data = np.asarray(X.data, dtype=np.float64, order='C')
 
         kernel = self.kernel
-        if hasattr(kernel, '__call__'):
+        if callable(kernel):
             kernel = 'precomputed'
 
         kernel_type = self._sparse_kernels.index(kernel)
@@ -560,7 +561,7 @@ class BaseSVC(BaseLibSVM, ClassifierMixin):
             self.support_vectors_.indices,
             self.support_vectors_.indptr,
             self.dual_coef_.data, self._intercept_,
-            LIBSVM_IMPL.index(self.impl), kernel_type,
+            LIBSVM_IMPL.index(self._impl), kernel_type,
             self.degree, self._gamma, self.coef0, self.tol,
             self.C, self.class_weight_,
             self.nu, self.epsilon, self.shrinking,
@@ -574,7 +575,7 @@ class BaseSVC(BaseLibSVM, ClassifierMixin):
         return self.classes_
 
 
-class BaseLibLinear(BaseEstimator):
+class BaseLibLinear(six.with_metaclass(ABCMeta, BaseEstimator)):
     """Base for classes binding liblinear (dense and sparse versions)"""
 
     _solver_type_dict = {
@@ -588,17 +589,11 @@ class BaseLibLinear(BaseEstimator):
         'PL2_LLR_D1': 7,  # L2 penalty, logistic regression, dual form
     }
 
+    @abstractmethod
     def __init__(self, penalty='l2', loss='l2', dual=True, tol=1e-4, C=1.0,
                  multi_class='ovr', fit_intercept=True, intercept_scaling=1,
                  class_weight=None, verbose=0, random_state=None):
 
-        if C is None:  # pragma: no cover
-            warnings.warn("Using 'None' for C of BaseLibLinear is deprecated "
-                          "since version 0.12, and backward compatibility "
-                          "won't be maintained from version 0.14 onward. "
-                          "Setting C=1.0.", DeprecationWarning, stacklevel=2)
-            C = 1.0
-
         self.penalty = penalty
         self.loss = loss
         self.dual = dual
@@ -637,7 +632,7 @@ class BaseLibLinear(BaseEstimator):
                                 "and loss='l1' is not supported.")
             elif self.penalty.upper() == 'L2' and self.loss.upper() == 'L1':
                 # this has to be in primal
-                error_string = ("penalty='l2' and loss='l1' is "
+                error_string = ("penalty='l2' and ploss='l1' is "
                                 "only supported when dual='true'.")
             else:
                 # only PL1 in dual remains
@@ -659,10 +654,6 @@ class BaseLibLinear(BaseEstimator):
         y : array-like, shape = [n_samples]
             Target vector relative to X
 
-        class_weight : {dict, 'auto'}, optional
-            Weights associated with classes. If not given, all classes
-            are supposed to have weight one.
-
         Returns
         -------
         self : object
@@ -675,7 +666,6 @@ class BaseLibLinear(BaseEstimator):
                              " one.")
 
         X = atleast2d_or_csr(X, dtype=np.float64, order="C")
-        y = np.asarray(y, dtype=np.float64).ravel()
 
         self.class_weight_ = compute_class_weight(self.class_weight,
                                                   self.classes_, y)
@@ -687,22 +677,23 @@ class BaseLibLinear(BaseEstimator):
 
         liblinear.set_verbosity_wrap(self.verbose)
 
-        if sp.isspmatrix(X):
-            train = liblinear.csr_train_wrap
-        else:
-            train = liblinear.train_wrap
-
         rnd = check_random_state(self.random_state)
         if self.verbose:
-            print '[LibLinear]',
-        self.raw_coef_ = train(X, y, self._get_solver_type(), self.tol,
-                               self._get_bias(), self.C,
-                               self.class_weight_,
-                               # seed for srand in range [0..INT_MAX);
-                               # due to limitations in Numpy on 32-bit
-                               # platforms, we can't get to the UINT_MAX
-                               # limit that srand supports
-                               rnd.randint(np.iinfo('i').max))
+            print('[LibLinear]', end='')
+
+        # LibLinear wants targets as doubles, even for classification
+        y = np.asarray(y, dtype=np.float64).ravel()
+        self.raw_coef_ = liblinear.train_wrap(X, y,
+                                              sp.isspmatrix(X),
+                                              self._get_solver_type(),
+                                              self.tol, self._get_bias(),
+                                              self.C,
+                                              self.class_weight_,
+                                              rnd.randint(np.iinfo('i').max))
+        # Regarding rnd.randint(..) in the above signature:
+        # seed for srand in range [0..INT_MAX); due to limitations in Numpy
+        # on 32-bit platforms, we can't get to the UINT_MAX limit that
+        # srand supports
 
         if self.fit_intercept:
             self.coef_ = self.raw_coef_[:, :-1]
