@@ -1,10 +1,11 @@
 from .base import BaseLibLinear, BaseSVC, BaseLibSVM
 from ..base import RegressorMixin
-from ..linear_model.base import LinearClassifierMixin
-from ..feature_selection.selector_mixin import SelectorMixin
+from ..linear_model.base import LinearClassifierMixin, SparseCoefMixin
+from ..feature_selection.from_model import _LearntSelectorMixin
 
 
-class LinearSVC(BaseLibLinear, LinearClassifierMixin, SelectorMixin):
+class LinearSVC(BaseLibLinear, LinearClassifierMixin, _LearntSelectorMixin,
+                SparseCoefMixin):
     """Linear Support Vector Classification.
 
     Similar to SVC with parameter kernel='linear', but implemented in terms of
@@ -44,7 +45,7 @@ class LinearSVC(BaseLibLinear, LinearClassifierMixin, SelectorMixin):
         While `crammer_singer` is interesting from an theoretical perspective
         as it is consistent it is seldom used in practice and rarely leads to
         better accuracy and is more expensive to compute.
-        If `crammer_singer` is choosen, the options loss, penalty and dual will
+        If `crammer_singer` is chosen, the options loss, penalty and dual will
         be ignored.
 
     fit_intercept : boolean, optional (default=True)
@@ -75,6 +76,11 @@ class LinearSVC(BaseLibLinear, LinearClassifierMixin, SelectorMixin):
         per-process runtime setting in liblinear that, if enabled, may not work
         properly in a multithreaded context.
 
+    random_state : int seed, RandomState instance, or None (default)
+        The seed of the pseudo random number generator to use when
+        shuffling the data.
+
+
     Attributes
     ----------
     `coef_` : array, shape = [n_features] if n_classes == 2 \
@@ -128,8 +134,15 @@ class LinearSVC(BaseLibLinear, LinearClassifierMixin, SelectorMixin):
 
     """
 
-    # all the implementation is provided by the mixins
-    pass
+    def __init__(self, penalty='l2', loss='l2', dual=True, tol=1e-4, C=1.0,
+                 multi_class='ovr', fit_intercept=True, intercept_scaling=1,
+                 class_weight=None, verbose=0, random_state=None):
+        super(LinearSVC, self).__init__(
+            penalty=penalty, loss=loss, dual=dual, tol=tol, C=C,
+            multi_class=multi_class, fit_intercept=fit_intercept,
+            intercept_scaling=intercept_scaling,
+            class_weight=class_weight, verbose=verbose,
+            random_state=random_state)
 
 
 class SVC(BaseSVC):
@@ -161,11 +174,11 @@ class SVC(BaseSVC):
          used to precompute the kernel matrix.
 
     degree : int, optional (default=3)
-        Degree of kernel function.
-        It is significant only in 'poly' and 'sigmoid'.
+        Degree of the polynomial kernel function ('poly').
+        Ignored by all other kernels.
 
     gamma : float, optional (default=0.0)
-        Kernel coefficient for 'rbf' and 'poly'.
+        Kernel coefficient for 'rbf', 'poly' and 'sigm'.
         If gamma is 0.0 then 1/n_features will be used instead.
 
     coef0 : float, optional (default=0.0)
@@ -174,7 +187,7 @@ class SVC(BaseSVC):
 
     probability: boolean, optional (default=False)
         Whether to enable probability estimates. This must be enabled prior
-        to calling predict_proba.
+        to calling `fit`, and will slow down that method.
 
     shrinking: boolean, optional (default=True)
         Whether to use the shrinking heuristic.
@@ -200,6 +213,10 @@ class SVC(BaseSVC):
     max_iter : int, optional (default=-1)
         Hard limit on iterations within solver, or -1 for no limit.
 
+    random_state : int seed, RandomState instance, or None (default)
+        The seed of the pseudo random number generator to use when
+        shuffling the data for probability estimation.
+
     Attributes
     ----------
     `support_` : array-like, shape = [n_SV]
@@ -237,8 +254,8 @@ class SVC(BaseSVC):
     >>> clf = SVC()
     >>> clf.fit(X, y) #doctest: +NORMALIZE_WHITESPACE
     SVC(C=1.0, cache_size=200, class_weight=None, coef0=0.0, degree=3,
-            gamma=0.0, kernel='rbf', max_iter=-1, probability=False,
-            shrinking=True, tol=0.001, verbose=False)
+        gamma=0.0, kernel='rbf', max_iter=-1, probability=False,
+        random_state=None, shrinking=True, tol=0.001, verbose=False)
     >>> print(clf.predict([[-0.8, -1]]))
     [1]
 
@@ -248,7 +265,7 @@ class SVC(BaseSVC):
         Support Vector Machine for Regression implemented using libsvm.
 
     LinearSVC
-        Scalable Linear Support Vector Machine for classififcation
+        Scalable Linear Support Vector Machine for classification
         implemented using liblinear. Check the See also section of
         LinearSVC for more comparison element.
 
@@ -257,11 +274,12 @@ class SVC(BaseSVC):
     def __init__(self, C=1.0, kernel='rbf', degree=3, gamma=0.0,
                  coef0=0.0, shrinking=True, probability=False,
                  tol=1e-3, cache_size=200, class_weight=None,
-                 verbose=False, max_iter=-1):
+                 verbose=False, max_iter=-1, random_state=None):
 
         super(SVC, self).__init__(
             'c_svc', kernel, degree, gamma, coef0, tol, C, 0., 0., shrinking,
-            probability, cache_size, "auto", class_weight, verbose, max_iter)
+            probability, cache_size, class_weight, verbose, max_iter,
+            random_state)
 
 
 class NuSVC(BaseSVC):
@@ -300,7 +318,7 @@ class NuSVC(BaseSVC):
 
     probability: boolean, optional (default=False)
         Whether to enable probability estimates. This must be enabled prior
-        to calling predict_proba.
+        to calling `fit`, and will slow down that method.
 
     shrinking: boolean, optional (default=True)
         Whether to use the shrinking heuristic.
@@ -319,6 +337,10 @@ class NuSVC(BaseSVC):
     max_iter : int, optional (default=-1)
         Hard limit on iterations within solver, or -1 for no limit.
 
+    random_state : int seed, RandomState instance, or None (default)
+        The seed of the pseudo random number generator to use when
+        shuffling the data for probability estimation.
+
     Attributes
     ----------
     `support_` : array-like, shape = [n_SV]
@@ -356,8 +378,8 @@ class NuSVC(BaseSVC):
     >>> clf = NuSVC()
     >>> clf.fit(X, y) #doctest: +NORMALIZE_WHITESPACE
     NuSVC(cache_size=200, coef0=0.0, degree=3, gamma=0.0, kernel='rbf',
-            max_iter=-1, nu=0.5, probability=False, shrinking=True, tol=0.001,
-            verbose=False)
+          max_iter=-1, nu=0.5, probability=False, random_state=None,
+          shrinking=True, tol=0.001, verbose=False)
     >>> print(clf.predict([[-0.8, -1]]))
     [1]
 
@@ -373,11 +395,12 @@ class NuSVC(BaseSVC):
 
     def __init__(self, nu=0.5, kernel='rbf', degree=3, gamma=0.0,
                  coef0=0.0, shrinking=True, probability=False,
-                 tol=1e-3, cache_size=200, verbose=False, max_iter=-1):
+                 tol=1e-3, cache_size=200, verbose=False, max_iter=-1,
+                 random_state=None):
 
         super(NuSVC, self).__init__(
             'nu_svc', kernel, degree, gamma, coef0, tol, 0., nu, 0., shrinking,
-            probability, cache_size, "auto", None, verbose, max_iter)
+            probability, cache_size, None, verbose, max_iter, random_state)
 
 
 class SVR(BaseLibSVM, RegressorMixin):
@@ -419,7 +442,7 @@ class SVR(BaseLibSVM, RegressorMixin):
 
     probability: boolean, optional (default=False)
         Whether to enable probability estimates. This must be enabled prior
-        to calling predict_proba.
+        to calling `fit`, and will slow down that method.
 
     shrinking: boolean, optional (default=True)
         Whether to use the shrinking heuristic.
@@ -438,6 +461,10 @@ class SVR(BaseLibSVM, RegressorMixin):
     max_iter : int, optional (default=-1)
         Hard limit on iterations within solver, or -1 for no limit.
 
+    random_state : int seed, RandomState instance, or None (default)
+        The seed of the pseudo random number generator to use when
+        shuffling the data for probability estimaton.
+
     Attributes
     ----------
     `support_` : array-like, shape = [n_SV]
@@ -470,8 +497,8 @@ class SVR(BaseLibSVM, RegressorMixin):
     >>> clf = SVR(C=1.0, epsilon=0.2)
     >>> clf.fit(X, y) #doctest: +NORMALIZE_WHITESPACE
     SVR(C=1.0, cache_size=200, coef0=0.0, degree=3, epsilon=0.2, gamma=0.0,
-      kernel='rbf', max_iter=-1, probability=False, shrinking=True, tol=0.001,
-      verbose=False)
+        kernel='rbf', max_iter=-1, probability=False, random_state=None,
+        shrinking=True, tol=0.001, verbose=False)
 
     See also
     --------
@@ -482,12 +509,13 @@ class SVR(BaseLibSVM, RegressorMixin):
     """
     def __init__(self, kernel='rbf', degree=3, gamma=0.0, coef0=0.0, tol=1e-3,
                  C=1.0, epsilon=0.1, shrinking=True, probability=False,
-                 cache_size=200, verbose=False, max_iter=-1):
+                 cache_size=200, verbose=False, max_iter=-1,
+                 random_state=None):
 
         super(SVR, self).__init__(
             'epsilon_svr', kernel, degree, gamma, coef0, tol, C, 0., epsilon,
-            shrinking, probability, cache_size, "auto", None, verbose,
-            max_iter)
+            shrinking, probability, cache_size, None, verbose,
+            max_iter, random_state)
 
 
 class NuSVR(BaseLibSVM, RegressorMixin):
@@ -530,7 +558,7 @@ class NuSVR(BaseLibSVM, RegressorMixin):
 
     probability: boolean, optional (default=False)
         Whether to enable probability estimates. This must be enabled prior
-        to calling predict_proba.
+        to calling `fit`, and will slow down that method.
 
     shrinking: boolean, optional (default=True)
         Whether to use the shrinking heuristic.
@@ -549,6 +577,10 @@ class NuSVR(BaseLibSVM, RegressorMixin):
     max_iter : int, optional (default=-1)
         Hard limit on iterations within solver, or -1 for no limit.
 
+    random_state : int seed, RandomState instance, or None (default)
+        The seed of the pseudo random number generator to use when
+        shuffling the data for probability estimation.
+
     Attributes
     ----------
     `support_` : array-like, shape = [n_SV]
@@ -581,8 +613,8 @@ class NuSVR(BaseLibSVM, RegressorMixin):
     >>> clf = NuSVR(C=1.0, nu=0.1)
     >>> clf.fit(X, y)  #doctest: +NORMALIZE_WHITESPACE
     NuSVR(C=1.0, cache_size=200, coef0=0.0, degree=3, gamma=0.0, kernel='rbf',
-       max_iter=-1, nu=0.1, probability=False, shrinking=True, tol=0.001,
-       verbose=False)
+          max_iter=-1, nu=0.1, probability=False, random_state=None,
+          shrinking=True, tol=0.001, verbose=False)
 
     See also
     --------
@@ -597,11 +629,11 @@ class NuSVR(BaseLibSVM, RegressorMixin):
     def __init__(self, nu=0.5, C=1.0, kernel='rbf', degree=3,
                  gamma=0.0, coef0=0.0, shrinking=True,
                  probability=False, tol=1e-3, cache_size=200,
-                 verbose=False, max_iter=-1):
+                 verbose=False, max_iter=-1, random_state=None):
 
         super(NuSVR, self).__init__(
             'nu_svr', kernel, degree, gamma, coef0, tol, C, nu, 0., shrinking,
-            probability, cache_size, "auto", None, verbose, max_iter)
+            probability, cache_size, None, verbose, max_iter, random_state)
 
 
 class OneClassSVM(BaseLibSVM):
@@ -654,6 +686,10 @@ class OneClassSVM(BaseLibSVM):
     max_iter : int, optional (default=-1)
         Hard limit on iterations within solver, or -1 for no limit.
 
+    random_state : int seed, RandomState instance, or None (default)
+        The seed of the pseudo random number generator to use when
+        shuffling the data for probability estimation.
+
     Attributes
     ----------
     `support_` : array-like, shape = [n_SV]
@@ -678,11 +714,12 @@ class OneClassSVM(BaseLibSVM):
     """
     def __init__(self, kernel='rbf', degree=3, gamma=0.0, coef0=0.0, tol=1e-3,
                  nu=0.5, shrinking=True, cache_size=200, verbose=False,
-                 max_iter=-1):
+                 max_iter=-1, random_state=None):
 
         super(OneClassSVM, self).__init__(
             'one_class', kernel, degree, gamma, coef0, tol, 0., nu, 0.,
-            shrinking, False, cache_size, "auto", None, verbose, max_iter)
+            shrinking, False, cache_size, None, verbose, max_iter,
+            random_state)
 
     def fit(self, X, sample_weight=None, **params):
         """
@@ -690,10 +727,14 @@ class OneClassSVM(BaseLibSVM):
 
         Parameters
         ----------
-        X : {array-like, sparse matrix}, shape = [n_samples, n_features]
+        X : {array-like, sparse matrix}, shape (n_samples, n_features)
             Set of samples, where n_samples is the number of samples and
             n_features is the number of features.
 
+        sample_weight : array-like, shape (n_samples,)
+            Per-sample weights. Rescale C per sample. Higher weights
+            force the classifier to put more emphasis on these points.
+
         Returns
         -------
         self : object
