@@ -1,16 +1,17 @@
 import warnings
+from nose.tools import assert_raises, assert_true, assert_false
+
 import numpy as np
 from scipy import sparse
-from sklearn import datasets, svm, linear_model, base
 from numpy.testing import (assert_array_almost_equal, assert_array_equal,
                            assert_equal)
 
-from nose.tools import assert_raises, assert_true, assert_false
-from nose.tools import assert_equal as nose_assert_equal
+from sklearn import datasets, svm, linear_model, base
 from sklearn.datasets import make_classification, load_digits
 from sklearn.svm.tests import test_svm
 from sklearn.utils import ConvergenceWarning
 from sklearn.utils.extmath import safe_sparse_dot
+from sklearn.utils.testing import assert_warns
 
 # test sample 1
 X = np.array([[-2, -1], [-1, -1], [-1, -2], [1, 1], [1, 2], [2, 1]])
@@ -41,8 +42,10 @@ iris.data = sparse.csr_matrix(iris.data)
 def test_svc():
     """Check that sparse SVC gives the same result as SVC"""
 
-    clf = svm.SVC(kernel='linear', probability=True).fit(X, Y)
-    sp_clf = svm.SVC(kernel='linear', probability=True).fit(X_sp, Y)
+    clf = svm.SVC(kernel='linear', probability=True, random_state=0)
+    clf.fit(X, Y)
+    sp_clf = svm.SVC(kernel='linear', probability=True, random_state=0)
+    sp_clf.fit(X_sp, Y)
 
     assert_array_equal(sp_clf.predict(T), true_result)
 
@@ -55,6 +58,7 @@ def test_svc():
 
     assert_true(sparse.issparse(sp_clf.coef_))
     assert_array_almost_equal(clf.coef_, sp_clf.coef_.todense())
+    assert_array_almost_equal(clf.support_, sp_clf.support_)
     assert_array_almost_equal(clf.predict(T), sp_clf.predict(T))
 
     # refit with a different dataset
@@ -64,6 +68,7 @@ def test_svc():
                               sp_clf.support_vectors_.todense())
     assert_array_almost_equal(clf.dual_coef_, sp_clf.dual_coef_.todense())
     assert_array_almost_equal(clf.coef_, sp_clf.coef_.todense())
+    assert_array_almost_equal(clf.support_, sp_clf.support_)
     assert_array_almost_equal(clf.predict(T2), sp_clf.predict(T2))
     assert_array_almost_equal(clf.predict_proba(T2),
                               sp_clf.predict_proba(T2), 4)
@@ -78,8 +83,10 @@ def test_unsorted_indices():
     X_test = sparse.csr_matrix(digits.data[50:100])
 
     X_sparse = sparse.csr_matrix(X)
-    coef_dense = svm.SVC(kernel='linear', probability=True).fit(X, y).coef_
-    sparse_svc = svm.SVC(kernel='linear', probability=True).fit(X_sparse, y)
+    coef_dense = svm.SVC(kernel='linear', probability=True,
+                         random_state=0).fit(X, y).coef_
+    sparse_svc = svm.SVC(kernel='linear', probability=True,
+                         random_state=0).fit(X_sparse, y)
     coef_sorted = sparse_svc.coef_
     # make sure dense and sparse SVM give the same result
     assert_array_almost_equal(coef_dense, coef_sorted.toarray())
@@ -91,8 +98,8 @@ def test_unsorted_indices():
     assert_false(X_sparse_unsorted.has_sorted_indices)
     assert_false(X_test_unsorted.has_sorted_indices)
 
-    unsorted_svc = svm.SVC(kernel='linear',
-                           probability=True).fit(X_sparse_unsorted, y)
+    unsorted_svc = svm.SVC(kernel='linear', probability=True,
+                           random_state=0).fit(X_sparse_unsorted, y)
     coef_unsorted = unsorted_svc.coef_
     # make sure unsorted indices give same result
     assert_array_almost_equal(coef_unsorted.toarray(), coef_sorted.toarray())
@@ -145,8 +152,8 @@ def test_linearsvc():
     """
     Similar to test_SVC
     """
-    clf = svm.LinearSVC().fit(X, Y)
-    sp_clf = svm.LinearSVC().fit(X_sp, Y)
+    clf = svm.LinearSVC(random_state=0).fit(X, Y)
+    sp_clf = svm.LinearSVC(random_state=0).fit(X_sp, Y)
 
     assert_true(sp_clf.fit_intercept)
 
@@ -163,8 +170,8 @@ def test_linearsvc():
 def test_linearsvc_iris():
     """Test the sparse LinearSVC with the iris dataset"""
 
-    sp_clf = svm.LinearSVC().fit(iris.data, iris.target)
-    clf = svm.LinearSVC().fit(iris.data.todense(), iris.target)
+    sp_clf = svm.LinearSVC(random_state=0).fit(iris.data, iris.target)
+    clf = svm.LinearSVC(random_state=0).fit(iris.data.todense(), iris.target)
 
     assert_equal(clf.fit_intercept, sp_clf.fit_intercept)
 
@@ -176,6 +183,13 @@ def test_linearsvc_iris():
     pred = np.argmax(sp_clf.decision_function(iris.data), 1)
     assert_array_almost_equal(pred, clf.predict(iris.data.todense()))
 
+    # sparsify the coefficients on both models and check that they still
+    # produce the same results
+    clf.sparsify()
+    assert_array_equal(pred, clf.predict(iris.data))
+    sp_clf.sparsify()
+    assert_array_equal(pred, sp_clf.predict(iris.data))
+
 
 def test_weight():
     """
@@ -186,7 +200,7 @@ def test_weight():
 
     X_ = sparse.csr_matrix(X_)
     for clf in (linear_model.LogisticRegression(),
-                svm.LinearSVC(),
+                svm.LinearSVC(random_state=0),
                 svm.SVC()):
         clf.set_params(class_weight={0: 5})
         clf.fit(X_[:180], y_[:180])
@@ -247,15 +261,10 @@ def test_sparse_realdata():
 
 
 def test_sparse_svc_clone_with_callable_kernel():
-    # first, test that we raise a value error for "sparse kernels"
-    # this test is only relevant for the deprecated sparse.SVC class.
-    with warnings.catch_warnings(record=True):
-        sp = svm.sparse.SVC(C=1, kernel=lambda x, y: x * y.T, probability=True)
-    assert_raises(ValueError, sp.fit, X_sp, Y)
-
     # Test that the "dense_fit" is called even though we use sparse input
     # meaning that everything works fine.
-    a = svm.SVC(C=1, kernel=lambda x, y: x * y.T, probability=True)
+    a = svm.SVC(C=1, kernel=lambda x, y: x * y.T, probability=True,
+                random_state=0)
     b = base.clone(a)
 
     b.fit(X_sp, Y)
@@ -263,7 +272,7 @@ def test_sparse_svc_clone_with_callable_kernel():
     b.predict_proba(X_sp)
 
     dense_svm = svm.SVC(C=1, kernel=lambda x, y: np.dot(x, y.T),
-                        probability=True)
+                        probability=True, random_state=0)
     pred_dense = dense_svm.fit(X, Y).predict(X)
     assert_array_equal(pred_dense, pred)
     # b.decision_function(X_sp)  # XXX : should be supported
@@ -271,14 +280,16 @@ def test_sparse_svc_clone_with_callable_kernel():
 
 def test_timeout():
     sp = svm.SVC(C=1, kernel=lambda x, y: x * y.T, probability=True,
-                 max_iter=1)
-    with warnings.catch_warnings(record=True) as foo:
-        sp.fit(X_sp, Y)
-        nose_assert_equal(len(foo), 1, msg=foo)
-        nose_assert_equal(foo[0].category, ConvergenceWarning,
-                          msg=foo[0].category)
+                 random_state=0, max_iter=1)
+    with warnings.catch_warnings(record=True):
+        warnings.simplefilter("always")
+
+        assert_warns(ConvergenceWarning, sp.fit, X_sp, Y)
 
 
-if __name__ == '__main__':
-    import nose
-    nose.runmodule()
+def test_consistent_proba():
+    a = svm.SVC(probability=True, max_iter=1, random_state=0)
+    proba_1 = a.fit(X, Y).predict_proba(X)
+    a = svm.SVC(probability=True, max_iter=1, random_state=0)
+    proba_2 = a.fit(X, Y).predict_proba(X)
+    assert_array_almost_equal(proba_1, proba_2)
