@@ -16,6 +16,7 @@ from sklearn.datasets.samples_generator import make_classification
 from sklearn.metrics import f1_score
 from sklearn.utils import check_random_state
 from sklearn.utils import ConvergenceWarning
+from sklearn.utils.fixes import unique
 from sklearn.utils.testing import assert_greater, assert_less
 
 # toy sample
@@ -73,7 +74,8 @@ def test_libsvm_iris():
 
     pred = svm.libsvm.cross_validation(iris.data,
                                        iris.target.astype(np.float64), 5,
-                                       kernel='linear')
+                                       kernel='linear',
+                                       random_seed=0)
     assert_greater(np.mean(pred == iris.target), .95)
 
 
@@ -174,6 +176,10 @@ def test_svr():
         clf.fit(diabetes.data, diabetes.target)
         assert_greater(clf.score(diabetes.data, diabetes.target), 0.02)
 
+    # non-regression test; previously, BaseLibSVM would check that
+    # len(np.unique(y)) < 2, which must only be done for SVC
+    svm.SVR().fit(diabetes.data, np.ones(len(diabetes.data)))
+
 
 def test_svr_errors():
     X = [[0.0], [1.0]]
@@ -259,8 +265,8 @@ def test_probability():
     This uses cross validation, so we use a slightly bigger testing set.
     """
 
-    for clf in (svm.SVC(probability=True, C=1.0),
-                svm.NuSVC(probability=True)):
+    for clf in (svm.SVC(probability=True, random_state=0, C=1.0),
+                svm.NuSVC(probability=True, random_state=0)):
 
         clf.fit(iris.data, iris.target)
 
@@ -335,19 +341,29 @@ def test_sample_weights():
     clf.fit(X, Y, sample_weight=sample_weight)
     assert_array_equal(clf.predict(X[2]), [2.])
 
+    # test that rescaling all samples is the same as changing C
+    clf = svm.SVC()
+    clf.fit(X, Y)
+    dual_coef_no_weight = clf.dual_coef_
+    clf.set_params(C=100)
+    clf.fit(X, Y, sample_weight=np.repeat(0.01, len(X)))
+    assert_array_almost_equal(dual_coef_no_weight, clf.dual_coef_)
+
 
 def test_auto_weight():
     """Test class weights for imbalanced data"""
     from sklearn.linear_model import LogisticRegression
-    # we take as dataset a the two-dimensional projection of iris so
+    # We take as dataset the two-dimensional projection of iris so
     # that it is not separable and remove half of predictors from
-    # class 1
+    # class 1.
+    # We add one to the targets as a non-regression test: class_weight="auto"
+    # used to work only when the labels where a range [0..K).
     from sklearn.utils import compute_class_weight
-    X, y = iris.data[:, :2], iris.target
-    unbalanced = np.delete(np.arange(y.size), np.where(y > 1)[0][::2])
+    X, y = iris.data[:, :2], iris.target + 1
+    unbalanced = np.delete(np.arange(y.size), np.where(y > 2)[0][::2])
 
-    classes = np.unique(y[unbalanced])
-    class_weights = compute_class_weight('auto', classes, y[unbalanced])
+    classes, y_ind = unique(y[unbalanced], return_inverse=True)
+    class_weights = compute_class_weight('auto', classes, y_ind)
     assert_true(np.argmax(class_weights) == 2)
 
     for clf in (svm.SVC(kernel='linear'), svm.LinearSVC(random_state=0),
@@ -597,13 +613,29 @@ def test_linearsvc_verbose():
 
 
 def test_svc_clone_with_callable_kernel():
-    a = svm.SVC(kernel=lambda x, y: np.dot(x, y.T), probability=True)
-    b = base.clone(a)
+    # create SVM with callable linear kernel, check that results are the same
+    # as with built-in linear kernel
+    svm_callable = svm.SVC(kernel=lambda x, y: np.dot(x, y.T),
+                           probability=True, random_state=0)
+    # clone for checking clonability with lambda functions..
+    svm_cloned = base.clone(svm_callable)
+    svm_cloned.fit(iris.data, iris.target)
 
-    b.fit(X, Y)
-    b.predict(X)
-    b.predict_proba(X)
-    b.decision_function(X)
+    svm_builtin = svm.SVC(kernel='linear', probability=True, random_state=0)
+    svm_builtin.fit(iris.data, iris.target)
+
+    assert_array_almost_equal(svm_cloned.dual_coef_,
+                              svm_builtin.dual_coef_)
+    assert_array_almost_equal(svm_cloned.intercept_,
+                              svm_builtin.intercept_)
+    assert_array_equal(svm_cloned.predict(iris.data),
+                       svm_builtin.predict(iris.data))
+
+    assert_array_almost_equal(svm_cloned.predict_proba(iris.data),
+                              svm_builtin.predict_proba(iris.data),
+                              decimal=4)
+    assert_array_almost_equal(svm_cloned.decision_function(iris.data),
+                              svm_builtin.decision_function(iris.data))
 
 
 def test_svc_bad_kernel():
@@ -613,7 +645,7 @@ def test_svc_bad_kernel():
 
 def test_timeout():
     a = svm.SVC(kernel=lambda x, y: np.dot(x, y.T), probability=True,
-                max_iter=1)
+                random_state=0, max_iter=1)
     with warnings.catch_warnings(record=True) as foo:
         # Hackish way to reset the  warning counter
         from sklearn.svm import base
@@ -624,6 +656,14 @@ def test_timeout():
         assert_equal(foo[0].category, ConvergenceWarning, msg=foo[0].category)
 
 
+def test_consistent_proba():
+    a = svm.SVC(probability=True, max_iter=1, random_state=0)
+    proba_1 = a.fit(X, Y).predict_proba(X)
+    a = svm.SVC(probability=True, max_iter=1, random_state=0)
+    proba_2 = a.fit(X, Y).predict_proba(X)
+    assert_array_almost_equal(proba_1, proba_2)
+
+
 if __name__ == '__main__':
     import nose
     nose.runmodule()
