@@ -1,6 +1,6 @@
 
 # Author: Gael Varoquaux
-# License: BSD
+# License: BSD 3 clause
 
 import numpy as np
 import scipy.sparse as sp
@@ -15,6 +15,7 @@ from sklearn.base import BaseEstimator, clone, is_classifier
 from sklearn.svm import SVC
 from sklearn.pipeline import Pipeline
 from sklearn.grid_search import GridSearchCV
+from sklearn.utils import deprecated
 
 
 #############################################################################
@@ -38,6 +39,19 @@ class T(BaseEstimator):
         self.b = b
 
 
+class DeprecatedAttributeEstimator(BaseEstimator):
+    def __init__(self, a=None, b=None):
+        self.a = a
+        if b is not None:
+            DeprecationWarning("b is deprecated and renamed 'a'")
+            self.a = b
+
+    @property
+    @deprecated("Parameter 'b' is deprecated and renamed to 'a'")
+    def b(self):
+        return self._b
+
+
 class Buggy(BaseEstimator):
     " A buggy estimator that does not set its parameters right. "
 
@@ -155,6 +169,19 @@ def test_get_params():
     assert_raises(ValueError, test.set_params, a__a=2)
 
 
+def test_get_params_deprecated():
+    # deprecated attribute should not show up as params
+    est = DeprecatedAttributeEstimator(a=1)
+
+    assert_true('a' in est.get_params())
+    assert_true('a' in est.get_params(deep=True))
+    assert_true('a' in est.get_params(deep=False))
+
+    assert_true('b' not in est.get_params())
+    assert_true('b' not in est.get_params(deep=True))
+    assert_true('b' not in est.get_params(deep=False))
+
+
 def test_is_classifier():
     svc = SVC()
     assert_true(is_classifier(svc))
