@@ -1,11 +1,13 @@
 """Test the cross_validation module"""
 
-import numpy as np
 import warnings
+
+import numpy as np
 from scipy.sparse import coo_matrix
 
 from sklearn.utils.testing import assert_true
 from sklearn.utils.testing import assert_equal
+from sklearn.utils.testing import assert_almost_equal
 from sklearn.utils.testing import assert_raises
 from sklearn.utils.testing import assert_greater
 from sklearn.utils.testing import assert_less
@@ -20,11 +22,13 @@ from sklearn.datasets import make_regression
 from sklearn.datasets import load_iris
 from sklearn.metrics import accuracy_score
 from sklearn.metrics import f1_score
-from sklearn.metrics import mean_squared_error
-from sklearn.metrics import r2_score
 from sklearn.metrics import explained_variance_score
-from sklearn.svm import SVC
+from sklearn.metrics import fbeta_score
+from sklearn.metrics import make_scorer
+
+from sklearn.externals import six
 from sklearn.linear_model import Ridge
+from sklearn.svm import SVC
 
 
 class MockListClassifier(BaseEstimator):
@@ -79,7 +83,7 @@ class MockClassifier(BaseEstimator):
 
 X = np.ones((10, 2))
 X_sparse = coo_matrix(X)
-y = np.arange(10) / 2
+y = np.arange(10) // 2
 
 ##############################################################################
 # Tests
@@ -103,14 +107,18 @@ def test_kfold_valueerrors():
         # a characteristic of the code and not a behavior
         assert_true("The least populated class" in str(w[0]))
 
-    # Error when number of folds is <= 0
+    # Error when number of folds is <= 1
     assert_raises(ValueError, cval.KFold, 2, 0)
+    assert_raises(ValueError, cval.KFold, 2, 1)
+    assert_raises(ValueError, cval.StratifiedKFold, y, 0)
+    assert_raises(ValueError, cval.StratifiedKFold, y, 1)
 
     # When n is not integer:
-    assert_raises(ValueError, cval.KFold, 2.5, 1)
+    assert_raises(ValueError, cval.KFold, 2.5, 2)
 
     # When n_folds is not integer:
     assert_raises(ValueError, cval.KFold, 5, 1.5)
+    assert_raises(ValueError, cval.StratifiedKFold, y, 1.5)
 
 
 def test_kfold_indices():
@@ -127,6 +135,17 @@ def test_kfold_indices():
     assert_array_equal(all_folds, np.arange(300))
 
 
+def test_kfold_balance():
+    # Check that KFold returns folds with balanced sizes
+    for kf in [cval.KFold(i, 5) for i in range(11, 17)]:
+        sizes = []
+        for _, test in kf:
+            sizes.append(len(test))
+
+        assert_true((np.max(sizes) - np.min(sizes)) <= 1)
+        assert_equal(np.sum(sizes), kf.n)
+
+
 def test_shuffle_kfold():
     # Check the indices are shuffled properly, and that all indices are
     # returned in the different test folds
@@ -156,7 +175,8 @@ def test_shuffle_split():
     ss1 = cval.ShuffleSplit(10, test_size=0.2, random_state=0)
     ss2 = cval.ShuffleSplit(10, test_size=2, random_state=0)
     ss3 = cval.ShuffleSplit(10, test_size=np.int32(2), random_state=0)
-    ss4 = cval.ShuffleSplit(10, test_size=long(2), random_state=0)
+    for typ in six.integer_types:
+        ss4 = cval.ShuffleSplit(10, test_size=typ(2), random_state=0)
     for t1, t2, t3, t4 in zip(ss1, ss2, ss3, ss4):
         assert_array_equal(t1[0], t2[0])
         assert_array_equal(t2[0], t3[0])
@@ -215,14 +235,30 @@ def test_stratified_shuffle_split_iter_no_indices():
     y = np.asarray([0, 1, 2] * 10)
 
     sss1 = cval.StratifiedShuffleSplit(y, indices=False, random_state=0)
-    train_mask, test_mask = iter(sss1).next()
+    train_mask, test_mask = next(iter(sss1))
 
     sss2 = cval.StratifiedShuffleSplit(y, indices=True, random_state=0)
-    train_indices, test_indices = iter(sss2).next()
+    train_indices, test_indices = next(iter(sss2))
 
     assert_array_equal(sorted(test_indices), np.where(test_mask)[0])
 
 
+def test_leave_label_out_changing_labels():
+    """Check that LeaveOneLabelOut and LeavePLabelOut work normally if
+    the labels variable is changed before calling __iter__"""
+    labels = np.array([0, 1, 2, 1, 1, 2, 0, 0])
+    labels_changing = np.array(labels, copy=True)
+    lolo = cval.LeaveOneLabelOut(labels)
+    lolo_changing = cval.LeaveOneLabelOut(labels_changing)
+    lplo = cval.LeavePLabelOut(labels, p=2)
+    lplo_changing = cval.LeavePLabelOut(labels_changing, p=2)
+    labels_changing[:] = 0
+    for llo, llo_changing in [(lolo, lolo_changing), (lplo, lplo_changing)]:
+        for (train, test), (train_chan, test_chan) in zip(llo, llo_changing):
+            assert_array_equal(train, train_chan)
+            assert_array_equal(test, test_chan)
+
+
 def test_cross_val_score():
     clf = MockClassifier()
     for a in range(-10, 10):
@@ -231,13 +267,24 @@ def test_cross_val_score():
         scores = cval.cross_val_score(clf, X, y)
         assert_array_equal(scores, clf.score(X, y))
 
+        # test with multioutput y
+        scores = cval.cross_val_score(clf, X_sparse, X)
+        assert_array_equal(scores, clf.score(X_sparse, X))
+
         scores = cval.cross_val_score(clf, X_sparse, y)
         assert_array_equal(scores, clf.score(X_sparse, y))
 
+        # test with multioutput y
+        scores = cval.cross_val_score(clf, X_sparse, X)
+        assert_array_equal(scores, clf.score(X_sparse, X))
+
     # test with X as list
     clf = MockListClassifier()
     scores = cval.cross_val_score(clf, X.tolist(), y)
 
+    assert_raises(ValueError, cval.cross_val_score, clf, X, y,
+                  scoring="sklearn")
+
 
 def test_cross_val_score_precomputed():
     # test for svm with precomputed kernel
@@ -254,6 +301,11 @@ def test_cross_val_score_precomputed():
     svm = SVC(kernel="precomputed")
     assert_raises(ValueError, cval.cross_val_score, svm, X, y)
 
+    # test error is raised when the precomputed kernel is not array-like
+    # or sparse
+    assert_raises(ValueError, cval.cross_val_score, svm,
+                  linear_kernel.tolist(), y)
+
 
 def test_cross_val_score_fit_params():
     clf = MockClassifier()
@@ -266,24 +318,16 @@ def test_cross_val_score_fit_params():
 
 def test_cross_val_score_score_func():
     clf = MockClassifier()
-    _score_func1_args = []
-    _score_func2_args = []
+    _score_func_args = []
 
-    def score_func1(data):
-        _score_func1_args.append(data)
+    def score_func(y_test, y_predict):
+        _score_func_args.append((y_test, y_predict))
         return 1.0
 
-    def score_func2(y_test, y_predict):
-        _score_func2_args.append((y_test, y_predict))
-        return 1.0
-
-    score1 = cval.cross_val_score(clf, X, score_func=score_func1)
-    assert_array_equal(score1, [1.0, 1.0, 1.0])
-    assert len(_score_func1_args) == 3
-
-    score2 = cval.cross_val_score(clf, X, y, score_func=score_func2)
-    assert_array_equal(score2, [1.0, 1.0, 1.0])
-    assert len(_score_func2_args) == 3
+    with warnings.catch_warnings(record=True):
+        score = cval.cross_val_score(clf, X, y, score_func=score_func)
+    assert_array_equal(score, [1.0, 1.0, 1.0])
+    assert len(_score_func_args) == 3
 
 
 def test_cross_val_score_errors():
@@ -335,13 +379,18 @@ def test_cross_val_score_with_score_func_classification():
     # Correct classification score (aka. zero / one score) - should be the
     # same as the default estimator score
     zo_scores = cval.cross_val_score(clf, iris.data, iris.target,
-                                     score_func=accuracy_score, cv=5)
+                                     scoring="accuracy", cv=5)
     assert_array_almost_equal(zo_scores, [1., 0.97, 0.90, 0.97, 1.], 2)
 
     # F1 score (class are balanced so f1_score should be equal to zero/one
     # score
     f1_scores = cval.cross_val_score(clf, iris.data, iris.target,
-                                     score_func=f1_score, cv=5)
+                                     scoring="f1", cv=5)
+    assert_array_almost_equal(f1_scores, [1., 0.97, 0.90, 0.97, 1.], 2)
+    # also test deprecated old way
+    with warnings.catch_warnings(record=True):
+        f1_scores = cval.cross_val_score(clf, iris.data, iris.target,
+                                         score_func=f1_score, cv=5)
     assert_array_almost_equal(f1_scores, [1., 0.97, 0.90, 0.97, 1.], 2)
 
 
@@ -356,18 +405,19 @@ def test_cross_val_score_with_score_func_regression():
 
     # R2 score (aka. determination coefficient) - should be the
     # same as the default estimator score
-    r2_scores = cval.cross_val_score(reg, X, y, score_func=r2_score, cv=5)
+    r2_scores = cval.cross_val_score(reg, X, y, scoring="r2", cv=5)
     assert_array_almost_equal(r2_scores, [0.94, 0.97, 0.97, 0.99, 0.92], 2)
 
-    # Mean squared error
+    # Mean squared error; this is a loss function, so "scores" are negative
     mse_scores = cval.cross_val_score(reg, X, y, cv=5,
-                                      score_func=mean_squared_error)
-    expected_mse = np.array([763.07, 553.16, 274.38, 273.26, 1681.99])
+                                      scoring="mean_squared_error")
+    expected_mse = np.array([-763.07, -553.16, -274.38, -273.26, -1681.99])
     assert_array_almost_equal(mse_scores, expected_mse, 2)
 
     # Explained variance
-    ev_scores = cval.cross_val_score(reg, X, y, cv=5,
-                                     score_func=explained_variance_score)
+    with warnings.catch_warnings(record=True):
+        ev_scores = cval.cross_val_score(reg, X, y, cv=5,
+                                         score_func=explained_variance_score)
     assert_array_almost_equal(ev_scores, [0.94, 0.97, 0.97, 0.99, 0.92], 2)
 
 
@@ -380,23 +430,30 @@ def test_permutation_score():
     cv = cval.StratifiedKFold(y, 2)
 
     score, scores, pvalue = cval.permutation_test_score(
-        svm, X, y, accuracy_score, cv)
-
+        svm, X, y, cv=cv, scoring="accuracy")
     assert_greater(score, 0.9)
-    np.testing.assert_almost_equal(pvalue, 0.0, 1)
+    assert_almost_equal(pvalue, 0.0, 1)
 
     score_label, _, pvalue_label = cval.permutation_test_score(
-        svm, X, y, accuracy_score, cv, labels=np.ones(y.size), random_state=0)
-
+        svm, X, y, cv=cv, scoring="accuracy", labels=np.ones(y.size),
+        random_state=0)
     assert_true(score_label == score)
     assert_true(pvalue_label == pvalue)
 
+    # test with custom scoring object
+    scorer = make_scorer(fbeta_score, beta=2)
+    score_label, _, pvalue_label = cval.permutation_test_score(
+        svm, X, y, scoring=scorer, cv=cv, labels=np.ones(y.size),
+        random_state=0)
+    assert_almost_equal(score_label, .95, 2)
+    assert_almost_equal(pvalue_label, 0.01, 3)
+
     # check that we obtain the same results with a sparse representation
     svm_sparse = SVC(kernel='linear')
     cv_sparse = cval.StratifiedKFold(y, 2, indices=True)
     score_label, _, pvalue_label = cval.permutation_test_score(
-        svm_sparse, X_sparse, y, accuracy_score, cv_sparse,
-        labels=np.ones(y.size), random_state=0)
+        svm_sparse, X_sparse, y, cv=cv_sparse,
+        scoring="accuracy", labels=np.ones(y.size), random_state=0)
 
     assert_true(score_label == score)
     assert_true(pvalue_label == pvalue)
@@ -404,12 +461,19 @@ def test_permutation_score():
     # set random y
     y = np.mod(np.arange(len(y)), 3)
 
-    score, scores, pvalue = cval.permutation_test_score(svm, X, y,
-                                                        accuracy_score, cv)
+    score, scores, pvalue = cval.permutation_test_score(svm, X, y, cv=cv,
+                                                        scoring="accuracy")
 
     assert_less(score, 0.5)
     assert_greater(pvalue, 0.4)
 
+    # test with deprecated interface
+    with warnings.catch_warnings(record=True):
+        score, scores, pvalue = cval.permutation_test_score(
+            svm, X, y, score_func=accuracy_score, cv=cv)
+    assert_less(score, 0.5)
+    assert_greater(pvalue, 0.4)
+
 
 def test_cross_val_generator_with_mask():
     X = np.array([[1, 2], [3, 4], [5, 6], [7, 8]])
@@ -446,6 +510,34 @@ def test_cross_val_generator_with_indices():
             y_train, y_test = y[train], y[test]
 
 
+def test_cross_val_generator_mask_indices_same():
+    # Test that the cross validation generators return the same results when
+    # indices=True and when indices=False
+    y = np.array([0, 0, 0, 1, 1, 1, 1, 1, 1, 2, 2, 2, 2, 2, 2])
+    labels = np.array([1, 1, 2, 3, 3, 3, 4])
+
+    loo_mask = cval.LeaveOneOut(5, indices=False)
+    loo_ind = cval.LeaveOneOut(5, indices=True)
+    lpo_mask = cval.LeavePOut(10, 2, indices=False)
+    lpo_ind = cval.LeavePOut(10, 2, indices=True)
+    kf_mask = cval.KFold(10, 5, indices=False, shuffle=True, random_state=1)
+    kf_ind = cval.KFold(10, 5, indices=True, shuffle=True, random_state=1)
+    skf_mask = cval.StratifiedKFold(y, 3, indices=False)
+    skf_ind = cval.StratifiedKFold(y, 3, indices=True)
+    lolo_mask = cval.LeaveOneLabelOut(labels, indices=False)
+    lolo_ind = cval.LeaveOneLabelOut(labels, indices=True)
+    lopo_mask = cval.LeavePLabelOut(labels, 2, indices=False)
+    lopo_ind = cval.LeavePLabelOut(labels, 2, indices=True)
+
+    for cv_mask, cv_ind in [(loo_mask, loo_ind), (lpo_mask, lpo_ind),
+                            (kf_mask, kf_ind), (skf_mask, skf_ind),
+                            (lolo_mask, lolo_ind), (lopo_mask, lopo_ind)]:
+        for (train_mask, test_mask), (train_ind, test_ind) in \
+                zip(cv_mask, cv_ind):
+            assert_array_equal(np.where(train_mask)[0], train_ind)
+            assert_array_equal(np.where(test_mask)[0], test_ind)
+
+
 def test_bootstrap_errors():
     assert_raises(ValueError, cval.Bootstrap, 10, train_size=100)
     assert_raises(ValueError, cval.Bootstrap, 10, test_size=100)
