@@ -3,23 +3,29 @@ This module gathers tree-based methods, including decision, regression and
 randomized trees. Single and multi-output problems are both handled.
 """
 
-# Code is originally adapted from MILK: Machine Learning Toolkit
-# Copyright (C) 2008-2011, Luis Pedro Coelho <luis@luispedro.org>
-# License: MIT. See COPYING.MIT file in the milk distribution
-
-# Authors: Brian Holt, Peter Prettenhofer, Satrajit Ghosh, Gilles Louppe,
-#          Noel Dawe
-# License: BSD3
+# Authors: Gilles Louppe <g.louppe@gmail.com>
+#          Peter Prettenhofer <peter.prettenhofer@gmail.com>
+#          Brian Holt <bdholt1@gmail.com>
+#          Noel Dawe <noel@dawe.me>
+#          Satrajit Gosh <satrajit.ghosh@gmail.com>
+# Licence: BSD 3 clause
 
 from __future__ import division
+
+import numbers
 import numpy as np
 from abc import ABCMeta, abstractmethod
+from warnings import warn
 
 from ..base import BaseEstimator, ClassifierMixin, RegressorMixin
-from ..feature_selection.selector_mixin import SelectorMixin
+from ..externals import six
+from ..externals.six.moves import xrange
+from ..feature_selection.from_model import _LearntSelectorMixin
 from ..utils import array2d, check_random_state
+from ..utils.fixes import unique
 from ..utils.validation import check_arrays
 
+from ._tree import Criterion, Splitter, Tree
 from . import _tree
 
 
@@ -28,162 +34,65 @@ __all__ = ["DecisionTreeClassifier",
            "ExtraTreeClassifier",
            "ExtraTreeRegressor"]
 
+
+# =============================================================================
+# Types and constants
+# =============================================================================
+
 DTYPE = _tree.DTYPE
 DOUBLE = _tree.DOUBLE
 
-CLASSIFICATION = {
-    "gini": _tree.Gini,
-    "entropy": _tree.Entropy,
-}
-
-REGRESSION = {
-    "mse": _tree.MSE,
-}
+CRITERIA_CLF = {"gini": _tree.Gini, "entropy": _tree.Entropy}
+CRITERIA_REG = {"mse": _tree.MSE}
+SPLITTERS = {"best": _tree.BestSplitter, "random": _tree.RandomSplitter}
 
 
-def export_graphviz(decision_tree, out_file=None, feature_names=None):
-    """Export a decision tree in DOT format.
+# =============================================================================
+# Base decision tree
+# =============================================================================
 
-    This function generates a GraphViz representation of the decision tree,
-    which is then written into `out_file`. Once exported, graphical renderings
-    can be generated using, for example::
-
-        $ dot -Tps tree.dot -o tree.ps      (PostScript format)
-        $ dot -Tpng tree.dot -o tree.png    (PNG format)
-
-    Parameters
-    ----------
-    decision_tree : decision tree classifier
-        The decision tree to be exported to graphviz.
-
-    out : file object or string, optional (default=None)
-        Handle or name of the output file.
-
-    feature_names : list of strings, optional (default=None)
-        Names of each of the features.
-
-    Returns
-    -------
-    out_file : file object
-        The file object to which the tree was exported.  The user is
-        expected to `close()` this object when done with it.
-
-    Examples
-    --------
-    >>> from sklearn.datasets import load_iris
-    >>> from sklearn import tree
-
-    >>> clf = tree.DecisionTreeClassifier()
-    >>> iris = load_iris()
-
-    >>> clf = clf.fit(iris.data, iris.target)
-    >>> import tempfile
-    >>> out_file = tree.export_graphviz(clf, out_file=tempfile.TemporaryFile())
-    >>> out_file.close()
-    """
-    def node_to_str(tree, node_id):
-        value = tree.value[node_id]
-        if tree.n_outputs == 1:
-            value = value[0, :]
-
-        if tree.children_left[node_id] == _tree.TREE_LEAF:
-            return "error = %.4f\\nsamples = %s\\nvalue = %s" \
-                   % (tree.init_error[node_id],
-                      tree.n_samples[node_id],
-                      value)
-        else:
-            if feature_names is not None:
-                feature = feature_names[tree.feature[node_id]]
-            else:
-                feature = "X[%s]" % tree.feature[node_id]
-
-            return "%s <= %.4f\\nerror = %s\\nsamples = %s\\nvalue = %s" \
-                   % (feature,
-                      tree.threshold[node_id],
-                      tree.init_error[node_id],
-                      tree.n_samples[node_id],
-                      value)
-
-    def recurse(tree, node_id, parent=None):
-        if node_id == _tree.TREE_LEAF:
-            raise ValueError("Invalid node_id %s" % _tree.TREE_LEAF)
-
-        left_child = tree.children_left[node_id]
-        right_child = tree.children_right[node_id]
-
-        # Add node with description
-        out_file.write('%d [label="%s", shape="box"] ;\n' %
-                       (node_id, node_to_str(tree, node_id)))
-
-        if parent is not None:
-            # Add edge to parent
-            out_file.write('%d -> %d ;\n' % (parent, node_id))
-
-        if left_child != _tree.TREE_LEAF:  # and right_child != _tree.TREE_LEAF
-            recurse(tree, left_child, node_id)
-            recurse(tree, right_child, node_id)
-
-    if out_file is None:
-        out_file = open("tree.dot", "w")
-    elif isinstance(out_file, basestring):
-        out_file = open(out_file, "w")
-
-    out_file.write("digraph Tree {\n")
-    if isinstance(decision_tree, _tree.Tree):
-        recurse(decision_tree, 0)
-    else:
-        recurse(decision_tree.tree_, 0)
-    out_file.write("}")
-
-    return out_file
-
-
-class BaseDecisionTree(BaseEstimator, SelectorMixin):
+class BaseDecisionTree(six.with_metaclass(ABCMeta, BaseEstimator,
+                                          _LearntSelectorMixin)):
     """Base class for decision trees.
 
     Warning: This class should not be used directly.
     Use derived classes instead.
     """
-    __metaclass__ = ABCMeta
 
     @abstractmethod
     def __init__(self,
                  criterion,
+                 splitter,
                  max_depth,
                  min_samples_split,
                  min_samples_leaf,
-                 min_density,
                  max_features,
-                 compute_importances,
                  random_state):
         self.criterion = criterion
+        self.splitter = splitter
         self.max_depth = max_depth
         self.min_samples_split = min_samples_split
         self.min_samples_leaf = min_samples_leaf
-        self.min_density = min_density
         self.max_features = max_features
-        self.compute_importances = compute_importances
         self.random_state = random_state
 
         self.n_features_ = None
         self.n_outputs_ = None
         self.classes_ = None
         self.n_classes_ = None
-        self.find_split_ = _tree.TREE_SPLIT_BEST
 
+        self.splitter_ = None
         self.tree_ = None
-        self.feature_importances_ = None
 
-    def fit(self, X, y,
-            sample_mask=None, X_argsorted=None,
-            check_input=True, sample_weight=None):
+    def fit(self, X, y, sample_mask=None, X_argsorted=None, check_input=True,
+            sample_weight=None):
         """Build a decision tree from the training set (X, y).
 
         Parameters
         ----------
         X : array-like, shape = [n_samples, n_features]
-            The training input samples. Use ``dtype=np.float32``
-            and ``order='F'`` for maximum efficiency.
+            The training input samples. Use ``dtype=np.float32`` for maximum
+            efficiency.
 
         y : array-like, shape = [n_samples] or [n_samples, n_outputs]
             The target values (integers that correspond to classes in
@@ -191,23 +100,6 @@ class BaseDecisionTree(BaseEstimator, SelectorMixin):
             Use ``dtype=np.float64`` and ``order='C'`` for maximum
             efficiency.
 
-        sample_mask : array-like, shape = [n_samples], dtype = bool or None
-            A bit mask that encodes the rows of ``X`` that should be
-            used to build the decision tree. It can be used for bagging
-            without the need to create of copy of ``X``.
-            If None a mask will be created that includes all samples.
-
-        X_argsorted : array-like, shape = [n_samples, n_features] or None
-            Each column of ``X_argsorted`` holds the row indices of ``X``
-            sorted according to the value of the corresponding feature
-            in ascending order.
-            I.e. ``X[X_argsorted[i, k], k] <= X[X_argsorted[j, k], k]``
-            for each j > i.
-            If None, ``X_argsorted`` is computed internally.
-            The argument is supported to enable multiple decision trees
-            to share the data structure and to avoid re-computation in
-            tree ensembles. For maximum efficiency use dtype np.int32.
-
         sample_weight : array-like, shape = [n_samples] or None
             Sample weights. If None, then samples are equally weighted. Splits
             that would create child nodes with net zero or negative weight are
@@ -224,20 +116,28 @@ class BaseDecisionTree(BaseEstimator, SelectorMixin):
         self : object
             Returns self.
         """
-        if check_input:
-            X, y = check_arrays(X, y)
         random_state = check_random_state(self.random_state)
 
-        # Convert data
-        if (getattr(X, "dtype", None) != DTYPE or
-                X.ndim != 2 or
-                not X.flags.fortran):
-            X = array2d(X, dtype=DTYPE, order="F")
+        # Deprecations
+        if sample_mask is not None:
+            warn("The sample_mask parameter is deprecated as of version 0.14 "
+                 "and will be removed in 0.16.", DeprecationWarning)
 
+        if X_argsorted is not None:
+            warn("The X_argsorted parameter is deprecated as of version 0.14 "
+                 "and will be removed in 0.16.", DeprecationWarning)
+
+        # Convert data
+        if check_input:
+            X, = check_arrays(X, dtype=DTYPE, sparse_format="dense",
+                              check_ccontiguous=True)
+
+        # Determine output settings
         n_samples, self.n_features_ = X.shape
         is_classification = isinstance(self, ClassifierMixin)
 
         y = np.atleast_1d(y)
+
         if y.ndim == 1:
             # reshape is necessary to preserve the data contiguity against vs
             # [:, np.newaxis] that does not.
@@ -252,28 +152,23 @@ class BaseDecisionTree(BaseEstimator, SelectorMixin):
             self.n_classes_ = []
 
             for k in xrange(self.n_outputs_):
-                unique = np.unique(y[:, k])
-                self.classes_.append(unique)
-                self.n_classes_.append(unique.shape[0])
-                y[:, k] = np.searchsorted(unique, y[:, k])
+                classes_k, y[:, k] = unique(y[:, k], return_inverse=True)
+                self.classes_.append(classes_k)
+                self.n_classes_.append(classes_k.shape[0])
 
         else:
             self.classes_ = [None] * self.n_outputs_
             self.n_classes_ = [1] * self.n_outputs_
 
+        self.n_classes_ = np.array(self.n_classes_, dtype=np.intp)
+
         if getattr(y, "dtype", None) != DOUBLE or not y.flags.contiguous:
             y = np.ascontiguousarray(y, dtype=DOUBLE)
 
-        if is_classification:
-            criterion = CLASSIFICATION[self.criterion](self.n_outputs_,
-                                                       self.n_classes_)
-        else:
-            criterion = REGRESSION[self.criterion](self.n_outputs_)
-
         # Check parameters
-        max_depth = np.inf if self.max_depth is None else self.max_depth
+        max_depth = (2 ** 31) - 1 if self.max_depth is None else self.max_depth
 
-        if isinstance(self.max_features, basestring):
+        if isinstance(self.max_features, six.string_types):
             if self.max_features == "auto":
                 if is_classification:
                     max_features = max(1, int(np.sqrt(self.n_features_)))
@@ -289,8 +184,10 @@ class BaseDecisionTree(BaseEstimator, SelectorMixin):
                     'values are "auto", "sqrt" or "log2".')
         elif self.max_features is None:
             max_features = self.n_features_
-        else:
+        elif isinstance(self.max_features, (numbers.Integral, np.integer)):
             max_features = self.max_features
+        else:  # float
+            max_features = int(self.max_features * self.n_features_)
 
         if len(y) != n_samples:
             raise ValueError("Number of labels=%d does not match "
@@ -301,19 +198,9 @@ class BaseDecisionTree(BaseEstimator, SelectorMixin):
             raise ValueError("min_samples_leaf must be greater than zero.")
         if max_depth <= 0:
             raise ValueError("max_depth must be greater than zero. ")
-        if self.min_density < 0.0 or self.min_density > 1.0:
-            raise ValueError("min_density must be in [0, 1]")
         if not (0 < max_features <= self.n_features_):
             raise ValueError("max_features must be in (0, n_features]")
 
-        if sample_mask is not None:
-            sample_mask = np.asarray(sample_mask, dtype=np.bool)
-
-            if sample_mask.shape[0] != n_samples:
-                raise ValueError("Length of sample_mask=%d does not match "
-                                 "number of samples=%d"
-                                 % (sample_mask.shape[0], n_samples))
-
         if sample_weight is not None:
             if (getattr(sample_weight, "dtype", None) != DOUBLE or
                     not sample_weight.flags.contiguous):
@@ -328,38 +215,39 @@ class BaseDecisionTree(BaseEstimator, SelectorMixin):
                                  "number of samples=%d" %
                                  (len(sample_weight), n_samples))
 
-        if X_argsorted is not None:
-            X_argsorted = np.asarray(X_argsorted, dtype=np.int32,
-                                     order='F')
-            if X_argsorted.shape != X.shape:
-                raise ValueError("Shape of X_argsorted does not match "
-                                 "the shape of X")
-
         # Set min_samples_split sensibly
         min_samples_split = max(self.min_samples_split,
                                 2 * self.min_samples_leaf)
 
         # Build tree
-        self.tree_ = _tree.Tree(self.n_features_, self.n_classes_,
-                                self.n_outputs_, criterion, max_depth,
-                                min_samples_split, self.min_samples_leaf,
-                                self.min_density, max_features,
-                                self.find_split_, random_state)
+        criterion = self.criterion
+        if not isinstance(criterion, Criterion):
+            if is_classification:
+                criterion = CRITERIA_CLF[self.criterion](self.n_outputs_,
+                                                         self.n_classes_)
+            else:
+                criterion = CRITERIA_REG[self.criterion](self.n_outputs_)
 
-        self.tree_.build(X, y,
-                         sample_weight=sample_weight,
-                         sample_mask=sample_mask,
-                         X_argsorted=X_argsorted)
+        splitter = self.splitter
+        if not isinstance(self.splitter, Splitter):
+            splitter = SPLITTERS[self.splitter](criterion,
+                                                max_features,
+                                                self.min_samples_leaf,
+                                                random_state)
+
+        self.criterion_ = criterion
+        self.splitter_ = splitter
+        self.tree_ = Tree(self.n_features_, self.n_classes_,
+                          self.n_outputs_, splitter, max_depth,
+                          min_samples_split, self.min_samples_leaf,
+                          random_state)
+
+        self.tree_.build(X, y, sample_weight=sample_weight)
 
         if self.n_outputs_ == 1:
             self.n_classes_ = self.n_classes_[0]
             self.classes_ = self.classes_[0]
 
-        # Compute importances
-        if self.compute_importances:
-            self.feature_importances_ = \
-                self.tree_.compute_feature_importances()
-
         return self
 
     def predict(self, X):
@@ -380,7 +268,7 @@ class BaseDecisionTree(BaseEstimator, SelectorMixin):
             The predicted classes, or the predict values.
         """
         if getattr(X, "dtype", None) != DTYPE or X.ndim != 2:
-            X = array2d(X, dtype=DTYPE, order="F")
+            X = array2d(X, dtype=DTYPE)
 
         n_samples, n_features = X.shape
 
@@ -398,9 +286,7 @@ class BaseDecisionTree(BaseEstimator, SelectorMixin):
         # Classification
         if isinstance(self, ClassifierMixin):
             if self.n_outputs_ == 1:
-                return np.array(self.classes_.take(
-                    np.argmax(proba[:, 0], axis=1),
-                    axis=0))
+                return self.classes_.take(np.argmax(proba, axis=1), axis=0)
 
             else:
                 predictions = np.zeros((n_samples, self.n_outputs_))
@@ -415,11 +301,33 @@ class BaseDecisionTree(BaseEstimator, SelectorMixin):
         # Regression
         else:
             if self.n_outputs_ == 1:
-                return proba[:, 0, 0]
+                return proba[:, 0]
 
             else:
                 return proba[:, :, 0]
 
+    @property
+    def feature_importances_(self):
+        """Return the feature importances.
+
+        The importance of a feature is computed as the (normalized) total
+        reduction of the criterion brought by that feature.
+        It is also known as the Gini importance.
+
+        Returns
+        -------
+        feature_importances_ : array, shape = [n_features]
+        """
+        if self.tree_ is None:
+            raise ValueError("Estimator not fitted, "
+                             "call `fit` before `feature_importances_`.")
+
+        return self.tree_.compute_feature_importances()
+
+
+# =============================================================================
+# Public estimators
+# =============================================================================
 
 class DecisionTreeClassifier(BaseDecisionTree, ClassifierMixin):
     """A decision tree classifier.
@@ -430,11 +338,13 @@ class DecisionTreeClassifier(BaseDecisionTree, ClassifierMixin):
         The function to measure the quality of a split. Supported criteria are
         "gini" for the Gini impurity and "entropy" for the information gain.
 
-    max_features : int, string or None, optional (default=None)
+    max_features : int, float, string or None, optional (default=None)
         The number of features to consider when looking for the best split:
-          - If "auto", then `max_features=sqrt(n_features)` on
-            classification tasks and `max_features=n_features`
-            on regression problems.
+          - If int, then consider `max_features` features at each split.
+          - If float, then `max_features` is a percentage and
+            `int(max_features * n_features)` features are considered at each
+            split.
+          - If "auto", then `max_features=sqrt(n_features)`.
           - If "sqrt", then `max_features=sqrt(n_features)`.
           - If "log2", then `max_features=log2(n_features)`.
           - If None, then `max_features=n_features`.
@@ -450,20 +360,6 @@ class DecisionTreeClassifier(BaseDecisionTree, ClassifierMixin):
     min_samples_leaf : integer, optional (default=1)
         The minimum number of samples required to be at a leaf node.
 
-    min_density : float, optional (default=0.1)
-        This parameter controls a trade-off in an optimization heuristic. It
-        controls the minimum density of the `sample_mask` (i.e. the
-        fraction of samples in the mask). If the density falls below this
-        threshold the mask is recomputed and the input data is packed
-        which results in data copying.  If `min_density` equals to one,
-        the partitions are always represented as copies of the original
-        data. Otherwise, partitions are represented as bit masks (aka
-        sample masks).
-
-    compute_importances : boolean, optional (default=False)
-        Whether feature importances are computed and stored into the
-        ``feature_importances_`` attribute when calling fit.
-
     random_state : int, RandomState instance or None, optional (default=None)
         If int, random_state is the seed used by the random number generator;
         If RandomState instance, random_state is the random number generator;
@@ -485,11 +381,10 @@ class DecisionTreeClassifier(BaseDecisionTree, ClassifierMixin):
         output (for multi-output problems).
 
     `feature_importances_` : array of shape = [n_features]
-        The feature importances
-        (the higher, the more important the feature).
-        The importance of a feature is computed as the
-        (normalized) total reduction of error brought by that
-        feature.  It is also known as the Gini importance [4]_.
+        The feature importances. The higher, the more important the
+        feature. The importance of a feature is computed as the (normalized)
+        total reduction of the criterion brought by that feature.  It is also
+        known as the Gini importance [4]_.
 
     See also
     --------
@@ -514,10 +409,8 @@ class DecisionTreeClassifier(BaseDecisionTree, ClassifierMixin):
     >>> from sklearn.datasets import load_iris
     >>> from sklearn.cross_validation import cross_val_score
     >>> from sklearn.tree import DecisionTreeClassifier
-
     >>> clf = DecisionTreeClassifier(random_state=0)
     >>> iris = load_iris()
-
     >>> cross_val_score(clf, iris.data, iris.target, cv=10)
     ...                             # doctest: +SKIP
     ...
@@ -526,21 +419,31 @@ class DecisionTreeClassifier(BaseDecisionTree, ClassifierMixin):
     """
     def __init__(self,
                  criterion="gini",
+                 splitter="best",
                  max_depth=None,
                  min_samples_split=2,
                  min_samples_leaf=1,
-                 min_density=0.1,
                  max_features=None,
-                 compute_importances=False,
-                 random_state=None):
+                 random_state=None,
+                 min_density=None,
+                 compute_importances=None):
         super(DecisionTreeClassifier, self).__init__(criterion,
+                                                     splitter,
                                                      max_depth,
                                                      min_samples_split,
                                                      min_samples_leaf,
-                                                     min_density,
                                                      max_features,
-                                                     compute_importances,
                                                      random_state)
+        if min_density is not None:
+            warn("The min_density parameter is deprecated as of version 0.14 "
+                 "and will be removed in 0.16.", DeprecationWarning)
+
+        if compute_importances is not None:
+            warn("Setting compute_importances is no longer required as "
+                 "version 0.14. Variable importances are now computed on the "
+                 "fly when accessing the feature_importances_ attribute. "
+                 "This parameter will be removed in 0.16.",
+                 DeprecationWarning)
 
     def predict_proba(self, X):
         """Predict class probabilities of the input samples X.
@@ -558,7 +461,7 @@ class DecisionTreeClassifier(BaseDecisionTree, ClassifierMixin):
             by arithmetical order.
         """
         if getattr(X, "dtype", None) != DTYPE or X.ndim != 2:
-            X = array2d(X, dtype=DTYPE, order="F")
+            X = array2d(X, dtype=DTYPE)
 
         n_samples, n_features = X.shape
 
@@ -574,7 +477,7 @@ class DecisionTreeClassifier(BaseDecisionTree, ClassifierMixin):
         proba = self.tree_.predict(X)
 
         if self.n_outputs_ == 1:
-            proba = proba[:, 0, :self.n_classes_]
+            proba = proba[:, :self.n_classes_]
             normalizer = proba.sum(axis=1)[:, np.newaxis]
             normalizer[normalizer == 0.0] = 1.0
             proba /= normalizer
@@ -629,11 +532,13 @@ class DecisionTreeRegressor(BaseDecisionTree, RegressorMixin):
         The function to measure the quality of a split. The only supported
         criterion is "mse" for the mean squared error.
 
-    max_features : int, string or None, optional (default=None)
+    max_features : int, float, string or None, optional (default=None)
         The number of features to consider when looking for the best split:
-          - If "auto", then `max_features=sqrt(n_features)` on
-            classification tasks and `max_features=n_features`
-            on regression problems.
+          - If int, then consider `max_features` features at each split.
+          - If float, then `max_features` is a percentage and
+            `int(max_features * n_features)` features are considered at each
+            split.
+          - If "auto", then `max_features=n_features`.
           - If "sqrt", then `max_features=sqrt(n_features)`.
           - If "log2", then `max_features=log2(n_features)`.
           - If None, then `max_features=n_features`.
@@ -649,20 +554,6 @@ class DecisionTreeRegressor(BaseDecisionTree, RegressorMixin):
     min_samples_leaf : integer, optional (default=1)
         The minimum number of samples required to be at a leaf node.
 
-    min_density : float, optional (default=0.1)
-        This parameter controls a trade-off in an optimization heuristic. It
-        controls the minimum density of the `sample_mask` (i.e. the
-        fraction of samples in the mask). If the density falls below this
-        threshold the mask is recomputed and the input data is packed
-        which results in data copying.  If `min_density` equals to one,
-        the partitions are always represented as copies of the original
-        data. Otherwise, partitions are represented as bit masks (aka
-        sample masks).
-
-    compute_importances : boolean, optional (default=True)
-        Whether feature importances are computed and stored into the
-        ``feature_importances_`` attribute when calling fit.
-
     random_state : int, RandomState instance or None, optional (default=None)
         If int, random_state is the seed used by the random number generator;
         If RandomState instance, random_state is the random number generator;
@@ -675,11 +566,11 @@ class DecisionTreeRegressor(BaseDecisionTree, RegressorMixin):
         The underlying Tree object.
 
     `feature_importances_` : array of shape = [n_features]
-        The feature importances
-        (the higher, the more important the feature).
+        The feature importances.
+        The higher, the more important the feature.
         The importance of a feature is computed as the
-        (normalized) total reduction of error brought by that
-        feature.  It is also known as the Gini importance [4]_.
+        (normalized) total reduction of the criterion brought
+        by that feature. It is also known as the Gini importance [4]_.
 
     See also
     --------
@@ -704,12 +595,8 @@ class DecisionTreeRegressor(BaseDecisionTree, RegressorMixin):
     >>> from sklearn.datasets import load_boston
     >>> from sklearn.cross_validation import cross_val_score
     >>> from sklearn.tree import DecisionTreeRegressor
-
     >>> boston = load_boston()
     >>> regressor = DecisionTreeRegressor(random_state=0)
-
-    R2 scores (a.k.a. coefficient of determination) over 10-folds CV:
-
     >>> cross_val_score(regressor, boston.data, boston.target, cv=10)
     ...                    # doctest: +SKIP
     ...
@@ -718,21 +605,31 @@ class DecisionTreeRegressor(BaseDecisionTree, RegressorMixin):
     """
     def __init__(self,
                  criterion="mse",
+                 splitter="best",
                  max_depth=None,
                  min_samples_split=2,
                  min_samples_leaf=1,
-                 min_density=0.1,
                  max_features=None,
-                 compute_importances=False,
-                 random_state=None):
+                 random_state=None,
+                 min_density=None,
+                 compute_importances=None):
         super(DecisionTreeRegressor, self).__init__(criterion,
+                                                    splitter,
                                                     max_depth,
                                                     min_samples_split,
                                                     min_samples_leaf,
-                                                    min_density,
                                                     max_features,
-                                                    compute_importances,
                                                     random_state)
+        if min_density is not None:
+            warn("The min_density parameter is deprecated as of version 0.14 "
+                 "and will be removed in 0.16.", DeprecationWarning)
+
+        if compute_importances is not None:
+            warn("Setting compute_importances is no longer required as "
+                 "version 0.14. Variable importances are now computed on the "
+                 "fly when accessing the feature_importances_ attribute. "
+                 "This parameter will be removed in 0.16.",
+                 DeprecationWarning)
 
 
 class ExtraTreeClassifier(DecisionTreeClassifier):
@@ -759,23 +656,31 @@ class ExtraTreeClassifier(DecisionTreeClassifier):
     """
     def __init__(self,
                  criterion="gini",
+                 splitter="random",
                  max_depth=None,
                  min_samples_split=2,
                  min_samples_leaf=1,
-                 min_density=0.1,
                  max_features="auto",
-                 compute_importances=False,
-                 random_state=None):
+                 random_state=None,
+                 min_density=None,
+                 compute_importances=None):
         super(ExtraTreeClassifier, self).__init__(criterion,
+                                                  splitter,
                                                   max_depth,
                                                   min_samples_split,
                                                   min_samples_leaf,
-                                                  min_density,
                                                   max_features,
-                                                  compute_importances,
                                                   random_state)
+        if min_density is not None:
+            warn("The min_density parameter is deprecated as of version 0.14 "
+                 "and will be removed in 0.16.", DeprecationWarning)
 
-        self.find_split_ = _tree.TREE_SPLIT_RANDOM
+        if compute_importances is not None:
+            warn("Setting compute_importances is no longer required as "
+                 "version 0.14. Variable importances are now computed on the "
+                 "fly when accessing the feature_importances_ attribute. "
+                 "This parameter will be removed in 0.16.",
+                 DeprecationWarning)
 
 
 class ExtraTreeRegressor(DecisionTreeRegressor):
@@ -792,11 +697,7 @@ class ExtraTreeRegressor(DecisionTreeRegressor):
 
     See also
     --------
-    ExtraTreeClassifier : A classifier base on extremely randomized trees
-    sklearn.ensemble.ExtraTreesClassifier : An ensemble of extra-trees for
-        classification
-    sklearn.ensemble.ExtraTreesRegressor : An ensemble of extra-trees for
-        regression
+    ExtraTreeClassifier, ExtraTreesClassifier, ExtraTreesRegressor
 
     References
     ----------
@@ -806,20 +707,28 @@ class ExtraTreeRegressor(DecisionTreeRegressor):
     """
     def __init__(self,
                  criterion="mse",
+                 splitter="random",
                  max_depth=None,
                  min_samples_split=2,
                  min_samples_leaf=1,
-                 min_density=0.1,
                  max_features="auto",
-                 compute_importances=False,
-                 random_state=None):
+                 random_state=None,
+                 min_density=None,
+                 compute_importances=None):
         super(ExtraTreeRegressor, self).__init__(criterion,
+                                                 splitter,
                                                  max_depth,
                                                  min_samples_split,
                                                  min_samples_leaf,
-                                                 min_density,
                                                  max_features,
-                                                 compute_importances,
                                                  random_state)
+        if min_density is not None:
+            warn("The min_density parameter is deprecated as of version 0.14 "
+                 "and will be removed in 0.16.", DeprecationWarning)
 
-        self.find_split_ = _tree.TREE_SPLIT_RANDOM
+        if compute_importances is not None:
+            warn("Setting compute_importances is no longer required as "
+                 "version 0.14. Variable importances are now computed on the "
+                 "fly when accessing the feature_importances_ attribute. "
+                 "This parameter will be removed in 0.16.",
+                 DeprecationWarning)
