@@ -1,13 +1,13 @@
 # Authors: Emmanuelle Gouillart <emmanuelle.gouillart@normalesup.org>
 #          Gael Varoquaux <gael.varoquaux@normalesup.org>
-# License: BSD
+# License: BSD 3 clause
 
 import numpy as np
 
 from nose.tools import assert_equal
 from numpy.testing import assert_array_equal
 
-from ..fixes import _in1d, _copysign
+from ..fixes import _in1d, _copysign, divide
 
 
 def test_in1d():
@@ -16,6 +16,10 @@ def test_in1d():
     assert_equal(_in1d(a, b).sum(), 5)
 
 
+def test_divide():
+    assert_equal(divide(.6, 1), .600000000000)
+
+
 def test_copysign():
     a = np.array([-1, 1, -1])
     b = np.array([1, -1, 1])
